#!python

# foildb2020.py (C) Copyright 2020 Chris Dake.
# This module is part of the "Airfoil Tools" add-in for Fusion 360

# Top-performing results from extensive flow analysis on 2000 popular foil shapes and 10,000+ NACA shpaes, at 64 reynolds numbers under 12 flow conditions at 200 AoA's (1,843,200,000+ inviscid linear-vorticity solutions with Karman-Tsien compressiblity correction performed)

DBVERSION=1.20200620 # Gen: 2020-06-20 03:46:31               # Remember to update this regularly!

'''

File format:

       'id' => 0,
       'Foil_fn' => 'spline_foil_e377m.dat-s17_n17s0.dat',    # Original file name
       'cmt' => 'NEWv1.20200425 s(0) foildb2020/e377m.dat (sim 0.000193213738 ) l3 Foil spline 17pts', # foil comments
       'Re' => 50,                                            # Tested Reynolds Number
       'n' => 3,                                              # log(critical angle)
       'alpha' => 19,                                         # Best-performing AoA
       'sym' => 9.80774009205041,                             # Degree of symmetry <0.00125==symmetric (strut)
       'CL' => 1.49155,                                       # Coefficient of lift
       'CD' => 0.73709,                                       # Coefficient of drag
       'clcd' => 2.02355,                                     # CL/CD (foils) or 1/CD (symmetric)
       'CDf' => 0.41782,                                      # Friction component of drag
       'CDpres' => 0.31928,                                   # Pressure component of drag
       'CDp' => 0.3769,                                       # Pressure component of drag (solver gives 2)
       'Top_Xtr' => 1,                                        # top stream-separation transition location
       'Bot_Xtr' => 1,                                        # bottom transition location
       'Cm' => -0.1803,                                       # center of pressure relative to quarter chord
       'Cpmin' => -1.993,                                     # minimum pressure (cavitation avoidance)
       'diter' => 5,                                          # convergance iteration count
       'xver' => 6.991,                                       # solver version number
       'r' => 6,                                              # range of critera constituting "good" (6 means +/- 6 degrees AoA, but bell extremities are very thin, so, +/- 3 degrees are really only significant)
       'good' => 1.7727212979792,                             # average cl/cd (or 1/cd for struts) across target range (bell-spline-curve weighted +/- 'r' (6 dgrees) AoA)
       'xy' => [ 1, 0, 0.944745701831204, 0.00812549193285718, 0.823418809574247, 0.0283642592220089, 0.688707079475762, 0.0513273485009391, 0.468475171960841, #  ... etc x1,y1, x2,y2, ... etc coordinates
       'iver' => 1.20200516,                                  # converter version number
       'src' => 'ca9'                                         # solving machine ID

'''

def VERSION(progver):
    if progver:
        return 'db' +str(int(DBVERSION * 100000000 - progver * 100000000))   # Printable delta-version number
    else:
        return DBVERSION

def Foildb2020():

    return [ {"src":"retest_153.txt","Re":50,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":6,"alpha":22,"clcd":1.88245854738915,"CDpres":0.41201,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356,"Cpmin":-2.9109880068349,"CDf":0.33843,"CDp":0.445058029670172,"CL":1.41267482743049,"CD":0.750441399833096,"n":3,"Cm":-0.153808803284402,"r":6,"id":0,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"good":1.60452690650455},
             {"alpha":22,"clcd":1.88245854738915,"CDpres":0.41201,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356,"src":"retest_154.txt","Re":50,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":6,"Cm":-0.153808803284402,"r":6,"id":1,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"iver":1.2020052,"good":1.60452690650455,"Cpmin":-2.9109880068349,"CDf":0.33843,"CDp":0.445058029670172,"CD":0.750441399833096,"CL":1.41267482743049,"n":4},
             {"n":5,"CD":0.761421040081079,"CL":1.44419505440082,"CDp":0.44714601386707,"CDf":0.35397,"Cpmin":-2.8651004927807,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","good":1.61653181109584,"xver":6.991,"iver":1.2020052,"id":2,"r":6,"Cm":-0.155851965983348,"diter":5,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Top_Xtr":1,"Re":50,"src":"retest_20.txt","sym":4.7175033712718,"Bot_Xtr":1,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"CDpres":0.40745,"clcd":1.89671020155555,"alpha":22},
             {"Cm":-0.155851965983348,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","xver":6.991,"good":1.61653181109584,"id":3,"Cpmin":-2.8651004927807,"CDf":0.35397,"CDp":0.44714601386707,"n":6,"CD":0.761421040081079,"CL":1.44419505440082,"alpha":22,"clcd":1.89671020155555,"CDpres":0.40745,"Bot_Xtr":1,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"sym":4.7175033712718,"src":"retest_21.txt","Re":50,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Top_Xtr":1,"diter":5},
             {"Cm":-0.155851965983348,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","iver":1.2020052,"xver":6.991,"good":1.61653181109584,"id":4,"Cpmin":-2.8651004927807,"CDf":0.35397,"CDp":0.44714601386707,"n":7,"CD":0.761421040081079,"CL":1.44419505440082,"alpha":22,"clcd":1.89671020155555,"CDpres":0.40745,"Bot_Xtr":1,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"sym":4.7175033712718,"src":"retest_22.txt","Re":50,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Top_Xtr":1,"diter":5},
             {"diter":5,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Re":50,"src":"retest_23.txt","sym":4.7175033712718,"Bot_Xtr":1,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"CDpres":0.40745,"clcd":1.89671020155555,"alpha":22,"CD":0.761421040081079,"CL":1.44419505440082,"n":8,"CDp":0.44714601386707,"CDf":0.35397,"Cpmin":-2.8651004927807,"id":5,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","xver":6.991,"good":1.61653181109584,"r":6,"Cm":-0.155851965983348},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","good":1.61653181109584,"xver":6.991,"iver":1.2020052,"id":6,"Cm":-0.155851965983348,"CDp":0.44714601386707,"n":9,"CL":1.44419505440082,"CD":0.761421040081079,"Cpmin":-2.8651004927807,"CDf":0.35397,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"Bot_Xtr":1,"sym":4.7175033712718,"alpha":22,"clcd":1.89671020155555,"CDpres":0.40745,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Top_Xtr":1,"diter":5,"src":"retest_24.txt","Re":50},
             {"sym":4.7175033712718,"Bot_Xtr":1,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"CDpres":0.40745,"clcd":1.89671020155555,"alpha":22,"diter":5,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Re":50,"src":"retest_25.txt","id":7,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","xver":6.991,"good":1.61653181109584,"iver":1.2020052,"r":6,"Cm":-0.155851965983348,"CD":0.761421040081079,"CL":1.44419505440082,"n":10,"CDp":0.44714601386707,"CDf":0.35397,"Cpmin":-2.8651004927807},
             {"alpha":22,"clcd":1.90166825577553,"CDpres":0.39456,"Bot_Xtr":1,"xy":[1,0,0.910648798765237,0.0205080754645704,0.684314248787321,0.0635421420215223,0.479115813972853,0.0861192266009147,0.302094621366809,0.0861017284497502,0.168581079577418,0.0681111978646833,0.0720930845483887,0.0431935793526978,0.0279165583128725,0.0227811887333466,0,0,0.0123787654854006,-0.00572665650354067,0.0434818912828438,-0.0044251049683053,0.0959112242522722,0.00371716126728922,0.208919327183629,0.023285609319882,0.386612592501753,0.0386359270662357,0.634028359351713,0.0284047095639621,0.925305417465977,0.00388247417734546,1,0],"sym":5.02508351898373,"src":"retest_149.txt","Re":50,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe396.dat-s17_n17s0_nsopt-Re200-N3.dat","diter":5,"Cm":-0.15932577763289,"r":6,"id":8,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe396.dat-s17_n17s0.dat (opt3.13649253608101>3.1141395617662) l1 Foil spline 17pts Re200 N3","good":1.6386979534916,"iver":1.2020052,"Cpmin":-2.41877113626938,"CDf":0.36816,"CDp":0.449977369506909,"CD":0.762720884325104,"CL":1.45044209373809,"n":11},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe396.dat-s17_n17s0.dat (opt3.13649253608101>3.1141395617662) l1 Foil spline 17pts Re200 N3","xver":6.991,"iver":1.2020052,"good":1.6386979534916,"id":9,"Cm":-0.15932577763289,"CDp":0.449977369506909,"n":12,"CD":0.762720884325104,"CL":1.45044209373809,"Cpmin":-2.41877113626938,"CDf":0.36816,"xy":[1,0,0.910648798765237,0.0205080754645704,0.684314248787321,0.0635421420215223,0.479115813972853,0.0861192266009147,0.302094621366809,0.0861017284497502,0.168581079577418,0.0681111978646833,0.0720930845483887,0.0431935793526978,0.0279165583128725,0.0227811887333466,0,0,0.0123787654854006,-0.00572665650354067,0.0434818912828438,-0.0044251049683053,0.0959112242522722,0.00371716126728922,0.208919327183629,0.023285609319882,0.386612592501753,0.0386359270662357,0.634028359351713,0.0284047095639621,0.925305417465977,0.00388247417734546,1,0],"Bot_Xtr":1,"sym":5.02508351898373,"alpha":22,"clcd":1.90166825577553,"CDpres":0.39456,"Foil_fn":"optbs_spline_goe396.dat-s17_n17s0_nsopt-Re200-N3.dat","Top_Xtr":1,"diter":5,"src":"retest_150.txt","Re":50},
             {"CDp":0.44714601386707,"CD":0.761421040081079,"CL":1.44419505440082,"n":13,"Cpmin":-2.8651004927807,"CDf":0.35397,"r":6,"id":10,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","iver":1.2020052,"good":1.61653181109584,"Cm":-0.155851965983348,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","diter":5,"src":"retest_28.txt","Re":50,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"Bot_Xtr":1,"sym":4.7175033712718,"alpha":22,"CDpres":0.40745,"clcd":1.89671020155555},
             {"Cm":-0.155851965983348,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe451-il.dat-s17_n17s0.dat (opt1.64917412191645>1.62737792106749) l1 Foil spline 17pts Re50 N11","good":1.61653181109584,"xver":6.991,"iver":1.2020052,"id":11,"r":6,"CDf":0.35397,"Cpmin":-2.8651004927807,"n":14,"CD":0.761421040081079,"CL":1.44419505440082,"CDp":0.44714601386707,"CDpres":0.40745,"clcd":1.89671020155555,"alpha":22,"sym":4.7175033712718,"xy":[1,0,0.895349767999199,0.0236264025527738,0.698164533677399,0.0572569842689757,0.497724846435537,0.0795785550388164,0.30716231749753,0.0802140811028408,0.152783036207102,0.061755534476358,0.0701443909987835,0.0380450054128202,0.0256748419180575,0.0209987917006273,0,0,0.0276472572463621,-0.000483347724071546,0.0518680598285975,0.00359565684732927,0.187634126338149,0.0230067497544764,0.348365902028679,0.0351757360549503,0.502387771006137,0.0358949595745945,0.701193709065862,0.0258970141800538,0.939553026886492,0.00652386991038784,1,0],"Bot_Xtr":1,"Re":50,"src":"retest_29.txt","diter":5,"Foil_fn":"optbs_spline_goe451-il.dat-s17_n17s0_nsopt-Re50-N11.dat","Top_Xtr":1},
             {"Re":100,"n":3,"diter":5,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","Top_Xtr":1,"src":"retestc_11.txt","sym":36.5329625779388,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"CDpres":0.30917,"clcd":2.99534665574768,"alpha":22.8,"CD":0.549673238416638,"CL":1.64646189644527,"CDp":0.455668958174868,"CDf":0.2405,"Cpmin":-2.10787052072447,"good":2.92689253532044,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","xver":6.991,"iver":1.2020052,"id":12,"r":6,"Cm":-0.27749463719874},        #dud
             {"Re":100,"n":4,"src":"retestc_12.txt","Top_Xtr":1,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","diter":5,"alpha":22.8,"clcd":2.99534665574768,"CDpres":0.30917,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"sym":36.5329625779388,"Cpmin":-2.10787052072447,"CDf":0.2405,"CDp":0.455668958174868,"CD":0.549673238416638,"CL":1.64646189644527,"Cm":-0.27749463719874,"r":6,"id":13,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","xver":6.991,"iver":1.2020052,"good":2.92689253532044},        #dud
             {"Re":100,"n":5,"diter":5,"Top_Xtr":1,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","src":"retestc_13.txt","sym":36.5329625779388,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"clcd":2.99534665574768,"CDpres":0.30917,"alpha":22.8,"CL":1.64646189644527,"CD":0.549673238416638,"CDp":0.455668958174868,"CDf":0.2405,"Cpmin":-2.10787052072447,"id":14,"xver":6.991,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","iver":1.2020052,"good":2.92689253532044,"r":6,"Cm":-0.27749463719874},        #dud
             {"Re":100,"n":6,"CDp":0.455668958174868,"CD":0.549673238416638,"CL":1.64646189644527,"Cpmin":-2.10787052072447,"CDf":0.2405,"r":6,"xver":6.991,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","iver":1.2020052,"good":2.92689253532044,"id":15,"Cm":-0.27749463719874,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","Top_Xtr":1,"diter":5,"src":"retestc_14.txt","xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"Bot_Xtr":1,"sym":36.5329625779388,"alpha":22.8,"CDpres":0.30917,"clcd":2.99534665574768},        #dud
             {"Re":100,"n":7,"Cpmin":-2.10787052072447,"CDf":0.2405,"CDp":0.455668958174868,"CD":0.549673238416638,"CL":1.64646189644527,"Cm":-0.27749463719874,"r":6,"id":16,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","xver":6.991,"iver":1.2020052,"good":2.92689253532044,"src":"retestc_15.txt","Top_Xtr":1,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","diter":5,"alpha":22.8,"CDpres":0.30917,"clcd":2.99534665574768,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"sym":36.5329625779388},        #dud
             {"Re":100,"n":8,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","xver":6.991,"good":2.92689253532044,"iver":1.2020052,"id":17,"r":6,"Cm":-0.27749463719874,"CD":0.549673238416638,"CL":1.64646189644527,"CDp":0.455668958174868,"CDf":0.2405,"Cpmin":-2.10787052072447,"sym":36.5329625779388,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"clcd":2.99534665574768,"CDpres":0.30917,"alpha":22.8,"diter":5,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","Top_Xtr":1,"src":"retestc_16.txt"},        #dud
             {"Re":100,"n":9,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","Top_Xtr":1,"diter":5,"src":"retestc_17.txt","xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"Bot_Xtr":1,"sym":36.5329625779388,"alpha":22.8,"CDpres":0.30917,"clcd":2.99534665574768,"CDp":0.455668958174868,"CL":1.64646189644527,"CD":0.549673238416638,"Cpmin":-2.10787052072447,"CDf":0.2405,"r":6,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","iver":1.2020052,"xver":6.991,"good":2.92689253532044,"id":18,"Cm":-0.27749463719874},        #dud
             {"Re":100,"n":10,"CDp":0.455668958174868,"CL":1.64646189644527,"CD":0.549673238416638,"Cpmin":-2.10787052072447,"CDf":0.2405,"r":6,"id":19,"good":2.92689253532044,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","xver":6.991,"iver":1.2020052,"Cm":-0.27749463719874,"Top_Xtr":1,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","diter":5,"src":"retestc_18.txt","xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"Bot_Xtr":1,"sym":36.5329625779388,"alpha":22.8,"clcd":2.99534665574768,"CDpres":0.30917},        #dud
             {"Re":100,"n":11,"CD":0.549673238416638,"CL":1.64646189644527,"CDp":0.455668958174868,"CDf":0.2405,"Cpmin":-2.10787052072447,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","xver":6.991,"good":2.92689253532044,"iver":1.2020052,"id":20,"r":6,"Cm":-0.27749463719874,"diter":5,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","Top_Xtr":1,"src":"retestc_19.txt","sym":36.5329625779388,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"clcd":2.99534665574768,"CDpres":0.30917,"alpha":22.8},        #dud
             {"Re":100,"n":12,"Cm":-0.27749463719874,"r":6,"id":21,"cmt":"NEWv1.20200506 s(0) foildb2020/cp-180-050-gn.dat (sim 0.000331357294 ) l2 Foil spline 17pts","iver":1.2020052,"xver":6.991,"good":2.92689253532044,"Cpmin":-2.10787052072447,"CDf":0.2405,"CDp":0.455668958174868,"CL":1.64646189644527,"CD":0.549673238416638,"alpha":22.8,"CDpres":0.30917,"clcd":2.99534665574768,"Bot_Xtr":1,"xy":[1,0,0.881505301832122,0.0825261046342205,0.728410412615166,0.149118395150251,0.578854088277904,0.181098568249033,0.417631843232969,0.183931556689224,0.236292967245553,0.146280812894229,0.0903612300377599,0.0770108344101389,0.00985325964789057,0.0221183868050877,0,3.41835082190764e-07,0.00274589304588497,-0.00613081576928319,0.0241513949742748,-0.0159270973545363,0.0780025897436987,0.0226740794644619,0.223292169860757,0.0992679427955625,0.428001029285069,0.145825780047179,0.637514233447336,0.132988915988833,0.796982010174291,0.0812834937908626,1,0],"sym":36.5329625779388,"src":"retestc_20.txt","Top_Xtr":1,"Foil_fn":"spline_foil_cp-180-050-gn.dat-s17_n17s0-Re100-N3.dat","diter":5},        #dud
             {"CDpres":0.31883,"clcd":2.61631262982554,"alpha":23,"sym":7.12790975651086,"xy":[1,0,0.877210873675894,0.0383109690168356,0.691863104456041,0.0803108260980579,0.499696975102915,0.102958576182511,0.304152678898764,0.0974831823489284,0.141625923030713,0.0707978605208008,0.0720026374146952,0.0483349735519576,0.0217724080392941,0.0231794409614143,0,0,0.0197576807063861,-0.011181408401697,0.0621428654159445,-0.00717793766412422,0.145753650424787,0.00228213328950028,0.323023593158921,0.0296721262693589,0.493779274322263,0.0458244068360395,0.691249867108052,0.0442923558076522,0.886431933821134,0.0206109555595122,1,0],"Bot_Xtr":1,"Re":100,"src":"retest_9.txt","diter":6,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N4.dat","Top_Xtr":1,"Cm":-0.176609166900091,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20138660514193>3.14249773910627) l1 Foil spline 17pts Re200 N4","good":2.56049892509516,"iver":1.2020052,"id":22,"r":6,"CDf":0.22483,"Cpmin":-2.79838494927051,"n":13,"CL":1.42240503866739,"CD":0.543667840934683,"CDp":0.443318567165883},
             {"Cm":-0.176609166900091,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20138660514193>3.14249773910627) l1 Foil spline 17pts Re200 N4","xver":6.991,"good":2.56049892509516,"id":23,"Cpmin":-2.79838494927051,"CDf":0.22483,"CDp":0.443318567165883,"n":14,"CL":1.42240503866739,"CD":0.543667840934683,"alpha":23,"clcd":2.61631262982554,"CDpres":0.31883,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0383109690168356,0.691863104456041,0.0803108260980579,0.499696975102915,0.102958576182511,0.304152678898764,0.0974831823489284,0.141625923030713,0.0707978605208008,0.0720026374146952,0.0483349735519576,0.0217724080392941,0.0231794409614143,0,0,0.0197576807063861,-0.011181408401697,0.0621428654159445,-0.00717793766412422,0.145753650424787,0.00228213328950028,0.323023593158921,0.0296721262693589,0.493779274322263,0.0458244068360395,0.691249867108052,0.0442923558076522,0.886431933821134,0.0206109555595122,1,0],"sym":7.12790975651086,"src":"retest_10.txt","Re":100,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N4.dat","Top_Xtr":1,"diter":6},
             {"Cm":-0.138671468618613,"r":6,"id":24,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":3.20325365580572,"Cpmin":-2.0467665474095,"CDf":0.16092,"CDp":0.242961212042116,"CL":1.16013622286677,"CD":0.360057628936344,"n":3,"alpha":17.3,"CDpres":0.19914,"clcd":3.22208482651504,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"sym":6.87210078969056,"src":"retest_74.txt","Re":200,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4},
             {"src":"retest_75.txt","Re":200,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"alpha":17.3,"CDpres":0.19914,"clcd":3.22208482651504,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"sym":6.87210078969056,"Cpmin":-2.0467665474095,"CDf":0.16092,"CDp":0.242961212042116,"n":4,"CD":0.360057628936344,"CL":1.16013622286677,"Cm":-0.138671468618613,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","good":3.20325365580572,"iver":1.2020052,"id":25},
             {"CDf":0.16092,"Cpmin":-2.0467665474095,"CD":0.360057628936344,"CL":1.16013622286677,"n":5,"CDp":0.242961212042116,"Cm":-0.138671468618613,"id":26,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":3.20325365580572,"iver":1.2020052,"r":6,"Re":200,"src":"retest_76.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","CDpres":0.19914,"clcd":3.22208482651504,"alpha":17.3,"sym":6.87210078969056,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"Bot_Xtr":1},
             {"CDp":0.242961212042116,"n":6,"CL":1.16013622286677,"CD":0.360057628936344,"Cpmin":-2.0467665474095,"CDf":0.16092,"r":6,"good":3.20325365580572,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"iver":1.2020052,"id":27,"Cm":-0.138671468618613,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_77.txt","Re":200,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"Bot_Xtr":1,"sym":6.87210078969056,"alpha":17.3,"clcd":3.22208482651504,"CDpres":0.19914},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retestc_1.txt","Re":200,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"Bot_Xtr":1,"sym":6.87210078969056,"alpha":17.3,"CDpres":0.19914,"clcd":3.22208482651504,"CDp":0.242961212042116,"CL":1.16013622286677,"CD":0.360057628936344,"n":7,"Cpmin":-2.0467665474095,"CDf":0.16092,"r":6,"id":28,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","good":3.20325365580572,"xver":6.991,"iver":1.2020052,"Cm":-0.138671468618613},
             {"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_79.txt","Re":200,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"Bot_Xtr":1,"sym":6.87210078969056,"alpha":17.3,"clcd":3.22208482651504,"CDpres":0.19914,"CDp":0.242961212042116,"n":8,"CD":0.360057628936344,"CL":1.16013622286677,"Cpmin":-2.0467665474095,"CDf":0.16092,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"iver":1.2020052,"good":3.20325365580572,"id":29,"Cm":-0.138671468618613},
             {"sym":6.87210078969056,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"CDpres":0.19914,"clcd":3.22208482651558,"alpha":17.3,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Re":200,"src":"retest_152.txt","id":30,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","good":3.20325365607176,"iver":1.2020052,"r":6,"Cm":-0.138671468618727,"CL":1.16013622286719,"CD":0.360057628936414,"n":9,"CDp":0.242961212042238,"CDf":0.16092,"Cpmin":-2.04676654740953},
             {"diter":4,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"Re":200,"src":"retest_153.txt","sym":6.87210078969056,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"clcd":3.22208482651558,"CDpres":0.19914,"alpha":17.3,"n":10,"CD":0.360057628936414,"CL":1.16013622286719,"CDp":0.242961212042238,"CDf":0.16092,"Cpmin":-2.04676654740953,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":3.20325365607176,"iver":1.2020052,"id":31,"r":6,"Cm":-0.138671468618727},
             {"Cpmin":-2.04676654740953,"CDf":0.16092,"CDp":0.242961212042238,"CL":1.16013622286719,"CD":0.360057628936414,"n":11,"Cm":-0.138671468618727,"r":6,"id":32,"good":3.20325365607176,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"iver":1.2020052,"src":"retest_154.txt","Re":200,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"alpha":17.3,"CDpres":0.19914,"clcd":3.22208482651558,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"sym":6.87210078969056},
             {"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"Bot_Xtr":1,"sym":6.87210078969056,"alpha":17.3,"clcd":3.22208482651558,"CDpres":0.19914,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_155.txt","Re":200,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"good":3.20325365607176,"id":33,"Cm":-0.138671468618727,"CDp":0.242961212042238,"n":12,"CL":1.16013622286719,"CD":0.360057628936414,"Cpmin":-2.04676654740953,"CDf":0.16092},
             {"Cm":-0.138671468618727,"id":34,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":3.20325365607176,"r":6,"CDf":0.16092,"Cpmin":-2.04676654740953,"CD":0.360057628936414,"CL":1.16013622286719,"n":13,"CDp":0.242961212042238,"clcd":3.22208482651558,"CDpres":0.19914,"alpha":17.3,"sym":6.87210078969056,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"Bot_Xtr":1,"Re":200,"src":"retest_156.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat"},
             {"id":35,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.20325365625953>3.14249773910376) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":3.2032536573751,"iver":1.2020052,"r":6,"Cm":-0.138671468618663,"CD":0.360057628936371,"CL":1.16013622286694,"n":14,"CDp":0.242961212042168,"CDf":0.16092,"Cpmin":-2.04676654740883,"sym":6.87210078969056,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0375034898731632,0.691863104456041,0.0786181172277396,0.499696975102915,0.100788521363667,0.304152678898764,0.0954285322415144,0.141625923030713,0.0693056561403255,0.0720026374146952,0.0473162187656714,0.0217724080392941,0.0226908885802384,0,0,0.0197576807063861,-0.0110685947139718,0.0621428654159445,-0.00710551658897342,0.145753650424787,0.00225910793678802,0.323023593158921,0.0293727523562672,0.493779274322263,0.0453620661239154,0.691249867108052,0.0438454725692278,0.886431933821134,0.0204030034106707,1,0],"clcd":3.22208482651525,"CDpres":0.19914,"alpha":17.3,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N7.dat","Re":200,"src":"retest_59.txt"},
             {"CDp":0.157689619542132,"n":3,"CL":1.011223919994,"CD":0.279319430442939,"Cpmin":-1.62025689141843,"CDf":0.13397,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","iver":1.2020052,"xver":6.991,"good":3.58630551572738,"id":36,"Cm":-0.117039073714539,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"diter":4,"src":"retest_106.txt","Re":300,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1,"sym":6.80575829276563,"alpha":14.2,"CDpres":0.14534,"clcd":3.62031355423582},
             {"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","xver":6.991,"good":3.58630551572738,"id":37,"r":6,"Cm":-0.117039073714539,"n":4,"CD":0.279319430442939,"CL":1.011223919994,"CDp":0.157689619542132,"CDf":0.13397,"Cpmin":-1.62025689141843,"sym":6.80575829276563,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"CDpres":0.14534,"clcd":3.62031355423582,"alpha":14.2,"diter":4,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"Re":300,"src":"retest_107.txt"},
             {"Cm":-0.117039073714539,"id":38,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","xver":6.991,"good":3.58630551572738,"iver":1.2020052,"r":6,"CDf":0.13397,"Cpmin":-1.62025689141843,"CL":1.011223919994,"CD":0.279319430442939,"n":5,"CDp":0.157689619542132,"clcd":3.62031355423582,"CDpres":0.14534,"alpha":14.2,"sym":6.80575829276563,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1,"Re":300,"src":"retest_108.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat"},
             {"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1,"sym":6.80575829276563,"alpha":14.2,"CDpres":0.14534,"clcd":3.62031355423582,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","diter":4,"src":"retest_109.txt","Re":300,"r":6,"id":39,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","good":3.58630551572738,"iver":1.2020052,"Cm":-0.117039073714539,"CDp":0.157689619542132,"CL":1.011223919994,"CD":0.279319430442939,"n":6,"Cpmin":-1.62025689141843,"CDf":0.13397},
             {"id":40,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","good":3.58630551572738,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.117039073714539,"CL":1.011223919994,"CD":0.279319430442939,"n":7,"CDp":0.157689619542132,"CDf":0.13397,"Cpmin":-1.62025689141843,"sym":6.80575829276563,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"clcd":3.62031355423582,"CDpres":0.14534,"alpha":14.2,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Re":300,"src":"retest_110.txt"},
             {"Cm":-0.117039073714539,"r":6,"id":41,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","iver":1.2020052,"xver":6.991,"good":3.58630551572738,"Cpmin":-1.62025689141843,"CDf":0.13397,"CDp":0.157689619542132,"CL":1.011223919994,"CD":0.279319430442939,"n":8,"alpha":14.2,"CDpres":0.14534,"clcd":3.62031355423582,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"sym":6.80575829276563,"src":"retest_111.txt","Re":300,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","diter":4},
             {"CDp":0.157689619542267,"n":9,"CD":0.279319430443025,"CL":1.01122391999474,"Cpmin":-1.62025689141978,"CDf":0.13397,"r":6,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","iver":1.2020052,"good":3.58629246334402,"id":42,"Cm":-0.117039073714721,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"diter":4,"src":"retest_154.txt","Re":300,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1,"sym":6.80575829276563,"alpha":14.2,"CDpres":0.14534,"clcd":3.62031355423736},
             {"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","diter":4,"src":"retest_155.txt","Re":300,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1,"sym":6.80575829276563,"alpha":14.2,"CDpres":0.14534,"clcd":3.62031355423736,"CDp":0.157689619542267,"CL":1.01122391999474,"CD":0.279319430443025,"n":10,"Cpmin":-1.62025689141978,"CDf":0.13397,"r":6,"id":43,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","iver":1.2020052,"xver":6.991,"good":3.58629246334402,"Cm":-0.117039073714721},
             {"sym":6.80575829276563,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"clcd":3.62031355423736,"CDpres":0.14534,"alpha":14.2,"diter":4,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"Re":300,"src":"retest_156.txt","xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","iver":1.2020052,"good":3.58629246334402,"id":44,"r":6,"Cm":-0.117039073714721,"n":11,"CL":1.01122391999474,"CD":0.279319430443025,"CDp":0.157689619542267,"CDf":0.13397,"Cpmin":-1.62025689141978},
             {"Re":300,"src":"retest_24.txt","diter":4,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"clcd":3.62024554331867,"CDpres":0.14708,"alpha":14.3,"sym":6.80575829276563,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1,"CDf":0.13339,"Cpmin":-1.6347618713813,"n":12,"CL":1.01538276544177,"CD":0.280473452226384,"CDp":0.159846808475808,"Cm":-0.117624576385352,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","iver":1.2020052,"good":3.58257975937627,"id":45,"r":6},
             {"n":13,"CD":0.280473452226384,"CL":1.01538276544177,"CDp":0.159846808475808,"CDf":0.13339,"Cpmin":-1.6347618713813,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","xver":6.991,"iver":1.2020052,"good":3.58257975937627,"id":46,"r":6,"Cm":-0.117624576385352,"diter":4,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"Re":300,"src":"retest_34.txt","sym":6.80575829276563,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"CDpres":0.14708,"clcd":3.62024554331867,"alpha":14.3},
             {"CDf":0.13339,"Cpmin":-1.6347618713813,"n":14,"CL":1.01538276544177,"CD":0.280473452226384,"CDp":0.159846808475808,"Cm":-0.117624576385352,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt1.48042216446105>1.4665525875909) l1 Foil spline 17pts Re300 N6","good":3.58257975937627,"xver":6.991,"iver":1.2020052,"id":47,"r":6,"Re":300,"src":"retest_44.txt","diter":4,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re300-N6-sq1.dat","Top_Xtr":1,"CDpres":0.14708,"clcd":3.62024554331867,"alpha":14.3,"sym":6.80575829276563,"xy":[1,0,0.946714574040677,0.0230410225292458,0.854728633619417,0.048736512215659,0.691363149797408,0.077793138786867,0.513763139089403,0.0930612455614288,0.327229099655296,0.0903312630353125,0.155573716106985,0.0684996981358732,0.0401397957317501,0.0328266517235714,0,0,0.0290164970646396,-0.00440903590831124,0.113543374367374,0.00685181256111361,0.264712879181914,0.0270184938641432,0.449425033656063,0.0425556393195545,0.653083287629906,0.0451638519522208,0.83008632648885,0.0341069851761375,0.943258507857798,0.0167145210929157,1,0],"Bot_Xtr":1},
             {"CDp":0.112863479729294,"CL":0.885570143135721,"CD":0.227343316922712,"n":3,"Cpmin":-1.94656381902766,"CDf":0.11018,"r":6,"id":48,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"xver":6.991,"good":3.83199916603018,"Cm":-0.0857986897705347,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":4,"src":"retest_153.txt","Re":400,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":11.7,"CDpres":0.11716,"clcd":3.89529877157894},
             {"id":49,"good":3.83199916603018,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0857986897705347,"CL":0.885570143135721,"CD":0.227343316922712,"n":4,"CDp":0.112863479729294,"CDf":0.11018,"Cpmin":-1.94656381902766,"sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"CDpres":0.11716,"clcd":3.89529877157894,"alpha":11.7,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Re":400,"src":"retest_154.txt"},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"good":3.83199916603018,"id":50,"r":6,"Cm":-0.0857986897705347,"n":5,"CL":0.885570143135721,"CD":0.227343316922712,"CDp":0.112863479729294,"CDf":0.11018,"Cpmin":-1.94656381902766,"sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"CDpres":0.11716,"clcd":3.89529877157894,"alpha":11.7,"diter":4,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"Re":400,"src":"retest_155.txt"},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"iver":1.2020052,"good":3.83199916603018,"id":51,"r":6,"Cm":-0.0857986897705347,"n":6,"CL":0.885570143135721,"CD":0.227343316922712,"CDp":0.112863479729294,"CDf":0.11018,"Cpmin":-1.94656381902766,"sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"CDpres":0.11716,"clcd":3.89529877157894,"alpha":11.7,"diter":4,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"Re":400,"src":"retest_156.txt"},
             {"Cm":-0.0857986897705347,"r":6,"id":52,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"good":3.83199916603018,"Cpmin":-1.94656381902766,"CDf":0.11018,"CDp":0.112863479729294,"CL":0.885570143135721,"CD":0.227343316922712,"n":7,"alpha":11.7,"CDpres":0.11716,"clcd":3.89529877157894,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356,"src":"retest_157.txt","Re":400,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":4},
             {"src":"retest_158.txt","Re":400,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":4,"alpha":11.7,"CDpres":0.11716,"clcd":3.89529877157894,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356,"Cpmin":-1.94656381902766,"CDf":0.11018,"CDp":0.112863479729294,"CL":0.885570143135721,"CD":0.227343316922712,"n":8,"Cm":-0.0857986897705347,"r":6,"id":53,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","good":3.83199916603018,"iver":1.2020052},
             {"CDf":0.11018,"Cpmin":-1.94656381902766,"CL":0.885570143135721,"CD":0.227343316922712,"n":9,"CDp":0.112863479729294,"Cm":-0.0857986897705347,"id":54,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"xver":6.991,"good":3.83199916603018,"r":6,"Re":400,"src":"retest_159.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","clcd":3.89529877157894,"CDpres":0.11716,"alpha":11.7,"sym":3.35739386007356,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1},
             {"diter":4,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"Re":400,"src":"retest_154.txt","sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"CDpres":0.11716,"clcd":3.89529877157894,"alpha":11.7,"n":10,"CD":0.227343316922712,"CL":0.885570143135721,"CDp":0.112863479729294,"CDf":0.11018,"Cpmin":-1.94656381902766,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"good":3.83199916603018,"id":55,"r":6,"Cm":-0.0857986897705347},
             {"alpha":11.7,"CDpres":0.11716,"clcd":3.89529877157894,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356,"src":"retest_155.txt","Re":400,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":4,"Cm":-0.0857986897705347,"r":6,"id":56,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"good":3.83199916603018,"iver":1.2020052,"Cpmin":-1.94656381902766,"CDf":0.11018,"CDp":0.112863479729294,"CL":0.885570143135721,"CD":0.227343316922712,"n":11},
             {"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Re":400,"src":"retest_156.txt","sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"CDpres":0.11716,"clcd":3.89529877157894,"alpha":11.7,"CL":0.885570143135721,"CD":0.227343316922712,"n":12,"CDp":0.112863479729294,"CDf":0.11018,"Cpmin":-1.94656381902766,"id":57,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"good":3.83199916603018,"r":6,"Cm":-0.0857986897705347},
             {"CDp":0.112863479729294,"n":13,"CL":0.885570143135721,"CD":0.227343316922712,"Cpmin":-1.94656381902766,"CDf":0.11018,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","good":3.83199916603018,"iver":1.2020052,"id":58,"Cm":-0.0857986897705347,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":4,"src":"retest_157.txt","Re":400,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":11.7,"clcd":3.89529877157894,"CDpres":0.11716},
             {"Cm":-0.0857986897705347,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"good":3.83199916603018,"id":59,"Cpmin":-1.94656381902766,"CDf":0.11018,"CDp":0.112863479729294,"n":14,"CL":0.885570143135721,"CD":0.227343316922712,"alpha":11.7,"clcd":3.89529877157894,"CDpres":0.11716,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356,"src":"retest_158.txt","Re":400,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":4},
             {"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"CDpres":0.10446,"clcd":4.1636658814345,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":23,"src":"retestc_16.txt","Re":500,"r":6,"id":60,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"xver":6.991,"good":4.08157432507707,"Cm":-0.0824749969119529,"CDp":0.0949796299514679,"CD":0.203014479858104,"CL":0.845284463222358,"n":3,"Cpmin":-1.84737615859538,"CDf":0.09855},
             {"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":23,"src":"retestc_15.txt","Re":500,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"CDpres":0.10446,"clcd":4.1636658814345,"CDp":0.0949796299514679,"n":4,"CD":0.203014479858104,"CL":0.845284463222358,"Cpmin":-1.84737615859538,"CDf":0.09855,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"iver":1.2020052,"good":4.08157432507707,"id":61,"Cm":-0.0824749969119529},
             {"Cpmin":-1.84737615859538,"CDf":0.09855,"CDp":0.0949796299514679,"n":5,"CD":0.203014479858104,"CL":0.845284463222358,"Cm":-0.0824749969119529,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"iver":1.2020052,"good":4.08157432507707,"id":62,"src":"retestc_22.txt","Re":500,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":23,"alpha":10.8,"clcd":4.1636658814345,"CDpres":0.10446,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356},
             {"CD":0.203014479858104,"CL":0.845284463222358,"n":6,"CDp":0.0949796299514679,"CDf":0.09855,"Cpmin":-1.84737615859538,"id":63,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"good":4.08157432507707,"iver":1.2020052,"r":6,"Cm":-0.0824749969119529,"diter":23,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Re":500,"src":"retestc_21.txt","sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"clcd":4.1636658814345,"CDpres":0.10446,"alpha":10.8},
             {"Cpmin":-1.84737615859538,"CDf":0.09855,"CDp":0.0949796299514679,"n":7,"CL":0.845284463222358,"CD":0.203014479858104,"Cm":-0.0824749969119529,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"xver":6.991,"good":4.08157432507707,"id":64,"src":"retestc_23.txt","Re":500,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":23,"alpha":10.8,"CDpres":0.10446,"clcd":4.1636658814345,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"sym":3.35739386007356},
             {"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"clcd":4.1636658814345,"CDpres":0.10446,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":23,"src":"retestc_0.txt","Re":500,"r":6,"id":65,"good":4.08157432507707,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"iver":1.2020052,"Cm":-0.0824749969119529,"CDp":0.0949796299514679,"CD":0.203014479858104,"CL":0.845284463222358,"n":8,"Cpmin":-1.84737615859538,"CDf":0.09855},
             {"CDp":0.0949796299514679,"n":9,"CL":0.845284463222358,"CD":0.203014479858104,"Cpmin":-1.84737615859538,"CDf":0.09855,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","good":4.08157432507707,"iver":1.2020052,"id":66,"Cm":-0.0824749969119529,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":23,"src":"retestc_1.txt","Re":500,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"clcd":4.1636658814345,"CDpres":0.10446},
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","good":4.08157432507707,"iver":1.2020052,"id":67,"r":6,"Cm":-0.0824749969119529,"n":10,"CL":0.845284463222358,"CD":0.203014479858104,"CDp":0.0949796299514679,"CDf":0.09855,"Cpmin":-1.84737615859538,"sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"clcd":4.1636658814345,"CDpres":0.10446,"alpha":10.8,"diter":23,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"Re":500,"src":"retestc_2.txt"},
             {"sym":3.35739386007356,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"clcd":4.1636658814345,"CDpres":0.10446,"alpha":10.8,"diter":23,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"Re":500,"src":"retestc_3.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","good":4.08157432507707,"xver":6.991,"iver":1.2020052,"id":68,"r":6,"Cm":-0.0824749969119529,"n":11,"CD":0.203014479858104,"CL":0.845284463222358,"CDp":0.0949796299514679,"CDf":0.09855,"Cpmin":-1.84737615859538},
             {"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"clcd":4.1636658814345,"CDpres":0.10446,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":23,"src":"retestc_4.txt","Re":500,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"good":4.08157432507707,"id":69,"Cm":-0.0824749969119529,"CDp":0.0949796299514679,"n":12,"CD":0.203014479858104,"CL":0.845284463222358,"Cpmin":-1.84737615859538,"CDf":0.09855},
             {"CDp":0.0949796299514679,"n":13,"CD":0.203014479858104,"CL":0.845284463222358,"Cpmin":-1.84737615859538,"CDf":0.09855,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","iver":1.2020052,"xver":6.991,"good":4.08157432507707,"id":70,"Cm":-0.0824749969119529,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","Top_Xtr":1,"diter":23,"src":"retestc_5.txt","Re":500,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"CDpres":0.10446,"clcd":4.1636658814345},
             {"CDp":0.0949796299514679,"CD":0.203014479858104,"CL":0.845284463222358,"n":14,"Cpmin":-1.84737615859538,"CDf":0.09855,"r":6,"id":71,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.83199916584883>3.82938829291497) l1 Foil spline 17pts Re400 N10","xver":6.991,"good":4.08157432507707,"Cm":-0.0824749969119529,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re400-N10.dat","diter":23,"src":"retest_69.txt","Re":500,"xy":[1,0,0.877210873675894,0.0262671653615004,0.691863104456041,0.0550635445558517,0.499696975102915,0.0705915307123189,0.304152678898764,0.0668374341980059,0.141625923030713,0.0485411660749977,0.0720026374146952,0.0331399276921209,0.0217724080392941,0.0158925295899731,0,0,0.0197576807063861,-0.00769442366017751,0.0621428654159445,-0.0049394576613206,0.145753650424787,0.0015704372604568,0.323023593158921,0.0204187077524223,0.493779274322263,0.0315338092935868,0.691249867108052,0.0304795369463185,0.886431933821134,0.0141833138025715,1,0],"Bot_Xtr":1,"sym":3.35739386007356,"alpha":10.8,"clcd":4.1636658814345,"CDpres":0.10446},
             {"Cpmin":-1.42824890244315,"CDf":0.08416,"CDp":0.0769634009632914,"n":3,"CD":0.173795948687923,"CL":0.808582810400751,"Cm":-0.0893632214295863,"r":6,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt1.69178939908294>1.65221032893318) l1 Foil spline 17pts Re500 N13","xver":6.991,"good":4.54635659022671,"id":72,"src":"retest_75.txt","Re":750,"Foil_fn":"optbs-spline_foil_goe494.dat-s17_n17s0-Re500-N13-sq1.dat","Top_Xtr":1,"diter":4,"alpha":9.8,"clcd":4.6524836539929,"CDpres":0.08964,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0299389572452042,0.691863104456041,0.062760677961974,0.499696975102915,0.0804592650475825,0.304152678898764,0.0761803969820881,0.141625923030713,0.0553265598229251,0.0720026374146952,0.037772438122988,0.0217724080392941,0.0181140887249956,0,0,0.0197576807063861,-0.00872215500329646,0.0621428654159445,-0.00559921278798737,0.145753650424787,0.00178019794770964,0.323023593158921,0.023146000512731,0.493779274322263,0.0357457276399451,0.691249867108052,0.0345506378925278,0.886431933821134,0.0160777553862389,1,0],"sym":4.34875352247544},
             {"r":6,"id":73,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"good":4.68159794156274,"Cm":-0.0814591581495098,"CDp":0.0645629203427145,"CD":0.162317497066887,"CL":0.781988703779208,"n":4,"Cpmin":-1.36929706274846,"CDf":0.08419,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"sym":3.87362993702821,"alpha":9.1,"clcd":4.81764885431279,"CDpres":0.07812,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","diter":4,"src":"retest_149.txt","Re":750},
             {"Re":750,"src":"retestc_13.txt","diter":4,"Foil_fn":"optbs-spline_foil_goe494.dat-s17_n17s0-Re500-N13-sq1.dat","Top_Xtr":1,"clcd":4.6524836539929,"CDpres":0.08964,"alpha":9.8,"sym":4.34875352247544,"xy":[1,0,0.877210873675894,0.0299389572452042,0.691863104456041,0.062760677961974,0.499696975102915,0.0804592650475825,0.304152678898764,0.0761803969820881,0.141625923030713,0.0553265598229251,0.0720026374146952,0.037772438122988,0.0217724080392941,0.0181140887249956,0,0,0.0197576807063861,-0.00872215500329646,0.0621428654159445,-0.00559921278798737,0.145753650424787,0.00178019794770964,0.323023593158921,0.023146000512731,0.493779274322263,0.0357457276399451,0.691249867108052,0.0345506378925278,0.886431933821134,0.0160777553862389,1,0],"Bot_Xtr":1,"CDf":0.08416,"Cpmin":-1.42824890244315,"n":5,"CD":0.173795948687923,"CL":0.808582810400751,"CDp":0.0769634009632914,"Cm":-0.0893632214295863,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt1.69178939908294>1.65221032893318) l1 Foil spline 17pts Re500 N13","good":4.54635659022671,"xver":6.991,"iver":1.2020052,"id":74,"r":6},
             {"CDp":0.0769634009632914,"n":6,"CL":0.808582810400751,"CD":0.173795948687923,"Cpmin":-1.42824890244315,"CDf":0.08416,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt1.69178939908294>1.65221032893318) l1 Foil spline 17pts Re500 N13","good":4.54635659022671,"xver":6.991,"iver":1.2020052,"id":75,"Cm":-0.0893632214295863,"Foil_fn":"optbs-spline_foil_goe494.dat-s17_n17s0-Re500-N13-sq1.dat","Top_Xtr":1,"diter":4,"src":"retestc_11.txt","Re":750,"xy":[1,0,0.877210873675894,0.0299389572452042,0.691863104456041,0.062760677961974,0.499696975102915,0.0804592650475825,0.304152678898764,0.0761803969820881,0.141625923030713,0.0553265598229251,0.0720026374146952,0.037772438122988,0.0217724080392941,0.0181140887249956,0,0,0.0197576807063861,-0.00872215500329646,0.0621428654159445,-0.00559921278798737,0.145753650424787,0.00178019794770964,0.323023593158921,0.023146000512731,0.493779274322263,0.0357457276399451,0.691249867108052,0.0345506378925278,0.886431933821134,0.0160777553862389,1,0],"Bot_Xtr":1,"sym":4.34875352247544,"alpha":9.8,"clcd":4.6524836539929,"CDpres":0.08964},
             {"CDp":0.0645629203427145,"CD":0.162317497066887,"CL":0.781988703779208,"n":7,"Cpmin":-1.36929706274846,"CDf":0.08419,"r":6,"id":76,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"good":4.68159794156274,"Cm":-0.0814591581495098,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","diter":4,"src":"retest_152.txt","Re":750,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"sym":3.87362993702821,"alpha":9.1,"CDpres":0.07812,"clcd":4.81764885431279},
             {"n":8,"CL":0.781988703779208,"CD":0.162317497066887,"CDp":0.0645629203427145,"CDf":0.08419,"Cpmin":-1.36929706274846,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","iver":1.2020052,"xver":6.991,"good":4.68159794156274,"id":77,"r":6,"Cm":-0.0814591581495098,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"Re":750,"src":"retest_153.txt","sym":3.87362993702821,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"CDpres":0.07812,"clcd":4.81764885431279,"alpha":9.1},
             {"CDf":0.08419,"Cpmin":-1.36929706274846,"CD":0.162317497066887,"CL":0.781988703779208,"n":9,"CDp":0.0645629203427145,"Cm":-0.0814591581495098,"id":78,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"iver":1.2020052,"good":4.68159794156274,"r":6,"Re":750,"src":"retest_154.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","clcd":4.81764885431279,"CDpres":0.07812,"alpha":9.1,"sym":3.87362993702821,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1},
             {"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"sym":3.87362993702821,"alpha":9.1,"CDpres":0.07812,"clcd":4.81764885431279,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","diter":4,"src":"retest_155.txt","Re":750,"r":6,"id":79,"good":4.68159794156274,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"iver":1.2020052,"Cm":-0.0814591581495098,"CDp":0.0645629203427145,"CD":0.162317497066887,"CL":0.781988703779208,"n":10,"Cpmin":-1.36929706274846,"CDf":0.08419},
             {"Re":750,"src":"retest_156.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","clcd":4.81764885431279,"CDpres":0.07812,"alpha":9.1,"sym":3.87362993702821,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"CDf":0.08419,"Cpmin":-1.36929706274846,"CL":0.781988703779208,"CD":0.162317497066887,"n":11,"CDp":0.0645629203427145,"Cm":-0.0814591581495098,"id":80,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","good":4.68159794156274,"xver":6.991,"iver":1.2020052,"r":6},
             {"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"sym":3.87362993702821,"alpha":9.1,"CDpres":0.07812,"clcd":4.81764885431279,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","diter":4,"src":"retest_157.txt","Re":750,"r":6,"id":81,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"iver":1.2020052,"good":4.68159794156274,"Cm":-0.0814591581495098,"CDp":0.0645629203427145,"CL":0.781988703779208,"CD":0.162317497066887,"n":12,"Cpmin":-1.36929706274846,"CDf":0.08419},
             {"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"diter":4,"src":"retest_158.txt","Re":750,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"sym":3.87362993702821,"alpha":9.1,"CDpres":0.07812,"clcd":4.81764885431279,"CDp":0.0645629203427145,"n":13,"CD":0.162317497066887,"CL":0.781988703779208,"Cpmin":-1.36929706274846,"CDf":0.08419,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","good":4.68159794156274,"xver":6.991,"iver":1.2020052,"id":82,"Cm":-0.0814591581495098},
             {"Cm":-0.0814591581495098,"id":83,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"good":4.68159794156274,"iver":1.2020052,"r":6,"CDf":0.08419,"Cpmin":-1.36929706274846,"CD":0.162317497066887,"CL":0.781988703779208,"n":14,"CDp":0.0645629203427145,"clcd":4.81764885431279,"CDpres":0.07812,"alpha":9.1,"sym":3.87362993702821,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"Re":750,"src":"retest_159.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat"},
             {"Re":1000,"src":"retest_70.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Top_Xtr":1,"CDpres":0.07164,"clcd":5.24916233945001,"alpha":8.5,"sym":4.54488881393926,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"Bot_Xtr":1,"CDf":0.07465,"Cpmin":-1.16372420787074,"n":3,"CL":0.767887668301202,"CD":0.146287658609861,"CDp":0.0574952671822745,"Cm":-0.0883279423768853,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"good":5.09071162738918,"id":84,"r":6},
             {"alpha":8.5,"CDpres":0.07164,"clcd":5.24916233945001,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"sym":4.54488881393926,"src":"retest_71.txt","Re":1000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Top_Xtr":1,"diter":4,"Cm":-0.0883279423768853,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"good":5.09071162738918,"iver":1.2020052,"id":85,"Cpmin":-1.16372420787074,"CDf":0.07465,"CDp":0.0574952671822745,"n":4,"CD":0.146287658609861,"CL":0.767887668301202},
             {"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Top_Xtr":1,"Re":1000,"src":"retest_72.txt","sym":4.54488881393926,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"CDpres":0.07164,"clcd":5.24916233945001,"alpha":8.5,"n":5,"CL":0.767887668301202,"CD":0.146287658609861,"CDp":0.0574952671822745,"CDf":0.07465,"Cpmin":-1.16372420787074,"good":5.09071162738918,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"iver":1.2020052,"id":86,"r":6,"Cm":-0.0883279423768853},
             {"Cm":-0.0883279423768853,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"iver":1.2020052,"good":5.09071162738918,"id":87,"r":6,"CDf":0.07465,"Cpmin":-1.16372420787074,"n":6,"CD":0.146287658609861,"CL":0.767887668301202,"CDp":0.0574952671822745,"clcd":5.24916233945001,"CDpres":0.07164,"alpha":8.5,"sym":4.54488881393926,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"Bot_Xtr":1,"Re":1000,"src":"retest_73.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Top_Xtr":1},
             {"id":88,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","iver":1.2020052,"good":5.09071162738918,"r":6,"Cm":-0.0883279423768853,"CL":0.767887668301202,"CD":0.146287658609861,"n":7,"CDp":0.0574952671822745,"CDf":0.07465,"Cpmin":-1.16372420787074,"sym":4.54488881393926,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"clcd":5.24916233945001,"CDpres":0.07164,"alpha":8.5,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Re":1000,"src":"retest_74.txt"},
             {"alpha":8.5,"clcd":5.24916233945001,"CDpres":0.07164,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"sym":4.54488881393926,"src":"retest_75.txt","Re":1000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Top_Xtr":1,"diter":4,"Cm":-0.0883279423768853,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","iver":1.2020052,"good":5.09071162738918,"id":89,"Cpmin":-1.16372420787074,"CDf":0.07465,"CDp":0.0574952671822745,"n":8,"CL":0.767887668301202,"CD":0.146287658609861},
             {"Cm":-0.0883279423768853,"r":6,"id":90,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","good":5.09071162738918,"xver":6.991,"iver":1.2020052,"Cpmin":-1.16372420787074,"CDf":0.07465,"CDp":0.0574952671822745,"CL":0.767887668301202,"CD":0.146287658609861,"n":9,"alpha":8.5,"clcd":5.24916233945001,"CDpres":0.07164,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"sym":4.54488881393926,"src":"retest_76.txt","Re":1000,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","diter":4},
             {"Cm":-0.0883279423768853,"r":6,"id":91,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"good":5.09071162738918,"Cpmin":-1.16372420787074,"CDf":0.07465,"CDp":0.0574952671822745,"CL":0.767887668301202,"CD":0.146287658609861,"n":10,"alpha":8.5,"clcd":5.24916233945001,"CDpres":0.07164,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"sym":4.54488881393926,"src":"retest_77.txt","Re":1000,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","diter":4},
             {"Re":1000,"src":"retest_78.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","CDpres":0.07164,"clcd":5.24916233945001,"alpha":8.5,"sym":4.54488881393926,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"Bot_Xtr":1,"CDf":0.07465,"Cpmin":-1.16372420787074,"CL":0.767887668301202,"CD":0.146287658609861,"n":11,"CDp":0.0574952671822745,"Cm":-0.0883279423768853,"id":92,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"good":5.09071162738918,"iver":1.2020052,"r":6},
             {"alpha":8.5,"clcd":5.24916233945001,"CDpres":0.07164,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"sym":4.54488881393926,"src":"retest_79.txt","Re":1000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","Top_Xtr":1,"diter":4,"Cm":-0.0883279423768853,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","xver":6.991,"good":5.09071162738918,"id":93,"Cpmin":-1.16372420787074,"CDf":0.07465,"CDp":0.0574952671822745,"n":12,"CL":0.767887668301202,"CD":0.146287658609861},
             {"CDp":0.0574952671822745,"CD":0.146287658609861,"CL":0.767887668301202,"n":13,"Cpmin":-1.16372420787074,"CDf":0.07465,"r":6,"id":94,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.09071162739018>4.95096754549334) l1 Foil spline 17pts Re1000 N6","iver":1.2020052,"good":5.09071162738918,"Cm":-0.0883279423768853,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1000-N6.dat","diter":4,"src":"retest_80.txt","Re":1000,"xy":[1,0,0.946714574040677,0.0188153476753372,0.854728633619417,0.0397983388392164,0.691363149797408,0.0635260414841743,0.513763139089403,0.0759940097326718,0.327229099655296,0.0737647002343075,0.155573716106985,0.0559369982146487,0.0401397957317501,0.026806313149177,0,0,0.0290164970646396,-0.00360911540373468,0.113543374367374,0.00560870511650916,0.264712879181914,0.0221165951964632,0.449425033656063,0.0348348746932317,0.653083287629906,0.0369698857442932,0.83008632648885,0.0279190390221378,0.943258507857798,0.0136820467777945,1,0],"Bot_Xtr":1,"sym":4.54488881393926,"alpha":8.5,"CDpres":0.07164,"clcd":5.24916233945001},
             {"id":95,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe494.dat-s17_n17s0.dat (opt3.1864774300738>3.14249773910495) l1 Foil spline 17pts Re200 N12","xver":6.991,"iver":1.2020052,"good":4.875581709977,"r":6,"Cm":-0.0985874264451725,"CL":0.79829800892459,"CD":0.159849468570888,"n":14,"CDp":0.0717401445487249,"CDf":0.07458,"Cpmin":-1.17807365453915,"sym":5.28787917304175,"Bot_Xtr":1,"xy":[1,0,0.877210873675894,0.0328271781771512,0.691863104456041,0.0688152209545157,0.499696975102915,0.0882211964861506,0.304152678898764,0.0835295446282688,0.141625923030713,0.0606639310234129,0.0720026374146952,0.0414163575001387,0.0217724080392941,0.0198615607491609,0,0,0.0197576807063861,-0.00976499654455601,0.0621428654159445,-0.0062686679503249,0.145753650424787,0.00199304263699055,0.323023593158921,0.0259133912366482,0.493779274322263,0.0400195716259091,0.691249867108052,0.0386815941135221,0.886431933821134,0.0180000499568631,1,0],"CDpres":0.08527,"clcd":4.99406107547095,"alpha":9.3,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe494.dat-s17_n17s0_nsopt-Re200-N12.dat","Re":1000,"src":"retest_137.txt"},
             {"id":96,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.50204354177347>5.26709719986151) l1 Foil spline 17pts Re1250 N3","xver":6.991,"good":5.50204354177139,"iver":1.2020052,"r":6,"Cm":-0.0817549194413525,"CD":0.127976252579259,"CL":0.731511528527174,"n":3,"CDp":0.0459239541015327,"CDf":0.06664,"Cpmin":-1.15994706651345,"sym":3.85183240111755,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173607634199537,0.854728633619417,0.0367215932980312,0.691363149797408,0.0586149454287535,0.513763139089403,0.0701190351125907,0.327229099655296,0.068062069944645,0.155573716106985,0.0516125988838249,0.0401397957317501,0.024733960210263,0,0,0.0290164970646396,-0.00330489525574249,0.113543374367374,0.00513593522424599,0.264712879181914,0.0202523395240652,0.449425033656063,0.0318985677179828,0.653083287629906,0.0338536140670991,0.83008632648885,0.0255656828024044,0.943258507857798,0.0125287574451038,1,0],"clcd":5.71599428631599,"CDpres":0.06134,"alpha":7.7,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N3.dat","Re":1250,"src":"retest_81.txt"},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":5.51568951598826,"xver":6.991,"iver":1.2020052,"id":97,"Cm":-0.0825318743158887,"CDp":0.0461030680993462,"n":4,"CL":0.733743582561266,"CD":0.128056089207579,"Cpmin":-1.16186254144257,"CDf":0.06655,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":7.7,"clcd":5.72986093126637,"CDpres":0.06151,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_152.txt","Re":1250},
             {"Re":1250,"src":"retest_153.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"clcd":5.72986093126637,"CDpres":0.06151,"alpha":7.7,"sym":3.88417008469547,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"CDf":0.06655,"Cpmin":-1.16186254144257,"n":5,"CL":0.733743582561266,"CD":0.128056089207579,"CDp":0.0461030680993462,"Cm":-0.0825318743158887,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":5.51568951598826,"iver":1.2020052,"id":98,"r":6},
             {"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":7.7,"CDpres":0.06151,"clcd":5.72986093126637,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_154.txt","Re":1250,"r":6,"good":5.51568951598826,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"id":99,"Cm":-0.0825318743158887,"CDp":0.0461030680993462,"n":6,"CL":0.733743582561266,"CD":0.128056089207579,"Cpmin":-1.16186254144257,"CDf":0.06655},
             {"src":"retest_155.txt","Re":1250,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"alpha":7.7,"CDpres":0.06151,"clcd":5.72986093126637,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"Cpmin":-1.16186254144257,"CDf":0.06655,"CDp":0.0461030680993462,"n":7,"CD":0.128056089207579,"CL":0.733743582561266,"Cm":-0.0825318743158887,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":5.51568951598826,"xver":6.991,"iver":1.2020052,"id":100},
             {"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":5.72986093126637,"CDpres":0.06151,"alpha":7.7,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":1250,"src":"retest_156.txt","good":5.51568951598826,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"id":101,"r":6,"Cm":-0.0825318743158887,"n":8,"CD":0.128056089207579,"CL":0.733743582561266,"CDp":0.0461030680993462,"CDf":0.06655,"Cpmin":-1.16186254144257},
             {"CDp":0.0461030680993462,"CL":0.733743582561266,"CD":0.128056089207579,"n":9,"Cpmin":-1.16186254144257,"CDf":0.06655,"r":6,"id":102,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":5.51568951598826,"Cm":-0.0825318743158887,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4,"src":"retest_157.txt","Re":1250,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":7.7,"clcd":5.72986093126637,"CDpres":0.06151},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4,"src":"retest_158.txt","Re":1250,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":7.7,"CDpres":0.06151,"clcd":5.72986093126637,"CDp":0.0461030680993462,"CL":0.733743582561266,"CD":0.128056089207579,"n":10,"Cpmin":-1.16186254144257,"CDf":0.06655,"r":6,"id":103,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":5.51568951598826,"Cm":-0.0825318743158887},
             {"CDp":0.0461030680993462,"n":11,"CD":0.128056089207579,"CL":0.733743582561266,"Cpmin":-1.16186254144257,"CDf":0.06655,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":5.51568951598826,"id":104,"Cm":-0.0825318743158887,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_159.txt","Re":1250,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":7.7,"CDpres":0.06151,"clcd":5.72986093126637},
             {"sym":3.87362993702821,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"CDpres":0.06142,"clcd":5.72150920642914,"alpha":7.7,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"Re":1250,"src":"retest_67.txt","iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"good":5.50766489045451,"id":105,"r":6,"Cm":-0.0821788977482031,"n":12,"CD":0.128039560912102,"CL":0.732579526545734,"CDp":0.0460216125933225,"CDf":0.06662,"Cpmin":-1.15952984543987},
             {"CDpres":0.06142,"clcd":5.72150920642914,"alpha":7.7,"sym":3.87362993702821,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"Re":1250,"src":"retest_68.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"Cm":-0.0821788977482031,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","iver":1.2020052,"good":5.50766489045451,"id":106,"r":6,"CDf":0.06662,"Cpmin":-1.15952984543987,"n":13,"CL":0.732579526545734,"CD":0.128039560912102,"CDp":0.0460216125933225},
             {"CDf":0.06662,"Cpmin":-1.15952984543987,"n":14,"CD":0.128039560912102,"CL":0.732579526545734,"CDp":0.0460216125933225,"Cm":-0.0821788977482031,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"good":5.50766489045451,"iver":1.2020052,"id":107,"r":6,"Re":1250,"src":"retest_69.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"CDpres":0.06142,"clcd":5.72150920642914,"alpha":7.7,"sym":3.87362993702821,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1},
             {"Cm":-0.0835594058290602,"id":108,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":5.86969641537052,"iver":1.2020052,"r":6,"CDf":0.06103,"Cpmin":-1.10862601191711,"CD":0.118004162033131,"CL":0.722280897210154,"n":3,"CDp":0.0420046894975683,"CDpres":0.05697,"clcd":6.12080866272639,"alpha":7.3,"sym":3.88417008469547,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"Re":1500,"src":"retest_64.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat"},
             {"CDf":0.06103,"Cpmin":-1.10862601191711,"CL":0.722280897210154,"CD":0.118004162033131,"n":4,"CDp":0.0420046894975683,"Cm":-0.0835594058290602,"id":109,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"xver":6.991,"good":5.86969641537052,"r":6,"Re":1500,"src":"retest_65.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","CDpres":0.05697,"clcd":6.12080866272639,"alpha":7.3,"sym":3.88417008469547,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"xver":6.991,"good":5.86969641537052,"id":110,"r":6,"Cm":-0.0835594058290602,"n":5,"CL":0.722280897210154,"CD":0.118004162033131,"CDp":0.0420046894975683,"CDf":0.06103,"Cpmin":-1.10862601191711,"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"CDpres":0.05697,"clcd":6.12080866272639,"alpha":7.3,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":1500,"src":"retest_66.txt"},
             {"n":6,"CL":0.722280897210154,"CD":0.118004162033131,"CDp":0.0420046894975683,"CDf":0.06103,"Cpmin":-1.10862601191711,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":5.86969641537052,"xver":6.991,"iver":1.2020052,"id":111,"r":6,"Cm":-0.0835594058290602,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":1500,"src":"retestc_5.txt","sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":6.12080866272639,"CDpres":0.05697,"alpha":7.3},
             {"Cm":-0.0835594058290602,"r":6,"id":112,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":5.86969641537052,"Cpmin":-1.10862601191711,"CDf":0.06103,"CDp":0.0420046894975683,"CL":0.722280897210154,"CD":0.118004162033131,"n":7,"alpha":7.3,"clcd":6.12080866272639,"CDpres":0.05697,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retestc_4.txt","Re":1500,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4},
             {"Re":1500,"src":"retestc_3.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","clcd":6.12080866272639,"CDpres":0.05697,"alpha":7.3,"sym":3.88417008469547,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"CDf":0.06103,"Cpmin":-1.10862601191711,"CL":0.722280897210154,"CD":0.118004162033131,"n":8,"CDp":0.0420046894975683,"Cm":-0.0835594058290602,"id":113,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"good":5.86969641537052,"r":6},
             {"Cm":-0.0835594058290602,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":5.86969641537052,"xver":6.991,"iver":1.2020052,"id":114,"Cpmin":-1.10862601191711,"CDf":0.06103,"CDp":0.0420046894975683,"n":9,"CL":0.722280897210154,"CD":0.118004162033131,"alpha":7.3,"clcd":6.12080866272639,"CDpres":0.05697,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retest_70.txt","Re":1500,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4},
             {"CDp":0.0420046894975683,"n":10,"CD":0.118004162033131,"CL":0.722280897210154,"Cpmin":-1.10862601191711,"CDf":0.06103,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":5.86969641537052,"id":115,"Cm":-0.0835594058290602,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_71.txt","Re":1500,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":7.3,"clcd":6.12080866272639,"CDpres":0.05697},
             {"sym":0.000104152522855331,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"clcd":11.8032117950547,"CDpres":0.0186,"alpha":0,"diter":3,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"Re":1500,"src":"retesth_13.txt","cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"iver":1.2020052,"good":11.642789244969,"id":116,"r":6,"Cm":-0.000179312210725122,"n":11,"CD":0.0847227023765664,"CL":-7.3887704560909e-05,"CDp":0.00644776091368076,"CDf":0.06612,"Cpmin":-0.301299769907272},
             {"src":"retesth_14.txt","Re":1500,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":11.8032117950547,"CDpres":0.0186,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"sym":0.000104152522855331,"Cpmin":-0.301299769907272,"CDf":0.06612,"CDp":0.00644776091368076,"n":12,"CL":-7.3887704560909e-05,"CD":0.0847227023765664,"Cm":-0.000179312210725122,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"iver":1.2020052,"good":11.642789244969,"id":117},
             {"r":6,"id":118,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","good":11.642789244969,"iver":1.2020052,"Cm":-0.000179312210725122,"CDp":0.00644776091368076,"CD":0.0847227023765664,"CL":-7.3887704560909e-05,"n":13,"Cpmin":-0.301299769907272,"CDf":0.06612,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"clcd":11.8032117950547,"CDpres":0.0186,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","diter":3,"src":"retesth_15.txt","Re":1500},
             {"src":"retesth_16.txt","Re":1500,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":11.8032117950547,"CDpres":0.0186,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"sym":0.000104152522855331,"Cpmin":-0.301299769907272,"CDf":0.06612,"CDp":0.00644776091368076,"n":14,"CL":-7.3887704560909e-05,"CD":0.0847227023765664,"Cm":-0.000179312210725122,"r":6,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"good":11.642789244969,"id":119},
             {"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"CDpres":0.01428,"clcd":13.7277049895245,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"src":"retestg_5.txt","Re":2000,"r":6,"good":13.5263669381139,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"iver":1.2020052,"id":120,"Cm":-0.000189879506601768,"CDp":0.00634131213198223,"n":3,"CL":-5.03204565975465e-05,"CD":0.0728453882686937,"Cpmin":-0.32962383609735,"CDf":0.05856},
             {"Cm":-0.000189879506601768,"id":121,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"good":13.5263669381138,"iver":1.2020052,"r":6,"CDf":0.05856,"Cpmin":-0.32962383609735,"CL":-5.03204565975465e-05,"CD":0.0728453882686937,"n":4,"CDp":0.00634131213198223,"CDpres":0.01428,"clcd":13.7277049895245,"alpha":0,"sym":0.000104152522855331,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"Re":2000,"src":"retestg_6.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat"},
             {"Cm":-0.000189879506601768,"id":122,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","good":13.5263669381138,"xver":6.991,"iver":1.2020052,"r":6,"CDf":0.05856,"Cpmin":-0.32962383609735,"CL":-5.03204565975465e-05,"CD":0.0728453882686937,"n":5,"CDp":0.00634131213198223,"CDpres":0.01428,"clcd":13.7277049895245,"alpha":0,"sym":0.000104152522855331,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"Re":2000,"src":"retestg_7.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat"},
             {"CDp":0.00634131213198223,"n":6,"CL":-5.03204565975465e-05,"CD":0.0728453882686937,"Cpmin":-0.32962383609735,"CDf":0.05856,"r":6,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"good":13.5263669381138,"id":123,"Cm":-0.000189879506601768,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"src":"retestg_8.txt","Re":2000,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"clcd":13.7277049895245,"CDpres":0.01428},
             {"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"clcd":13.7277049895245,"CDpres":0.01428,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","diter":3,"src":"retestg_9.txt","Re":2000,"r":6,"id":124,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"good":13.5263669381138,"Cm":-0.000189879506601768,"CDp":0.00634131213198223,"CD":0.0728453882686937,"CL":-5.03204565975465e-05,"n":7,"Cpmin":-0.32962383609735,"CDf":0.05856},
             {"r":6,"id":125,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"xver":6.991,"good":13.5263669381138,"Cm":-0.000189879506601768,"CDp":0.00634131213198223,"CD":0.0728453882686937,"CL":-5.03204565975465e-05,"n":8,"Cpmin":-0.32962383609735,"CDf":0.05856,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"CDpres":0.01428,"clcd":13.7277049895245,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","diter":3,"src":"retestg_10.txt","Re":2000},
             {"Cpmin":-0.32962383609735,"CDf":0.05856,"CDp":0.00634131213198223,"CD":0.0728453882686937,"CL":-5.03204565975465e-05,"n":9,"Cm":-0.000189879506601768,"r":6,"id":126,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"xver":6.991,"good":13.5263669381138,"src":"retestg_11.txt","Re":2000,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","diter":3,"alpha":0,"clcd":13.7277049895245,"CDpres":0.01428,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"sym":0.000104152522855331},
             {"Cm":-0.000189879506601768,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","good":13.5263669381138,"xver":6.991,"iver":1.2020052,"id":127,"r":6,"CDf":0.05856,"Cpmin":-0.32962383609735,"n":10,"CD":0.0728453882686937,"CL":-5.03204565975465e-05,"CDp":0.00634131213198223,"clcd":13.7277049895245,"CDpres":0.01428,"alpha":0,"sym":0.000104152522855331,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"Re":2000,"src":"retestg_12.txt","diter":3,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1},
             {"src":"retestg_13.txt","Re":2000,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":13.7277049895245,"CDpres":0.01428,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"sym":0.000104152522855331,"Cpmin":-0.32962383609735,"CDf":0.05856,"CDp":0.00634131213198223,"n":11,"CL":-5.03204565975465e-05,"CD":0.0728453882686937,"Cm":-0.000189879506601768,"r":6,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"good":13.5263669381138,"id":128},
             {"CDf":0.05856,"Cpmin":-0.32962383609735,"n":12,"CD":0.0728453882686937,"CL":-5.03204565975465e-05,"CDp":0.00634131213198223,"Cm":-0.000189879506601768,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"iver":1.2020052,"good":13.5263669381138,"id":129,"r":6,"Re":2000,"src":"retestg_14.txt","diter":3,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"clcd":13.7277049895245,"CDpres":0.01428,"alpha":0,"sym":0.000104152522855331,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1},
             {"CDp":0.00634131213198223,"n":13,"CL":-5.03204565975465e-05,"CD":0.0728453882686937,"Cpmin":-0.32962383609735,"CDf":0.05856,"r":6,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"good":13.5263669381138,"id":130,"Cm":-0.000189879506601768,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"src":"retestg_15.txt","Re":2000,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"CDpres":0.01428,"clcd":13.7277049895245},
             {"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3,"src":"retestg_16.txt","Re":2000,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"sym":0.000104152522855331,"alpha":0,"clcd":13.7277049895245,"CDpres":0.01428,"CDp":0.00634131213198223,"n":14,"CD":0.0728453882686937,"CL":-5.03204565975465e-05,"Cpmin":-0.32962383609735,"CDf":0.05856,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","xver":6.991,"iver":1.2020052,"good":13.5263669381138,"id":131,"Cm":-0.000189879506601768},
             {"clcd":15.4338978988723,"CDpres":0.01291,"alpha":0,"sym":0.000104152522855331,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"Bot_Xtr":1,"Re":2500,"src":"retesti_13.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Cm":-0.000191183853723762,"id":132,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"good":15.1743821715952,"r":6,"CDf":0.05188,"Cpmin":-0.332860707896206,"CL":-3.63171117633165e-05,"CD":0.064792446247365,"n":3,"CDp":0.00569231139005472},
             {"diter":3,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"Re":2500,"src":"retesti_14.txt","sym":0.000104152522855331,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"CDpres":0.01291,"clcd":15.4338978988723,"alpha":0,"n":4,"CL":-3.63171117633165e-05,"CD":0.064792446247365,"CDp":0.00569231139005472,"CDf":0.05188,"Cpmin":-0.332860707896206,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"good":15.1743821749271,"id":133,"r":6,"Cm":-0.000191183853723762},
             {"r":6,"good":7.06028228851115,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"id":134,"Cm":-0.0875476624081798,"CDp":0.0332881486741785,"n":5,"CL":0.697766050930777,"CD":0.0937456635595206,"Cpmin":-0.979931430067607,"CDf":0.04799,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":6.3,"clcd":7.44318216370354,"CDpres":0.04575,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_90.txt","Re":2500},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4,"src":"retest_91.txt","Re":2500,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":6.3,"CDpres":0.04575,"clcd":7.44318216370354,"CDp":0.0332881486741785,"CD":0.0937456635595206,"CL":0.697766050930777,"n":6,"Cpmin":-0.979931430067607,"CDf":0.04799,"r":6,"id":135,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"xver":6.991,"good":7.06028228851115,"Cm":-0.0875476624081798},
             {"Cm":-0.0875476624081798,"r":6,"id":136,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":7.06028228851115,"xver":6.991,"iver":1.2020052,"Cpmin":-0.979931430067607,"CDf":0.04799,"CDp":0.0332881486741785,"CL":0.697766050930777,"CD":0.0937456635595206,"n":7,"alpha":6.3,"clcd":7.44318216370354,"CDpres":0.04575,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retest_92.txt","Re":2500,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4},
             {"alpha":6.3,"clcd":7.44318216370354,"CDpres":0.04575,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retest_93.txt","Re":2500,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"Cm":-0.0875476624081798,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"good":7.06028228851115,"id":137,"Cpmin":-0.979931430067607,"CDf":0.04799,"CDp":0.0332881486741785,"n":8,"CD":0.0937456635595206,"CL":0.697766050930777},
             {"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":2500,"src":"retest_94.txt","sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":7.44318216370354,"CDpres":0.04575,"alpha":6.3,"n":9,"CD":0.0937456635595206,"CL":0.697766050930777,"CDp":0.0332881486741785,"CDf":0.04799,"Cpmin":-0.979931430067607,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"good":7.06028228851115,"id":138,"r":6,"Cm":-0.0875476624081798},
             {"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":6.3,"CDpres":0.04575,"clcd":7.44318216370354,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_95.txt","Re":2500,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":7.06028228851115,"id":139,"Cm":-0.0875476624081798,"CDp":0.0332881486741785,"n":10,"CL":0.697766050930777,"CD":0.0937456635595206,"Cpmin":-0.979931430067607,"CDf":0.04799},
             {"n":11,"CL":0.697766050930777,"CD":0.0937456635595206,"CDp":0.0332881486741785,"CDf":0.04799,"Cpmin":-0.979931430067607,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":7.06028228851115,"id":140,"r":6,"Cm":-0.0875476624081798,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":2500,"src":"retest_96.txt","sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":7.44318216370354,"CDpres":0.04575,"alpha":6.3},
             {"alpha":6.3,"clcd":7.44318216370354,"CDpres":0.04575,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retest_97.txt","Re":2500,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4,"Cm":-0.0875476624081798,"r":6,"id":141,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":7.06028228851115,"Cpmin":-0.979931430067607,"CDf":0.04799,"CDp":0.0332881486741785,"CD":0.0937456635595206,"CL":0.697766050930777,"n":12},
             {"Cm":-0.000191183853723762,"r":6,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"good":15.1743821749272,"id":142,"Cpmin":-0.332860707896206,"CDf":0.05188,"CDp":0.00569231139005472,"n":13,"CD":0.064792446247365,"CL":-3.63171117633165e-05,"alpha":0,"clcd":15.4338978988723,"CDpres":0.01291,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"sym":0.000104152522855331,"src":"retesti_15.txt","Re":2500,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","Top_Xtr":1,"diter":3},
             {"Cpmin":-0.332860707896206,"CDf":0.05188,"CDp":0.00569231139005472,"CL":-3.63171117633165e-05,"CD":0.064792446247365,"n":14,"Cm":-0.000191183853723762,"r":6,"id":143,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ht21.dat-s17_n17s0.dat (opt78.6909719965785>53.038198124843) l1 Foil spline 17pts Re45000000 N10","iver":1.2020052,"xver":6.991,"good":15.1743821749272,"src":"retesti_16.txt","Re":2500,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_ht21.dat-s17_n17s0-Re45000000-N10-sq1.dat","diter":3,"alpha":0,"clcd":15.4338978988723,"CDpres":0.01291,"Bot_Xtr":1,"xy":[1,0,0.957968138815468,0.00732068314299526,0.882107264960607,0.0102784230697875,0.665111387186872,0.0173296189571501,0.505630406345119,0.0219364455570832,0.314681774746718,0.0262699755255652,0.133080801872824,0.0269058002213689,0.0317257601594004,0.0180299495087365,0,0,0.0300218096690704,-0.0176492750675619,0.128050952563939,-0.0268240198137589,0.311260879386817,-0.0262245819763714,0.51237298136662,-0.021601630643896,0.706680903852781,-0.0158814952697627,0.898312584767046,-0.00965823363887464,0.958902303559064,-0.00728970730118375,1,0],"sym":0.000104152522855331},
             {"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":7.9971642967171,"CDpres":0.04251,"alpha":6,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Re":3000,"src":"retest_100.txt","id":144,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":7.50846252512406,"r":6,"Cm":-0.0892273824507666,"CL":0.691774812690184,"CD":0.0865025135189686,"n":3,"CDp":0.0310430963912859,"CDf":0.044,"Cpmin":-0.947481316584859},
             {"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"CDpres":0.04251,"clcd":7.99716429671712,"alpha":6,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Re":3000,"src":"retest_101.txt","id":145,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":7.55515302657341,"iver":1.2020052,"r":6,"Cm":-0.0892273824507669,"CL":0.691774812690185,"CD":0.0865025135189685,"n":4,"CDp":0.0310430963912859,"CDf":0.044,"Cpmin":-0.947481316584859},
             {"n":5,"CD":0.0865025135189685,"CL":0.691774812690183,"CDp":0.0310430963912859,"CDf":0.044,"Cpmin":-0.947481316584857,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":7.55782403852407,"xver":6.991,"iver":1.2020052,"id":146,"r":6,"Cm":-0.0892273824507666,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":3000,"src":"retest_102.txt","sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":7.9971642967171,"CDpres":0.04251,"alpha":6},
             {"Cm":-0.0892273824507666,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"good":7.5578035222344,"id":147,"Cpmin":-0.947481316584857,"CDf":0.044,"CDp":0.0310430963912859,"n":6,"CD":0.0865025135189685,"CL":0.691774812690183,"alpha":6,"clcd":7.9971642967171,"CDpres":0.04251,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retest_103.txt","Re":3000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4},
             {"r":6,"id":148,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":7.5578035222344,"iver":1.2020052,"Cm":-0.0892273824507666,"CDp":0.0310430963912859,"CD":0.0865025135189685,"CL":0.691774812690183,"n":7,"Cpmin":-0.947481316584857,"CDf":0.044,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":6,"clcd":7.9971642967171,"CDpres":0.04251,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","diter":4,"src":"retest_104.txt","Re":3000},
             {"id":149,"good":7.5578035222344,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0892273824507666,"CD":0.0865025135189685,"CL":0.691774812690183,"n":8,"CDp":0.0310430963912859,"CDf":0.044,"Cpmin":-0.947481316584857,"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"CDpres":0.04251,"clcd":7.9971642967171,"alpha":6,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Re":3000,"src":"retest_105.txt"},
             {"src":"retest_106.txt","Re":3000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"alpha":6,"CDpres":0.04251,"clcd":7.9971642967171,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"Cpmin":-0.947481316584857,"CDf":0.044,"CDp":0.0310430963912859,"n":9,"CL":0.691774812690183,"CD":0.0865025135189685,"Cm":-0.0892273824507666,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"xver":6.991,"good":7.5578035222344,"id":150},
             {"Cpmin":-0.947481316584857,"CDf":0.044,"CDp":0.0310430963912859,"n":10,"CD":0.0865025135189685,"CL":0.691774812690183,"Cm":-0.0892273824507666,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"xver":6.991,"good":7.5578035222344,"id":151,"src":"retest_107.txt","Re":3000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"alpha":6,"CDpres":0.04251,"clcd":7.9971642967171,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547},
             {"Cm":-0.0892273824507666,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":7.5578035222344,"xver":6.991,"iver":1.2020052,"id":152,"Cpmin":-0.947481316584857,"CDf":0.044,"CDp":0.0310430963912859,"n":11,"CD":0.0865025135189685,"CL":0.691774812690183,"alpha":6,"clcd":7.9971642967171,"CDpres":0.04251,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"sym":3.88417008469547,"src":"retest_108.txt","Re":3000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4},
             {"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":7.9971642967171,"CDpres":0.04251,"alpha":6,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Re":3000,"src":"retest_109.txt","id":153,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","iver":1.2020052,"good":7.5578035222344,"r":6,"Cm":-0.0892273824507666,"CL":0.691774812690183,"CD":0.0865025135189685,"n":12,"CDp":0.0310430963912859,"CDf":0.044,"Cpmin":-0.947481316584857},
             {"Cm":-0.0892273824507666,"id":154,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","good":7.5578035222344,"iver":1.2020052,"r":6,"CDf":0.044,"Cpmin":-0.947481316584857,"CD":0.0865025135189685,"CL":0.691774812690183,"n":13,"CDp":0.0310430963912859,"clcd":7.9971642967171,"CDpres":0.04251,"alpha":6,"sym":3.88417008469547,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"Re":3000,"src":"retest_110.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat"},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":7.5578035222344,"iver":1.2020052,"id":155,"Cm":-0.0892273824507666,"CDp":0.0310430963912859,"n":14,"CL":0.691774812690183,"CD":0.0865025135189685,"Cpmin":-0.947481316584857,"CDf":0.044,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1,"sym":3.88417008469547,"alpha":6,"clcd":7.9971642967171,"CDpres":0.04251,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"diter":4,"src":"retest_111.txt","Re":3000},
             {"id":156,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":7.89316835509747,"r":6,"Cm":-0.0906482891845944,"CL":0.683501042513994,"CD":0.0804383414352308,"n":3,"CDp":0.0289372857818014,"CDf":0.04099,"Cpmin":-0.912801953693187,"sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"CDpres":0.03945,"clcd":8.49720457083705,"alpha":5.7,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Re":3500,"src":"retest_148.txt"},
             {"n":4,"CL":0.683501042513995,"CD":0.0804383414352308,"CDp":0.0289372857818015,"CDf":0.04099,"Cpmin":-0.912801953693189,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":7.99591740116897,"iver":1.2020052,"id":157,"r":6,"Cm":-0.0906482891845947,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"Re":3500,"src":"retest_149.txt","sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"CDpres":0.03945,"clcd":8.49720457083705,"alpha":5.7},
             {"CL":0.683501042513994,"CD":0.0804383414352309,"n":5,"CDp":0.0289372857818014,"CDf":0.04099,"Cpmin":-0.912801953693186,"id":158,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"iver":1.2020052,"good":8.00591579592584,"r":6,"Cm":-0.0906482891845942,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Re":3500,"src":"retest_150.txt","sym":3.88417008469547,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"clcd":8.49720457083703,"CDpres":0.03945,"alpha":5.7},
             {"CDf":0.04099,"Cpmin":-0.912801953693186,"n":6,"CD":0.0804383414352308,"CL":0.683501042513994,"CDp":0.0289372857818015,"Cm":-0.0906482891845944,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.51568951598784>5.26709719986121) l1 Foil spline 17pts Re1250 N7","xver":6.991,"good":8.00662262640633,"id":159,"r":6,"Re":3500,"src":"retest_151.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N7.dat","Top_Xtr":1,"clcd":8.49720457083705,"CDpres":0.03945,"alpha":5.7,"sym":3.88417008469547,"xy":[1,0,0.946714574040677,0.0173695342779075,0.854728633619417,0.0367401454705865,0.691363149797408,0.0586445583753673,0.513763139089403,0.0701544600580242,0.327229099655296,0.0680964556875464,0.155573716106985,0.051638674164185,0.0401397957317501,0.0247464560922927,0,0,0.0290164970646396,-0.00334747431922254,0.113543374367374,0.00520210473795831,0.264712879181914,0.0205132632700497,0.449425033656063,0.032309537214649,0.653083287629906,0.0342897716669164,0.83008632648885,0.0258950617226782,0.943258507857798,0.0126901733803455,1,0],"Bot_Xtr":1},
             {"alpha":5.7,"CDpres":0.03938,"clcd":8.48010475246148,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"sym":3.87362993702821,"src":"retest_107.txt","Re":3500,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"diter":4,"Cm":-0.0902370617756252,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","good":7.99059858480537,"iver":1.2020052,"id":160,"Cpmin":-0.911028713441467,"CDf":0.04104,"CDp":0.0288811785480826,"n":7,"CL":0.681970371410879,"CD":0.0804200409450045},
             {"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"diter":4,"src":"retest_108.txt","Re":3500,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"Bot_Xtr":1,"sym":3.87362993702821,"alpha":5.7,"clcd":8.48010475246148,"CDpres":0.03938,"CDp":0.0288811785480826,"n":8,"CL":0.681970371410879,"CD":0.0804200409450045,"Cpmin":-0.911028713441467,"CDf":0.04104,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"good":7.99060702990451,"iver":1.2020052,"id":161,"Cm":-0.0902370617756252},
             {"sym":3.87362993702821,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"CDpres":0.03938,"clcd":8.48010475246148,"alpha":5.7,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"Re":3500,"src":"retest_109.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","iver":1.2020052,"good":7.99061446235722,"id":162,"r":6,"Cm":-0.0902370617756252,"n":9,"CL":0.681970371410879,"CD":0.0804200409450045,"CDp":0.0288811785480826,"CDf":0.04104,"Cpmin":-0.911028713441467},
             {"Cpmin":-0.911028713441467,"CDf":0.04104,"CDp":0.0288811785480826,"CL":0.681970371410879,"CD":0.0804200409450045,"n":10,"Cm":-0.0902370617756252,"r":6,"id":163,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","good":7.99060746626364,"xver":6.991,"iver":1.2020052,"src":"retest_110.txt","Re":3500,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","diter":4,"alpha":5.7,"clcd":8.48010475246148,"CDpres":0.03938,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"sym":3.87362993702821},
             {"alpha":5.7,"CDpres":0.03938,"clcd":8.48010475246148,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0173807720207304,0.854728633619417,0.0367639156131515,0.691363149797408,0.0586825002369302,0.513763139089403,0.0701998485967954,0.327229099655296,0.0681405127384681,0.155573716106985,0.0516720833581615,0.0401397957317501,0.0247624665566433,0,0,0.0290164970646396,-0.00332728509807921,0.113543374367374,0.00517072990638385,0.264712879181914,0.020389544080883,0.449425033656063,0.0321146725705441,0.653083287629906,0.0340829638718088,0.83008632648885,0.0257388839367465,0.943258507857798,0.0126136366567471,1,0],"sym":3.87362993702821,"src":"retest_111.txt","Re":3500,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re1250-N11.dat","Top_Xtr":1,"diter":4,"Cm":-0.0902370617756252,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt5.507664890452>5.26709719986121) l1 Foil spline 17pts Re1250 N11","xver":6.991,"iver":1.2020052,"good":7.99060469533992,"id":164,"Cpmin":-0.911028713441467,"CDf":0.04104,"CDp":0.0288811785480826,"n":11,"CD":0.0804200409450045,"CL":0.681970371410879},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","iver":1.2020052,"xver":6.991,"good":7.87590985394645,"id":165,"r":6,"Cm":-0.0698652136884609,"n":12,"CL":0.659059329555633,"CD":0.0774785184297558,"CDp":0.0266880447792842,"CDf":0.03793,"Cpmin":-1.88606388179516,"sym":2.67247264764926,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"clcd":8.50634915216087,"CDpres":0.03954,"alpha":6.1,"diter":4,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","Top_Xtr":1,"Re":3500,"src":"retest_155.txt"},
             {"Cm":-0.0698652136884609,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","good":7.87590985394645,"xver":6.991,"iver":1.2020052,"id":166,"Cpmin":-1.88606388179516,"CDf":0.03793,"CDp":0.0266880447792842,"n":13,"CD":0.0774785184297558,"CL":0.659059329555633,"alpha":6.1,"CDpres":0.03954,"clcd":8.50634915216087,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"sym":2.67247264764926,"src":"retest_156.txt","Re":3500,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","Top_Xtr":1,"diter":4},
             {"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","Re":3500,"src":"retest_157.txt","sym":2.67247264764926,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"clcd":8.50634915216087,"CDpres":0.03954,"alpha":6.1,"CD":0.0774785184297558,"CL":0.659059329555633,"n":14,"CDp":0.0266880447792842,"CDf":0.03793,"Cpmin":-1.88606388179516,"id":167,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","good":7.87590985394645,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0698652136884609},
             {"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"sym":5.36696924573919,"alpha":5.2,"clcd":9.23580254487353,"CDpres":0.04209,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":4,"src":"retest_100.txt","Re":4500,"r":6,"id":168,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":8.55621337934186,"iver":1.2020052,"Cm":-0.118885565375374,"CDp":0.032202287497111,"CL":0.720511513411044,"CD":0.0780128754280238,"n":3,"Cpmin":-0.85698339851472,"CDf":0.03593},
             {"id":169,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"iver":1.2020052,"good":8.66799475450267,"r":6,"Cm":-0.118885565375374,"CD":0.0780128754280237,"CL":0.720511513411044,"n":4,"CDp":0.0322022874971109,"CDf":0.03593,"Cpmin":-0.85698339851472,"sym":5.36696924573919,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"clcd":9.23580254487355,"CDpres":0.04209,"alpha":5.2,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Re":4500,"src":"retest_101.txt"},
             {"Cpmin":-0.85698339851472,"CDf":0.03593,"CDp":0.0322022874971109,"CL":0.720511513411044,"CD":0.0780128754280237,"n":5,"Cm":-0.118885565375374,"r":6,"id":170,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","good":8.67635564632262,"xver":6.991,"iver":1.2020052,"src":"retest_102.txt","Re":4500,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":4,"alpha":5.2,"clcd":9.23580254487355,"CDpres":0.04209,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"sym":5.36696924573919},
             {"Re":4500,"n":6,"sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"CDpres":0.03313,"clcd":9.57786965312767,"alpha":5.5,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","src":"retest_66.txt","id":171,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":8.74561677315562,"iver":1.2020052,"r":6,"Cm":-0.0719750648243309,"CL":0.641127897774433,"CD":0.0669384655454224,"CDp":0.0227028458896287,"CDf":0.03381,"Cpmin":-1.19267623343833},        #dud
             {"Re":4500,"n":7,"sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"CDpres":0.03313,"clcd":9.57786965312767,"alpha":5.5,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","src":"retest_67.txt","id":172,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":8.75372705367609,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0719750648243309,"CL":0.641127897774433,"CD":0.0669384655454224,"CDp":0.0227028458896287,"CDf":0.03381,"Cpmin":-1.19267623343833},        #dud
             {"Re":4500,"n":8,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":8.75372308440475,"xver":6.991,"iver":1.2020052,"id":173,"r":6,"Cm":-0.0719750648243309,"CL":0.641127897774433,"CD":0.0669384655454224,"CDp":0.0227028458896287,"CDf":0.03381,"Cpmin":-1.19267623343833,"sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"CDpres":0.03313,"clcd":9.57786965312767,"alpha":5.5,"diter":4,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"src":"retest_68.txt"},        #dud
             {"Re":4500,"n":9,"Cm":-0.0719750648243309,"id":174,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"good":8.75372308440475,"iver":1.2020052,"r":6,"CDf":0.03381,"Cpmin":-1.19267623343833,"CD":0.0669384655454224,"CL":0.641127897774433,"CDp":0.0227028458896287,"clcd":9.57786965312767,"CDpres":0.03313,"alpha":5.5,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"src":"retest_69.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat"},        #dud
             {"Re":4500,"n":10,"Cm":-0.0719750648243309,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"xver":6.991,"good":8.75372308440475,"id":175,"Cpmin":-1.19267623343833,"CDf":0.03381,"CDp":0.0227028458896287,"CL":0.641127897774433,"CD":0.0669384655454224,"alpha":5.5,"clcd":9.57786965312767,"CDpres":0.03313,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"sym":2.34679265682815,"src":"retest_70.txt","Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":4},        #dud
             {"Re":4500,"n":11,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":4,"src":"retest_71.txt","xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":5.5,"CDpres":0.03313,"clcd":9.57786965312767,"CDp":0.0227028458896287,"CD":0.0669384655454224,"CL":0.641127897774433,"Cpmin":-1.19267623343833,"CDf":0.03381,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"xver":6.991,"good":8.75372308440475,"id":176,"Cm":-0.0719750648243309},        #dud
             {"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"diter":4,"src":"retest_78.txt","Re":4500,"xy":[1,0,0.946714574040677,0.0206894864849189,0.854728633619417,0.0437625287475022,0.691363149797408,0.0698536747450068,0.513763139089403,0.083563538895421,0.327229099655296,0.0811121747466966,0.155573716106985,0.0615087102581626,0.0401397957317501,0.0294764074084781,0,0,0.0290164970646396,-0.00417063589384079,0.113543374367374,0.00648132970552172,0.264712879181914,0.0255575828028294,0.449425033656063,0.0402546226708905,0.653083287629906,0.0427218072098193,0.83008632648885,0.0322627938543551,0.943258507857798,0.0158107538854619,1,0],"Bot_Xtr":1,"sym":5.66416392272273,"alpha":5.3,"clcd":8.73685165615135,"CDpres":0.04385,"CDp":0.0342430723802692,"n":12,"CD":0.0805598695473923,"CL":0.70383962967447,"Cpmin":-0.801414643835771,"CDf":0.03671,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt11.1277157272271>9.97612309699884) l1 Foil spline 17pts Re12500 N6","xver":6.991,"good":8.27496647053965,"iver":1.2020052,"id":177,"Cm":-0.114791929251039},
             {"Cm":-0.11410104426231,"id":178,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt10.8161311496198>10.2884581440255) l1 Foil spline 17pts Re15000 N7","xver":6.991,"iver":1.2020052,"good":7.93116422245225,"r":6,"CDf":0.03702,"Cpmin":-0.779456195173099,"CD":0.083122153888613,"CL":0.694181895661635,"n":13,"CDp":0.0361795926604674,"clcd":8.35134634013294,"CDpres":0.0461,"alpha":5.4,"sym":5.95661515284558,"xy":[1,0,0.946714574040677,0.0216141355295885,0.854728633619417,0.0457183520797148,0.691363149797408,0.0729755566567067,0.513763139089403,0.0872981384208941,0.327229099655296,0.0847372185555544,0.155573716106985,0.064257641229481,0.0401397957317501,0.0307937591934249,0,0,0.0290164970646396,-0.00409858511907259,0.113543374367374,0.00636936001104405,0.264712879181914,0.02511605693267,0.449425033656063,0.039559194725305,0.653083287629906,0.0419837568531553,0.83008632648885,0.0317054305762934,0.943258507857798,0.0155376115886723,1,0],"Bot_Xtr":1,"Re":4500,"src":"retest_6.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re15000-N7.dat"},
             {"CDp":0.0860745509709568,"CD":0.136023289146565,"CL":0.77660530614395,"n":14,"Cpmin":-0.798346252071908,"CDf":0.03719,"r":6,"id":179,"xver":6.991,"cmt":"NEWv1.20200520 s(0) foildb2020/naca9509.dat (sim 0.000190720253 ) l1 Foil spline 17pts","good":5.61533846056246,"iver":1.2020052,"Cm":-0.139479826697256,"Top_Xtr":1,"Foil_fn":"spline_foil_naca9509.dat-s17_n17s0.dat","diter":4,"src":"retest_158.txt","Re":4500,"xy":[1,0,0.868404934428401,0.0548257517349933,0.722773919369552,0.097239400253242,0.589947936661528,0.120675069773583,0.454088707914007,0.129431781311308,0.287832380408253,0.117360928102374,0.125929559573223,0.0756632887896152,0.0322921917674163,0.0302258769020873,0,0,0.0267824752538243,-0.0136071280290676,0.143907937879878,0.00215488044314032,0.289174939313896,0.027400906199305,0.448922595264423,0.0457237392307359,0.584696204855116,0.0510788063378944,0.710872136082522,0.046495427158662,0.847616132436765,0.0305866277227292,1,0],"Bot_Xtr":1,"sym":10.2403165203052,"alpha":8.6,"clcd":5.7093554421196,"CDpres":0.09883},
             {"Re":5500,"src":"retest_108.txt","diter":4,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Top_Xtr":1,"clcd":9.94592340217396,"CDpres":0.03949,"alpha":4.9,"sym":5.36696924573919,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"CDf":0.03255,"Cpmin":-0.836651429823286,"n":3,"CL":0.716528022860424,"CD":0.0720423829831433,"CDp":0.0304584278878545,"Cm":-0.121537016786333,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":9.09017721048611,"iver":1.2020052,"id":180,"r":6},
             {"sym":5.36696924573919,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"clcd":9.94592340217395,"CDpres":0.03949,"alpha":4.9,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Re":5500,"src":"retest_109.txt","id":181,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":9.25127325609607,"r":6,"Cm":-0.121537016786333,"CD":0.0720423829831433,"CL":0.716528022860424,"n":4,"CDp":0.0304584278878546,"CDf":0.03255,"Cpmin":-0.836651429823286},
             {"CDp":0.0304584278878545,"CL":0.716528022860423,"CD":0.0720423829831434,"n":5,"Cpmin":-0.836651429823285,"CDf":0.03255,"r":6,"id":182,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":9.28256261961411,"Cm":-0.121537016786333,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":4,"src":"retest_110.txt","Re":5500,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"sym":5.36696924573919,"alpha":4.9,"CDpres":0.03949,"clcd":9.94592340217393},
             {"Re":5500,"n":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"good":9.40164760961263,"iver":1.2020052,"id":183,"r":6,"Cm":-0.073630115977925,"CD":0.0613800776033395,"CL":0.639442968253351,"CDp":0.0212155536759922,"CDf":0.03063,"Cpmin":-1.1761053113643,"sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"CDpres":0.03075,"clcd":10.4177608308948,"alpha":5.3,"diter":4,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"src":"retest_75.txt"},        #dud
             {"Re":5500,"n":7,"CD":0.0613800776033395,"CL":0.63944296825335,"CDp":0.0212155536759922,"CDf":0.03063,"Cpmin":-1.1761053113643,"id":184,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"good":9.4710422726572,"r":6,"Cm":-0.0736301159779249,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","src":"retest_76.txt","sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"CDpres":0.03075,"clcd":10.4177608308947,"alpha":5.3},        #dud
             {"Re":5500,"n":8,"r":6,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":9.47723812414555,"iver":1.2020052,"id":185,"Cm":-0.0736301159779252,"CDp":0.0212155536759922,"CD":0.0613800776033395,"CL":0.639442968253351,"Cpmin":-1.1761053113643,"CDf":0.03063,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":5.3,"CDpres":0.03075,"clcd":10.4177608308948,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":4,"src":"retest_77.txt",},        #dud
             {"Re":5500,"n":9,"CDf":0.03063,"Cpmin":-1.1761053113643,"CL":0.639442968253351,"CD":0.0613800776033395,"CDp":0.0212155536759922,"Cm":-0.0736301159779252,"good":9.47724012128738,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"id":186,"r":6,"src":"retest_78.txt","diter":4,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"clcd":10.4177608308948,"CDpres":0.03075,"alpha":5.3,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1},        #dud
             {"Re":5500,"n":10,"Cm":-0.0736301159779252,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":9.47724012128738,"iver":1.2020052,"id":187,"r":6,"CDf":0.03063,"Cpmin":-1.1761053113643,"CL":0.639442968253351,"CD":0.0613800776033395,"CDp":0.0212155536759922,"clcd":10.4177608308948,"CDpres":0.03075,"alpha":5.3,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"src":"retest_79.txt","diter":4,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1},        #dud
             {"Re":5500,"n":11,"CDpres":0.03075,"clcd":10.4177608308948,"alpha":5.3,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"src":"retest_80.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Cm":-0.0736301159779252,"id":188,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"good":9.47724012128738,"r":6,"CDf":0.03063,"Cpmin":-1.1761053113643,"CD":0.0613800776033395,"CL":0.639442968253351,"CDp":0.0212155536759922},        #dud
             {"Cm":-0.0739075321186992,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","good":9.36637874394349,"xver":6.991,"iver":1.2020052,"id":189,"r":6,"CDf":0.03064,"Cpmin":-1.78890499425225,"n":12,"CD":0.0633595099154889,"CL":0.647173596632379,"CDp":0.0222700978671398,"clcd":10.214308751687,"CDpres":0.03272,"alpha":5.5,"sym":2.67247264764926,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"Bot_Xtr":1,"Re":5500,"src":"retest_66.txt","diter":4,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","Top_Xtr":1},
             {"Cpmin":-1.78890499425225,"CDf":0.03064,"CDp":0.0222700978671398,"CL":0.647173596632379,"CD":0.0633595099154889,"n":13,"Cm":-0.0739075321186992,"r":6,"id":190,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","xver":6.991,"good":9.36637874394349,"src":"retest_67.txt","Re":5500,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","diter":4,"alpha":5.5,"clcd":10.214308751687,"CDpres":0.03272,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"sym":2.67247264764926},
             {"id":191,"good":9.36637874394349,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0739075321186992,"CL":0.647173596632379,"CD":0.0633595099154889,"n":14,"CDp":0.0222700978671398,"CDf":0.03064,"Cpmin":-1.78890499425225,"sym":2.67247264764926,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"clcd":10.214308751687,"CDpres":0.03272,"alpha":5.5,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","Re":5500,"src":"retest_68.txt"},
             {"Re":7000,"n":3,"CD":0.0808408562928742,"CL":0.836669903380778,"CDp":0.0442674708147382,"CDf":0.02476,"Cpmin":-1.22638705623617,"id":192,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid151a.dat-s17_n17s0.dat (opt12.793176940688>12.6295180489583) l1 Foil spline 17pts Re25000 N4","xver":6.991,"iver":1.2020052,"good":7.22194207544592,"r":6,"Cm":-0.11866338176427,"diter":4,"Top_Xtr":0.755129827505306,"Foil_fn":"optbs_spline_mid151a.dat-s17_n17s0_nsopt-Re25000-N4.dat","src":"retest_147.txt","sym":3.86153476593077,"Bot_Xtr":1,"xy":[1,0,0.870588443819102,0.0319527254023728,0.713516798884012,0.0574967571223721,0.580442629593444,0.070406247601661,0.42583065729969,0.0771425034081745,0.229768114218089,0.0728024803677191,0.081788256748409,0.0499761552930452,0.010957950883341,0.0179477892572116,0,0,0.0162649038866205,-0.00766319777259635,0.04389732811481,-0.0113088836409753,0.149688687874769,-0.00627460044700536,0.394602510713099,0.0199568058945888,0.578063605817522,0.0347780417470268,0.727546442647447,0.034399725145672,0.841413116633622,0.0241956602013736,1,0],"clcd":10.3495922946394,"CDpres":0.05608,"alpha":6.4},        #dud
             {"CDp":0.0288324218014457,"n":4,"CD":0.0658735753034754,"CL":0.71445639299884,"Cpmin":-0.818085909452138,"CDf":0.02886,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":9.99599858606985,"id":193,"Cm":-0.124680119096424,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Top_Xtr":1,"diter":4,"src":"retest_154.txt","Re":7000,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"sym":5.36696924573919,"alpha":4.6,"clcd":10.8458724110143,"CDpres":0.03701},
             {"CDpres":0.03701,"clcd":10.8458724110143,"alpha":4.6,"sym":5.36696924573919,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"Re":7000,"src":"retest_155.txt","diter":4,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Top_Xtr":1,"Cm":-0.124680119096424,"good":10.0552524894793,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"iver":1.2020052,"id":194,"r":6,"CDf":0.02886,"Cpmin":-0.818085909452138,"n":5,"CL":0.714456392998839,"CD":0.0658735753034755,"CDp":0.0288324218014458},
             {"Re":7000,"n":6,"Cm":-0.0755842989023312,"r":6,"id":195,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"good":10.2909229846622,"Cpmin":-1.14345897440767,"CDf":0.02736,"CDp":0.0191886924008914,"CD":0.0549946098064768,"CL":0.632588042714322,"alpha":5,"CDpres":0.02763,"clcd":11.5027280844498,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"sym":2.34679265682815,"src":"retest_84.txt","Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","diter":4},        #dud
             {"Re":7000,"n":7,"Cm":-0.0755842989023313,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":10.334041041082,"xver":6.991,"iver":1.2020052,"id":196,"r":6,"CDf":0.02736,"Cpmin":-1.14345897440767,"CL":0.632588042714322,"CD":0.0549946098064768,"CDp":0.0191886924008914,"CDpres":0.02763,"clcd":11.5027280844499,"alpha":5,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"src":"retest_85.txt","diter":4,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1},        #dud
             {"Re":7000,"n":8,"src":"retest_86.txt","diter":4,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"clcd":11.5027280844499,"CDpres":0.02763,"alpha":5,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"CDf":0.02736,"Cpmin":-1.14345897440767,"CD":0.0549946098064768,"CL":0.632588042714322,"CDp":0.0191886924008914,"Cm":-0.0755842989023312,"good":10.3996066324678,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"id":197,"r":6},        #dud
             {"Re":7000,"n":9,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"good":10.4054964436173,"id":198,"Cm":-0.0755842989023313,"CDp":0.0191886924008914,"CD":0.0549946098064768,"CL":0.632588042714322,"Cpmin":-1.14345897440767,"CDf":0.02736,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":5,"clcd":11.5027280844498,"CDpres":0.02763,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":4,"src":"retest_87.txt",},        #dud
             {"Re":7000,"n":10,"sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"clcd":11.5027280844538,"CDpres":0.02763,"alpha":5,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","src":"retest_88.txt","id":199,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"good":10.4055035424344,"r":6,"Cm":-0.0755842989024121,"CD":0.0549946098064914,"CL":0.632588042714708,"CDp":0.0191886924008987,"CDf":0.02736,"Cpmin":-1.1434589744091},        #dud
             {"Re":7000,"n":11,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":5,"CDpres":0.02763,"clcd":11.5027280844538,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":4,"src":"retest_89.txt","r":6,"good":10.4055023663075,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"id":200,"Cm":-0.0755842989024121,"CDp":0.0191886924008987,"CD":0.0549946098064914,"CL":0.632588042714708,"Cpmin":-1.1434589744091,"CDf":0.02736},        #dud
             {"Cpmin":-1.79231211535321,"CDf":0.02711,"CDp":0.0209673550440195,"CD":0.0576433406108348,"CL":0.646922829580325,"n":12,"Cm":-0.0761168656431849,"r":6,"id":201,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","xver":6.991,"good":10.2406974991037,"src":"retest_78.txt","Re":7000,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","diter":4,"alpha":5.3,"clcd":11.2228545869309,"CDpres":0.03053,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"sym":2.67247264764926},
             {"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","Top_Xtr":1,"diter":4,"src":"retest_79.txt","Re":7000,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"Bot_Xtr":1,"sym":2.67247264764926,"alpha":5.3,"clcd":11.2228545869309,"CDpres":0.03053,"CDp":0.0209673550440195,"n":13,"CL":0.646922829580325,"CD":0.0576433406108348,"Cpmin":-1.79231211535321,"CDf":0.02711,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","xver":6.991,"good":10.2406957771734,"iver":1.2020052,"id":202,"Cm":-0.0761168656431849},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re1500-N11.dat","diter":4,"src":"retest_80.txt","Re":7000,"xy":[1,0,0.932888316288692,0.018144507961463,0.790017354891618,0.043985561199883,0.601959273332201,0.0603857568255768,0.382453204572511,0.0617762965836275,0.200384671554421,0.0491595427701865,0.116944579071743,0.0372748911508391,0.0451296130806224,0.0222289846551098,0,0,0.031935439186916,-0.00472225316556875,0.0817149379280138,-0.000189804822883236,0.178982980222827,0.00908150124993006,0.301974084079985,0.016485383388128,0.511035570473631,0.0233888473001156,0.710372454413702,0.0220247285518101,0.907539857851309,0.0151050641362942,1,0],"Bot_Xtr":1,"sym":2.67247264764926,"alpha":5.3,"CDpres":0.03053,"clcd":11.2228545869309,"CDp":0.0209673550440195,"CL":0.646922829580325,"CD":0.0576433406108348,"n":14,"Cpmin":-1.79231211535321,"CDf":0.02711,"r":6,"id":203,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt5.71737958398965>5.37450101663268) l1 Foil spline 17pts Re1500 N11","iver":1.2020052,"xver":6.991,"good":10.2406965596132,"Cm":-0.0761168656431849},
             {"r":6,"id":204,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe396.dat-s17_n17s0.dat (opt7.57695241720921>7.52942641120104) l1 Foil spline 17pts Re8192 N3","xver":6.991,"good":7.57695236223499,"iver":1.2020052,"Cm":-0.0877686097585578,"CDp":0.037477267336803,"CL":0.77393730102286,"CD":0.0742188182444565,"n":3,"Cpmin":-1.31429062070536,"CDf":0.02648,"xy":[1,0,0.910648798765237,0.0177018724948139,0.684314248787321,0.0548474135496316,0.479115813972853,0.0743351842680239,0.302094621366809,0.0743200804597049,0.168581079577418,0.0587912669890755,0.0720930845483887,0.0372832270691131,0.0279165583128725,0.0196639464748742,0,0,0.0123787654854006,-0.00493625395513853,0.0434818912828438,-0.00381434470326531,0.0959112242522722,0.00320411255611358,0.208919327183629,0.0200716912271603,0.386612592501753,0.0333033328737691,0.634028359351713,0.0244842448369269,0.925305417465977,0.00334660870645821,1,0],"Bot_Xtr":1,"sym":3.74123620169456,"alpha":6.3,"CDpres":0.04773,"clcd":10.4277772043435,"Top_Xtr":0.809325379847449,"Foil_fn":"optbs_spline_goe396.dat-s17_n17s0_nsopt-Re8192-N3.dat","diter":3,"src":"retest_27.txt","Re":8192},
             {"CDp":0.0277892422211028,"CD":0.0621441282504418,"CL":0.711950985745323,"n":4,"Cpmin":-0.803716545283169,"CDf":0.02669,"r":6,"id":205,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":10.4510142326937,"iver":1.2020052,"Cm":-0.126658849236794,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":4,"src":"retestc_4.txt","Re":8192,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"sym":5.36696924573919,"alpha":4.4,"clcd":11.4564481921148,"CDpres":0.03546},
             {"clcd":11.4564481921227,"CDpres":0.03546,"alpha":4.4,"sym":5.36696924573919,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"Re":8192,"src":"retest_126.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Cm":-0.126658849236939,"id":206,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":10.5737493621685,"r":6,"CDf":0.02669,"Cpmin":-0.803716545284148,"CD":0.0621441282504729,"CL":0.711950985746171,"n":5,"CDp":0.0277892422211069},
             {"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"Bot_Xtr":1,"sym":5.36696924573919,"alpha":4.4,"clcd":11.4564481921227,"CDpres":0.03546,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Top_Xtr":1,"diter":4,"src":"retest_127.txt","Re":8192,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":10.6044252588873,"id":207,"Cm":-0.126658849236939,"CDp":0.0277892422211069,"n":6,"CD":0.0621441282504729,"CL":0.711950985746171,"Cpmin":-0.803716545284148,"CDf":0.02669},
             {"Re":8192,"n":7,"CD":0.0511814197013277,"CL":0.627134165644512,"CDp":0.0179445358557919,"CDf":0.02545,"Cpmin":-1.11861268043469,"id":208,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","good":10.9444478275046,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0768590054819943,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","src":"retest_94.txt","sym":2.34679265682815,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"CDpres":0.02573,"clcd":12.253160801404,"alpha":4.8},        #dud
             {"Re":8192,"n":8,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"xver":6.991,"good":10.9947899309947,"id":209,"Cm":-0.0768590054819943,"CDp":0.0179445358557918,"CD":0.0511814197013276,"CL":0.627134165644513,"Cpmin":-1.11861268043469,"CDf":0.02545,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":4.8,"CDpres":0.02573,"clcd":12.253160801404,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":3,"src":"retest_95.txt",},        #dud
             {"Re":8192,"n":9,"src":"retest_96.txt","Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"diter":3,"alpha":4.8,"clcd":12.2531608014039,"CDpres":0.02573,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"sym":2.34679265682815,"Cpmin":-1.11861268043469,"CDf":0.02545,"CDp":0.0179445358557919,"CD":0.0511814197013277,"CL":0.627134165644512,"Cm":-0.0768590054819943,"r":6,"good":11.0530054368549,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"id":210},        #dud
             {"Re":8192,"n":10,"src":"retest_97.txt","diter":3,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":1,"clcd":12.253160801404,"CDpres":0.02573,"alpha":4.8,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"CDf":0.02545,"Cpmin":-1.11861268043469,"CD":0.0511814197013277,"CL":0.627134165644512,"CDp":0.0179445358557919,"Cm":-0.0768590054819943,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"good":11.0530070998389,"id":211,"r":6},        #dud
             {"Re":8192,"n":11,"CDp":0.0179445358557918,"CL":0.627134165644513,"CD":0.0511814197013277,"Cpmin":-1.11861268043469,"CDf":0.02545,"r":6,"id":212,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"xver":6.991,"good":11.0530041522553,"Cm":-0.0768590054819943,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","diter":3,"src":"retest_98.txt","xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":4.8,"clcd":12.253160801404,"CDpres":0.02573},        #dud
             {"alpha":5.1,"clcd":11.7429938566467,"CDpres":0.02932,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"sym":2.88024052520835,"src":"retest_64.txt","Re":8192,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"diter":4,"Cm":-0.0808438543700963,"r":6,"good":10.7420420588089,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","xver":6.991,"iver":1.2020052,"id":213,"Cpmin":-1.50318454462594,"CDf":0.02565,"CDp":0.0206715653693504,"n":12,"CL":0.645528126986518,"CD":0.0549713416243626},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","iver":1.2020052,"xver":6.991,"good":10.7420417624095,"id":214,"Cm":-0.0808438543700963,"CDp":0.0206715653693504,"n":13,"CD":0.0549713416243626,"CL":0.645528126986518,"Cpmin":-1.50318454462594,"CDf":0.02565,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"Bot_Xtr":1,"sym":2.88024052520835,"alpha":5.1,"CDpres":0.02932,"clcd":11.7429938566467,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"diter":4,"src":"retest_65.txt","Re":8192},
             {"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Re":8192,"src":"retest_66.txt","sym":2.88024052520835,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"CDpres":0.02932,"clcd":11.7429938566467,"alpha":5.1,"CD":0.0549713416243626,"CL":0.645528126986518,"n":14,"CDp":0.0206715653693504,"CDf":0.02565,"Cpmin":-1.50318454462594,"id":215,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","xver":6.991,"iver":1.2020052,"good":10.7420385091926,"r":6,"Cm":-0.0808438543700963},
             {"Re":10000,"src":"retest_109.txt","diter":4,"Foil_fn":"optbs_spline_mid34_F3J_F5J.dat-s17_n17s0_nsopt-Re10000-N3.dat","Top_Xtr":0.589160127888905,"CDpres":0.02932,"clcd":14.9943136471783,"alpha":5.3,"sym":0.746502431487176,"xy":[1,0,0.867855831895755,0.0186608280081223,0.727999275220985,0.0265871709300405,0.586393873923742,0.0375273765048525,0.439252978319006,0.0456247186756394,0.328548715392245,0.0481565665007702,0.168740207268058,0.0454883245071082,0.0464948375930086,0.0267004036114198,0,4.27693591081943e-11,0.0473910407549042,-0.0105014751023156,0.186537339825854,-0.0100612075531098,0.31824671471519,-0.00520175631380886,0.460162144938495,-0.000266125171470999,0.600229568311338,0.00326835471546946,0.736228014462223,0.00472077236110022,0.875972029411257,0.00381996446940867,1,0],"Bot_Xtr":1,"CDf":0.01933,"Cpmin":-1.73451811505479,"n":3,"CD":0.048655280025971,"CL":0.729552529300699,"CDp":0.0200809917568805,"Cm":-0.052572727327249,"good":7.32175240718394,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid34_F3J_F5J.dat-s17_n17s0.dat (opt7.32175240718603>6.89147873620148) l1 Foil spline 17pts Re10000 N3","xver":6.991,"iver":1.2020052,"id":216,"r":6},
             {"Re":10000,"n":4,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"good":7.57661768646568,"iver":1.2020052,"id":217,"Cm":-0.0889009293399438,"CDp":0.0236153931584183,"CD":0.0540354118984594,"CL":0.983853596224701,"Cpmin":-3.50495373872068,"CDf":0.01503,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"sym":2.34679265682815,"alpha":6.5,"clcd":18.2075709550157,"CDpres":0.03901,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":0.394786792335344,"diter":12,"src":"retest_100.txt",},        #dud
             {"id":218,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt10.9676848705336>9.49591877050334) l1 Foil spline 17pts Re10000 N5","good":10.967711679928,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.124939518135493,"CL":0.677196919787639,"CD":0.0567683708324918,"n":5,"CDp":0.0257851580532225,"CDf":0.0245,"Cpmin":-0.693345912119897,"sym":5.43181097300436,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0199170368962341,0.854728633619417,0.042128638638366,0.691363149797408,0.0672456621022456,0.513763139089403,0.0804436634313361,0.327229099655296,0.0780838218648554,0.155573716106985,0.0592122599342706,0.0401397957317501,0.0283758948947827,0,0,0.0290164970646396,-0.00423817692092198,0.113543374367374,0.00658629107743367,0.264712879181914,0.0259714730191307,0.449425033656063,0.0409065229156405,0.653083287629906,0.0434136620758787,0.83008632648885,0.0327852710709948,0.943258507857798,0.0160667998658672,1,0],"clcd":11.929123733106,"CDpres":0.03226,"alpha":3.9,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re10000-N5.dat","Re":10000,"src":"retestc_15.txt"},
             {"alpha":4.1,"CDpres":0.03313,"clcd":12.2551410292966,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"sym":5.36696924573919,"src":"retest_135.txt","Re":10000,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":4,"Cm":-0.129084818433361,"r":6,"id":219,"good":11.2448828681112,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"iver":1.2020052,"Cpmin":-0.776623986808764,"CDf":0.02435,"CDp":0.0262175805824594,"CD":0.0574817027378014,"CL":0.70444637365586,"n":6},
             {"Cm":-0.129084818433361,"r":6,"id":220,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":11.2740128721009,"iver":1.2020052,"Cpmin":-0.776623986808764,"CDf":0.02435,"CDp":0.0262175805824594,"CL":0.70444637365586,"CD":0.0574817027378014,"n":7,"alpha":4.1,"CDpres":0.03313,"clcd":12.2551410292966,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"sym":5.36696924573919,"src":"retest_136.txt","Re":10000,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":4},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","xver":6.991,"iver":1.2020052,"good":11.3587791653913,"id":221,"Cm":-0.0827067606154131,"CDp":0.0196040386526785,"n":8,"CD":0.0508602981167702,"CL":0.641929233321548,"Cpmin":-1.44543153345342,"CDf":0.0233,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"Bot_Xtr":1,"sym":2.88024052520835,"alpha":4.9,"CDpres":0.02756,"clcd":12.6214209725579,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"diter":4,"src":"retest_72.txt","Re":10000},
             {"Re":10000,"n":9,"Cm":-0.0784522196765174,"id":222,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"xver":6.991,"good":11.8384197848242,"r":6,"CDf":0.02314,"Cpmin":-1.09688529312914,"CD":0.047010801504075,"CL":0.622974512454614,"CDp":0.0167618169458725,"CDpres":0.02387,"clcd":13.2517313579649,"alpha":4.6,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"src":"retest_105.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat"},        #dud
             {"Re":10000,"n":10,"CDf":0.02314,"Cpmin":-1.09688529312914,"CL":0.622974512454613,"CD":0.0470108015040751,"CDp":0.0167618169458725,"Cm":-0.0784522196765173,"id":223,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"good":11.8960643991898,"r":6,"src":"retest_106.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","clcd":13.2517313579649,"CDpres":0.02387,"alpha":4.6,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1},        #dud
             {"Re":10000,"n":11,"src":"retest_107.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","clcd":13.2517313579649,"CDpres":0.02387,"alpha":4.6,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"CDf":0.02314,"Cpmin":-1.09688529312914,"CD":0.0470108015040751,"CL":0.622974512454614,"CDp":0.0167618169458725,"Cm":-0.0784522196765172,"id":224,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","iver":1.2020052,"good":11.8988399353593,"r":6},        #dud
             {"n":12,"CD":0.0530559644990689,"CL":0.675861301017882,"CDp":0.021759067800428,"CDf":0.02427,"Cpmin":-0.826540846727242,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.41522478026>12.3257402013722) l1 Foil spline 17pts Re25000 N11","xver":6.991,"iver":1.2020052,"good":11.71783870624,"id":225,"r":6,"Cm":-0.107034136726917,"diter":3,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re25000-N11.dat","Top_Xtr":1,"Re":10000,"src":"retest_148.txt","sym":4.02815685280864,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0334416245909756,0.724865975963962,0.060484230711275,0.512480027985969,0.0721848655413721,0.336073009809416,0.0690641996803086,0.224244466354051,0.0606837894541856,0.126806077178113,0.0468710817005621,0.0410787060933097,0.0250965833705678,0,0,0.0283459581556997,-0.00516782327111456,0.0784008671678989,-0.00209323795522636,0.103458959629261,0.000491464976179716,0.213799276880961,0.0140989773246022,0.400704281820966,0.0287721422854831,0.651800254290461,0.0350093776277712,0.880021621959914,0.0234678202974621,1,0],"clcd":12.7386488474777,"CDpres":0.02879,"alpha":4.4},
             {"Re":10000,"n":13,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","diter":3,"src":"retest_148.txt","xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"Bot_Xtr":1,"sym":2.47986741752562,"alpha":4.6,"CDpres":0.0245,"clcd":13.1444625525693,"CDp":0.0174205664596861,"CL":0.627581131167006,"CD":0.0477449061653976,"Cpmin":-1.0889787577602,"CDf":0.02325,"r":6,"id":226,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"good":11.8444066754099,"iver":1.2020052,"Cm":-0.0811402881097706},        #dud
             {"Cm":-0.107034136726917,"r":6,"id":227,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.41522478026>12.3257402013722) l1 Foil spline 17pts Re25000 N11","good":11.7178323202226,"iver":1.2020052,"Cpmin":-0.826540846727243,"CDf":0.02427,"CDp":0.021759067800428,"CL":0.675861301017883,"CD":0.0530559644990689,"n":14,"alpha":4.4,"clcd":12.7386488474777,"CDpres":0.02879,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0334416245909756,0.724865975963962,0.060484230711275,0.512480027985969,0.0721848655413721,0.336073009809416,0.0690641996803086,0.224244466354051,0.0606837894541856,0.126806077178113,0.0468710817005621,0.0410787060933097,0.0250965833705678,0,0,0.0283459581556997,-0.00516782327111456,0.0784008671678989,-0.00209323795522636,0.103458959629261,0.000491464976179716,0.213799276880961,0.0140989773246022,0.400704281820966,0.0287721422854831,0.651800254290461,0.0350093776277712,0.880021621959914,0.0234678202974621,1,0],"sym":4.02815685280864,"src":"retest_150.txt","Re":10000,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re25000-N11.dat","diter":3},
             {"Re":12500,"n":3,"CDpres":0.03019,"clcd":21.0471076134773,"alpha":6.1,"sym":2.34679265682815,"xy":[1,0,0.929108869578711,0.0186920367706042,0.810731849907413,0.0385434946701093,0.632771041968728,0.0545352004313088,0.400628633190993,0.0587958719156624,0.234054815995728,0.0506109178262005,0.150822785333074,0.0424327109972064,0.0831000552881464,0.0313653578547664,0.0212179764407992,0.0151439568829887,0,0,0.00765047037479315,-0.00458663645547244,0.0288620880716639,-0.00669585491169238,0.108544117736146,-0.00191827153212827,0.174711230942372,0.00353930818576663,0.274245774017556,0.0104171630136255,0.491712653700056,0.0217661706844145,0.704228601122901,0.0238965538480712,0.900679019477577,0.0152581869181391,1,0],"Bot_Xtr":1,"src":"retest_108.txt","diter":12,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re12500-N5-sq1.dat","Top_Xtr":0.420457698734567,"Cm":-0.0884517849796078,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.50090355844685>6.00772572253057) l1 Foil spline 19pts Re12500 N5","xver":6.991,"iver":1.2020052,"good":8.02466471731953,"id":228,"r":6,"CDf":0.01433,"Cpmin":-3.30154347611756,"CL":0.936930554673197,"CD":0.0445158817961876,"CDp":0.0169197254278516},        #dud
             {"Cm":-0.0780099005771505,"r":6,"id":229,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103c3.dat-s17_n17s0.dat (opt8.85144670318478>8.5855445926956) l1 Foil spline 17pts Re15000 N5","iver":1.2020052,"xver":6.991,"good":8.0632924216745,"Cpmin":-2.13944290198984,"CDf":0.01616,"CDp":0.0243105609728563,"CL":0.854148841089578,"CD":0.050251658920148,"n":4,"alpha":5.8,"clcd":16.9974257456228,"CDpres":0.03409,"Bot_Xtr":1,"xy":[1,0,0.878975273482532,0.02065300147736,0.693171356185715,0.0416787959485658,0.544333140623122,0.0526179254448334,0.407469712002341,0.0588695731250507,0.22072973095756,0.0591667317441808,0.076291614436262,0.043075133973877,0.00869208529312013,0.0167110058527757,0,0,0.0187574897119247,-0.00877429876878116,0.0549926622788392,-0.0147019052702624,0.176538175043836,-0.0142743135833706,0.441887065428039,0.005088908833351,0.574320105122134,0.0134597764106829,0.692814874122089,0.0162485447064551,0.809542173172325,0.0134002211113766,1,0],"sym":1.51962099877062,"src":"retest_148.txt","Re":12500,"Top_Xtr":0.547666212205091,"Foil_fn":"optbs_spline_mid103c3.dat-s17_n17s0_nsopt-Re15000-N5.dat","diter":4},
             {"CDpres":0.02524,"clcd":13.6407535946101,"alpha":4.6,"sym":2.88024052520835,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"Bot_Xtr":1,"Re":12500,"src":"retest_81.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Cm":-0.0847674279876955,"id":230,"good":10.3980574351032,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.02107,"Cpmin":-1.29591665963165,"CL":0.63166317781318,"CD":0.0463070587289819,"n":5,"CDp":0.0181230667754982},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt11.1277157272271>9.97612309699884) l1 Foil spline 17pts Re12500 N6","iver":1.2020052,"xver":6.991,"good":11.1277157248736,"id":231,"r":6,"Cm":-0.126387841818053,"n":6,"CL":0.659900654620383,"CD":0.0544802706836986,"CDp":0.026258679878188,"CDf":0.0219,"Cpmin":-0.68158925588547,"sym":5.66416392272273,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0206894864849189,0.854728633619417,0.0437625287475022,0.691363149797408,0.0698536747450068,0.513763139089403,0.083563538895421,0.327229099655296,0.0811121747466966,0.155573716106985,0.0615087102581626,0.0401397957317501,0.0294764074084781,0,0,0.0290164970646396,-0.00417063589384079,0.113543374367374,0.00648132970552172,0.264712879181914,0.0255575828028294,0.449425033656063,0.0402546226708905,0.653083287629906,0.0427218072098193,0.83008632648885,0.0322627938543551,0.943258507857798,0.0158107538854619,1,0],"clcd":12.1126537430703,"CDpres":0.03258,"alpha":3.7,"diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"Re":12500,"src":"retestc_2.txt"},
             {"Cm":-0.131683536546556,"r":6,"id":232,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"good":12.0439873213341,"Cpmin":-0.748961841140861,"CDf":0.0218,"CDp":0.0248160293357507,"CD":0.0529118511232428,"CL":0.697025536015936,"n":7,"alpha":3.8,"CDpres":0.03111,"clcd":13.1733349187201,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"sym":5.36696924573919,"src":"retest_144.txt","Re":12500,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","diter":3},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Re":12500,"src":"retest_145.txt","sym":5.36696924573919,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"CDpres":0.03111,"clcd":13.1733349187201,"alpha":3.8,"CD":0.0529118511232428,"CL":0.697025536015936,"n":8,"CDp":0.0248160293357507,"CDf":0.0218,"Cpmin":-0.748961841140861,"id":233,"good":12.0356689081186,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.131683536546556},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","diter":3,"src":"retest_71.txt","Re":12500,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1,"sym":2.19487122966388,"alpha":4.3,"CDpres":0.02109,"clcd":13.9061933327589,"CDp":0.0151670914575311,"CL":0.591219476476592,"CD":0.0425148322283032,"n":9,"Cpmin":-0.866061047395875,"CDf":0.02143,"r":6,"id":234,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","xver":6.991,"good":12.538784209653,"iver":1.2020052,"Cm":-0.0750212832874216},
             {"r":6,"id":235,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","xver":6.991,"good":12.5957002112694,"iver":1.2020052,"Cm":-0.0750212832874216,"CDp":0.0151670914575311,"CL":0.591219476476592,"CD":0.0425148322283032,"n":10,"Cpmin":-0.866061047395875,"CDf":0.02143,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1,"sym":2.19487122966388,"alpha":4.3,"CDpres":0.02109,"clcd":13.9061933327589,"Top_Xtr":1,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","diter":3,"src":"retest_72.txt","Re":12500},
             {"Re":12500,"n":11,"sym":2.47986741752562,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"clcd":14.2961977418384,"CDpres":0.02189,"alpha":4.3,"diter":3,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","Top_Xtr":1,"src":"retest_65.txt","iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"good":12.8226283778089,"id":236,"r":6,"Cm":-0.0829715238703,"CL":0.616842491419808,"CD":0.0431473110933961,"CDp":0.0157641531333051,"CDf":0.02126,"Cpmin":-1.04323982389625},        #dud
             {"Re":12500,"n":12,"alpha":4.3,"CDpres":0.02189,"clcd":14.2961977418384,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"sym":2.47986741752562,"src":"retest_66.txt","Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","diter":3,"Cm":-0.0829715238703,"r":6,"id":237,"good":12.8138909422676,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"iver":1.2020052,"Cpmin":-1.04323982389625,"CDf":0.02126,"CDp":0.015764153133305,"CD":0.0431473110933961,"CL":0.616842491419808,},        #dud
             {"Re":12500,"n":13,"CD":0.0431473110933961,"CL":0.616842491419808,"CDp":0.015764153133305,"CDf":0.02126,"Cpmin":-1.04323982389625,"id":238,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","iver":1.2020052,"xver":6.991,"good":12.8242556205305,"r":6,"Cm":-0.0829715238703,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","src":"retest_67.txt","sym":2.47986741752562,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"clcd":14.2961977418384,"CDpres":0.02189,"alpha":4.3},        #dud
             {"CDf":0.02143,"Cpmin":-0.866061047395875,"n":14,"CL":0.591219476476592,"CD":0.0425148322283032,"CDp":0.0151670914575311,"Cm":-0.0750212832874216,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","iver":1.2020052,"xver":6.991,"good":12.5898404771457,"id":239,"r":6,"Re":12500,"src":"retest_76.txt","diter":3,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","Top_Xtr":1,"clcd":13.9061933327589,"CDpres":0.02109,"alpha":4.3,"sym":2.19487122966388,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1},
             {"sym":1.60471281573753,"Bot_Xtr":1,"xy":[1,0,0.894957294025289,0.0230258019050173,0.725740011338264,0.0403364732569373,0.627845958649707,0.0496642891370443,0.522817456081957,0.0563263932400137,0.321100453166116,0.0618070536545027,0.140240266598662,0.0503932089992628,0.0431646850364435,0.0279740233708185,0,0,0.0353495406229427,-0.0153395931119644,0.155567962670699,-0.0161631274482238,0.418349884355931,0.00478558840172706,0.500592315581806,0.0104951478749927,0.626268179355836,0.0164733616428027,0.749650274977797,0.0164797089038021,0.839666401611446,0.0143487321133161,1,0],"clcd":21.2650881633554,"CDpres":0.02652,"alpha":5.8,"diter":4,"Top_Xtr":0.496139708372801,"Foil_fn":"optbs_spline_mid101tip.dat-s17_n17s0_nsopt-Re15000-N3.dat","Re":15000,"src":"retestc_9.txt","id":240,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid101tip.dat-s17_n17s0.dat (opt9.19030035764916>8.53804136288417) l1 Foil spline 17pts Re15000 N3","iver":1.2020052,"xver":6.991,"good":9.1903003576524,"r":6,"Cm":-0.0812070774276473,"CD":0.0424294562134557,"CL":0.902266127102361,"n":3,"CDp":0.0168301185628654,"CDf":0.0159,"Cpmin":-2.03466257624873},
             {"CDf":0.01473,"Cpmin":-2.32705664093326,"n":4,"CD":0.0472515306142381,"CL":0.949484719912463,"CDp":0.0219872703051337,"Cm":-0.0849254622237172,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid101tip.dat-s17_n17s0.dat (opt10.6728508864026>9.92950645266297) l1 Foil spline 17pts Re20000 N5","xver":6.991,"good":8.77588161995155,"iver":1.2020052,"id":241,"r":6,"Re":15000,"src":"retest_67.txt","diter":5,"Foil_fn":"optbs_spline_mid101tip.dat-s17_n17s0_nsopt-Re20000-N5.dat","Top_Xtr":0.507177283110817,"clcd":20.0942637745233,"CDpres":0.03252,"alpha":6.2,"sym":1.59592027690127,"xy":[1,0,0.894957294025289,0.0229804511895399,0.725740011338264,0.0402570281227533,0.627845958649707,0.0495664723028974,0.522817456081957,0.0562154549871687,0.321100453166116,0.0616853209080669,0.140240266598662,0.0502939565131714,0.0431646850364435,0.027918926832601,0,0,0.0353495406229427,-0.0152610783383426,0.155567962670699,-0.0160803974642305,0.418349884355931,0.00476109365879183,0.500592315581806,0.0104414290994348,0.626268179355836,0.0163890437439684,0.749650274977797,0.0163953585168987,0.839666401611446,0.0140023369193245,1,0],"Bot_Xtr":1},
             {"Cpmin":-1.19175799269953,"CDf":0.01935,"CDp":0.0172369521799421,"n":5,"CL":0.625478696523317,"CD":0.0431462579879071,"Cm":-0.0863923686953567,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","iver":1.2020052,"good":10.9554949880683,"id":242,"src":"retest_93.txt","Re":15000,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"diter":3,"alpha":4.4,"clcd":14.4967078419321,"CDpres":0.0238,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"sym":2.88024052520835},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","iver":1.2020052,"xver":6.991,"good":11.0513708057482,"id":243,"r":6,"Cm":-0.0863923686953569,"n":6,"CD":0.043146257987907,"CL":0.625478696523318,"CDp":0.0172369521799421,"CDf":0.01935,"Cpmin":-1.19175799269953,"sym":2.88024052520835,"Bot_Xtr":1,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"CDpres":0.0238,"clcd":14.4967078419321,"alpha":4.4,"diter":3,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"Re":15000,"src":"retest_94.txt"},
             #"Re":15000,"n":7,#{"sym":2.47986741752562,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"CDpres":0.02677,"clcd":14.9073655675253,"alpha":5,"diter":15,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","src":"retestc_0.txt","id":244,"good":12.1777210270823,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0843104179612426,"CL":0.668010513233661,"CD":0.0448107688919145,"CDp":0.0197642803834037,"CDf":0.01804,"Cpmin":-1.2246368986082},        #dud
             {"Bot_Xtr":1,"CD":0.0416577078573161,"CDf":0.01423,"CDp":0.0202027090910909,"CDpres":0.02742,"CL":0.948637405422523,"Cm":-0.130572000421805,"Cpmin":-1.51210971329867,"Foil_fn":"opt_spline_foil_e59.dat-s17_n17s0.dat-re15000-ncrit7_n17sopt-Re15000-N7.dat","Re":15000,"Top_Xtr":0.694507856070126,"alpha":4.6,"clcd":22.7721940120121,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e59.dat-s17_n17s0.dat (opt14.5463569751607>7.77969415476437) l2 Foil spline 17pts Re15000 N7","diter":4,"good":12.7177126772354,"id":0,"iver":1.2020062,"n":7,"r":6,"src":"","sym":2.83502765580185,"xver":6.991,"xy":[1,0,0.878343165060231,0.0367635552542084,0.767835427791356,0.0408832177609127,0.495602647863951,0.0554712229999843,0.412037898852082,0.0552761097404494,0.247123632554427,0.0443804837001407,0.119482426648992,0.0451002046305951,0.0315936526083364,0.0203897902993342,0,0,0.0190373645552806,-0.00449256558164805,0.081617600794017,0.011236270652445,0.182439983210628,0.0121503675802421,0.227798485938429,0.0118916581160392,0.41003029295843,0.0209205929818295,0.658573172517308,0.02969326540596,0.876142227224987,0.0274061974646408,1,0]},        #15000 7
             {"Bot_Xtr":1,"CD":0.0416577078573161,"CDf":0.01423,"CDp":0.0202027090910909,"CDpres":0.02742,"CL":0.948637405422523,"Cm":-0.130572000421805,"Cpmin":-1.51210971329867,"Foil_fn":"opt_spline_foil_e59.dat-s17_n17s0.dat-re15000-ncrit7_n17sopt-Re15000-N7.dat","Re":15000,"Top_Xtr":0.694507856070126,"alpha":4.6,"clcd":22.7721940120121,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e59.dat-s17_n17s0.dat (opt14.5463569751607>7.77969415476437) l2 Foil spline 17pts Re15000 N7","diter":4,"good":12.7177126772354,"id":0,"iver":1.2020062,"n":7,"r":6,"src":"","sym":2.83502765580185,"xver":6.991,"xy":[1,0,0.878343165060231,0.0367635552542084,0.767835427791356,0.0408832177609127,0.495602647863951,0.0554712229999843,0.412037898852082,0.0552761097404494,0.247123632554427,0.0443804837001407,0.119482426648992,0.0451002046305951,0.0315936526083364,0.0203897902993342,0,0,0.0190373645552806,-0.00449256558164805,0.081617600794017,0.011236270652445,0.182439983210628,0.0121503675802421,0.227798485938429,0.0118916581160392,0.41003029295843,0.0209205929818295,0.658573172517308,0.02969326540596,0.876142227224987,0.0274061974646408,1,0]},        #15000 7
             {"Re":15000,"n":8,"src":"retest_73.txt","Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","diter":15,"alpha":5,"clcd":14.9073994111929,"CDpres":0.02677,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"sym":2.47986741752562,"Cpmin":-1.22463835948978,"CDf":0.01804,"CDp":0.0197642626570339,"CL":0.668011218950612,"CD":0.0448107144998777,"Cm":-0.0843104721261336,"r":6,"id":245,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","good":12.7605400947608,"iver":1.2020052},        #dud
             {"CD":0.0497270157112176,"CL":0.693053381290928,"n":9,"CDp":0.023951720270332,"CDf":0.01989,"Cpmin":-0.731349692483787,"id":246,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt10.4510142315343>9.50926371726528) l1 Foil spline 17pts Re8192 N4","iver":1.2020052,"xver":6.991,"good":12.6235689667352,"r":6,"Cm":-0.133696220115258,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re8192-N4.dat","Re":15000,"src":"retest_6.txt","sym":5.36696924573919,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0374990524265979,0.724865975963962,0.0678227019819067,0.512480027985969,0.0809429592745711,0.336073009809416,0.0774436671749434,0.224244466354051,0.0680464729216898,0.126806077178113,0.0525578877066587,0.0410787060933097,0.0281415184534835,0,0,0.0283459581556997,-0.00637828359505569,0.0784008671678989,-0.00258353751859024,0.103458959629261,0.000606580920178303,0.213799276880961,0.0174013837275007,0.400704281820966,0.0355114471812279,0.651800254290461,0.0432096314602034,0.880021621959914,0.0289646927463011,1,0],"clcd":13.9371601407922,"CDpres":0.02983,"alpha":3.6},
             {"Re":15000,"src":"retest_98.txt","diter":3,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"CDpres":0.0238,"clcd":14.4967078419321,"alpha":4.4,"sym":2.88024052520835,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"Bot_Xtr":1,"CDf":0.01935,"Cpmin":-1.19175799269952,"n":10,"CD":0.043146257987907,"CL":0.625478696523316,"CDp":0.0172369521799421,"Cm":-0.0863923686953567,"good":13.0963499818515,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","xver":6.991,"iver":1.2020052,"id":247,"r":6},
             {"Re":15000,"n":11,"diter":3,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","Top_Xtr":1,"src":"retest_76.txt","sym":2.47986741752562,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"CDpres":0.02101,"clcd":15.2769299996019,"alpha":4.2,"CD":0.0404042364321922,"CL":0.617252691661965,"CDp":0.0152581301386117,"CDf":0.01939,"Cpmin":-1.03875756404948,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","iver":1.2020052,"xver":6.991,"good":13.6644719528965,"id":248,"r":6,"Cm":-0.0843342393095239},        #dud
             #"Re":15000,"n":12,#{"diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","src":"retest_77.txt","sym":2.47986741752562,"Bot_Xtr":1,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"clcd":15.2769299996019,"CDpres":0.02101,"alpha":4.2,"CD":0.0404042364321921,"CL":0.617252691661965,"CDp":0.0152581301386116,"CDf":0.01939,"Cpmin":-1.03875756404948,"id":249,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","iver":1.2020052,"good":13.6561919682482,"r":6,"Cm":-0.0843342393095239},        #dud
             {"Bot_Xtr":1,"CD":0.0368979320385029,"CDf":0.01821,"CDp":0.0125489832901774,"CDpres":0.01869,"CL":0.586014769328187,"Cm":-0.0674309180809444,"Cpmin":-1.43727238350272,"Foil_fn":"opt_spline_foil_e59.dat-s17_n17s0.dat-re15000-ncrit12_n17sopt-Re15000-N12.dat","Re":15000,"Top_Xtr":1,"alpha":4.3,"clcd":15.8820491272162,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e59.dat-s17_n17s0.dat (opt15.4710435904784>11.7611057118416) l2 Foil spline 17pts Re15000 N12","diter":3,"good":13.9357076217317,"id":1,"iver":1.2020062,"n":12,"r":6,"src":"","sym":1.73004654695002,"xver":6.991,"xy":[1,0,0.888374658076499,0.0226670711044765,0.695301453059757,0.0427180734436409,0.481153896266438,0.0495952224758887,0.33316134456209,0.0478810707627167,0.20061317654614,0.0404663808030454,0.120470837751455,0.0322396266919631,0.0325498963497451,0.0163980607904141,0,0,0.0203918183828165,-0.00508660008566278,0.0787413779362379,-0.00327595969212678,0.154661372810437,0.00184043635756542,0.227129121664492,0.0063746501498417,0.405170312078622,0.0153957468523023,0.634489487657532,0.0209703698208689,0.880829744300136,0.0144673273094727,1,0]},        #15000 12
             {"Bot_Xtr":1,"CD":0.0368979320385029,"CDf":0.01821,"CDp":0.0125489832901774,"CDpres":0.01869,"CL":0.586014769328187,"Cm":-0.0674309180809444,"Cpmin":-1.43727238350272,"Foil_fn":"opt_spline_foil_e59.dat-s17_n17s0.dat-re15000-ncrit12_n17sopt-Re15000-N12.dat","Re":15000,"Top_Xtr":1,"alpha":4.3,"clcd":15.8820491272162,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e59.dat-s17_n17s0.dat (opt15.4710435904784>11.7611057118416) l2 Foil spline 17pts Re15000 N12","diter":3,"good":13.9357076217317,"id":1,"iver":1.2020062,"n":12,"r":6,"src":"","sym":1.73004654695002,"xver":6.991,"xy":[1,0,0.888374658076499,0.0226670711044765,0.695301453059757,0.0427180734436409,0.481153896266438,0.0495952224758887,0.33316134456209,0.0478810707627167,0.20061317654614,0.0404663808030454,0.120470837751455,0.0322396266919631,0.0325498963497451,0.0163980607904141,0,0,0.0203918183828165,-0.00508660008566278,0.0787413779362379,-0.00327595969212678,0.154661372810437,0.00184043635756542,0.227129121664492,0.0063746501498417,0.405170312078622,0.0153957468523023,0.634489487657532,0.0209703698208689,0.880829744300136,0.0144673273094727,1,0]},        #15000 12
             {"Re":15000,"n":13,"Cm":-0.0843342393095241,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"good":13.6470257367736,"id":250,"r":6,"CDf":0.01939,"Cpmin":-1.03875756404948,"CD":0.0404042364321922,"CL":0.617252691661965,"CDp":0.0152581301386117,"CDpres":0.02101,"clcd":15.2769299996019,"alpha":4.2,"sym":2.47986741752562,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"Bot_Xtr":1,"src":"retest_78.txt","diter":3,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","Top_Xtr":1},        #dud
             {"Re":15000,"src":"retest_87.txt","diter":3,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","Top_Xtr":1,"clcd":14.8216726523019,"CDpres":0.01968,"alpha":4.1,"sym":2.19487122966388,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1,"CDf":0.01966,"Cpmin":-0.822070289669591,"n":14,"CL":0.583083008060555,"CD":0.039339892449318,"CDp":0.0142405223346034,"Cm":-0.0761425881552486,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","xver":6.991,"iver":1.2020052,"good":13.3470998004147,"id":251,"r":6},
             {"Re":20000,"n":3,"sym":2.42863448019717,"Bot_Xtr":1,"xy":[1,0,0.872698141247438,0.0272289676703864,0.714161267721381,0.0470674771286808,0.635512217143926,0.0543246663503675,0.474011231124192,0.0646107455194607,0.271049042074955,0.0657479096951066,0.11202427196111,0.0495783344230532,0.0331845342728825,0.0244379187325802,0,0,0.0240615882590061,-0.0157019945217759,0.12652606258289,-0.0166668053173095,0.359596968815521,0.0105123239782776,0.47886911639845,0.0213038813953855,0.597083436840087,0.0265967994848759,0.713873005854957,0.0255547904358041,0.817006552045902,0.0195236686207615,1,0],"clcd":26.5498033288742,"CDpres":0.02259,"alpha":5.8,"diter":3,"Top_Xtr":0.450439616770769,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re35000-N7.dat","src":"retest_102.txt","id":252,"good":10.8900551953386,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt16.3310787745201>15.9094883797073) l1 Foil spline 17pts Re35000 N7","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0967738474150781,"CL":0.992505815587158,"CD":0.03738279351048,"CDp":0.0137553939377644,"CDf":0.01479,"Cpmin":-2.04619674443039},        #dud
             {"xy":[1,0,0.894957294025289,0.0230258019050173,0.725740011338264,0.0403364732569373,0.627845958649707,0.0496642891370443,0.522817456081957,0.0563263932400137,0.321100453166116,0.0618070536545027,0.140240266598662,0.0503932089992628,0.0431646850364435,0.0279740233708185,0,0,0.0353495406229427,-0.0153395931119644,0.155567962670699,-0.0161631274482238,0.418349884355931,0.00478558840172706,0.500592315581806,0.0104951478749927,0.626268179355836,0.0164733616428027,0.749650274977797,0.0164797089038021,0.839666401611446,0.0143487321133161,1,0],"Bot_Xtr":1,"sym":1.60471281573753,"alpha":5.6,"clcd":25.4061890800879,"CDpres":0.02264,"Foil_fn":"optbs_spline_mid101tip.dat-s17_n17s0_nsopt-Re15000-N3.dat","Top_Xtr":0.515999209145754,"diter":4,"src":"retestc_16.txt","Re":20000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid101tip.dat-s17_n17s0.dat (opt9.19030035764916>8.53804136288417) l1 Foil spline 17pts Re15000 N3","iver":1.2020052,"xver":6.991,"good":10.9422336418008,"id":253,"Cm":-0.0858105639616529,"CDp":0.0141299694585232,"n":4,"CD":0.0364326432314795,"CL":0.925614622626354,"Cpmin":-2.10804320956525,"CDf":0.01379},
             {"CDp":0.0143835628090013,"CL":0.844289441117957,"CD":0.0350364284227807,"n":5,"Cpmin":-2.12479549908904,"CDf":0.01327,"r":6,"id":254,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103c3.dat-s17_n17s0.dat (opt10.7330281450083>10.6751420929747) l1 Foil spline 17pts Re20000 N5","xver":6.991,"good":10.7314630668844,"Cm":-0.0780615927799655,"Top_Xtr":0.567114770261151,"Foil_fn":"optbs_spline_mid103c3.dat-s17_n17s0_nsopt-Re20000-N5.dat","diter":4,"src":"retest_56.txt","Re":20000,"xy":[1,0,0.878975273482532,0.0202224152420767,0.693171356185715,0.0408098512647479,0.544333140623122,0.0515209151894211,0.407469712002341,0.0576422247470224,0.22072973095756,0.0579331880239775,0.076291614436262,0.042177077592461,0.00869208529312013,0.0163626047205804,0,0,0.0187574897119247,-0.00845971834507331,0.0549926622788392,-0.014174805417487,0.176538175043836,-0.0137625439555603,0.441887065428039,0.00490645880068263,0.574320105122134,0.0129772099654473,0.692814874122089,0.0156659939849571,0.809542173172325,0.0134425555585781,1,0],"Bot_Xtr":1,"sym":1.45866264802107,"alpha":5.1,"CDpres":0.02176,"clcd":24.0974745179505},
             {"CDpres":0.02541,"clcd":22.622429508324,"alpha":5.2,"sym":1.47381507368016,"xy":[1,0,0.878975273482532,0.0203204182314685,0.693171356185715,0.0410076262274665,0.544333140623122,0.0517705987036959,0.407469712002341,0.0579215736908939,0.22072973095756,0.0582139470502058,0.076291614436262,0.0423814784831752,0.00869208529312013,0.0164419020823276,0,0,0.0187574897119247,-0.00880149619681203,0.0549926622788392,-0.0147474763205585,0.176538175043836,-0.0143185592406709,0.441887065428039,0.00510468276986695,0.574320105122134,0.0135014972717896,0.692814874122089,0.0162989098281481,0.809542173172325,0.0134417573707266,1,0],"Bot_Xtr":1,"Re":20000,"src":"retestc_22.txt","diter":4,"Top_Xtr":0.595346895387717,"Foil_fn":"optbs_spline_mid103c3.dat-s17_n17s0_nsopt-Re20000-N6.dat","Cm":-0.0840741685128644,"id":255,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103c3.dat-s17_n17s0.dat (opt10.5435775188975>10.5426792964659) l1 Foil spline 17pts Re20000 N6","xver":6.991,"good":10.5435712287349,"r":6,"CDf":0.01266,"Cpmin":-2.15822106834092,"CL":0.861356333991582,"CD":0.0380753240351415,"n":6,"CDp":0.0180069223663327},
             {"CDf":0.01312,"Cpmin":-1.56991357940369,"n":7,"CD":0.0355235781831435,"CL":0.717892371254037,"CDp":0.0162277686398662,"Cm":-0.0602761912928948,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ag13.dat-s17_n17s0.dat (opt18.0521875911391>16.2493226765787) l1 Foil spline 17pts Re55000 N12","xver":6.991,"iver":1.2020052,"good":9.84504450387955,"id":256,"r":6,"Re":20000,"src":"retest_20.txt","diter":5,"Foil_fn":"optbs_spline_ag13.dat-s17_n17s0_nsopt-Re55000-N12.dat","Top_Xtr":0.645592107676769,"CDpres":0.0224,"clcd":20.2088980888386,"alpha":4.5,"sym":0.578678921788749,"xy":[1,0,0.869096015625,0.0175701997057341,0.73138607421875,0.0237961328980856,0.594386054102955,0.0337468464133408,0.455657540388373,0.0418197207790438,0.325524702491026,0.0457853260265536,0.187963209843909,0.0444725350655347,0.0557256738271807,0.0295748822991634,0,5.10592567001292e-05,0.0548520109483167,-0.0132168419278074,0.192834567378491,-0.0130535428132256,0.325536273725442,-0.00771999422607074,0.465369299885471,-0.00214639273782085,0.600668871331738,0.00219465550922684,0.737779062164382,0.00382997834711732,0.872041,0.0027036226006804,1,0],"Bot_Xtr":1},
             {"CDp":0.020601109810453,"n":8,"CD":0.0434521881811579,"CL":0.67565196526521,"Cpmin":-1.8262983994891,"CDf":0.01564,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","good":12.341211861465,"iver":1.2020052,"id":257,"Cm":-0.0886039880439807,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","Top_Xtr":1,"diter":30,"src":"retest_108.txt","Re":20000,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"Bot_Xtr":1,"sym":2.88024052520835,"alpha":5,"clcd":15.5493196901461,"CDpres":0.02781},
             {"CDp":0.0206011123125984,"CD":0.0434521276018626,"CL":0.675652105868572,"n":9,"Cpmin":-1.82629914424339,"CDf":0.01564,"r":6,"id":258,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_goe804.dat-s17_n17s0.dat (opt13.0963499818617>10.2711363390859) l1 Foil spline 17pts Re15000 N10","xver":6.991,"good":13.2008833442966,"Cm":-0.088604012061001,"Top_Xtr":1,"Foil_fn":"optbs_spline_goe804.dat-s17_n17s0_nsopt-Re15000-N10.dat","diter":30,"src":"retest_109.txt","Re":20000,"xy":[1,0,0.932888316288692,0.0188032777542489,0.790017354891618,0.0455825380426146,0.601959273332201,0.0625781729878497,0.382453204572511,0.0640191988538851,0.200384671554421,0.0509443705468858,0.116944579071743,0.0386282247530346,0.0451296130806224,0.0230360488999043,0,0,0.031935439186916,-0.00492827553873374,0.0817149379280138,-0.000198085624161254,0.178982980222827,0.00947770881733736,0.301974084079985,0.0172046073875782,0.511035570473631,0.024409255494555,0.710372454413702,0.0229856229989023,0.907539857851309,0.0157640675931311,1,0],"Bot_Xtr":1,"sym":2.88024052520835,"alpha":5,"clcd":15.5493446042354,"CDpres":0.02781},
             {"src":"retest_100.txt","Re":20000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re8192-N4.dat","Top_Xtr":1,"diter":3,"alpha":3.2,"clcd":14.9302284185317,"CDpres":0.02441,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0187483584721152,0.854728633619417,0.0396566428655676,0.691363149797408,0.0632998666094761,0.513763139089403,0.0757234445403895,0.327229099655296,0.073502072161743,0.155573716106985,0.0557378429821392,0.0401397957317501,0.0267108733204707,0,0,0.0290164970646396,-0.00372684332385588,0.113543374367374,0.00579165886391676,0.264712879181914,0.0228380298033887,0.449425033656063,0.0359711745580332,0.653083287629906,0.0381758288269916,0.83008632648885,0.0288297470567043,0.943258507857798,0.0141283497440238,1,0],"sym":4.61120446540594,"Cpmin":-0.636710556129703,"CDf":0.01748,"CDp":0.0194612588881368,"n":10,"CL":0.625328248301427,"CD":0.041883367807371,"Cm":-0.117779195661245,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt10.3550731625661>9.04223755457044) l1 Foil spline 17pts Re8192 N4","iver":1.2020052,"good":13.536430840904,"id":259},
             {"CDp":0.0129316128127737,"n":11,"CL":0.569722042564037,"CD":0.0349321393304268,"Cpmin":-0.753851849461583,"CDf":0.01735,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","good":14.7071811907044,"iver":1.2020052,"id":260,"Cm":-0.0778323554468107,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","Top_Xtr":1,"diter":3,"src":"retest_95.txt","Re":20000,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1,"sym":2.19487122966388,"alpha":3.8,"CDpres":0.01758,"clcd":16.3093945428013},
             {"diter":3,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re35000-N12.dat","Top_Xtr":1,"Re":20000,"src":"retest_64.txt","sym":3.70720346786897,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0322924439570789,0.724865975963962,0.0584057639071146,0.512480027985969,0.0697043206947869,0.336073009809416,0.0666908927091633,0.224244466354051,0.0585984650572652,0.126806077178113,0.0452604141555825,0.0410787060933097,0.0242341698981609,0,0,0.0283459581556997,-0.00487844434434457,0.0784008671678989,-0.00197602439718087,0.103458959629261,0.000463944761208965,0.213799276880961,0.0133094869119651,0.400704281820966,0.0271610090832343,0.651800254290461,0.0330489823910694,0.880021621959914,0.0221537094436198,1,0],"CDpres":0.02224,"clcd":16.2576937785832,"alpha":3.7,"n":12,"CL":0.646574104597091,"CD":0.0397703458684185,"CDp":0.0170913171171987,"CDf":0.01754,"Cpmin":-0.763265051252652,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.7862519216457>12.9287676329622) l1 Foil spline 17pts Re35000 N12","good":14.7076298661293,"iver":1.2020052,"id":261,"r":6,"Cm":-0.107691228075479},
             {"Re":20000,"n":13,"CDp":0.0139101875796372,"CD":0.0359144943076556,"CL":0.606500221494498,"Cpmin":-0.992361136494931,"CDf":0.01694,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"good":15.0075976003486,"iver":1.2020052,"id":262,"Cm":-0.0864297897546224,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","Top_Xtr":1,"diter":3,"src":"retest_89.txt","xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"Bot_Xtr":1,"sym":2.47986741752562,"alpha":3.9,"CDpres":0.01897,"clcd":16.8873384739602},        #dud
             {"Re":20000,"src":"retest_66.txt","diter":3,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re35000-N12.dat","Top_Xtr":1,"clcd":16.2576937785832,"CDpres":0.02224,"alpha":3.7,"sym":3.70720346786897,"xy":[1,0,0.886567063170893,0.0322924439570789,0.724865975963962,0.0584057639071146,0.512480027985969,0.0697043206947869,0.336073009809416,0.0666908927091633,0.224244466354051,0.0585984650572652,0.126806077178113,0.0452604141555825,0.0410787060933097,0.0242341698981609,0,0,0.0283459581556997,-0.00487844434434457,0.0784008671678989,-0.00197602439718087,0.103458959629261,0.000463944761208965,0.213799276880961,0.0133094869119651,0.400704281820966,0.0271610090832343,0.651800254290461,0.0330489823910694,0.880021621959914,0.0221537094436198,1,0],"Bot_Xtr":1,"CDf":0.01754,"Cpmin":-0.763265051252652,"n":14,"CD":0.0397703458684185,"CL":0.64657410459709,"CDp":0.0170913171171987,"Cm":-0.107691228075479,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.7862519216457>12.9287676329622) l1 Foil spline 17pts Re35000 N12","good":14.6533305906797,"iver":1.2020052,"id":263,"r":6},
             {"Re":25000,"n":3,"CDf":0.01422,"Cpmin":-1.6701445840626,"CD":0.0319090860654759,"CL":0.966622478720842,"CDp":0.0105289254121726,"Cm":-0.10327956793975,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt19.3599414781884>18.9451609837954) l1 Foil spline 17pts Re45000 N8","good":13.0807234760287,"xver":6.991,"iver":1.2020052,"id":264,"r":6,"src":"retest_98.txt","diter":3,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re45000-N8.dat","Top_Xtr":0.477792084409463,"CDpres":0.01769,"clcd":30.2930167519489,"alpha":5.2,"sym":2.64859184348515,"xy":[1,0,0.872698141247438,0.0285047171395745,0.714161267721381,0.0492727134670471,0.635512217143926,0.0568699212825138,0.474011231124192,0.0676379305856778,0.271049042074955,0.0688283739238326,0.11202427196111,0.0519012110957605,0.0331845342728825,0.0255829001446026,0,0,0.0240615882590061,-0.0162246634127557,0.12652606258289,-0.0172215896562859,0.359596968815521,0.0108622454298312,0.47886911639845,0.0220130190814959,0.597083436840087,0.027482121389115,0.713873005854957,0.0264054272105004,0.817006552045902,0.0201735487497934,1,0],"Bot_Xtr":1},        #dud
             {"Re":25000,"n":4,"src":"retest_23.txt","diter":4,"Top_Xtr":0.500682119003771,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re35000-N6.dat","CDpres":0.02086,"clcd":29.9680831968518,"alpha":5.6,"sym":2.88000458683892,"xy":[1,0,0.872698141247438,0.0297332325145057,0.714161267721381,0.0513963018458563,0.635512217143926,0.0593209392078835,0.474011231124192,0.0705530353820579,0.271049042074955,0.0717947852438573,0.11202427196111,0.0541380842243896,0.0331845342728825,0.0266854890953745,0,0,0.0240615882590061,-0.0168952975627051,0.12652606258289,-0.0179334309959861,0.359596968815521,0.0113112281017707,0.47886911639845,0.0229229105204723,0.597083436840087,0.0286180740217044,0.713873005854957,0.0274968755062748,0.817006552045902,0.0210074070785058,1,0],"Bot_Xtr":1,"CDf":0.01354,"Cpmin":-1.79211010458382,"CL":1.03106756059996,"CD":0.0344055224962895,"CDp":0.0130740683123618,"Cm":-0.109047153991683,"id":265,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt16.9951313006478>16.1739146312688) l1 Foil spline 17pts Re35000 N6","good":13.2827013424326,"xver":6.991,"iver":1.2020052,"r":6},        #dud
             {"Top_Xtr":0.535306080413442,"Foil_fn":"optbs-spline_foil_mid117.dat-s17_n17s0-Re65536-N12.dat","diter":4,"src":"retest_91.txt","Re":25000,"xy":[1,0,0.872698141247438,0.0268471305397061,0.714161267721381,0.0464074407059735,0.635512217143926,0.053562860946083,0.474011231124192,0.0637046964184111,0.271049042074955,0.0648259139187663,0.11202427196111,0.0488830877582083,0.0331845342728825,0.0240952210261668,0,0,0.0240615882590061,-0.0142346433568457,0.12652606258289,-0.0151092925972469,0.359596968815521,0.00952994745189067,0.47886911639845,0.0193130339817209,0.597083436840087,0.0241113289509622,0.713873005854957,0.023166695632719,0.817006552045902,0.0176991820655882,1,0],"Bot_Xtr":1,"sym":2.29082429046993,"alpha":5.6,"clcd":29.4708638279492,"CDpres":0.02138,"CDp":0.0137117924058038,"CD":0.0340210955973256,"CL":1.00263107562643,"n":5,"Cpmin":-2.04849855743617,"CDf":0.01264,"r":6,"id":266,"good":13.1346600580323,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt17.0747915417592>17.0203424728352) l1 Foil spline 17pts Re65536 N12","xver":6.991,"iver":1.2020052,"Cm":-0.100737234658407},
             {"Re":25000,"n":6,"CDp":0.0187213905905804,"CL":1.08260897188234,"CD":0.0393104794531859,"Cpmin":-2.14251304961957,"CDf":0.01223,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt20.5686809238884>20.1617375474975) l1 Foil spline 17pts Re55000 N10","xver":6.991,"good":12.1449153572509,"id":267,"Cm":-0.109349195860849,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re55000-N10.dat","Top_Xtr":0.524143798919331,"diter":4,"src":"retest_57.txt","xy":[1,0,0.872698141247438,0.0286615317752937,0.714161267721381,0.0495437802724252,0.635512217143926,0.0571827830430998,0.474011231124192,0.0680100310136054,0.271049042074955,0.0692070234059923,0.11202427196111,0.0521867382059406,0.0331845342728825,0.0257236408208623,0,0,0.0240615882590061,-0.0152982840075366,0.12652606258289,-0.0162382887657309,0.359596968815521,0.0102420439375328,0.47886911639845,0.0207561420046032,0.597083436840087,0.0259129750457405,0.713873005854957,0.0248977568612598,0.817006552045902,0.0190216998875668,1,0],"Bot_Xtr":1,"sym":2.6169135973697,"alpha":6.1,"CDpres":0.02708,"clcd":27.5399584777794},        #dud
             {"alpha":5.1,"CDpres":0.02266,"clcd":25.7921948208693,"Bot_Xtr":1,"xy":[1,0,0.878975273482532,0.0210414379644735,0.693171356185715,0.0424626803201971,0.544333140623122,0.0536075502284947,0.407469712002341,0.0599767773349391,0.22072973095756,0.0602795248390677,0.076291614436262,0.0438852803219077,0.00869208529312013,0.0170253022719524,0,0,0.0187574897119247,-0.00878651761718394,0.0549926622788392,-0.0147223787413013,0.176538175043836,-0.0142941916019251,0.441887065428039,0.00509599550856105,0.574320105122134,0.0134785201270563,0.692814874122089,0.0162711719852572,0.809542173172325,0.0140939684124857,1,0],"sym":1.57995489261013,"src":"retest_124.txt","Re":25000,"Top_Xtr":0.592494314019105,"Foil_fn":"optbs_spline_mid103c3.dat-s17_n17s0_nsopt-Re25000-N7.dat","diter":4,"Cm":-0.0875972800077012,"r":6,"id":268,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103c3.dat-s17_n17s0.dat (opt11.6217276721936>11.3589101518786) l1 Foil spline 17pts Re25000 N7","xver":6.991,"good":11.6212988394522,"iver":1.2020052,"Cpmin":-2.07242641197146,"CDf":0.01161,"CDp":0.016117432177773,"CD":0.0342743791040699,"CL":0.884011463216502,"n":7},
             {"Cm":-0.0907066316283445,"r":6,"id":269,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103c3.dat-s17_n17s0.dat (opt8.85144670318478>8.5855445926956) l1 Foil spline 17pts Re15000 N5","xver":6.991,"iver":1.2020052,"good":11.0908273712591,"Cpmin":-2.16323902740762,"CDf":0.01107,"CDp":0.0198899490891325,"CD":0.037495109902538,"CL":0.889247119821556,"n":8,"alpha":5.2,"CDpres":0.02643,"clcd":23.7163492021492,"Bot_Xtr":1,"xy":[1,0,0.878975273482532,0.02065300147736,0.693171356185715,0.0416787959485658,0.544333140623122,0.0526179254448334,0.407469712002341,0.0588695731250507,0.22072973095756,0.0591667317441808,0.076291614436262,0.043075133973877,0.00869208529312013,0.0167110058527757,0,0,0.0187574897119247,-0.00877429876878116,0.0549926622788392,-0.0147019052702624,0.176538175043836,-0.0142743135833706,0.441887065428039,0.005088908833351,0.574320105122134,0.0134597764106829,0.692814874122089,0.0162485447064551,0.809542173172325,0.0134002211113766,1,0],"sym":1.51962099877062,"src":"retest_72.txt","Re":25000,"Top_Xtr":0.607949411809215,"Foil_fn":"optbs_spline_mid103c3.dat-s17_n17s0_nsopt-Re15000-N5.dat","diter":4},
             {"Cm":-0.0673018460320114,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ag13.dat-s17_n17s0.dat (opt18.0521875911391>16.2493226765787) l1 Foil spline 17pts Re55000 N12","good":10.7039450829407,"iver":1.2020052,"id":270,"r":6,"CDf":0.01163,"Cpmin":-1.48436383643082,"n":9,"CD":0.033406014934981,"CL":0.716760718537655,"CDp":0.0166055744164457,"CDpres":0.02178,"clcd":21.4560377804029,"alpha":4.3,"sym":0.578678921788749,"xy":[1,0,0.869096015625,0.0175701997057341,0.73138607421875,0.0237961328980856,0.594386054102955,0.0337468464133408,0.455657540388373,0.0418197207790438,0.325524702491026,0.0457853260265536,0.187963209843909,0.0444725350655347,0.0557256738271807,0.0295748822991634,0,5.10592567001292e-05,0.0548520109483167,-0.0132168419278074,0.192834567378491,-0.0130535428132256,0.325536273725442,-0.00771999422607074,0.465369299885471,-0.00214639273782085,0.600668871331738,0.00219465550922684,0.737779062164382,0.00382997834711732,0.872041,0.0027036226006804,1,0],"Bot_Xtr":1,"Re":25000,"src":"retest_31.txt","diter":5,"Foil_fn":"optbs_spline_ag13.dat-s17_n17s0_nsopt-Re55000-N12.dat","Top_Xtr":0.687038599250089},
             {"Re":25000,"n":10,"Cm":-0.0880350881878708,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"good":14.1216756348768,"iver":1.2020052,"id":271,"r":6,"CDf":0.01531,"Cpmin":-0.935659310296247,"CD":0.0325668821629015,"CL":0.59205780877459,"CDp":0.0127137753681678,"CDpres":0.01726,"clcd":18.1797510063469,"alpha":3.6,"sym":2.47986741752562,"xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"Bot_Xtr":1,"src":"retest_97.txt","diter":3,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","Top_Xtr":1},        #dud
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt15.0941836078143>12.624602765761) l1 Foil spline 17pts Re35000 N12","good":13.9171913119504,"iver":1.2020052,"id":272,"r":6,"Cm":-0.0898225114999249,"n":11,"CD":0.0360056572355162,"CL":0.551012424842972,"CDp":0.0156862329160803,"CDf":0.01587,"Cpmin":-0.628324029227812,"sym":2.9456310693317,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.0157151299406333,0.863082022377036,0.0321349576300939,0.698195158425591,0.0543096474433878,0.497241313912823,0.0676745338038654,0.28552715888499,0.0632564455718427,0.125732819683231,0.0444470670769709,0.0360765344716023,0.0212487866244665,0,0,0.0192507166066205,-0.00754436646182311,0.113363722509556,-0.00119836197508259,0.268607859414087,0.0125606395297192,0.440775378221921,0.0227263034636579,0.638477319107758,0.0259044181634568,0.818181208003633,0.0205828807065632,0.939515187720928,0.0102655709963558,1,0],"CDpres":0.02014,"clcd":15.3034958156367,"alpha":3.4,"diter":3,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re35000-N12.dat","Top_Xtr":1,"Re":25000,"src":"retest_141.txt"},
             {"Re":25000,"src":"retest_107.txt","diter":3,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","Top_Xtr":1,"CDpres":0.01646,"clcd":17.4865468670892,"alpha":3.6,"sym":2.19487122966388,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1,"CDf":0.01559,"Cpmin":-0.707510596955908,"n":12,"CL":0.560486755158602,"CD":0.0320524549197003,"CDp":0.0122034062963358,"Cm":-0.0790298525432685,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","good":15.688028121498,"xver":6.991,"iver":1.2020052,"id":273,"r":6},
             {"Re":25000,"n":13,"CDp":0.0127137753681678,"CL":0.59205780877459,"CD":0.0325668821629015,"Cpmin":-0.935659310296247,"CDf":0.01531,"r":6,"good":16.1155987859272,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e59.dat-s19_n19s0.dat (opt6.85079765103286>6.23076567960037) l1 Foil spline 19pts Re15000 N6","xver":6.991,"iver":1.2020052,"id":274,"Cm":-0.0880350881878709,"Foil_fn":"optbs-spline_foil_e59.dat-s17_n17s0-Re15000-N6-sq1.dat","Top_Xtr":1,"diter":3,"src":"retest_100.txt","xy":[1,0,0.929108869578711,0.019159866438981,0.810731849907413,0.0395081723320941,0.632771041968728,0.0559001231010933,0.400628633190993,0.0602674318958721,0.234054815995728,0.0518776224231074,0.150822785333074,0.0434947290831846,0.0831000552881464,0.0321503790455439,0.0212179764407992,0.0155229841882218,0,0,0.00765047037479315,-0.00475635076555621,0.0288620880716639,-0.00694361433361104,0.108544117736146,-0.00198925124303168,0.174711230942372,0.00367026934930173,0.274245774017556,0.0108026179436272,0.491712653700056,0.0225715605767099,0.704228601122901,0.0247807719868047,0.900679019477577,0.015822768979761,1,0],"Bot_Xtr":1,"sym":2.47986741752562,"alpha":3.6,"CDpres":0.01726,"clcd":18.1797510063469},        #dud
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re20000-N11.dat","diter":3,"src":"retest_109.txt","Re":25000,"xy":[1,0,0.945514649029338,0.0134643377155177,0.863082022377036,0.0275324431703681,0.698195158425591,0.0465311732802004,0.497241313912823,0.0579818799664816,0.28552715888499,0.0541965703802656,0.125732819683231,0.0380811564300999,0.0360765344716023,0.0182054389774433,0,0,0.0192507166066205,-0.00666727610542995,0.113363722509556,-0.00105904322152893,0.268607859414087,0.0111003690275642,0.440775378221921,0.0200841967068737,0.638477319107758,0.0228928312430551,0.818181208003633,0.0181899632540678,0.939515187720928,0.00907211978089126,1,0],"Bot_Xtr":1,"sym":2.19487122966388,"alpha":3.6,"clcd":17.4865468670892,"CDpres":0.01646,"CDp":0.0122034062963358,"CD":0.0320524549197003,"CL":0.560486755158602,"n":14,"Cpmin":-0.707510596955908,"CDf":0.01559,"r":6,"id":275,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.7046947386492>11.8739624185289) l1 Foil spline 17pts Re20000 N11","xver":6.991,"good":15.6693098840485,"iver":1.2020052,"Cm":-0.0790298525432685},
             {"alpha":5.6,"clcd":33.3916504121055,"CDpres":0.01743,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"sym":4.5387969219134,"src":"retest_139.txt","Re":30000,"Top_Xtr":0.477105808533032,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","diter":3,"Cm":-0.10785561601108,"r":6,"id":276,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","xver":6.991,"good":14.7474344002802,"Cpmin":-1.57587738862746,"CDf":0.01429,"CDp":0.0100350442096026,"CD":0.0317181298570585,"CL":1.05912070391266,"n":3},
             {"Cpmin":-1.67727210803463,"CDf":0.01373,"CDp":0.0120879257741415,"n":4,"CL":1.09445101202279,"CD":0.0337434864995442,"Cm":-0.106059413181489,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt14.9504653998426>14.8660280987781) l1 Foil spline 17pts Re30000 N4","good":14.9504653998482,"xver":6.991,"iver":1.2020052,"id":277,"src":"retest_3.txt","Re":30000,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re30000-N4.dat","Top_Xtr":0.507160153766497,"diter":3,"alpha":6,"CDpres":0.02001,"clcd":32.4344377406754,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0338258991564894,0.641452589715019,0.0693401349586244,0.416262776127718,0.0843557447789177,0.233866556084622,0.080710028002726,0.132025845000493,0.0666583336757615,0.0665475051364794,0.0467977876847884,0.0222714169962174,0.0255218174459281,0,0,0.0219899769144022,-0.00804156057995758,0.0671574276679874,-0.00583050563161961,0.108585510576379,-0.00177832125431735,0.25711939037162,0.0161951907826701,0.414690606933141,0.0276250051651531,0.609466583507779,0.0297432640132506,0.764025880785643,0.0219930014949578,1,0],"sym":4.45120080716599},
             {"Re":30000,"n":5,"CDp":0.0113506549151856,"CL":1.01622590595523,"CD":0.0303148941882064,"Cpmin":-1.8248388456409,"CDf":0.01214,"r":6,"id":278,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt19.3599414781884>18.9451609837954) l1 Foil spline 17pts Re45000 N8","iver":1.2020052,"good":15.2880766070325,"Cm":-0.110224297547499,"Top_Xtr":0.539061768178371,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re45000-N8.dat","diter":4,"src":"retest_112.txt","xy":[1,0,0.872698141247438,0.0285047171395745,0.714161267721381,0.0492727134670471,0.635512217143926,0.0568699212825138,0.474011231124192,0.0676379305856778,0.271049042074955,0.0688283739238326,0.11202427196111,0.0519012110957605,0.0331845342728825,0.0255829001446026,0,0,0.0240615882590061,-0.0162246634127557,0.12652606258289,-0.0172215896562859,0.359596968815521,0.0108622454298312,0.47886911639845,0.0220130190814959,0.597083436840087,0.027482121389115,0.713873005854957,0.0264054272105004,0.817006552045902,0.0201735487497934,1,0],"Bot_Xtr":1,"sym":2.64859184348515,"alpha":5.3,"CDpres":0.01817,"clcd":33.5223306288359},        #dud
             {"Re":30000,"n":6,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re55000-N11.dat","Top_Xtr":0.564793652885222,"diter":4,"src":"retest_59.txt","xy":[1,0,0.872698141247438,0.028572452691705,0.714161267721381,0.0493897998578826,0.635512217143926,0.0570050608630551,0.474011231124192,0.0677986581084508,0.271049042074955,0.0689919302884563,0.11202427196111,0.0520245435664038,0.0331845342728825,0.0256436926042475,0,0,0.0240615882590061,-0.0162527970175647,0.12652606258289,-0.0172514519335638,0.359596968815521,0.0108810805891493,0.47886911639845,0.0220511897087525,0.597083436840087,0.0275297754527345,0.713873005854957,0.0264512142838624,0.817006552045902,0.0202085297311354,1,0],"Bot_Xtr":1,"sym":2.66056163256118,"alpha":5.4,"CDpres":0.02019,"clcd":32.6555846835,"CDp":0.0133192488565223,"CL":1.04036751191155,"CD":0.0318587929750717,"Cpmin":-1.88986654105684,"CDf":0.01167,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt19.5052323765844>18.8677579427738) l1 Foil spline 17pts Re55000 N11","xver":6.991,"iver":1.2020052,"good":14.7821997939791,"id":279,"Cm":-0.114234311773862},        #dud
             {"r":6,"id":280,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt17.0747915417592>17.0203424728352) l1 Foil spline 17pts Re65536 N12","iver":1.2020052,"xver":6.991,"good":13.8065056225522,"Cm":-0.108121018533351,"CDp":0.0152861667557753,"CD":0.0333791993288806,"CL":1.03848049390706,"n":7,"Cpmin":-2.14230246898055,"CDf":0.01101,"xy":[1,0,0.872698141247438,0.0268471305397061,0.714161267721381,0.0464074407059735,0.635512217143926,0.053562860946083,0.474011231124192,0.0637046964184111,0.271049042074955,0.0648259139187663,0.11202427196111,0.0488830877582083,0.0331845342728825,0.0240952210261668,0,0,0.0240615882590061,-0.0142346433568457,0.12652606258289,-0.0151092925972469,0.359596968815521,0.00952994745189067,0.47886911639845,0.0193130339817209,0.597083436840087,0.0241113289509622,0.713873005854957,0.023166695632719,0.817006552045902,0.0176991820655882,1,0],"Bot_Xtr":1,"sym":2.29082429046993,"alpha":5.6,"CDpres":0.02237,"clcd":31.1116058739175,"Top_Xtr":0.562080639996591,"Foil_fn":"optbs-spline_foil_mid117.dat-s17_n17s0-Re65536-N12.dat","diter":4,"src":"retest_103.txt","Re":30000},
             {"Top_Xtr":0.736040427876504,"Foil_fn":"optbs_spline_ag13.dat-s17_n17s0_nsopt-Re55000-N12.dat","diter":4,"src":"retest_39.txt","Re":30000,"xy":[1,0,0.869096015625,0.0175701997057341,0.73138607421875,0.0237961328980856,0.594386054102955,0.0337468464133408,0.455657540388373,0.0418197207790438,0.325524702491026,0.0457853260265536,0.187963209843909,0.0444725350655347,0.0557256738271807,0.0295748822991634,0,5.10592567001292e-05,0.0548520109483167,-0.0132168419278074,0.192834567378491,-0.0130535428132256,0.325536273725442,-0.00771999422607074,0.465369299885471,-0.00214639273782085,0.600668871331738,0.00219465550922684,0.737779062164382,0.00382997834711732,0.872041,0.0027036226006804,1,0],"Bot_Xtr":1,"sym":0.578678921788749,"alpha":3.8,"CDpres":0.01404,"clcd":26.2502821065244,"CDp":0.00959401366086555,"CL":0.665297930012651,"CD":0.0253444106738683,"n":8,"Cpmin":-1.27873617542882,"CDf":0.01131,"r":6,"id":281,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ag13.dat-s17_n17s0.dat (opt18.0521875911391>16.2493226765787) l1 Foil spline 17pts Re55000 N12","good":12.3750535437334,"xver":6.991,"iver":1.2020052,"Cm":-0.061811732824339},
             {"Re":30000,"n":9,"xy":[1,0,0.899630566949792,0.0264715048336189,0.727739042677004,0.0539498543909586,0.592614898283108,0.0687069257157547,0.4516898617015,0.0808168964366419,0.252873926024019,0.0816122781822707,0.0811582397809066,0.0527543199549571,0.00557700402728914,0.00769342219527083,0,0,0.00141252526740496,-0.0129235486996504,0.0452001277636599,-0.0136674352748887,0.199612166740877,0.0144604506818643,0.377122071379592,0.0333831739735341,0.554590024942112,0.036268539837168,0.69102752205303,0.0315234718291442,0.809701462099824,0.0232152481585428,1,0],"Bot_Xtr":1,"sym":4.68564842882372,"alpha":6.2,"CDpres":0.02321,"clcd":33.8704458443314,"Top_Xtr":0.449646387861045,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re30000-N9.dat","diter":4,"src":"retest_90.txt","r":6,"id":282,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt11.9372951851391>11.7166103994334) l1 Foil spline 17pts Re30000 N9","iver":1.2020052,"good":11.934210220376,"Cm":-0.113505416608406,"CDp":0.0145684894622389,"CD":0.0351231976672179,"CL":1.18963836446725,"Cpmin":-2.64475512699579,"CDf":0.01192},        #dud
             {"diter":9,"Top_Xtr":0.705232186216592,"Foil_fn":"optbs_spline_ag13.dat-s17_n17s0_nsopt-Re45000-N12.dat","Re":30000,"src":"retest_95.txt","sym":0.594895452744471,"Bot_Xtr":1,"xy":[1,0,0.869096015625,0.0178908188732777,0.73138607421875,0.0242303622437003,0.594386054102955,0.0343626553389921,0.455657540388373,0.042582842672229,0.325524702491026,0.046620811869754,0.187963209843909,0.04528406523651,0.0557256738271807,0.0301145616597721,0,5.25566822571611e-05,0.0548520109483167,-0.0138497516328164,0.192834567378491,-0.0136786326778368,0.325536273725442,-0.00808967854967708,0.465369299885471,-0.00224917620167309,0.600668871331738,0.002299750113409,0.737779062164382,0.00401338301209745,0.872041,0.00283308991155533,1,0],"CDpres":0.01951,"clcd":23.5011540893512,"alpha":4.1,"CL":0.710315486722615,"CD":0.0302247065834299,"n":10,"CDp":0.0149464722954085,"CDf":0.01072,"Cpmin":-1.38198664484496,"id":283,"good":12.0241572708135,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ag13.dat-s17_n17s0.dat (opt15.0376071749107>14.2186482017551) l1 Foil spline 17pts Re45000 N12","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.069762908411645},
             {"CDpres":0.02122,"clcd":15.5483953460908,"alpha":3.1,"sym":3.36859783931288,"xy":[1,0,0.945514649029338,0.0165934377278167,0.863082022377036,0.0339309582762192,0.698195158425591,0.057344976228381,0.497241313912823,0.0714568168812873,0.28552715888499,0.0667918047413295,0.125732819683231,0.0469311830390178,0.0360765344716023,0.0224363666719094,0,0,0.0192507166066205,-0.00839272300358051,0.113363722509556,-0.00133311659312761,0.268607859414087,0.013973071013213,0.440775378221921,0.0252818537952756,0.638477319107758,0.0288173443475962,0.818181208003633,0.0228974052705523,0.939515187720928,0.0114199242947677,1,0],"Bot_Xtr":1,"Re":30000,"src":"retestc_23.txt","diter":3,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re30000-N11.dat","Top_Xtr":1,"Cm":-0.0999298950661124,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.0179489827091>12.5576000281369) l1 Foil spline 17pts Re30000 N11","xver":6.991,"good":14.0179489756881,"id":284,"r":6,"CDf":0.01433,"Cpmin":-0.610212919907325,"n":11,"CL":0.552739672212494,"CD":0.0355496281068944,"CDp":0.0169156781926399},
             {"xy":[1,0,0.886567063170893,0.0334416245909756,0.724865975963962,0.060484230711275,0.512480027985969,0.0721848655413721,0.336073009809416,0.0690641996803086,0.224244466354051,0.0606837894541856,0.126806077178113,0.0468710817005621,0.0410787060933097,0.0250965833705678,0,0,0.0283459581556997,-0.00516782327111456,0.0784008671678989,-0.00209323795522636,0.103458959629261,0.000491464976179716,0.213799276880961,0.0140989773246022,0.400704281820966,0.0287721422854831,0.651800254290461,0.0350093776277712,0.880021621959914,0.0234678202974621,1,0],"Bot_Xtr":1,"sym":4.02815685280864,"alpha":3.2,"CDpres":0.02113,"clcd":17.9388730743933,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re25000-N11.dat","Top_Xtr":1,"diter":3,"src":"retestc_3.txt","Re":30000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.41522478026>12.3257402013722) l1 Foil spline 17pts Re25000 N11","good":16.0418554057324,"iver":1.2020052,"id":285,"Cm":-0.116566645853407,"CDp":0.0166589697316258,"n":12,"CL":0.637152582494272,"CD":0.0355179826431667,"Cpmin":-0.701299727253636,"CDf":0.01439},
             {"diter":3,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re35000-N12.dat","Top_Xtr":1,"Re":30000,"src":"retestc_16.txt","sym":3.70720346786897,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0322924439570789,0.724865975963962,0.0584057639071146,0.512480027985969,0.0697043206947869,0.336073009809416,0.0666908927091633,0.224244466354051,0.0585984650572652,0.126806077178113,0.0452604141555825,0.0410787060933097,0.0242341698981609,0,0,0.0283459581556997,-0.00487844434434457,0.0784008671678989,-0.00197602439718087,0.103458959629261,0.000463944761208965,0.213799276880961,0.0133094869119651,0.400704281820966,0.0271610090832343,0.651800254290461,0.0330489823910694,0.880021621959914,0.0221537094436198,1,0],"clcd":18.3001230393453,"CDpres":0.02007,"alpha":3.3,"n":13,"CL":0.631132712084967,"CD":0.0344878944654104,"CDp":0.015631665537398,"CDf":0.01442,"Cpmin":-0.71740436159114,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.7862519216457>12.9287676329622) l1 Foil spline 17pts Re35000 N12","good":16.3630451098105,"xver":6.991,"iver":1.2020052,"id":286,"r":6,"Cm":-0.110701704142251},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.7862519216457>12.9287676329622) l1 Foil spline 17pts Re35000 N12","good":16.5346786919519,"xver":6.991,"iver":1.2020052,"id":287,"r":6,"Cm":-0.110701704142251,"n":14,"CL":0.631132712084967,"CD":0.0344878944654105,"CDp":0.0156316655373979,"CDf":0.01442,"Cpmin":-0.71740436159114,"sym":3.70720346786897,"Bot_Xtr":1,"xy":[1,0,0.886567063170893,0.0322924439570789,0.724865975963962,0.0584057639071146,0.512480027985969,0.0697043206947869,0.336073009809416,0.0666908927091633,0.224244466354051,0.0585984650572652,0.126806077178113,0.0452604141555825,0.0410787060933097,0.0242341698981609,0,0,0.0283459581556997,-0.00487844434434457,0.0784008671678989,-0.00197602439718087,0.103458959629261,0.000463944761208965,0.213799276880961,0.0133094869119651,0.400704281820966,0.0271610090832343,0.651800254290461,0.0330489823910694,0.880021621959914,0.0221537094436198,1,0],"clcd":18.3001230393453,"CDpres":0.02007,"alpha":3.3,"diter":3,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re35000-N12.dat","Top_Xtr":1,"Re":30000,"src":"retest_82.txt"},
             {"Re":35000,"n":3,"xy":[1,0,0.870588443819102,0.0338750873555863,0.713516798884012,0.0609559167694237,0.580442629593444,0.0746420769387076,0.42583065729969,0.0817836040235389,0.229768114218089,0.0771824735168508,0.081788256748409,0.0529828552941695,0.010957950883341,0.0190275765610451,0,0,0.0162649038866205,-0.00826665824660573,0.04389732811481,-0.0121994340985015,0.149688687874769,-0.00676871184440525,0.394602510713099,0.021528361777947,0.578063605817522,0.0375167383304334,0.727546442647447,0.0371086301039171,0.841413116633622,0.0260322839743761,1,0],"Bot_Xtr":1,"sym":4.37416314390436,"alpha":5.2,"CDpres":0.01618,"clcd":37.4242974689806,"Top_Xtr":0.490355427907496,"Foil_fn":"optbs_spline_mid151a.dat-s17_n17s0_nsopt-Re35000-N3.dat","diter":3,"src":"retestc_1.txt","r":6,"id":288,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid151a.dat-s17_n17s0.dat (opt16.0760323466317>15.6431898415334) l1 Foil spline 17pts Re35000 N3","iver":1.2020052,"good":16.0760323480135,"Cm":-0.130498637804277,"CDp":0.00917476030693248,"CL":1.06379132746138,"CD":0.028425151556769,"Cpmin":-1.74197876329312,"CDf":0.01225},        #dud
             {"r":6,"id":289,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","good":18.5635312399738,"xver":6.991,"iver":1.2020052,"Cm":-0.150387676675614,"CDp":0.0128041714353068,"CD":0.0326595778938143,"CL":1.25227953535953,"n":4,"Cpmin":-1.73613342431045,"CDf":0.01255,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"Bot_Xtr":1,"sym":5.7279194130313,"alpha":5.7,"CDpres":0.02011,"clcd":38.343408461403,"Top_Xtr":0.538408658005029,"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","diter":3,"src":"retest_134.txt","Re":35000},
             {"Re":35000,"n":5,"src":"retestc_3.txt","diter":4,"Top_Xtr":0.538057989683511,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re35000-N5.dat","clcd":36.4512837833786,"CDpres":0.01599,"alpha":5.2,"sym":2.89148620956405,"xy":[1,0,0.872698141247438,0.0304188753310488,0.714161267721381,0.0525814910155944,0.635512217143926,0.0606888690425773,0.474011231124192,0.0721799752672999,0.271049042074955,0.0734503596501616,0.11202427196111,0.0553864983862791,0.0331845342728825,0.0273008515150259,0,0,0.0240615882590061,-0.0153266977398437,0.12652606258289,-0.0162684483829721,0.359596968815521,0.0102610666393322,0.47886911639845,0.0207946926984167,0.597083436840087,0.0259611036028955,0.713873005854957,0.0249439998384561,0.817006552045902,0.0190570291760259,1,0],"Bot_Xtr":1,"CDf":0.01202,"Cpmin":-1.59238908928287,"CL":1.02110925952355,"CD":0.0280129848263166,"CDp":0.00966497239555002,"Cm":-0.11100330407615,"id":290,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt16.9610059647374>16.8834842052965) l1 Foil spline 17pts Re35000 N5","good":16.9610056904219,"iver":1.2020052,"r":6},        #dud
             {"Re":35000,"n":6,"id":291,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt16.9951313006478>16.1739146312688) l1 Foil spline 17pts Re35000 N6","xver":6.991,"iver":1.2020052,"good":16.9951313012879,"r":6,"Cm":-0.118543744342768,"CD":0.0287806773585596,"CL":1.04555040025103,"CDp":0.0112002031826204,"CDf":0.0113,"Cpmin":-1.7388517065775,"sym":2.88000458683892,"Bot_Xtr":1,"xy":[1,0,0.872698141247438,0.0297332325145057,0.714161267721381,0.0513963018458563,0.635512217143926,0.0593209392078835,0.474011231124192,0.0705530353820579,0.271049042074955,0.0717947852438573,0.11202427196111,0.0541380842243896,0.0331845342728825,0.0266854890953745,0,0,0.0240615882590061,-0.0168952975627051,0.12652606258289,-0.0179334309959861,0.359596968815521,0.0113112281017707,0.47886911639845,0.0229229105204723,0.597083436840087,0.0286180740217044,0.713873005854957,0.0274968755062748,0.817006552045902,0.0210074070785058,1,0],"clcd":36.3282068460448,"CDpres":0.01748,"alpha":5.2,"diter":4,"Top_Xtr":0.563529796559684,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re35000-N6.dat","src":"retest_153.txt"},        #dud
             {"Re":35000,"n":7,"Cm":-0.120948706618804,"r":6,"id":292,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt17.5955369412669>12.877065903133) l1 Foil spline 17pts Re35000 N7","iver":1.2020052,"xver":6.991,"good":17.5954897800354,"Cpmin":-1.56929006829897,"CDf":0.01138,"CDp":0.00608426969714301,"CL":0.987089450325995,"CD":0.0181089682099517,"alpha":4,"clcd":54.5083208983461,"CDpres":0.00673,"Bot_Xtr":1,"xy":[1,0,0.899630566949792,0.0261921599288413,0.727739042677004,0.053380539687003,0.592614898283108,0.0679818845916378,0.4516898617015,0.0799640628564804,0.252873926024019,0.0807510512055346,0.0811582397809066,0.0521976213245977,0.00557700402728914,0.00761223609330723,0,0,0.00141252526740496,-0.0127307336381641,0.0452001277636599,-0.0134635216723534,0.199612166740877,0.0142447055524001,0.377122071379592,0.0328851080868409,0.554590024942112,0.0357274252485017,0.69102752205303,0.0310531520818165,0.809701462099824,0.0228688843535896,1,0],"sym":4.57651517262057,"src":"retestc_5.txt","Top_Xtr":0.583651880514081,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re35000-N7.dat","diter":58},        #dud
             {"Top_Xtr":0.614364163069606,"Foil_fn":"optbs-spline_foil_mid117.dat-s17_n17s0-Re65536-N12.dat","diter":4,"src":"retest_156.txt","Re":35000,"xy":[1,0,0.872698141247438,0.0268471305397061,0.714161267721381,0.0464074407059735,0.635512217143926,0.053562860946083,0.474011231124192,0.0637046964184111,0.271049042074955,0.0648259139187663,0.11202427196111,0.0488830877582083,0.0331845342728825,0.0240952210261668,0,0,0.0240615882590061,-0.0142346433568457,0.12652606258289,-0.0151092925972469,0.359596968815521,0.00952994745189067,0.47886911639845,0.0193130339817209,0.597083436840087,0.0241113289509622,0.713873005854957,0.023166695632719,0.817006552045902,0.0176991820655882,1,0],"Bot_Xtr":1,"sym":2.29082429046993,"alpha":5.2,"clcd":33.8133332624315,"CDpres":0.01978,"CDp":0.0137938332536428,"CD":0.0300797017154799,"CL":1.01709497854006,"n":8,"Cpmin":-1.95805217294987,"CDf":0.0103,"r":6,"id":293,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt17.0747915417592>17.0203424728352) l1 Foil spline 17pts Re65536 N12","xver":6.991,"iver":1.2020052,"good":15.4429133109454,"Cm":-0.113253876243889},
             {"clcd":30.0140113477237,"CDpres":0.02129,"alpha":5.1,"sym":1.89243733696084,"xy":[1,0,0.878975273482532,0.0230232997762278,0.693171356185715,0.0464621771556044,0.544333140623122,0.0586567658191277,0.407469712002341,0.0656259009733948,0.22072973095756,0.0659571638155934,0.076291614436262,0.0480187697400249,0.00869208529312013,0.0186288902236564,0,0,0.0187574897119247,-0.00999748933038275,0.0549926622788392,-0.016751440194709,0.176538175043836,-0.0162642396285884,0.441887065428039,0.00579833364527481,0.574320105122134,0.015336151024845,0.692814874122089,0.0185136905657929,0.809542173172325,0.0152682933549534,1,0],"Bot_Xtr":1,"Re":35000,"src":"retest_37.txt","diter":4,"Top_Xtr":0.573322142384675,"Foil_fn":"optbs_spline_mid103c3.dat-s17_n17s0_nsopt-Re35000-N8.dat","Cm":-0.0977684488683178,"id":294,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103c3.dat-s17_n17s0.dat (opt14.5108885579553>14.0103726947651) l1 Foil spline 17pts Re35000 N8","xver":6.991,"good":13.2703726688072,"iver":1.2020052,"r":6,"CDf":0.01007,"Cpmin":-1.93585961177137,"CL":0.941190815638799,"CD":0.0313583814150913,"n":9,"CDp":0.0157036255004955},
             {"CDp":0.0135344284962341,"n":10,"CD":0.0280836070346844,"CL":0.733268263369534,"Cpmin":-1.6568828095717,"CDf":0.01014,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_nm41-3f3j.dat-s17_n17s0.dat (opt8.60386885952982>7.16400583948353) l1 Foil spline 17pts Re15000 N6","good":13.8225319183579,"iver":1.2020052,"id":295,"Cm":-0.0568569319755773,"Foil_fn":"optbs_spline_nm41-3f3j.dat-s17_n17s0_nsopt-Re15000-N6.dat","Top_Xtr":0.630153204253388,"diter":5,"src":"retest_85.txt","Re":35000,"xy":[1,0,0.892848999841582,0.0123977459571567,0.756522100759719,0.0216157622293414,0.608188838447927,0.0320642317690672,0.55378653104057,0.0353892799510012,0.407118568807792,0.0428525837670961,0.204514619107291,0.0450704015452999,0.0562389665156836,0.028902566015506,0,0,0.0558257084704899,-0.0100234096147003,0.209141021385944,-0.00771715512636164,0.312525357045972,-0.0049947125790123,0.504881133701465,-0.000886244999363081,0.622884168776568,0.00124275551612207,0.756234201511708,0.0028679338801451,0.891544256201031,0.00272267139148484,1,0],"Bot_Xtr":1,"sym":0.608076815651157,"alpha":4.4,"CDpres":0.01794,"clcd":26.1101881415702},
             {"CDp":0.0162735554630982,"n":11,"CL":0.740832941984594,"CD":0.0303537310116813,"Cpmin":-1.62653262933012,"CDf":0.00979,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_nm41-3f3j.dat-s17_n17s0.dat (opt8.60386885952982>7.16400583948353) l1 Foil spline 17pts Re15000 N6","good":13.1930505228151,"iver":1.2020052,"id":296,"Cm":-0.0632619162458714,"Foil_fn":"optbs_spline_nm41-3f3j.dat-s17_n17s0_nsopt-Re15000-N6.dat","Top_Xtr":0.655858761818396,"diter":4,"src":"retest_86.txt","Re":35000,"xy":[1,0,0.892848999841582,0.0123977459571567,0.756522100759719,0.0216157622293414,0.608188838447927,0.0320642317690672,0.55378653104057,0.0353892799510012,0.407118568807792,0.0428525837670961,0.204514619107291,0.0450704015452999,0.0562389665156836,0.028902566015506,0,0,0.0558257084704899,-0.0100234096147003,0.209141021385944,-0.00771715512636164,0.312525357045972,-0.0049947125790123,0.504881133701465,-0.000886244999363081,0.622884168776568,0.00124275551612207,0.756234201511708,0.0028679338801451,0.891544256201031,0.00272267139148484,1,0],"Bot_Xtr":1,"sym":0.608076815651157,"alpha":4.4,"clcd":24.4066517456945,"CDpres":0.02057},
             {"id":297,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt15.0941836078143>12.624602765761) l1 Foil spline 17pts Re35000 N12","iver":1.2020052,"xver":6.991,"good":14.9529287173813,"r":6,"Cm":-0.0915520163489237,"CL":0.535198278187339,"CD":0.0322680899886566,"n":12,"CDp":0.0147927571330309,"CDf":0.01339,"Cpmin":-0.599209270475961,"sym":2.9456310693317,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.0157151299406333,0.863082022377036,0.0321349576300939,0.698195158425591,0.0543096474433878,0.497241313912823,0.0676745338038654,0.28552715888499,0.0632564455718427,0.125732819683231,0.0444470670769709,0.0360765344716023,0.0212487866244665,0,0,0.0192507166066205,-0.00754436646182311,0.113363722509556,-0.00119836197508259,0.268607859414087,0.0125606395297192,0.440775378221921,0.0227263034636579,0.638477319107758,0.0259044181634568,0.818181208003633,0.0205828807065632,0.939515187720928,0.0102655709963558,1,0],"CDpres":0.01888,"clcd":16.5859918692268,"alpha":3.1,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re35000-N12.dat","Re":35000,"src":"retestc_10.txt"},
             {"Cpmin":-0.649314544336256,"CDf":0.01304,"CDp":0.0135818613510574,"n":13,"CL":0.560246283502764,"CD":0.0303482973671686,"Cm":-0.102213114761734,"r":6,"cmt":"NEWv1.20200506 s(0) foildb2020/e71.dat (sim 0.000053267974 ) l2 Foil spline 17pts","xver":6.991,"iver":1.2020052,"good":16.3838597680699,"id":298,"src":"retest_67.txt","Re":35000,"Foil_fn":"spline_foil_e71.dat-s17_n17s0-Re30000-N12.dat","Top_Xtr":1,"diter":3,"alpha":2.8,"clcd":18.4605507427527,"CDpres":0.01731,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0186485947187742,0.833474960203591,0.0377710981415621,0.683294039292584,0.0559310324118528,0.512919921681868,0.065820745163278,0.327643312365742,0.0646504382976995,0.159685519883032,0.0504700417591885,0.0454559935430201,0.0260559565674557,0,-2.53280257524292e-11,0.0261984228078157,-0.00855507725543669,0.134241453700877,-0.00200465240735748,0.290009257938815,0.0116082655642347,0.464856398032139,0.022709087005342,0.654716626975926,0.0277767970592271,0.826995021496349,0.02336311130395,0.941457504275826,0.0124069690748623,1,0],"sym":2.91564656207883},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e58.dat-s17_n17s0.dat (opt15.41522478026>12.3257402013722) l1 Foil spline 17pts Re25000 N11","xver":6.991,"good":16.5879275630658,"iver":1.2020052,"id":299,"Cm":-0.117680208260449,"CDp":0.0159867704551604,"n":14,"CL":0.626648022734594,"CD":0.0335645184454961,"Cpmin":-0.674002019812619,"CDf":0.01335,"xy":[1,0,0.886567063170893,0.0334416245909756,0.724865975963962,0.060484230711275,0.512480027985969,0.0721848655413721,0.336073009809416,0.0690641996803086,0.224244466354051,0.0606837894541856,0.126806077178113,0.0468710817005621,0.0410787060933097,0.0250965833705678,0,0,0.0283459581556997,-0.00516782327111456,0.0784008671678989,-0.00209323795522636,0.103458959629261,0.000491464976179716,0.213799276880961,0.0140989773246022,0.400704281820966,0.0287721422854831,0.651800254290461,0.0350093776277712,0.880021621959914,0.0234678202974621,1,0],"Bot_Xtr":1,"sym":4.02815685280864,"alpha":3,"CDpres":0.02021,"clcd":18.6699542182373,"Foil_fn":"optbs_spline_e58.dat-s17_n17s0_nsopt-Re25000-N11.dat","Top_Xtr":1,"diter":3,"src":"retest_68.txt","Re":35000},
             {"Re":45000,"n":3,"Cm":-0.136458779904682,"id":300,"good":18.8665108268527,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid151b.dat-s17_n17s0.dat (opt18.8665108224329>18.5706754919291) l1 Foil spline 17pts Re45000 N3","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.01122,"Cpmin":-1.62812201500546,"CD":0.0240502188254044,"CL":1.04395797581856,"CDp":0.00688953880691612,"clcd":43.4074210882365,"CDpres":0.01283,"alpha":4.7,"sym":4.79496373833408,"xy":[1,0,0.862926473720977,0.0362091541628128,0.706232125768396,0.0631042386327788,0.589491403005069,0.0750719486474338,0.45243702485915,0.082169997409071,0.244588151966263,0.0789095546464975,0.0825412678338485,0.0543172092188476,0.00663965827932917,0.0188883323515757,0,8.13562220638123e-05,0.030250082137294,-0.00736628608771291,0.0862534058217635,-0.00627346530970516,0.199571300807936,0.00385136194203787,0.401803504652668,0.0261171687570399,0.575597831498413,0.0393333245981048,0.721642545045594,0.0383285659978626,0.840391845146695,0.0267063627132582,1,0],"Bot_Xtr":1,"src":"retest_111.txt","diter":3,"Top_Xtr":0.519809574858645,"Foil_fn":"optbs_spline_mid151b.dat-s17_n17s0_nsopt-Re45000-N3.dat"},        #dud
             {"Cpmin":-1.50690072584926,"CDf":0.01244,"CDp":0.0071485679878873,"CL":1.07587539023708,"CD":0.0256268164623264,"n":4,"Cm":-0.115631150760019,"r":6,"id":301,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt26.2922973321533>25.9993252592505) l1 Foil spline 17pts Re65536 N7","xver":6.991,"good":19.6301536867321,"src":"retest_22.txt","Re":45000,"Top_Xtr":0.499032839680092,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re65536-N7.dat","diter":3,"alpha":5.2,"clcd":41.9824051036033,"CDpres":0.01319,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0353871549839282,0.641452589715019,0.0725405728620992,0.416262776127718,0.0882492376763196,0.233866556084622,0.0844352505302647,0.132025845000493,0.0697349913402681,0.0665475051364794,0.0489577692538254,0.0222714169962174,0.0266997931156935,0,0,0.0219899769144022,-0.00857785692673669,0.0671574276679874,-0.00621934543939348,0.108585510576379,-0.00189691853187402,0.25711939037162,0.017275257464476,0.414690606933141,0.0294673328082166,0.609466583507779,0.0317268595694849,0.764025880785643,0.0234597275413734,1,0],"sym":4.91245488653155},
             {"Cm":-0.116809680699562,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt26.7512856822675>25.4456399415582) l1 Foil spline 17pts Re65536 N6","good":20.5610194085219,"iver":1.2020052,"id":302,"r":6,"CDf":0.01165,"Cpmin":-1.60635491059252,"n":5,"CD":0.0253113264916992,"CL":1.09178398936859,"CDp":0.00766315698208838,"CDpres":0.01366,"clcd":43.1342067246707,"alpha":5.3,"sym":4.4588776878371,"xy":[1,0,0.868523950462083,0.0331962074444972,0.641452589715019,0.0680493220199981,0.416262776127718,0.0827854062315085,0.233866556084622,0.0792075569088209,0.132025845000493,0.0654174442597359,0.0665475051364794,0.0459266156012807,0.0222714169962174,0.0250467117629622,0,0,0.0219899769144022,-0.00862467484406239,0.0671574276679874,-0.00625329060810969,0.108585510576379,-0.00190727190751987,0.25711939037162,0.017369545767797,0.414690606933141,0.0296281654221209,0.609466583507779,0.0319000246736613,0.764025880785643,0.0235877706637869,1,0],"Bot_Xtr":1,"Re":45000,"src":"retest_154.txt","diter":5,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re65536-N6.dat","Top_Xtr":0.532352492251405},
             {"Re":45000,"src":"retestc_14.txt","diter":5,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re45000-N6.dat","Top_Xtr":0.542274219348878,"CDpres":0.01568,"clcd":42.3939466512856,"alpha":5.6,"sym":4.64669926290376,"xy":[1,0,0.868523950462083,0.0341835828432945,0.641452589715019,0.0700733552346272,0.416262776127718,0.0852477439437033,0.233866556084622,0.0815634764282831,0.132025845000493,0.0673631959008608,0.0665475051364794,0.0472926394300732,0.0222714169962174,0.0257916916543207,0,0,0.0219899769144022,-0.00854659207733985,0.0671574276679874,-0.00619667696868217,0.108585510576379,-0.00189000458207005,0.25711939037162,0.017212292049276,0.414690606933141,0.0293599293238446,0.609466583507779,0.0316112204891474,0.764025880785643,0.0233742207703074,1,0],"Bot_Xtr":1,"CDf":0.0113,"Cpmin":-1.6934070648674,"n":6,"CD":0.0269779140013124,"CL":1.14370024693461,"CDp":0.00929311838534637,"Cm":-0.121071511984921,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt20.4630203072951>20.24323903623) l1 Foil spline 17pts Re45000 N6","xver":6.991,"good":20.4630225116829,"id":303,"r":6},
             {"Re":45000,"src":"retest_81.txt","diter":4,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re55000-N7.dat","Top_Xtr":0.586530014492041,"CDpres":0.01493,"clcd":42.3411716312219,"alpha":4.9,"sym":3.15950710469988,"xy":[1,0,0.872698141247438,0.031075857807284,0.714161267721381,0.0537171384646079,0.635512217143926,0.0619996184713312,0.474011231124192,0.0737389079487231,0.271049042074955,0.0750367299100139,0.11202427196111,0.0565827279793789,0.0331845342728825,0.0278904913631949,0,0,0.0240615882590061,-0.0178626551062865,0.12652606258289,-0.0189602279311616,0.359596968815521,0.0119588640366104,0.47886911639845,0.0242353852093922,0.597083436840087,0.0302566311222776,0.713873005854957,0.029071237239011,0.817006552045902,0.0222102076585522,1,0],"Bot_Xtr":1,"CDf":0.01026,"Cpmin":-1.61025083389526,"n":7,"CL":1.06660477908194,"CD":0.0251907242523122,"CDp":0.0095306912396226,"Cm":-0.128917197047397,"good":19.7198277320955,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt23.2089002984392>22.5436474954465) l1 Foil spline 17pts Re55000 N7","xver":6.991,"iver":1.2020052,"id":304,"r":6},
             {"Re":45000,"n":8,"Cm":-0.122804857416078,"r":6,"id":305,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt19.3599414781884>18.9451609837954) l1 Foil spline 17pts Re45000 N8","good":19.3599414769247,"xver":6.991,"iver":1.2020052,"Cpmin":-1.72196029883287,"CDf":0.00969,"CDp":0.0098755414239844,"CD":0.0246916103237253,"CL":1.02702202859414,"alpha":4.8,"CDpres":0.015,"clcd":41.5939671462945,"Bot_Xtr":1,"xy":[1,0,0.872698141247438,0.0285047171395745,0.714161267721381,0.0492727134670471,0.635512217143926,0.0568699212825138,0.474011231124192,0.0676379305856778,0.271049042074955,0.0688283739238326,0.11202427196111,0.0519012110957605,0.0331845342728825,0.0255829001446026,0,0,0.0240615882590061,-0.0162246634127557,0.12652606258289,-0.0172215896562859,0.359596968815521,0.0108622454298312,0.47886911639845,0.0220130190814959,0.597083436840087,0.027482121389115,0.713873005854957,0.0264054272105004,0.817006552045902,0.0201735487497934,1,0],"sym":2.64859184348515,"src":"retestc_16.txt","Top_Xtr":0.623604568592091,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re45000-N8.dat","diter":7},        #dud
             {"alpha":6.2,"CDpres":0.01498,"clcd":55.6875964835997,"Bot_Xtr":1,"xy":[1,0,0.862926473720977,0.0406066173791891,0.706232125768396,0.070768006942232,0.589491403005069,0.0841891495429415,0.45243702485915,0.0921492291655316,0.244588151966263,0.0884928181057411,0.0825412678338485,0.0609138264301218,0.00663965827932917,0.021182248038235,0,9.2084217915366e-05,0.030250082137294,-0.00845404044221571,0.0862534058217635,-0.007199846545405,0.199571300807936,0.00442007943051635,0.401803504652668,0.0299738020325437,0.575597831498413,0.0451415425520649,0.721642545045594,0.0439884146746017,0.840391845146695,0.0306500002516825,1,0],"sym":6.10045745564607,"src":"retest_0.txt","Re":45000,"Foil_fn":"optbs_spline_mid151b.dat-s17_n17s0_nsopt-Re45000-N9.dat","Top_Xtr":0.578029629015297,"diter":6,"Cm":-0.159009191504381,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid151b.dat-s17_n17s0.dat (opt19.5710031942665>15.7672585081046) l1 Foil spline 17pts Re45000 N9","good":19.571076560426,"iver":1.2020052,"id":306,"Cpmin":-2.48691422044302,"CDf":0.00822,"CDp":0.0107037334930452,"n":9,"CD":0.0231990813588162,"CL":1.29190108149996},
             {"Re":45000,"n":10,"sym":4.64055571359972,"Bot_Xtr":1,"xy":[1,0,0.899630566949792,0.0262528431047967,0.727739042677004,0.0535042141258894,0.592614898283108,0.0681393880841205,0.4516898617015,0.0801493271993072,0.252873926024019,0.0809381388784185,0.0811582397809066,0.0523185551249373,0.00557700402728914,0.00762987246478325,0,0,0.00141252526740496,-0.0129836822943098,0.0452001277636599,-0.0137310301923495,0.199612166740877,0.0145277355198066,0.377122071379592,0.0335385067152465,0.554590024942112,0.03643729825826,0.69102752205303,0.0316701513303622,0.809701462099824,0.0233232692876559,1,0],"clcd":43.5883577644141,"CDpres":0.01272,"alpha":4.3,"diter":4,"Top_Xtr":0.482524287572169,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re45000-N10.dat","src":"retest_2.txt","id":307,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt29.6128301461063>15.8697848428496) l1 Foil spline 17pts Re45000 N10","iver":1.2020052,"good":20.2637172489228,"r":6,"Cm":-0.122940295390371,"CL":1.04884667293691,"CD":0.0240625416219097,"CDp":0.005818927694775,"CDf":0.01134,"Cpmin":-1.75978376110841},        #dud
             {"Re":45000,"n":11,"CDpres":0.00419,"clcd":70.2762785871572,"alpha":3.7,"sym":4.64055571359972,"xy":[1,0,0.899630566949792,0.0262528431047967,0.727739042677004,0.0535042141258894,0.592614898283108,0.0681393880841205,0.4516898617015,0.0801493271993072,0.252873926024019,0.0809381388784185,0.0811582397809066,0.0523185551249373,0.00557700402728914,0.00762987246478325,0,0,0.00141252526740496,-0.0129836822943098,0.0452001277636599,-0.0137310301923495,0.199612166740877,0.0145277355198066,0.377122071379592,0.0335385067152465,0.554590024942112,0.03643729825826,0.69102752205303,0.0316701513303622,0.809701462099824,0.0233232692876559,1,0],"Bot_Xtr":1,"src":"retest_3.txt","diter":4,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re45000-N10.dat","Top_Xtr":0.607930509260406,"Cm":-0.128018076281858,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt29.6128301461063>15.8697848428496) l1 Foil spline 17pts Re45000 N10","iver":1.2020052,"good":23.1832618066546,"id":308,"r":6,"CDf":0.01001,"Cpmin":-1.48367106699546,"CL":0.997649130649747,"CD":0.0141961007427628,"CDp":0.00429068205519354},        #dud
             {"n":12,"CD":0.0223791104840432,"CL":0.681448849226732,"CDp":0.0099164140588776,"CDf":0.00896,"Cpmin":-1.22750485950006,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ag13.dat-s17_n17s0.dat (opt15.0376071749107>14.2186482017551) l1 Foil spline 17pts Re45000 N12","good":15.0376124194843,"xver":6.991,"iver":1.2020052,"id":309,"r":6,"Cm":-0.0721564005946158,"diter":5,"Foil_fn":"optbs_spline_ag13.dat-s17_n17s0_nsopt-Re45000-N12.dat","Top_Xtr":0.763481144621179,"Re":45000,"src":"retestc_20.txt","sym":0.594895452744471,"Bot_Xtr":1,"xy":[1,0,0.869096015625,0.0178908188732777,0.73138607421875,0.0242303622437003,0.594386054102955,0.0343626553389921,0.455657540388373,0.042582842672229,0.325524702491026,0.046620811869754,0.187963209843909,0.04528406523651,0.0557256738271807,0.0301145616597721,0,5.25566822571611e-05,0.0548520109483167,-0.0138497516328164,0.192834567378491,-0.0136786326778368,0.325536273725442,-0.00808967854967708,0.465369299885471,-0.00224917620167309,0.600668871331738,0.002299750113409,0.737779062164382,0.00401338301209745,0.872041,0.00283308991155533,1,0],"clcd":30.4502205175948,"CDpres":0.01342,"alpha":3.6},
             {"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re30000-N11.dat","Top_Xtr":1,"diter":3,"src":"retest_103.txt","Re":45000,"xy":[1,0,0.945514649029338,0.0165934377278167,0.863082022377036,0.0339309582762192,0.698195158425591,0.057344976228381,0.497241313912823,0.0714568168812873,0.28552715888499,0.0667918047413295,0.125732819683231,0.0469311830390178,0.0360765344716023,0.0224363666719094,0,0,0.0192507166066205,-0.00839272300358051,0.113363722509556,-0.00133311659312761,0.268607859414087,0.013973071013213,0.440775378221921,0.0252818537952756,0.638477319107758,0.0288173443475962,0.818181208003633,0.0228974052705523,0.939515187720928,0.0114199242947677,1,0],"Bot_Xtr":1,"sym":3.36859783931288,"alpha":2.7,"CDpres":0.01971,"clcd":16.9189499485556,"CDp":0.0157847862385207,"n":13,"CL":0.529968047534788,"CD":0.0313239325812908,"Cpmin":-0.574352887499602,"CDf":0.01161,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt14.0179489827091>12.5576000281369) l1 Foil spline 17pts Re30000 N11","good":14.4715474063547,"xver":6.991,"iver":1.2020052,"id":310,"Cm":-0.102095591638651},
             {"id":311,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt15.0941836078143>12.624602765761) l1 Foil spline 17pts Re35000 N12","iver":1.2020052,"xver":6.991,"good":15.4961282050326,"r":6,"Cm":-0.0926567848808253,"CL":0.5234021165445,"CD":0.0299466571881396,"n":14,"CDp":0.0142831164480304,"CDf":0.01178,"Cpmin":-0.579088570496293,"sym":2.9456310693317,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.0157151299406333,0.863082022377036,0.0321349576300939,0.698195158425591,0.0543096474433878,0.497241313912823,0.0676745338038654,0.28552715888499,0.0632564455718427,0.125732819683231,0.0444470670769709,0.0360765344716023,0.0212487866244665,0,0,0.0192507166066205,-0.00754436646182311,0.113363722509556,-0.00119836197508259,0.268607859414087,0.0125606395297192,0.440775378221921,0.0227263034636579,0.638477319107758,0.0259044181634568,0.818181208003633,0.0205828807065632,0.939515187720928,0.0102655709963558,1,0],"CDpres":0.01817,"clcd":17.4778144103441,"alpha":2.9,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re35000-N12.dat","Re":45000,"src":"retest_23.txt"},
             {"clcd":51.0188562569704,"CDpres":0.0123,"alpha":5,"sym":5.7279194130313,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"Bot_Xtr":1,"Re":55000,"src":"retest_9.txt","diter":3,"Top_Xtr":0.478932848017954,"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","Cm":-0.153781584482016,"id":312,"xver":6.991,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","good":21.8258465032386,"iver":1.2020052,"r":6,"CDf":0.01155,"Cpmin":-1.64734389773122,"CD":0.0238498041996377,"CL":1.2167897322182,"n":3,"CDp":0.0067284250215466},
             {"CDf":0.01138,"Cpmin":-1.41533910665146,"n":4,"CD":0.0214627478441878,"CL":1.03222621929668,"CDp":0.0051549133509518,"Cm":-0.119378227805736,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","good":22.7448131693734,"xver":6.991,"iver":1.2020052,"id":313,"r":6,"Re":55000,"src":"retest_16.txt","diter":3,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Top_Xtr":0.514234805199229,"clcd":48.0938520449612,"CDpres":0.01008,"alpha":4.6,"sym":4.5387969219134,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"Bot_Xtr":1},
             {"diter":3,"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","Top_Xtr":0.553832440131984,"Re":55000,"src":"retest_11.txt","sym":5.7279194130313,"Bot_Xtr":1,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"CDpres":0.01365,"clcd":51.7536108690122,"alpha":5.1,"n":5,"CD":0.0243045825801438,"CL":1.25784990918653,"CDp":0.00813407739163079,"CDf":0.01066,"Cpmin":-1.69986711563897,"xver":6.991,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","iver":1.2020052,"good":25.5369567024255,"id":314,"r":6,"Cm":-0.160434983925206},
             {"diter":5,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Top_Xtr":0.558484016851178,"Re":55000,"src":"retest_18.txt","sym":4.5387969219134,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"clcd":49.0340463374818,"CDpres":0.01181,"alpha":5,"n":6,"CD":0.0223767100547512,"CL":1.09722063770506,"CDp":0.00659573816363876,"CDf":0.01056,"Cpmin":-1.56696899354964,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","good":23.4398458863197,"iver":1.2020052,"id":315,"r":6,"Cm":-0.123999946695821},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt35.7177480060821>34.4566039170131) l1 Foil spline 17pts Re100000 N8","good":23.7551683350185,"xver":6.991,"iver":1.2020052,"id":316,"r":6,"Cm":-0.138382926468528,"n":7,"CL":1.18238513910651,"CD":0.024687511405233,"CDp":0.00850459789144109,"CDf":0.01063,"Cpmin":-1.58666102948031,"sym":5.65460418250154,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0371700970527708,0.641452589715019,0.076195448172435,0.416262776127718,0.0926955764245989,0.233866556084622,0.0886894258187853,0.132025845000493,0.0732485105759177,0.0665475051364794,0.0514244514846795,0.0222714169962174,0.0280450322115459,0,0,0.0219899769144022,-0.00989806604638302,0.0671574276679874,-0.00717655848659708,0.108585510576379,-0.00218887130823712,0.25711939037162,0.0199340745377419,0.414690606933141,0.0340026196330414,0.609466583507779,0.0366099078295714,0.764025880785643,0.0270703900307421,1,0],"CDpres":0.01406,"clcd":47.8940594577662,"alpha":5.2,"diter":4,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re100000-N8.dat","Top_Xtr":0.563818288410892,"Re":55000,"src":"retest_70.txt"},
             {"Cm":-0.133902527631554,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt23.0737829739957>22.3806890740437) l1 Foil spline 17pts Re55000 N8","xver":6.991,"iver":1.2020052,"good":23.0737829584583,"id":317,"r":6,"CDf":0.00945,"Cpmin":-1.50973412634237,"n":8,"CL":1.06227911008523,"CD":0.0224284715471281,"CDp":0.00831360235651706,"clcd":47.3629737921775,"CDpres":0.01298,"alpha":4.6,"sym":3.24560032404956,"xy":[1,0,0.872698141247438,0.0317274593209252,0.714161267721381,0.054843484483729,0.635512217143926,0.0632996323113875,0.474011231124192,0.0752850723163039,0.271049042074955,0.0766101071307253,0.11202427196111,0.0577691599493652,0.0331845342728825,0.0284753018131962,0,0,0.0240615882590061,-0.0175249838149494,0.12652606258289,-0.0186018083898635,0.359596968815521,0.011732796576978,0.47886911639845,0.0237772453768189,0.597083436840087,0.0296846671201862,0.713873005854957,0.0285216816348271,0.817006552045902,0.0217903512902629,1,0],"Bot_Xtr":1,"Re":55000,"src":"retest_94.txt","diter":5,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re55000-N8.dat","Top_Xtr":0.617657616911505},
             {"r":6,"id":318,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt29.1501133439728>27.2357069998813) l1 Foil spline 17pts Re80000 N11","iver":1.2020052,"xver":6.991,"good":22.362915926023,"Cm":-0.115155997381156,"CDp":0.00916698053862393,"CD":0.022643649224673,"CL":0.998458317106514,"n":9,"Cpmin":-1.38093145802143,"CDf":0.00991,"xy":[1,0,0.932175646467167,0.0160482403493011,0.822686565492564,0.0333184209106194,0.678803188734605,0.0501605170011316,0.467813461804766,0.0679332046947079,0.299436270431163,0.0721776690511335,0.134160023906898,0.0597786722341117,0.0364048536456623,0.0306761763134632,0,0,0.0270013726530119,-0.0127478700013051,0.12487691305341,0.000346563710990387,0.281461101187184,0.0200785620721386,0.47006254090453,0.0292008029795955,0.68986358510747,0.0255866978881908,0.86337155350222,0.0141654851163227,0.97248200666718,0.000624421251049684,1,0],"Bot_Xtr":1,"sym":3.33586957646476,"alpha":4.3,"clcd":44.0944084232931,"CDpres":0.01273,"Top_Xtr":0.633597996637624,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N11.dat","diter":5,"src":"retest_130.txt","Re":55000},
             {"Re":55000,"n":10,"CDpres":0.00103,"clcd":85.2774130484962,"alpha":3,"sym":4.67828473485017,"xy":[1,0,0.899630566949792,0.026408686488398,0.727739042677004,0.0538218284022946,0.592614898283108,0.0685438803805611,0.4516898617015,0.080625113471074,0.252873926024019,0.0814186077318245,0.0811582397809066,0.0526291310356398,0.00557700402728914,0.00767516527884579,0,0,0.00141252526740496,-0.012969962906616,0.0452001277636599,-0.0137165211091499,0.199612166740877,0.0145123845868901,0.377122071379592,0.0335030677876858,0.554590024942112,0.036398796282473,0.69102752205303,0.0316366866263919,0.809701462099824,0.0232986244321833,1,0],"Bot_Xtr":1,"src":"retestc_16.txt","diter":6,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re55000-N11.dat","Top_Xtr":0.573191857473211,"Cm":-0.127774154320454,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt36.1192239289666>17.792684054303) l1 Foil spline 17pts Re55000 N11","iver":1.2020052,"xver":6.991,"good":27.7182482692665,"id":319,"r":6,"CDf":0.00988,"Cpmin":-1.31609330974647,"CL":0.930691380617857,"CD":0.0109136915315265,"CDp":0.00130593461916361},        #dud
             {"Re":55000,"n":11,"Cm":-0.130674952857154,"r":6,"id":320,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt19.5052323765844>18.8677579427738) l1 Foil spline 17pts Re55000 N11","xver":6.991,"iver":1.2020052,"good":19.5284524977865,"Cpmin":-1.7855689867377,"CDf":0.0085,"CDp":0.0114447002442105,"CD":0.0244339523773018,"CL":1.06086121736693,"alpha":4.8,"clcd":43.4175036844398,"CDpres":0.01594,"Bot_Xtr":1,"xy":[1,0,0.872698141247438,0.028572452691705,0.714161267721381,0.0493897998578826,0.635512217143926,0.0570050608630551,0.474011231124192,0.0677986581084508,0.271049042074955,0.0689919302884563,0.11202427196111,0.0520245435664038,0.0331845342728825,0.0256436926042475,0,0,0.0240615882590061,-0.0162527970175647,0.12652606258289,-0.0172514519335638,0.359596968815521,0.0108810805891493,0.47886911639845,0.0220511897087525,0.597083436840087,0.0275297754527345,0.713873005854957,0.0264512142838624,0.817006552045902,0.0202085297311354,1,0],"sym":2.66056163256118,"src":"retestc_5.txt","Top_Xtr":0.637296040398485,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re55000-N11.dat","diter":4},        #dud
             {"Re":55000,"n":12,"xy":[1,0,0.899630566949792,0.0264715048336189,0.727739042677004,0.0539498543909586,0.592614898283108,0.0687069257157547,0.4516898617015,0.0808168964366419,0.252873926024019,0.0816122781822707,0.0811582397809066,0.0527543199549571,0.00557700402728914,0.00769342219527083,0,0,0.00141252526740496,-0.0129235486996504,0.0452001277636599,-0.0136674352748887,0.199612166740877,0.0144604506818643,0.377122071379592,0.0333831739735341,0.554590024942112,0.036268539837168,0.69102752205303,0.0315234718291442,0.809701462099824,0.0232152481585428,1,0],"Bot_Xtr":1,"sym":4.68564842882372,"alpha":4.3,"CDpres":0.01163,"clcd":48.9710335081933,"Top_Xtr":0.47981668919303,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re30000-N9.dat","diter":4,"src":"retest_129.txt","r":6,"id":321,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt11.9372951851391>11.7166103994334) l1 Foil spline 17pts Re30000 N9","good":18.917520521695,"iver":1.2020052,"Cm":-0.125996637160697,"CDp":0.00472811169001038,"CD":0.0218685808031077,"CL":1.07092700328562,"Cpmin":-1.76366972299045,"CDf":0.01024},        #dud
             {"Re":55000,"n":13,"CD":0.0216672982862771,"CL":1.06560882021098,"CDp":0.00454426978127982,"CDf":0.0103,"Cpmin":-2.00541443291577,"id":322,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt11.0328608490266>9.65783804940609) l1 Foil spline 17pts Re25000 N8","good":16.9500125001149,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.117354729290418,"diter":3,"Top_Xtr":0.458761065121549,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re25000-N8.dat","src":"retest_31.txt","sym":4.12331523561471,"Bot_Xtr":1,"xy":[1,0,0.899630566949792,0.0249046320647822,0.727739042677004,0.0507565127861194,0.592614898283108,0.0646400994581942,0.4516898617015,0.0760332698508331,0.252873926024019,0.0767815722178663,0.0811582397809066,0.0496317431352615,0.00557700402728914,0.00723804144481103,0,0,0.00141252526740496,-0.0120257886729748,0.0452001277636599,-0.0127179996870225,0.199612166740877,0.0134559267007504,0.377122071379592,0.0310641453650989,0.554590024942112,0.0337490735474963,0.69102752205303,0.029333631130745,0.809701462099824,0.0216025547497535,1,0],"clcd":49.1805118539343,"CDpres":0.01137,"alpha":4.6},        #dud
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re35000-N12.dat","Re":55000,"src":"retest_32.txt","sym":2.9456310693317,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.0157151299406333,0.863082022377036,0.0321349576300939,0.698195158425591,0.0543096474433878,0.497241313912823,0.0676745338038654,0.28552715888499,0.0632564455718427,0.125732819683231,0.0444470670769709,0.0360765344716023,0.0212487866244665,0,0,0.0192507166066205,-0.00754436646182311,0.113363722509556,-0.00119836197508259,0.268607859414087,0.0125606395297192,0.440775378221921,0.0227263034636579,0.638477319107758,0.0259044181634568,0.818181208003633,0.0205828807065632,0.939515187720928,0.0102655709963558,1,0],"CDpres":0.01751,"clcd":18.135985283703,"alpha":2.7,"CD":0.0281323346310924,"CL":0.510207606865698,"n":14,"CDp":0.0137670653662845,"CDf":0.01062,"Cpmin":-0.559431217283887,"id":323,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt15.0941836078143>12.624602765761) l1 Foil spline 17pts Re35000 N12","good":14.6829522202858,"iver":1.2020052,"r":6,"Cm":-0.0934787528612831},
             {"xy":[1,0,0.945514649029338,0.0208880031543503,0.863082022377036,0.0427126660026373,0.698195158425591,0.0721864910690915,0.497241313912823,0.0899506323463058,0.28552715888499,0.0840782634078808,0.125732819683231,0.059077492888231,0.0360765344716023,0.0282431468091372,0,0,0.0192507166066205,-0.0107916598604933,0.113363722509556,-0.00171416843154184,0.268607859414087,0.017967068556508,0.440775378221921,0.0325083011419463,0.638477319107758,0.0370543598483225,0.818181208003633,0.0294422929557246,0.939515187720928,0.0146841422705289,1,0],"Bot_Xtr":1,"sym":5.39506697104209,"alpha":5.7,"clcd":55.3604865343515,"CDpres":0.01373,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re80000-N5.dat","Top_Xtr":0.542847232711517,"diter":3,"src":"retest_26.txt","Re":65536,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt30.5918824698964>24.3302865260254) l1 Foil spline 17pts Re80000 N5","iver":1.2020052,"good":24.5512412288563,"id":324,"Cm":-0.165520739564807,"CDp":0.00649932092449165,"n":3,"CD":0.0230746575421089,"CL":1.27742426814469,"Cpmin":-1.94814411040754,"CDf":0.00935},
             {"Re":65536,"src":"retest_148.txt","diter":3,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re45000-N3.dat","Top_Xtr":0.524773070322619,"clcd":53.10440282428,"CDpres":0.00798,"alpha":4.2,"sym":4.06477204487081,"xy":[1,0,0.868523950462083,0.031126711010557,0.641452589715019,0.063807035322402,0.416262776127718,0.0776244521296026,0.233866556084622,0.0742696507688504,0.132025845000493,0.0613392323784734,0.0665475051364794,0.043063488318783,0.0222714169962174,0.023485265903159,0,0,0.0219899769144022,-0.00872864591178688,0.0671574276679874,-0.00632867447046646,0.108585510576379,-0.00193026420580951,0.25711939037162,0.0175789368755222,0.414690606933141,0.0299853350603219,0.609466583507779,0.0322845817364752,0.764025880785643,0.0238721229142191,1,0],"Bot_Xtr":1,"CDf":0.0106,"Cpmin":-1.36181648975459,"n":4,"CL":0.987012252094002,"CD":0.0185862602647088,"CDp":0.00384504350980273,"Cm":-0.118338608226554,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt18.6708345873005>17.866345107637) l1 Foil spline 17pts Re45000 N3","xver":6.991,"iver":1.2020052,"good":25.0242289671087,"id":325,"r":6},
             {"CDf":0.01032,"Cpmin":-1.42429462981215,"CL":1.04684280783553,"CD":0.0194477789418882,"n":5,"CDp":0.00462152923161571,"Cm":-0.123891560534438,"id":326,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","iver":1.2020052,"xver":6.991,"good":25.8612886625921,"r":6,"Re":65536,"src":"retest_25.txt","diter":3,"Top_Xtr":0.541939012891218,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","clcd":53.8283991690565,"CDpres":0.00913,"alpha":4.5,"sym":4.5387969219134,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"Bot_Xtr":1},
             {"sym":4.5387969219134,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"clcd":54.4081084560013,"CDpres":0.00981,"alpha":4.7,"diter":5,"Top_Xtr":0.558293158388646,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Re":65536,"src":"retest_26.txt","id":327,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","iver":1.2020052,"xver":6.991,"good":26.7872662023548,"r":6,"Cm":-0.12583124653794,"CD":0.0198122441668618,"CL":1.07794672938739,"n":6,"CDp":0.0051746009510202,"CDf":0.01,"Cpmin":-1.49908411846275},
             {"CDpres":0.01053,"clcd":54.3268767936778,"alpha":4.8,"sym":4.5387969219134,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"Bot_Xtr":1,"Re":65536,"src":"retest_27.txt","diter":4,"Top_Xtr":0.576345420755265,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Cm":-0.128237739791507,"id":328,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","iver":1.2020052,"xver":6.991,"good":27.1505050787446,"r":6,"CDf":0.0097,"Cpmin":-1.54300451873316,"CL":1.09889229492208,"CD":0.0202274152275575,"n":7,"CDp":0.0058717663449563},
             {"id":329,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid104.dat-s17_n17s0.dat (opt28.6959078950125>23.1342850401733) l1 Foil spline 17pts Re65536 N8","good":28.6959078795705,"iver":1.2020052,"r":6,"Cm":-0.135502608767091,"CD":0.0217013381930186,"CL":1.15481442578886,"n":8,"CDp":0.00785437895377026,"CDf":0.00871,"Cpmin":-1.77608613596304,"sym":4.24687396388763,"Bot_Xtr":1,"xy":[1,0,0.882447034172943,0.0287582242649913,0.699876483420286,0.0621340452704459,0.531195827457257,0.0812052333624574,0.375612650939196,0.0891679729825708,0.210128280080826,0.0833488036683229,0.0719473996254121,0.0576087729149519,0.00629073783956384,0.0193339762178939,0,0,0.0173281216346534,-0.008158696414437,0.0448737679273128,-0.0132572590755065,0.158853368939164,-0.0100916288653543,0.435570120459535,0.0192345320627287,0.592828639425523,0.0313323091681867,0.720413205967353,0.0317361303275589,0.830662579172746,0.0235016669646028,1,0],"clcd":53.2139730516882,"CDpres":0.01299,"alpha":5.3,"diter":5,"Top_Xtr":0.565265442145662,"Foil_fn":"optbs_spline_mid104.dat-s17_n17s0_nsopt-Re65536-N8.dat","Re":65536,"src":"retest_49.txt"},
             {"n":9,"CD":0.0220467074599539,"CL":1.14331200108205,"CDp":0.0079585090229124,"CDf":0.00945,"Cpmin":-1.6035780075561,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt20.4630203072951>20.24323903623) l1 Foil spline 17pts Re45000 N6","xver":6.991,"iver":1.2020052,"good":25.3620659462951,"id":330,"r":6,"Cm":-0.133459653497566,"diter":5,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re45000-N6.dat","Top_Xtr":0.600746805695676,"Re":65536,"src":"retest_23.txt","sym":4.64669926290376,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0341835828432945,0.641452589715019,0.0700733552346272,0.416262776127718,0.0852477439437033,0.233866556084622,0.0815634764282831,0.132025845000493,0.0673631959008608,0.0665475051364794,0.0472926394300732,0.0222714169962174,0.0257916916543207,0,0,0.0219899769144022,-0.00854659207733985,0.0671574276679874,-0.00619667696868217,0.108585510576379,-0.00189000458207005,0.25711939037162,0.017212292049276,0.414690606933141,0.0293599293238446,0.609466583507779,0.0316112204891474,0.764025880785643,0.0233742207703074,1,0],"CDpres":0.0126,"clcd":51.8586280132205,"alpha":5},
             {"Re":65536,"n":10,"diter":4,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N12.dat","Top_Xtr":0.628727878023978,"src":"retest_117.txt","sym":3.66672346977709,"Bot_Xtr":1,"xy":[1,0,0.932175646467167,0.0167651112291188,0.822686565492564,0.034806746433696,0.678803188734605,0.0524011747412981,0.467813461804766,0.0709677639459628,0.299436270431163,0.0754018274628769,0.134160023906898,0.0624489705612843,0.0364048536456623,0.0320464734316911,0,0,0.0270013726530119,-0.013513539976074,0.12487691305341,0.000367379221959878,0.281461101187184,0.0212845323333349,0.47006254090453,0.0309546785743677,0.68986358510747,0.0271235010031005,0.86337155350222,0.0150163007137906,0.97248200666718,0.000661925603030636,1,0],"CDpres":0.01204,"clcd":47.8287366440132,"alpha":4.2,"CD":0.0213626327803798,"CL":1.02174773727555,"CDp":0.00876663867755964,"CDf":0.00933,"Cpmin":-1.38729756731945,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt27.6262643582983>25.8530388924518) l1 Foil spline 17pts Re80000 N12","iver":1.2020052,"good":24.5744596108181,"id":331,"r":6,"Cm":-0.121581685257257},        #dud
             {"Re":65536,"n":11,"CL":1.27187238462089,"CD":0.0236847196719795,"CDp":0.0101781929334871,"CDf":0.00783,"Cpmin":-2.2607783424991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid151a.dat-s17_n17s0.dat (opt23.8890130025876>20.4946714299849) l1 Foil spline 17pts Re65536 N11","iver":1.2020052,"xver":6.991,"good":23.889185211147,"id":332,"r":6,"Cm":-0.161560444947321,"diter":4,"Foil_fn":"optbs_spline_mid151a.dat-s17_n17s0_nsopt-Re65536-N11.dat","Top_Xtr":0.605219836236028,"src":"retest_49.txt","sym":4.85084171734351,"Bot_Xtr":1,"xy":[1,0,0.870588443819102,0.035942139161075,0.713516798884012,0.0646754359692075,0.580442629593444,0.0791967231978306,0.42583065729969,0.0867740249952018,0.229768114218089,0.0818921343233427,0.081788256748409,0.0562158597008047,0.010957950883341,0.0201886358985968,0,0,0.0162649038866205,-0.00848318228235596,0.04389732811481,-0.0125189671705214,0.149688687874769,-0.00694600099337701,0.394602510713099,0.0220922423251036,0.578063605817522,0.038499393636745,0.727546442647447,0.0380805960557649,0.841413116633622,0.0267846664044344,1,0],"CDpres":0.01585,"clcd":53.7001240561691,"alpha":5.6},        #dud
             {"src":"retest_25.txt","Re":65536,"Top_Xtr":0.625386011717374,"Foil_fn":"optbs_spline_mid117.dat-s17_n17s0_nsopt-Re65536-N12.dat","diter":4,"alpha":4.8,"CDpres":0.01506,"clcd":47.0836721083232,"Bot_Xtr":1,"xy":[1,0,0.872698141247438,0.0303508130238361,0.714161267721381,0.0524638398021206,0.635512217143926,0.060553077551136,0.474011231124192,0.072018472397855,0.271049042074955,0.0732860142925839,0.11202427196111,0.055262570962021,0.0331845342728825,0.0272397657936519,0,0,0.0240615882590061,-0.0166307810310873,0.12652606258289,-0.0176526612167348,0.359596968815521,0.0111341370020304,0.47886911639845,0.0225640243414655,0.597083436840087,0.0281700230978477,0.713873005854957,0.0270663783154291,0.817006552045902,0.0206785104468799,1,0],"sym":2.96157361362173,"Cpmin":-1.67166746180687,"CDf":0.00816,"CDp":0.0108954071315158,"CD":0.0232140536073357,"CL":1.09300288835283,"n":12,"Cm":-0.136343573295756,"r":6,"id":333,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid117.dat-s17_n17s0.dat (opt21.2841445210604>20.8470983607875) l1 Foil spline 17pts Re65536 N12","iver":1.2020052,"good":21.283911093115},
             {"Re":65536,"n":13,"diter":8,"Top_Xtr":0.481151966364971,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re35000-N7.dat","src":"retest_73.txt","sym":4.57651517262057,"Bot_Xtr":1,"xy":[1,0,0.899630566949792,0.0261921599288413,0.727739042677004,0.053380539687003,0.592614898283108,0.0679818845916378,0.4516898617015,0.0799640628564804,0.252873926024019,0.0807510512055346,0.0811582397809066,0.0521976213245977,0.00557700402728914,0.00761223609330723,0,0,0.00141252526740496,-0.0127307336381641,0.0452001277636599,-0.0134635216723534,0.199612166740877,0.0142447055524001,0.377122071379592,0.0328851080868409,0.554590024942112,0.0357274252485017,0.69102752205303,0.0310531520818165,0.809701462099824,0.0228688843535896,1,0],"CDpres":0.0097,"clcd":53.6185329177205,"alpha":4,"CD":0.0195670016065477,"CL":1.04915391974177,"CDp":0.00331665344869607,"CDf":0.00987,"Cpmin":-1.64093781560911,"id":334,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt17.5955369412669>12.877065903133) l1 Foil spline 17pts Re35000 N7","good":19.9878793908731,"iver":1.2020052,"r":6,"Cm":-0.127620814011417},        #dud
             {"Re":65536,"n":14,"CDpres":0.01076,"clcd":54.2891126038383,"alpha":4.5,"sym":4.68564842882372,"xy":[1,0,0.899630566949792,0.0264715048336189,0.727739042677004,0.0539498543909586,0.592614898283108,0.0687069257157547,0.4516898617015,0.0808168964366419,0.252873926024019,0.0816122781822707,0.0811582397809066,0.0527543199549571,0.00557700402728914,0.00769342219527083,0,0,0.00141252526740496,-0.0129235486996504,0.0452001277636599,-0.0136674352748887,0.199612166740877,0.0144604506818643,0.377122071379592,0.0333831739735341,0.554590024942112,0.036268539837168,0.69102752205303,0.0315234718291442,0.809701462099824,0.0232152481585428,1,0],"Bot_Xtr":1,"src":"retest_143.txt","diter":3,"Top_Xtr":0.457968678638153,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re30000-N9.dat","Cm":-0.127472147012261,"id":335,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt11.9372951851391>11.7166103994334) l1 Foil spline 17pts Re30000 N9","iver":1.2020052,"good":20.9724109104238,"r":6,"CDf":0.00962,"Cpmin":-1.88611905229234,"CL":1.10637955415689,"CD":0.0203794002350052,"CDp":0.00387454014619946},        #dud
             {"good":30.5215129013697,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt31.0072013261422>26.7130171119343) l1 Foil spline 17pts Re80000 N4","xver":6.991,"iver":1.2020052,"id":336,"r":6,"Cm":-0.182244250659049,"n":3,"CD":0.0203369335775923,"CL":1.29063486522192,"CDp":0.00526170341888163,"CDf":0.00901,"Cpmin":-1.68737507755382,"sym":5.91617515239517,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.021748164268802,0.863082022377036,0.0444715595703252,0.698195158425591,0.0751591070797039,0.497241313912823,0.0936547698645212,0.28552715888499,0.0875405787005239,0.125732819683231,0.0615102846561299,0.0360765344716023,0.0294061903253342,0,0,0.0192507166066205,-0.0114920035927617,0.113363722509556,-0.00182541240444332,0.268607859414087,0.019133073046406,0.440775378221921,0.0346179844757218,0.638477319107758,0.0394590676512429,0.818181208003633,0.0313530022999506,0.939515187720928,0.0156370954895745,1,0],"clcd":63.4626090653103,"CDpres":0.01132,"alpha":5.1,"diter":3,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re80000-N4.dat","Top_Xtr":0.581938654232807,"Re":80000,"src":"retest_73.txt"},
             {"CDf":0.00834,"Cpmin":-1.94270428095134,"CL":1.34653308308626,"CD":0.0210556596691419,"n":4,"CDp":0.00596144155691444,"Cm":-0.182755944163668,"id":337,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt31.0072013261422>26.7130171119343) l1 Foil spline 17pts Re80000 N4","xver":6.991,"iver":1.2020052,"good":31.00730828623,"r":6,"Re":80000,"src":"retestc_18.txt","diter":4,"Top_Xtr":0.597047283965358,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re80000-N4.dat","CDpres":0.01271,"clcd":63.9511230825828,"alpha":5.6,"sym":5.91617515239517,"xy":[1,0,0.945514649029338,0.021748164268802,0.863082022377036,0.0444715595703252,0.698195158425591,0.0751591070797039,0.497241313912823,0.0936547698645212,0.28552715888499,0.0875405787005239,0.125732819683231,0.0615102846561299,0.0360765344716023,0.0294061903253342,0,0,0.0192507166066205,-0.0114920035927617,0.113363722509556,-0.00182541240444332,0.268607859414087,0.019133073046406,0.440775378221921,0.0346179844757218,0.638477319107758,0.0394590676512429,0.818181208003633,0.0313530022999506,0.939515187720928,0.0156370954895745,1,0],"Bot_Xtr":1},
             {"Re":80000,"src":"retestc_19.txt","diter":4,"Top_Xtr":0.614294817218197,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re80000-N5.dat","CDpres":0.01307,"clcd":64.5432982151872,"alpha":5.8,"sym":5.39506697104209,"xy":[1,0,0.945514649029338,0.0208880031543503,0.863082022377036,0.0427126660026373,0.698195158425591,0.0721864910690915,0.497241313912823,0.0899506323463058,0.28552715888499,0.0840782634078808,0.125732819683231,0.059077492888231,0.0360765344716023,0.0282431468091372,0,0,0.0192507166066205,-0.0107916598604933,0.113363722509556,-0.00171416843154184,0.268607859414087,0.017967068556508,0.440775378221921,0.0325083011419463,0.638477319107758,0.0370543598483225,0.818181208003633,0.0294422929557246,0.939515187720928,0.0146841422705289,1,0],"Bot_Xtr":1,"CDf":0.00773,"Cpmin":-2.35310187025395,"CD":0.0208031862825276,"CL":1.34270625605927,"n":5,"CDp":0.00615620419614125,"Cm":-0.176097713763708,"id":338,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt30.5918824698964>24.3302865260254) l1 Foil spline 17pts Re80000 N5","xver":6.991,"iver":1.2020052,"good":30.5918824717066,"r":6},
             {"CDpres":0.00762,"clcd":59.9283971766143,"alpha":4.2,"sym":4.22059222395739,"xy":[1,0,0.868523950462083,0.0327912351143664,0.641452589715019,0.0672191641609013,0.416262776127718,0.0817754776449839,0.233866556084622,0.078241275777491,0.132025845000493,0.0646193936126142,0.0665475051364794,0.0453663404985851,0.0222714169962174,0.0247411580263879,0,0,0.0219899769144022,-0.00795918809044197,0.0671574276679874,-0.00577078174354641,0.108585510576379,-0.00176010529394247,0.25711939037162,0.0160292978356874,0.414690606933141,0.0273420326717285,0.609466583507779,0.0294385934609702,0.764025880785643,0.0217677195652816,1,0],"Bot_Xtr":1,"Re":80000,"src":"retest_13.txt","diter":3,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re80000-N6.dat","Top_Xtr":0.587944698168083,"Cm":-0.122693167373367,"good":30.4956956654166,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt30.4956954745544>29.7209358798188) l1 Foil spline 17pts Re80000 N6","xver":6.991,"iver":1.2020052,"id":339,"r":6,"CDf":0.00933,"Cpmin":-1.36905687157133,"n":6,"CL":1.01593205782722,"CD":0.0169524316632927,"CDp":0.00381968319984516},
             {"Cm":-0.130213791022865,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","iver":1.2020052,"xver":6.991,"good":30.9404786663934,"id":340,"r":6,"CDf":0.00904,"Cpmin":-1.44085969552355,"n":7,"CD":0.0174940080135131,"CL":1.06800108865206,"CDp":0.00443813137867481,"CDpres":0.00845,"clcd":61.0495369515713,"alpha":4.4,"sym":4.5387969219134,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"Bot_Xtr":1,"Re":80000,"src":"retest_35.txt","diter":4,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Top_Xtr":0.588715215596544},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid103.dat-s17_n17s0.dat (opt33.2637304087461>25.3548122996961) l1 Foil spline 17pts Re80000 N8","iver":1.2020052,"xver":6.991,"good":33.2637303764057,"id":341,"Cm":-0.144915223041784,"CDp":0.00554215693375304,"n":8,"CL":1.08577495303415,"CD":0.0180386398619529,"Cpmin":-1.57388046772273,"CDf":0.0083,"xy":[1,0,0.860349218706042,0.0375211602855578,0.675295910544019,0.069230890652482,0.537916636773429,0.0825972915235277,0.467911882068168,0.0871047965094467,0.259105025451668,0.088831631930559,0.0865258731215584,0.0643831523789879,0.00721857996203114,0.0230789847899595,0,0,0.0191067933599684,-0.00898715719977778,0.0471611154364107,-0.013837891461078,0.16042445332282,-0.010199016953053,0.422178813053679,0.0192755264043557,0.594330104481387,0.0336668821489631,0.731047063676876,0.0333651578440786,0.836385875680056,0.0243209886061473,1,0],"Bot_Xtr":1,"sym":4.60474094130478,"alpha":4.4,"clcd":60.1916198418185,"CDpres":0.00974,"Foil_fn":"optbs_spline_mid103.dat-s17_n17s0_nsopt-Re80000-N8.dat","Top_Xtr":0.589339850954584,"diter":4,"src":"retest_4.txt","Re":80000},
             {"r":6,"id":342,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt20.4630203072951>20.24323903623) l1 Foil spline 17pts Re45000 N6","xver":6.991,"good":29.6500942054584,"Cm":-0.13356862003241,"CDp":0.0057382320136245,"CL":1.11856519869195,"CD":0.0188196979974212,"n":9,"Cpmin":-1.53368679110878,"CDf":0.00894,"xy":[1,0,0.868523950462083,0.0341835828432945,0.641452589715019,0.0700733552346272,0.416262776127718,0.0852477439437033,0.233866556084622,0.0815634764282831,0.132025845000493,0.0673631959008608,0.0665475051364794,0.0472926394300732,0.0222714169962174,0.0257916916543207,0,0,0.0219899769144022,-0.00854659207733985,0.0671574276679874,-0.00619667696868217,0.108585510576379,-0.00189000458207005,0.25711939037162,0.017212292049276,0.414690606933141,0.0293599293238446,0.609466583507779,0.0316112204891474,0.764025880785643,0.0233742207703074,1,0],"Bot_Xtr":1,"sym":4.64669926290376,"alpha":4.7,"clcd":59.4358739893285,"CDpres":0.00988,"Top_Xtr":0.59625886316062,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re45000-N6.dat","diter":4,"src":"retest_33.txt","Re":80000},
             {"clcd":58.0273442352722,"CDpres":0.01214,"alpha":5.3,"sym":4.23076721278613,"xy":[1,0,0.882447034172943,0.0289521188912833,0.699876483420286,0.0625529674325625,0.531195827457257,0.0817527379034431,0.375612650939196,0.0897691641632,0.210128280080826,0.0839107606580952,0.0719473996254121,0.057997184639979,0.00629073783956384,0.019464330375333,0,0,0.0173281216346534,-0.00777453799916352,0.0448737679273128,-0.0126330309661845,0.158853368939164,-0.00961645685802447,0.435570120459535,0.0183288595164786,0.592828639425523,0.0298570036015266,0.720413205967353,0.0302418105350031,0.830662579172746,0.0223950731316185,1,0],"Bot_Xtr":1,"Re":80000,"src":"retest_15.txt","diter":4,"Top_Xtr":0.57849535697937,"Foil_fn":"optbs_spline_mid104.dat-s17_n17s0_nsopt-Re80000-N10.dat","Cm":-0.137300144397232,"id":343,"good":31.0719859808064,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid104.dat-s17_n17s0.dat (opt31.0719858700129>25.2499337515354) l1 Foil spline 17pts Re80000 N10","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00804,"Cpmin":-1.80048757885533,"CL":1.17119653665366,"CD":0.0201835281639814,"n":10,"CDp":0.00753740775948121},
             {"xy":[1,0,0.932175646467167,0.0160482403493011,0.822686565492564,0.0333184209106194,0.678803188734605,0.0501605170011316,0.467813461804766,0.0679332046947079,0.299436270431163,0.0721776690511335,0.134160023906898,0.0597786722341117,0.0364048536456623,0.0306761763134632,0,0,0.0270013726530119,-0.0127478700013051,0.12487691305341,0.000346563710990387,0.281461101187184,0.0200785620721386,0.47006254090453,0.0292008029795955,0.68986358510747,0.0255866978881908,0.86337155350222,0.0141654851163227,0.97248200666718,0.000624421251049684,1,0],"Bot_Xtr":1,"sym":3.33586957646476,"alpha":3.8,"CDpres":0.00979,"clcd":53.1153859110953,"Top_Xtr":0.670765098587065,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N11.dat","diter":4,"src":"retestc_1.txt","Re":80000,"r":6,"id":344,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt29.1501133439728>27.2357069998813) l1 Foil spline 17pts Re80000 N11","xver":6.991,"good":29.1501131077171,"Cm":-0.119290056702702,"CDp":0.00707823370018105,"CL":0.965551538939022,"CD":0.0181783775525074,"n":11,"Cpmin":-1.29472148041129,"CDf":0.00838},
             #{"Re":80000,"n":12,"CDpres":0.01127,"clcd":50.8972296062,"alpha":3.8,"sym":3.66672346977709,"xy":[1,0,0.932175646467167,0.0167651112291188,0.822686565492564,0.034806746433696,0.678803188734605,0.0524011747412981,0.467813461804766,0.0709677639459628,0.299436270431163,0.0754018274628769,0.134160023906898,0.0624489705612843,0.0364048536456623,0.0320464734316911,0,0,0.0270013726530119,-0.013513539976074,0.12487691305341,0.000367379221959878,0.281461101187184,0.0212845323333349,0.47006254090453,0.0309546785743677,0.68986358510747,0.0271235010031005,0.86337155350222,0.0150163007137906,0.97248200666718,0.000661925603030636,1,0],"Bot_Xtr":1,"src":"retest_128.txt","diter":5,"Top_Xtr":0.678033072690544,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N12.dat","Cm":-0.126646292806963,"id":345,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt27.6262643582983>25.8530388924518) l1 Foil spline 17pts Re80000 N12","xver":6.991,"good":27.6262646206411,"r":6,"CDf":0.00825,"Cpmin":-1.30916959284989,"CL":0.993462255303216,"CD":0.0195189848836526,"CDp":0.00860545029102752},        #dud
             {"Bot_Xtr":1,"CD":0.0195026029115548,"CDf":0.00829,"CDp":0.00856101505767002,"CDpres":0.01122,"CL":0.989491836559291,"Cm":-0.125458626061394,"Cpmin":-1.30692339626054,"Foil_fn":"opt_spline_foil_mid113.dat-s17_n17s0.dat-re80000-ncrit12_n17sblowsuck-Re80000-N12-hpz.dat","Re":80000,"Top_Xtr":0.67919367637768,"alpha":3.8,"clcd":50.7363986769707,"cmt":"SPLN 10(B0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat -opt_clcd(7)=(27.6106106516417>26.0647693684736 aoa=3.8 pa=0.993001018573231 Cl=0.993001018573231 Cd=0.0195407703347045 x=0.678240926996742,1 s=YB u=1.02446727995716 Foil spline 17pts Re80000 N12","diter":5,"good":26.0048196685963,"id":5,"iver":1.2020062,"n":12,"r":6,"src":"","sym":3.77447977108334,"xver":6.991,"xy":[1,0,0.932175646467167,0.0168083779238257,0.822686565492564,0.0348965742225551,0.678803188734605,0.0525364094915381,0.467813461804766,0.0711509145695834,0.299436270431163,0.0755964213313335,0.134160023906898,0.0626101362408381,0.0364048536456623,0.032129177623954,0,0,0.0270013726530119,-0.0130622504704634,0.12487691305341,0.000355110461313635,0.281461101187184,0.0205737277557874,0.47006254090453,0.0299209360010009,0.68986358510747,0.0262177019763621,0.86337155350222,0.0145148259753264,0.97248200666718,0.000639820360535213,1,0]},        #80000 12
             #{"Re":80000,"n":13,"CDp":0.00994471692704293,"CD":0.0207033701996357,"CL":1.00632288434968,"Cpmin":-1.32496686872174,"CDf":0.00813,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt27.6262643582983>25.8530388924518) l1 Foil spline 17pts Re80000 N12","iver":1.2020052,"good":24.8656583083796,"id":346,"Cm":-0.128060525495307,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N12.dat","Top_Xtr":0.676425590886186,"diter":6,"src":"retest_129.txt","xy":[1,0,0.932175646467167,0.0167651112291188,0.822686565492564,0.034806746433696,0.678803188734605,0.0524011747412981,0.467813461804766,0.0709677639459628,0.299436270431163,0.0754018274628769,0.134160023906898,0.0624489705612843,0.0364048536456623,0.0320464734316911,0,0,0.0270013726530119,-0.013513539976074,0.12487691305341,0.000367379221959878,0.281461101187184,0.0212845323333349,0.47006254090453,0.0309546785743677,0.68986358510747,0.0271235010031005,0.86337155350222,0.0150163007137906,0.97248200666718,0.000661925603030636,1,0],"Bot_Xtr":1,"sym":3.66672346977709,"alpha":3.9,"clcd":48.6067183577382,"CDpres":0.01257},        #dud
             {"Bot_Xtr":1,"CD":0.0191033505943124,"CDf":0.00795,"CDp":0.00856988907474965,"CDpres":0.01115,"CL":0.947602230159734,"Cm":-0.115324291910963,"Cpmin":-1.29314279106539,"Foil_fn":"opt_spline_foil_mid113.dat-s17_n17s0.dat-re80000-ncrit13_n17sblowsuck-Re80000-N13-hpz.dat","Re":80000,"Top_Xtr":0.698164662443169,"alpha":3.9,"clcd":49.6039804892584,"cmt":"SPLN 10(B0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat -opt_clcd(6)=(23.807134230581>23.8061837559819 aoa=3.9 pa=0.950771966502601 Cl=0.950771966502601 Cd=0.0191196848111191 x=0.696873618542507,1 s=YB u=1.01952639464534 Foil spline 17pts Re80000 N13","diter":6,"good":23.7521167223851,"id":3,"iver":1.2020062,"n":13,"r":6,"src":"","sym":2.98427162359137,"xver":6.991,"xy":[1,0,0.932175646467167,0.014997708827798,0.822686565492564,0.0311373686175661,0.678803188734605,0.0468769667116522,0.467813461804766,0.0634862390875644,0.299436270431163,0.0674528571816416,0.134160023906898,0.0558655092873545,0.0364048536456623,0.0286680876087172,0,0,0.0270013726530119,-0.0114873079917846,0.12487691305341,0.000312294060616778,0.281461101187184,0.0180931109692213,0.47006254090453,0.0263133070387204,0.68986358510747,0.0230565795779452,0.86337155350222,0.0127647434722491,0.97248200666718,0.000562675900106356,1,0]},        #80000 13
             {"Re":80000,"n":14,"Cm":-0.133215681478736,"r":6,"id":347,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid115.dat-s17_n17s0.dat (opt11.9372951851391>11.7166103994334) l1 Foil spline 17pts Re30000 N9","xver":6.991,"good":22.9733333029786,"iver":1.2020052,"Cpmin":-1.50734441836693,"CDf":0.00911,"CDp":0.00223210066948682,"CL":1.03343724879898,"CD":0.017445918630413,"alpha":3.6,"clcd":59.2366197901104,"CDpres":0.00834,"Bot_Xtr":1,"xy":[1,0,0.899630566949792,0.0264715048336189,0.727739042677004,0.0539498543909586,0.592614898283108,0.0687069257157547,0.4516898617015,0.0808168964366419,0.252873926024019,0.0816122781822707,0.0811582397809066,0.0527543199549571,0.00557700402728914,0.00769342219527083,0,0,0.00141252526740496,-0.0129235486996504,0.0452001277636599,-0.0136674352748887,0.199612166740877,0.0144604506818643,0.377122071379592,0.0333831739735341,0.554590024942112,0.036268539837168,0.69102752205303,0.0315234718291442,0.809701462099824,0.0232152481585428,1,0],"sym":4.68564842882372,"src":"retest_7.txt","Top_Xtr":0.504630395626,"Foil_fn":"optbs_spline_mid115.dat-s17_n17s0_nsopt-Re30000-N9.dat","diter":4},        #dud
             {"alpha":4.1,"clcd":74.6235385078094,"CDpres":0.00915,"Bot_Xtr":1,"xy":[1,0,0.948055131462352,0.0225246399379023,0.865820520912136,0.047092157112848,0.698021119797309,0.0798542568111209,0.49780798647652,0.0997278026309258,0.288819832388076,0.0956381537937818,0.122702850725304,0.0661525795557786,0.0371194322134399,0.0324220076843369,0,0,0.0204147778197805,-0.0100652835782226,0.114150150047107,0.00113280701417326,0.275952073437055,0.0220831014227439,0.465991319968098,0.0398277100643394,0.656329004650391,0.0487637028524039,0.835590626685817,0.0392972143354166,0.934479269017308,0.0204884365274898,1,0],"sym":7.25310827590781,"src":"retest_83.txt","Re":100000,"Foil_fn":"opt_spline_e62_nsopt-Re125000-N4.dat","Top_Xtr":0.601515259534733,"diter":4,"Cm":-0.216913082250534,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re125000_N4_e62.dat-s17_n17s0_nsopt-Re125000-N4.dat (opt48.4418808424006>43.7924019055336) l1 Foil spline 17pts Re125000 N4","good":38.1757425562682,"iver":1.2020052,"id":348,"Cpmin":-1.47577797118789,"CDf":0.00877,"CDp":0.00417554596976685,"n":3,"CD":0.0179259417731775,"CL":1.33769720619946},
             {"Top_Xtr":0.616435642314232,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re100000-N4.dat","diter":3,"src":"retestc_4.txt","Re":100000,"xy":[1,0,0.945514649029338,0.0227750070881781,0.863082022377036,0.0465712908877289,0.698195158425591,0.0787077555293675,0.497241313912823,0.0980766937909309,0.28552715888499,0.0916738201792821,0.125732819683231,0.0644145019195397,0.0360765344716023,0.0307946079870534,0,0,0.0192507166066205,-0.0109449888792268,0.113363722509556,-0.00173852351379517,0.268607859414087,0.0182223465236512,0.440775378221921,0.0329701824446582,0.638477319107758,0.0375808320230193,0.818181208003633,0.0298606120972213,0.939515187720928,0.0148927760816746,1,0],"Bot_Xtr":1,"sym":6.18977666552182,"alpha":5.2,"clcd":72.1602311651044,"CDpres":0.01034,"CDp":0.00447284605223121,"CD":0.0184730713675375,"CL":1.33302110021098,"n":4,"Cpmin":-1.66456910589337,"CDf":0.00814,"r":6,"id":349,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt37.4002862790055>32.5871523270344) l1 Foil spline 17pts Re100000 N4","xver":6.991,"iver":1.2020052,"good":37.4002862790561,"Cm":-0.187794899539709},
             {"Cm":-0.194665176362789,"id":350,"good":37.0824919118053,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt37.0824918963482>30.9841448173804) l1 Foil spline 17pts Re100000 N5","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00761,"Cpmin":-1.96221424559621,"CL":1.42535255837209,"CD":0.0195704526924829,"n":5,"CDp":0.00524297975470056,"clcd":72.8318644831133,"CDpres":0.01196,"alpha":5.8,"sym":6.51738413177335,"xy":[1,0,0.945514649029338,0.0231085862615418,0.863082022377036,0.0472534075894565,0.698195158425591,0.0798605660608922,0.497241313912823,0.0995131957561931,0.28552715888499,0.0930165410415019,0.125732819683231,0.0653579631540309,0.0360765344716023,0.0312456480168813,0,0,0.0192507166066205,-0.0116311980622346,0.113363722509556,-0.00184752232715218,0.268607859414087,0.0193648183578815,0.440775378221921,0.0350372875106039,0.638477319107758,0.0399370072849437,0.818181208003633,0.0317327589269216,0.939515187720928,0.0158264965103104,1,0],"Bot_Xtr":1,"Re":100000,"src":"retestc_5.txt","diter":4,"Top_Xtr":0.611631731655939,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re100000-N5.dat"},
             {"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","Top_Xtr":0.601984010754016,"diter":3,"src":"retest_48.txt","Re":100000,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"Bot_Xtr":1,"sym":5.7279194130313,"alpha":3.6,"CDpres":0.0074,"clcd":71.5666992634859,"CDp":0.00412196629042861,"n":6,"CL":1.14962615437737,"CD":0.0160637023393354,"Cpmin":-1.42160194578346,"CDf":0.00867,"r":6,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","good":36.6173454670525,"xver":6.991,"iver":1.2020052,"id":351,"Cm":-0.17073803666769},
             {"Cm":-0.132784617856127,"r":6,"good":34.8385296820255,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","xver":6.991,"iver":1.2020052,"id":352,"Cpmin":-1.34924714374733,"CDf":0.00833,"CDp":0.00333859530758978,"n":7,"CL":1.03870579767743,"CD":0.0151009079747533,"alpha":4,"CDpres":0.00677,"clcd":68.784327367203,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"sym":4.5387969219134,"src":"retest_43.txt","Re":100000,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Top_Xtr":0.602964212776219,"diter":5},
             {"alpha":4.1,"clcd":68.6206147321631,"CDpres":0.00777,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0371700970527708,0.641452589715019,0.076195448172435,0.416262776127718,0.0926955764245989,0.233866556084622,0.0886894258187853,0.132025845000493,0.0732485105759177,0.0665475051364794,0.0514244514846795,0.0222714169962174,0.0280450322115459,0,0,0.0219899769144022,-0.00989806604638302,0.0671574276679874,-0.00717655848659708,0.108585510576379,-0.00218887130823712,0.25711939037162,0.0199340745377419,0.414690606933141,0.0340026196330414,0.609466583507779,0.0366099078295714,0.764025880785643,0.0270703900307421,1,0],"sym":5.65460418250154,"src":"retest_107.txt","Re":100000,"Top_Xtr":0.601110163746938,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re100000-N8.dat","diter":3,"Cm":-0.146148821490568,"r":6,"id":353,"good":35.4980325624083,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt35.7177480060821>34.4566039170131) l1 Foil spline 17pts Re100000 N8","xver":6.991,"iver":1.2020052,"Cpmin":-1.39324015955471,"CDf":0.00844,"CDp":0.00411097272502565,"CL":1.1122063780494,"CD":0.0162080503415849,"n":8},
             {"alpha":4.2,"CDpres":0.00758,"clcd":68.654268152458,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0331942363304941,0.641452589715019,0.0680452814086795,0.416262776127718,0.0827804906255993,0.233866556084622,0.0792028537473276,0.132025845000493,0.0654135599232302,0.0665475051364794,0.0459238885850913,0.0222714169962174,0.0250452245471599,0,0,0.0219899769144022,-0.00896106829352297,0.0671574276679874,-0.00649719151291767,0.108585510576379,-0.00198166239616207,0.25711939037162,0.0180470207476701,0.414690606933141,0.0307837708156851,0.609466583507779,0.0331442407782531,0.764025880785643,0.0245077788591265,1,0],"sym":4.5387969219134,"src":"retest_45.txt","Re":100000,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re55000-N4.dat","Top_Xtr":0.624518323150711,"diter":4,"Cm":-0.135396014005174,"r":6,"good":35.0268219707114,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt22.7448131694954>21.2819910073032) l1 Foil spline 17pts Re55000 N4","xver":6.991,"iver":1.2020052,"id":354,"Cpmin":-1.41731657171952,"CDf":0.00802,"CDp":0.00410541539243479,"n":9,"CL":1.07134848799289,"CD":0.0156049800955388},
             {"Cpmin":-1.4067897780482,"CDf":0.00832,"CDp":0.00492991425247147,"CL":1.11723172821577,"CD":0.0168685284692176,"n":10,"Cm":-0.141340241173501,"r":6,"id":355,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt42.6631989972607>33.6074125371031) l1 Foil spline 17pts Re100000 N10","xver":6.991,"iver":1.2020052,"good":42.6626917489548,"src":"retestc_10.txt","Re":100000,"Top_Xtr":0.618422757199292,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re100000-N10.dat","diter":3,"alpha":4.3,"clcd":66.2317243768206,"CDpres":0.00855,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0369838329999864,0.641452589715019,0.0758136231543251,0.416262776127718,0.0922310671790212,0.233866556084622,0.0882449919000717,0.132025845000493,0.0728814530344504,0.0665475051364794,0.0511667570607948,0.0222714169962174,0.0279044950116355,0,0,0.0219899769144022,-0.00842816531452735,0.0671574276679874,-0.00611081205469599,0.108585510576379,-0.00186381553240793,0.25711939037162,0.0169737880924318,0.414690606933141,0.02895310033812,0.609466583507779,0.031173196247765,0.764025880785643,0.0230503333922691,1,0],"sym":5.22768995313791},
             {"Cm":-0.133955691576423,"r":6,"id":356,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt45.3507896005082>32.5996976934759) l1 Foil spline 17pts Re100000 N11","iver":1.2020052,"xver":6.991,"good":45.3501392472095,"Cpmin":-1.46755805073116,"CDf":0.0081,"CDp":0.00514812689667097,"CL":1.0925055647391,"CD":0.0167437836741149,"n":11,"alpha":4.4,"clcd":65.2484280735223,"CDpres":0.00864,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0341656138079312,0.641452589715019,0.0700365202836507,0.416262776127718,0.0852029323821831,0.233866556084622,0.0815206015488706,0.132025845000493,0.0673277855796293,0.0665475051364794,0.0472677794522811,0.0222714169962174,0.0257781339233614,0,0,0.0219899769144022,-0.0076874136166081,0.0671574276679874,-0.00557373260308875,0.108585510576379,-0.00170000473032747,0.25711939037162,0.015481961356675,0.414690606933141,0.0264084114959919,0.609466583507779,0.0284333831106995,0.764025880785643,0.0210244389109996,1,0],"sym":4.43815454414797,"src":"retest_107.txt","Re":100000,"Top_Xtr":0.629297077701086,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re100000-N11.dat","diter":6},
             #{"Re":100000,"n":12,"CDp":0.0076429037972853,"CL":1.38769919248303,"CD":0.0199284041646777,"Cpmin":-1.89329381767933,"CDf":0.0073,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid151a.dat-s17_n17s0.dat (opt32.2470624480708>27.8898321405488) l1 Foil spline 17pts Re100000 N12","iver":1.2020052,"good":32.2470812542593,"id":357,"Cm":-0.195007813534438,"Foil_fn":"optbs_spline_mid151a.dat-s17_n17s0_nsopt-Re100000-N12.dat","Top_Xtr":0.604626322113858,"diter":7,"src":"retestc_12.txt","xy":[1,0,0.870588443819102,0.0426424329518152,0.713516798884012,0.0767321591401868,0.580442629593444,0.0939604886574021,0.42583065729969,0.102950342666982,0.229768114218089,0.0971583753408332,0.081788256748409,0.0666955580294546,0.010957950883341,0.0239521790519041,0,0,0.0162649038866205,-0.0105576796315114,0.04389732811481,-0.015580384849053,0.149688687874769,-0.00864459241442445,0.394602510713099,0.027494731227841,0.578063605817522,0.0479141259135266,0.727546442647447,0.0473929145870135,0.841413116633622,0.033334651728878,1,0],"Bot_Xtr":1,"sym":6.9791732775857,"alpha":5.3,"CDpres":0.01263,"clcd":69.634235687706},        #dud
             {"Bot_Xtr":1,"CD":0.0187755000948829,"CDf":0.00712,"CDp":0.00707868218979559,"CDpres":0.01166,"CL":1.31349661022485,"Cm":-0.182368988865326,"Cpmin":-1.79079668005203,"Foil_fn":"opt_spline_foil_mid151a.dat-s17_n17s0.dat-re100000-ncrit12_n17sblowsuck-Re100000-N12.dat","Re":100000,"Top_Xtr":0.627240893724881,"alpha":5.1,"clcd":69.958009298662,"cmt":"SPLN 10(B0) foildb2020_spline/spline_foil_mid151a.dat-s17_n17s0.dat -opt_clcd(7)=(30.7545915023734>30.738236254055 aoa=5.1 pa=1.31946859618181 Cl=1.31946859618181 Cd=0.0187911264592085 x=0.625938350807138,1 s=YB u=1.01952639464534 Foil spline 17pts Re100000 N12","diter":5,"good":30.687172793124,"id":6,"iver":1.2020062,"n":12,"r":6,"src":"","sym":5.55479199173955,"xver":6.991,"xy":[1,0,0.870588443819102,0.0403417478031085,0.713516798884012,0.0725922326223564,0.580442629593444,0.0888910428998493,0.42583065729969,0.097395867745351,0.229768114218089,0.0919163941557608,0.081788256748409,0.0630971357720647,0.010957950883341,0.0226598882793267,0,0,0.0162649038866205,-0.00950735445231851,0.04389732811481,-0.014030378495419,0.149688687874769,-0.00778458970609924,0.394602510713099,0.0247594324205587,0.578063605817522,0.0431474144160694,0.727546442647447,0.0426780555229531,0.841413116633622,0.0300183715165134,1,0]},        #100000 12
             {"r":6,"id":358,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt29.1501133439728>27.2357069998813) l1 Foil spline 17pts Re80000 N11","iver":1.2020052,"good":29.7295576112035,"Cm":-0.122357342733912,"CDp":0.00661789438658711,"CD":0.0165085382179725,"CL":0.957050843526168,"n":13,"Cpmin":-1.26347528252598,"CDf":0.0076,"xy":[1,0,0.932175646467167,0.0160482403493011,0.822686565492564,0.0333184209106194,0.678803188734605,0.0501605170011316,0.467813461804766,0.0679332046947079,0.299436270431163,0.0721776690511335,0.134160023906898,0.0597786722341117,0.0364048536456623,0.0306761763134632,0,0,0.0270013726530119,-0.0127478700013051,0.12487691305341,0.000346563710990387,0.281461101187184,0.0200785620721386,0.47006254090453,0.0292008029795955,0.68986358510747,0.0255866978881908,0.86337155350222,0.0141654851163227,0.97248200666718,0.000624421251049684,1,0],"Bot_Xtr":1,"sym":3.33586957646476,"alpha":3.6,"CDpres":0.00891,"clcd":57.9730822250663,"Top_Xtr":0.691797305806571,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N11.dat","diter":4,"src":"retest_16.txt","Re":100000},
             {"Re":100000,"n":14,"Cm":-0.128339430651249,"r":6,"id":359,"cmt":"OPT s(0) foildb2020_spline/spline_foil_mid113.dat-s17_n17s0.dat (opt27.6262643582983>25.8530388924518) l1 Foil spline 17pts Re80000 N12","xver":6.991,"iver":1.2020052,"good":30.0596411685285,"Cpmin":-1.29942687758867,"CDf":0.00751,"CDp":0.00809257868129007,"CD":0.0179230598982525,"CL":0.992773813430791,"alpha":3.7,"CDpres":0.01042,"clcd":55.3908662397309,"Bot_Xtr":1,"xy":[1,0,0.932175646467167,0.0167651112291188,0.822686565492564,0.034806746433696,0.678803188734605,0.0524011747412981,0.467813461804766,0.0709677639459628,0.299436270431163,0.0754018274628769,0.134160023906898,0.0624489705612843,0.0364048536456623,0.0320464734316911,0,0,0.0270013726530119,-0.013513539976074,0.12487691305341,0.000367379221959878,0.281461101187184,0.0212845323333349,0.47006254090453,0.0309546785743677,0.68986358510747,0.0271235010031005,0.86337155350222,0.0150163007137906,0.97248200666718,0.000661925603030636,1,0],"sym":3.66672346977709,"src":"retest_139.txt","Top_Xtr":0.678934489552855,"Foil_fn":"optbs_spline_mid113.dat-s17_n17s0_nsopt-Re80000-N12.dat","diter":5},        #dud
             {"CL":1.38533433630614,"CD":0.0165257122802242,"n":3,"CDp":0.00369775114156112,"CDf":0.0081,"Cpmin":-1.45779471559144,"id":360,"cmt":"OPT s(0) optbs_spline_Re150000_N4_e62.dat-s17_n17s0_nsopt-Re150000-N4.dat (opt55.5967572198397>51.1472182421528) l1 Foil spline 17pts Re150000 N4","xver":6.991,"iver":1.2020052,"good":43.6947194633367,"r":6,"Cm":-0.225778958304075,"diter":3,"Top_Xtr":0.626102228946451,"Foil_fn":"opt_spline_e62_nsopt-Re150000-N4.dat","Re":125000,"src":"retest_68.txt","sym":8.01052865769782,"Bot_Xtr":1,"xy":[1,0,0.953236148199186,0.0211830567317856,0.866850564998859,0.0494966423305079,0.698195158425591,0.085105436925536,0.497241313912823,0.106048760012916,0.28552715888499,0.0991254352066964,0.125732819683231,0.0696503704537445,0.0360765344716023,0.0332977169792488,0,0,0.0212271582440712,-0.00961392973046943,0.110798788227509,0.00523014671733095,0.292707809747911,0.0293818522657211,0.425671945921368,0.0407572171717382,0.682030032261522,0.0457747803875271,0.853333640927775,0.0327739380488424,0.932619737877224,0.0224831014198225,1,0],"clcd":83.8290242995407,"CDpres":0.00842,"alpha":4.1},
             {"Cpmin":-1.44761890329074,"CDf":0.00786,"CDp":0.0035341520056413,"n":4,"CL":1.3393969664926,"CD":0.0156599053335336,"Cm":-0.223993767506602,"r":6,"cmt":"OPT s(0) optbs_spline_Re125000_N4_e62.dat-s17_n17s0_nsopt-Re125000-N4.dat (opt48.4418808424006>43.7924019055336) l1 Foil spline 17pts Re125000 N4","xver":6.991,"good":48.4418810829605,"iver":1.2020052,"id":361,"src":"retest_93.txt","Re":125000,"Foil_fn":"opt_spline_e62_nsopt-Re125000-N4.dat","Top_Xtr":0.640575058326467,"diter":3,"alpha":3.8,"clcd":85.5303361013594,"CDpres":0.0078,"Bot_Xtr":1,"xy":[1,0,0.948055131462352,0.0225246399379023,0.865820520912136,0.047092157112848,0.698021119797309,0.0798542568111209,0.49780798647652,0.0997278026309258,0.288819832388076,0.0956381537937818,0.122702850725304,0.0661525795557786,0.0371194322134399,0.0324220076843369,0,0,0.0204147778197805,-0.0100652835782226,0.114150150047107,0.00113280701417326,0.275952073437055,0.0220831014227439,0.465991319968098,0.0398277100643394,0.656329004650391,0.0487637028524039,0.835590626685817,0.0392972143354166,0.934479269017308,0.0204884365274898,1,0],"sym":7.25310827590781},
             {"CDp":0.00383330929800933,"n":5,"CL":1.38477317589284,"CD":0.0165747557780593,"Cpmin":-1.75879694429405,"CDf":0.00727,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt43.0375048339941>37.4923174233652) l1 Foil spline 17pts Re125000 N3","xver":6.991,"good":44.1784174323042,"id":362,"Cm":-0.198614615828016,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re125000-N3.dat","Top_Xtr":0.630350850436991,"diter":3,"src":"retest_36.txt","Re":125000,"xy":[1,0,0.945514649029338,0.0229366693417796,0.863082022377036,0.0469018646525972,0.698195158425591,0.0792664413328682,0.497241313912823,0.098772864785857,0.28552715888499,0.0923245421004241,0.125732819683231,0.0648717309120319,0.0360765344716023,0.0310131952176386,0,0,0.0192507166066205,-0.0112877573132249,0.113363722509556,-0.00179296952455572,0.268607859414087,0.0187930227710741,0.440775378221921,0.0340027223521803,0.638477319107758,0.0387577654199388,0.818181208003633,0.0307957683920089,0.939515187720928,0.015359178888633,1,0],"Bot_Xtr":1,"sym":6.35023838591321,"alpha":5.2,"clcd":83.5471239778944,"CDpres":0.0093},
             {"sym":8.0179717748506,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0252803371788479,0.854728633619417,0.0534731243011909,0.691363149797408,0.0853537110272199,0.513763139089403,0.102105697049266,0.327229099655296,0.0991103925368476,0.155573716106985,0.0751570579528814,0.0401397957317501,0.0360170136968161,0,0,0.0290164970646396,-0.00466359926537952,0.113543374367374,0.0072474138771001,0.264712879181914,0.0285784536022845,0.449425033656063,0.0450126631752576,0.653083287629906,0.0477714655008924,0.83008632648885,0.036076211289617,0.943258507857798,0.0176795630407892,1,0],"clcd":83.874037911061,"CDpres":0.01088,"alpha":5.4,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re125000-N6.dat","Top_Xtr":0.663091038299042,"Re":125000,"src":"retestc_16.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt44.2982998464055>41.4174825644958) l1 Foil spline 17pts Re125000 N6","iver":1.2020052,"good":44.2373698229724,"id":363,"r":6,"Cm":-0.219422947482125,"n":6,"CD":0.017662589815872,"CL":1.48143272782396,"CDp":0.00439898281984829,"CDf":0.00678,"Cpmin":-1.86490599112753},
             {"r":6,"good":43.811505182878,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt67.2716838978204>64.4956545666036) l1 Foil spline 17pts Re275000 N4","xver":6.991,"iver":1.2020052,"id":364,"Cm":-0.221060477578185,"CDp":0.00464459989850781,"n":7,"CL":1.51021237501189,"CD":0.017782326329226,"Cpmin":-2.29453798218669,"CDf":0.00643,"xy":[1,0,0.946714574040677,0.0248265984612703,0.854728633619417,0.0525133733819828,0.691363149797408,0.0838217582250087,0.513763139089403,0.100273074813702,0.327229099655296,0.0973315308828223,0.155573716106985,0.073808117594563,0.0401397957317501,0.0353705700402243,0,0,0.0290164970646396,-0.00473805041952575,0.113543374367374,0.00736311385409665,0.264712879181914,0.0290346889547085,0.449425033656063,0.0457312593782958,0.653083287629906,0.0485341040852582,0.83008632648885,0.0366521431857545,0.943258507857798,0.017961805102829,1,0],"Bot_Xtr":1,"sym":7.88888383337012,"alpha":5.6,"CDpres":0.01136,"clcd":84.9277168268918,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N4.dat","Top_Xtr":0.663283075582272,"diter":4,"src":"retest_63.txt","Re":125000},
             {"Cm":-0.199575008994444,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt31.0072013261422>26.7130171119343) l1 Foil spline 17pts Re80000 N4","xver":6.991,"iver":1.2020052,"good":42.5509883379065,"id":365,"r":6,"CDf":0.00619,"Cpmin":-2.51654203979166,"n":8,"CD":0.0170762256719651,"CL":1.45319049389299,"CDp":0.00496775934785046,"clcd":85.1002160435701,"CDpres":0.01089,"alpha":5.8,"sym":5.91617515239517,"xy":[1,0,0.945514649029338,0.021748164268802,0.863082022377036,0.0444715595703252,0.698195158425591,0.0751591070797039,0.497241313912823,0.0936547698645212,0.28552715888499,0.0875405787005239,0.125732819683231,0.0615102846561299,0.0360765344716023,0.0294061903253342,0,0,0.0192507166066205,-0.0114920035927617,0.113363722509556,-0.00182541240444332,0.268607859414087,0.019133073046406,0.440775378221921,0.0346179844757218,0.638477319107758,0.0394590676512429,0.818181208003633,0.0313530022999506,0.939515187720928,0.0156370954895745,1,0],"Bot_Xtr":1,"Re":125000,"src":"retest_94.txt","diter":4,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re80000-N4.dat","Top_Xtr":0.654326324768777},
             {"diter":4,"Top_Xtr":0.687613267177291,"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","Re":125000,"src":"retestc_19.txt","sym":5.7279194130313,"Bot_Xtr":1,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"CDpres":0.00666,"clcd":79.5662265333655,"alpha":3,"CL":1.11223088077277,"CD":0.0139786807698662,"n":9,"CDp":0.004119048219007,"CDf":0.00732,"Cpmin":-1.31376806789021,"id":366,"xver":6.991,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","iver":1.2020052,"good":42.6061314387195,"r":6,"Cm":-0.17810256958749},
             {"Re":125000,"src":"retest_64.txt","diter":4,"Top_Xtr":0.692996744921145,"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","clcd":78.6772547055657,"CDpres":0.00723,"alpha":3.2,"sym":5.7279194130313,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"Bot_Xtr":1,"CDf":0.00725,"Cpmin":-1.36150644151084,"CD":0.0144793207288781,"CL":1.13919320494952,"n":10,"CDp":0.00466777397474502,"Cm":-0.179522386040617,"id":367,"good":42.6635827161981,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","xver":6.991,"iver":1.2020052,"r":6},
             {"Cm":-0.181143945784565,"r":6,"id":368,"cmt":"OPT s(na) foildb2020_spline/spline_foil_be6568.dat-s17_n17s0.dat (opt29.4917047265402>29.4917047265402) l1 Foil spline 17pts Re125000 N12","xver":6.991,"iver":1.2020052,"good":42.0404918236714,"Cpmin":-1.38506222468379,"CDf":0.00712,"CDp":0.00533716235825909,"CD":0.0149712019220415,"CL":1.15438944006438,"n":11,"alpha":3.3,"clcd":77.1073322018866,"CDpres":0.00785,"Bot_Xtr":1,"xy":[1,0,0.896866800105748,0.0301632991781163,0.724380844156728,0.060917897648545,0.510552344463168,0.0826298785144619,0.334472441945641,0.0881611787641998,0.190270468629251,0.077284105995217,0.0873478702982618,0.0541033747278037,0.0305344216970311,0.0288773683684043,0,-3.43565157668151e-09,0.0220756519913723,-0.016159129053836,0.135324553635068,0.00294665648312284,0.285751757739152,0.0276101636800961,0.44123537629784,0.0416652008361107,0.591955087760974,0.0448076159702944,0.726206007656939,0.040248526777877,0.854808845142057,0.0262245756217473,1,0],"sym":5.7279194130313,"src":"retest_65.txt","Re":125000,"Top_Xtr":0.703678472123042,"Foil_fn":"optbs-spline_foil_be6568.dat-s17_n17s0-Re125000-N12.dat","diter":4},
             {"src":"retestc_7.txt","Re":125000,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re125000-N11.dat","Top_Xtr":0.644714925963178,"diter":4,"alpha":4.1,"CDpres":0.00722,"clcd":74.2380463718251,"Bot_Xtr":1,"xy":[1,0,0.868523950462083,0.0336321964460009,0.641452589715019,0.0689430613427839,0.416262776127718,0.0838726848509803,0.233866556084622,0.0802478451316838,0.132025845000493,0.0662766172918183,0.0665475051364794,0.0465298019535748,0.0222714169962174,0.0253756677399588,0,0,0.0219899769144022,-0.00843181574474415,0.0671574276679874,-0.00611345878647464,0.108585510576379,-0.00186462279333414,0.25711939037162,0.016981139826366,0.414690606933141,0.0289656405848285,0.609466583507779,0.0311866980685398,0.764025880785643,0.0230603170162706,1,0],"sym":4.50349835062409,"Cpmin":-1.41017195584521,"CDf":0.00729,"CDp":0.00418011362465049,"n":12,"CL":1.07714160112905,"CD":0.0145092934656999,"Cm":-0.138324476669106,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt38.7394432311204>37.7355165368228) l1 Foil spline 17pts Re125000 N11","xver":6.991,"good":50.6218215141818,"iver":1.2020052,"id":369},
             {"xy":[1,0,0.868523950462083,0.0341656138079312,0.641452589715019,0.0700365202836507,0.416262776127718,0.0852029323821831,0.233866556084622,0.0815206015488706,0.132025845000493,0.0673277855796293,0.0665475051364794,0.0472677794522811,0.0222714169962174,0.0257781339233614,0,0,0.0219899769144022,-0.0076874136166081,0.0671574276679874,-0.00557373260308875,0.108585510576379,-0.00170000473032747,0.25711939037162,0.015481961356675,0.414690606933141,0.0264084114959919,0.609466583507779,0.0284333831106995,0.764025880785643,0.0210244389109996,1,0],"Bot_Xtr":1,"sym":4.43815454414797,"alpha":4.1,"clcd":71.8575559048679,"CDpres":0.00766,"Top_Xtr":0.656006378044079,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re100000-N11.dat","diter":4,"src":"retest_119.txt","Re":125000,"r":6,"id":370,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt45.3507896005082>32.5996976934759) l1 Foil spline 17pts Re100000 N11","xver":6.991,"good":44.9974192707909,"Cm":-0.137636339495821,"CDp":0.00469637978233823,"CL":1.0764718867517,"CD":0.0149806359706534,"n":13,"Cpmin":-1.40127234003946,"CDf":0.00732},
             {"Re":125000,"n":14,"CL":1.39839563224653,"CD":0.017355979988492,"CDp":0.00528354493605387,"CDf":0.00653,"Cpmin":-2.30143340458527,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ah7476.dat-s19_n19s0.dat (opt24.3466371385559>24.1396004398234) l1 Foil spline 19pts Re80000 N9","iver":1.2020052,"good":34.9484552209021,"id":371,"r":6,"Cm":-0.176527224784103,"diter":6,"Foil_fn":"optbs-spline_foil_ah7476.dat-s17_n17s0-Re80000-N9-sq1.dat","Top_Xtr":0.628504743530704,"src":"retest_100.txt","sym":6.28983420467395,"Bot_Xtr":1,"xy":[1,0,0.870376255627843,0.0431715692335938,0.649145112179754,0.0801344845384634,0.455676598192956,0.0912500210402624,0.305658377454195,0.0900148671321263,0.181372275654513,0.0767151663642071,0.0996294839871787,0.058918211995527,0.0606393826477274,0.0454801379899887,0.0201236032892939,0.0253859329708972,0,0,0.0187349310411378,-0.00786621884288976,0.0539931858925997,-0.002163755739364,0.0870669961979878,0.00168454393490285,0.176616410478542,0.0150060498073451,0.334348269331234,0.0322125907457213,0.510861902096612,0.0405726079898207,0.674992242720296,0.039509699670597,0.81540861206885,0.0291223654070039,1,0],"clcd":80.5714015096666,"CDpres":0.01082,"alpha":5.9},        #dud
             {"Cm":-0.223073513627423,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt48.9105167863018>43.0448397946629) l1 Foil spline 17pts Re150000 N3","iver":1.2020052,"xver":6.991,"good":48.9105167934696,"id":372,"r":6,"CDf":0.00756,"Cpmin":-1.42745484622521,"n":3,"CD":0.014234676287868,"CL":1.3194146473166,"CDp":0.00238529361870813,"CDpres":0.00668,"clcd":92.6901757815957,"alpha":3.7,"sym":7.7370440369536,"xy":[1,0,0.946714574040677,0.0246246154433233,0.854728633619417,0.0520861376632106,0.691363149797408,0.083139805289639,0.513763139089403,0.0994572780664641,0.327229099655296,0.0965396658039321,0.155573716106985,0.0732076331438239,0.0401397957317501,0.0350828038972155,0,0,0.0290164970646396,-0.00467510840254184,0.113543374367374,0.00726529952199307,0.264712879181914,0.0286489813907327,0.449425033656063,0.045123748387568,0.653083287629906,0.0478893590671292,0.83008632648885,0.0361652425378873,0.943258507857798,0.0177231938298917,1,0],"Bot_Xtr":1,"Re":150000,"src":"retestc_23.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re150000-N3.dat","Top_Xtr":0.635352929190835},
             {"Re":150000,"src":"retest_77.txt","diter":3,"Top_Xtr":0.666654455113994,"Foil_fn":"opt_spline_e62_nsopt-Re150000-N4.dat","CDpres":0.00745,"clcd":93.4591339597654,"alpha":3.8,"sym":8.01052865769782,"xy":[1,0,0.953236148199186,0.0211830567317856,0.866850564998859,0.0494966423305079,0.698195158425591,0.085105436925536,0.497241313912823,0.106048760012916,0.28552715888499,0.0991254352066964,0.125732819683231,0.0696503704537445,0.0360765344716023,0.0332977169792488,0,0,0.0212271582440712,-0.00961392973046943,0.110798788227509,0.00523014671733095,0.292707809747911,0.0293818522657211,0.425671945921368,0.0407572171717382,0.682030032261522,0.0457747803875271,0.853333640927775,0.0327739380488424,0.932619737877224,0.0224831014198225,1,0],"Bot_Xtr":1,"CDf":0.00735,"Cpmin":-1.42470811747654,"CL":1.38336700432581,"CD":0.0148018384690079,"n":4,"CDp":0.00336431432545505,"Cm":-0.232325410536449,"id":373,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re150000_N4_e62.dat-s17_n17s0_nsopt-Re150000-N4.dat (opt55.5967572198397>51.1472182421528) l1 Foil spline 17pts Re150000 N4","iver":1.2020052,"good":55.0167368217562,"r":6},
             {"CDp":0.00316295097504075,"CD":0.0143505489861352,"CL":1.36031831604468,"n":5,"Cpmin":-1.4718762231401,"CDf":0.00721,"r":6,"id":374,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re125000_N4_e62.dat-s17_n17s0_nsopt-Re125000-N4.dat (opt48.4418808424006>43.7924019055336) l1 Foil spline 17pts Re125000 N4","xver":6.991,"good":54.8262842503193,"Cm":-0.22829555907275,"Top_Xtr":0.656104626407915,"Foil_fn":"opt_spline_e62_nsopt-Re125000-N4.dat","diter":3,"src":"retestc_13.txt","Re":150000,"xy":[1,0,0.948055131462352,0.0225246399379023,0.865820520912136,0.047092157112848,0.698021119797309,0.0798542568111209,0.49780798647652,0.0997278026309258,0.288819832388076,0.0956381537937818,0.122702850725304,0.0661525795557786,0.0371194322134399,0.0324220076843369,0,0,0.0204147778197805,-0.0100652835782226,0.114150150047107,0.00113280701417326,0.275952073437055,0.0220831014227439,0.465991319968098,0.0398277100643394,0.656329004650391,0.0487637028524039,0.835590626685817,0.0392972143354166,0.934479269017308,0.0204884365274898,1,0],"Bot_Xtr":1,"sym":7.25310827590781,"alpha":3.8,"CDpres":0.00714,"clcd":94.7920750181026},
             {"Re":150000,"src":"retest_104.txt","diter":3,"Top_Xtr":0.659229470742437,"Foil_fn":"opt_spline_e62_nsopt-Re125000-N4.dat","CDpres":0.00781,"clcd":95.3470747465082,"alpha":4.2,"sym":7.25310827590781,"xy":[1,0,0.948055131462352,0.0225246399379023,0.865820520912136,0.047092157112848,0.698021119797309,0.0798542568111209,0.49780798647652,0.0997278026309258,0.288819832388076,0.0956381537937818,0.122702850725304,0.0661525795557786,0.0371194322134399,0.0324220076843369,0,0,0.0204147778197805,-0.0100652835782226,0.114150150047107,0.00113280701417326,0.275952073437055,0.0220831014227439,0.465991319968098,0.0398277100643394,0.656329004650391,0.0487637028524039,0.835590626685817,0.0392972143354166,0.934479269017308,0.0204884365274898,1,0],"Bot_Xtr":1,"CDf":0.00694,"Cpmin":-1.56407130236887,"CL":1.40580875269255,"CD":0.0147441204298094,"n":6,"CDp":0.00346465495202574,"Cm":-0.228791552889416,"id":375,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re125000_N4_e62.dat-s17_n17s0_nsopt-Re125000-N4.dat (opt48.4418808424006>43.7924019055336) l1 Foil spline 17pts Re125000 N4","iver":1.2020052,"good":55.1796009843911,"r":6},
             {"Top_Xtr":0.653707404695802,"Foil_fn":"opt_spline_e62_nsopt-Re150000-N4.dat","diter":3,"src":"retest_80.txt","Re":150000,"xy":[1,0,0.953236148199186,0.0211830567317856,0.866850564998859,0.0494966423305079,0.698195158425591,0.085105436925536,0.497241313912823,0.106048760012916,0.28552715888499,0.0991254352066964,0.125732819683231,0.0696503704537445,0.0360765344716023,0.0332977169792488,0,0,0.0212271582440712,-0.00961392973046943,0.110798788227509,0.00523014671733095,0.292707809747911,0.0293818522657211,0.425671945921368,0.0407572171717382,0.682030032261522,0.0457747803875271,0.853333640927775,0.0327739380488424,0.932619737877224,0.0224831014198225,1,0],"Bot_Xtr":1,"sym":8.01052865769782,"alpha":5.5,"clcd":93.8294364613737,"CDpres":0.0103,"CDp":0.00449940354783719,"CL":1.56671761828707,"CD":0.0166975064262699,"n":7,"Cpmin":-1.94474294056434,"CDf":0.0064,"r":6,"id":376,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re150000_N4_e62.dat-s17_n17s0_nsopt-Re150000-N4.dat (opt55.5967572198397>51.1472182421528) l1 Foil spline 17pts Re150000 N4","xver":6.991,"good":50.7685641387175,"Cm":-0.232393743033629},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt50.0579280705428>46.6668934683521) l1 Foil spline 17pts Re150000 N8","xver":6.991,"iver":1.2020052,"good":50.0580094504855,"id":377,"Cm":-0.229020042125671,"CDp":0.00413912161454009,"n":8,"CL":1.54676076279259,"CD":0.0165291475451484,"Cpmin":-2.3064859293808,"CDf":0.00595,"xy":[1,0,0.946714574040677,0.025449108193758,0.854728633619417,0.0538301097873765,0.691363149797408,0.0859235306595491,0.513763139089403,0.102787352598288,0.327229099655296,0.0997720514940937,0.155573716106985,0.0756588049374501,0.0401397957317501,0.0362574625449719,0,0,0.0290164970646396,-0.00478068209056194,0.113543374367374,0.00742936512198867,0.264712879181914,0.0292959350788642,0.449425033656063,0.0461427366386162,0.653083287629906,0.0489708005692956,0.83008632648885,0.0369819290623731,0.943258507857798,0.0181234204717166,1,0],"Bot_Xtr":1,"sym":8.21214876919899,"alpha":5.6,"CDpres":0.01058,"clcd":93.5777697287597,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re150000-N8.dat","Top_Xtr":0.672618139273859,"diter":3,"src":"retest_9.txt","Re":150000},
             {"sym":6.6604913419274,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0281409440425883,0.833474960203591,0.0569970217733746,0.683294039292584,0.0844005715755939,0.512919921681868,0.0993242619303931,0.327643312365742,0.0975582554020971,0.159685519883032,0.0761598738344922,0.0454559935430201,0.0393187383177299,0,-3.89682436008516e-11,0.0261984228078157,-0.0129952681600761,0.134241453700877,-0.00304509180028705,0.290009257938815,0.0176330989629277,0.464856398032139,0.0344953840267635,0.654716626975926,0.0421932982759772,0.826995021496349,0.0354888550253118,0.941457504275826,0.0188463394739241,1,0],"CDpres":0.01,"clcd":93.8269995688395,"alpha":5.4,"diter":3,"Top_Xtr":0.65815789347852,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N7.dat","Re":150000,"src":"retest_45.txt","id":378,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.3015001155412>53.2562181669305) l1 Foil spline 17pts Re225000 N7","xver":6.991,"good":47.9406816585558,"iver":1.2020052,"r":6,"Cm":-0.223690740634556,"CD":0.0159962734916076,"CL":1.50088234600011,"n":9,"CDp":0.00437001039033913,"CDf":0.00599,"Cpmin":-1.98265313609859},
             {"sym":8.97944120697462,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0267440757142718,0.854728633619417,0.0565692330316811,0.691363149797408,0.0902957145728259,0.513763139089403,0.108017645232551,0.327229099655296,0.104848911757966,0.155573716106985,0.0795086724569304,0.0401397957317501,0.0381024087809858,0,0,0.0290164970646396,-0.00493939242046591,0.113543374367374,0.00767600712142545,0.264712879181914,0.0302685091662294,0.449425033656063,0.047674595234494,0.653083287629906,0.0505965459685469,0.83008632648885,0.0382096647809982,0.943258507857798,0.0187250865075597,1,0],"clcd":90.8714497479247,"CDpres":0.01251,"alpha":6.2,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re350000-N7.dat","Top_Xtr":0.675726469749508,"Re":150000,"src":"retest_82.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt88.2253908824173>86.3705075262062) l1 Foil spline 17pts Re350000 N7","good":46.5452853714365,"iver":1.2020052,"id":379,"r":6,"Cm":-0.238258618865828,"n":10,"CD":0.0181295745904349,"CL":1.64746072634595,"CDp":0.00508083260451963,"CDf":0.00562,"Cpmin":-2.75081510376798},
             {"clcd":84.7999374362993,"CDpres":0.00935,"alpha":5.2,"sym":3.28879235231678,"xy":[1,0,0.950508917839312,0.0207848998336707,0.84680754955893,0.04788915069549,0.678208612492409,0.0762486882451967,0.479439484117614,0.0923021076500112,0.288549787301318,0.0888337146330105,0.136575629319395,0.0661728129624523,0.0420515725310539,0.0333349297785849,0,0,0.0172835986897574,-0.0196150419113891,0.125431438213165,-0.0263154931298256,0.312414658831194,-0.0133893766894865,0.391315360311591,-0.00577343877107311,0.641500437307113,0.0155559794982867,0.828871327794504,0.0214653204711706,0.941481064043605,0.0139576801125874,1,0],"Bot_Xtr":1,"Re":150000,"src":"retest_118.txt","diter":4,"Foil_fn":"optbs_spline_e216.dat-s17_n17s0_nsopt-Re275000-N12.dat","Top_Xtr":0.658165549784432,"Cm":-0.183265429778616,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e216.dat-s17_n17s0.dat (opt67.7788949392782>66.8351349330988) l1 Foil spline 17pts Re275000 N12","iver":1.2020052,"good":45.1034826204535,"id":380,"r":6,"CDf":0.00602,"Cpmin":-1.85790375327769,"n":11,"CD":0.0153676385377478,"CL":1.30317478654467,"CDp":0.00476619642899526},
             {"Re":150000,"n":12,"CDpres":0.00855,"clcd":90.1058149468677,"alpha":5.3,"sym":6.99905013852422,"xy":[1,0,0.870376255627843,0.045676525776036,0.649145112179754,0.0847841510871524,0.455676598192956,0.0965446476026187,0.305658377454195,0.0952378259993295,0.181372275654513,0.0811664328180339,0.0996294839871787,0.0623368405797376,0.0606393826477274,0.0481190452901325,0.0201236032892939,0.0268589083574848,0,0,0.0187349310411378,-0.00823170455906399,0.0539931858925997,-0.00226428965938612,0.0870669961979878,0.00176281238366734,0.176616410478542,0.0157032713022367,0.334348269331234,0.0337092744807752,0.510861902096612,0.0424577206448823,0.674992242720296,0.0413454267420589,0.81540861206885,0.0304754689488774,1,0],"Bot_Xtr":1,"src":"retest_88.txt","diter":4,"Foil_fn":"optbs-spline_foil_ah7476.dat-s17_n17s0-Re100000-N9-sq1.dat","Top_Xtr":0.64366848010408,"Cm":-0.182270713220069,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_ah7476.dat-s19_n19s0.dat (opt27.9844213027639>27.3437389817585) l1 Foil spline 19pts Re100000 N9","xver":6.991,"good":43.5468638814733,"id":381,"r":6,"CDf":0.00654,"Cpmin":-2.00274178114987,"CL":1.35952495842397,"CD":0.0150880934734971,"CDp":0.00364932229766201},        #dud
             {"r":6,"id":382,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.3015001155412>53.2562181669305) l1 Foil spline 17pts Re225000 N7","xver":6.991,"good":42.3873417679956,"iver":1.2020052,"Cm":-0.228089517007956,"CDp":0.00557626294655281,"CD":0.017135277966812,"CL":1.58484834231126,"n":13,"Cpmin":-2.28949544352656,"CDf":0.00541,"xy":[1,0,0.936135138855638,0.0281409440425883,0.833474960203591,0.0569970217733746,0.683294039292584,0.0844005715755939,0.512919921681868,0.0993242619303931,0.327643312365742,0.0975582554020971,0.159685519883032,0.0761598738344922,0.0454559935430201,0.0393187383177299,0,-3.89682436008516e-11,0.0261984228078157,-0.0129952681600761,0.134241453700877,-0.00304509180028705,0.290009257938815,0.0176330989629277,0.464856398032139,0.0344953840267635,0.654716626975926,0.0421932982759772,0.826995021496349,0.0354888550253118,0.941457504275826,0.0188463394739241,1,0],"Bot_Xtr":1,"sym":6.6604913419274,"alpha":6,"CDpres":0.01173,"clcd":92.4903783516575,"Top_Xtr":0.66071832111942,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N7.dat","diter":4,"src":"retest_49.txt","Re":150000},
             {"Re":150000,"src":"retest_0.txt","diter":6,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re275000-N9.dat","Top_Xtr":0.627841212439788,"CDpres":0.00425,"clcd":169.169132528544,"alpha":6.7,"sym":6.42692594669709,"xy":[1,0,0.945514649029338,0.0232676310951674,0.863082022377036,0.0475786291440444,0.698195158425591,0.0804102063676875,0.497241313912823,0.10019809527724,0.28552715888499,0.093656727339657,0.125732819683231,0.0658077893034236,0.0360765344716023,0.0314606961740521,0,0,0.0192507166066205,-0.0110599327147598,0.113363722509556,-0.00175678141821564,0.268607859414087,0.0184137168781534,0.440775378221921,0.0333164339822551,0.638477319107758,0.0379755044181139,0.818181208003633,0.0301742070513773,0.939515187720928,0.0150491794205407,1,0],"Bot_Xtr":1,"CDf":0.005,"Cpmin":-3.46887416530541,"n":14,"CD":0.0092525703156888,"CL":1.56524929396443,"CDp":0.000873302351267519,"Cm":-0.202173927217511,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt74.0663164623451>63.4361616031652) l1 Foil spline 17pts Re275000 N9","good":57.462549221253,"iver":1.2020052,"id":383,"r":6},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt57.6837701101429>52.8566922934394) l1 Foil spline 17pts Re200000 N3","xver":6.991,"good":57.6837701101249,"iver":1.2020052,"id":384,"r":6,"Cm":-0.245525986296005,"n":3,"CD":0.012469597556647,"CL":1.29668906697733,"CDp":0.00187872460305384,"CDf":0.00696,"Cpmin":-1.23679354404358,"sym":9.17687053759369,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.02691891811507,0.854728633619417,0.0569390607505464,0.691363149797408,0.0908860329553481,0.513763139089403,0.108723822728562,0.327229099655296,0.105534373302747,0.155573716106985,0.0800284693392443,0.0401397957317501,0.0383515075607917,0,0,0.0290164970646396,-0.00504627693385876,0.113543374367374,0.00784210979481786,0.264712879181914,0.0309234955690013,0.449425033656063,0.0487062354604713,0.653083287629906,0.0516914148784962,0.83008632648885,0.0390364914591336,0.943258507857798,0.0191302824485234,1,0],"clcd":103.988044609036,"CDpres":0.00551,"alpha":2.6,"diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re200000-N3.dat","Top_Xtr":0.672653982909005,"Re":200000,"src":"retestc_9.txt"},
             {"diter":3,"Top_Xtr":0.675681545068018,"Foil_fn":"opt_spline_e62_nsopt-Re200000-N4.dat","Re":200000,"src":"retest_88.txt","sym":6.82202146346359,"Bot_Xtr":1,"xy":[1,0,0.945386836151858,0.0235806258887676,0.863367568943953,0.048556526563407,0.698180057824213,0.0822207785005239,0.497241313912823,0.102510141999991,0.28552715888499,0.0958178335853405,0.125732819683231,0.0673262880649967,0.0360765344716023,0.0321866441003417,0,0,0.0194358184057632,-0.0113350816007532,0.113426574791703,-0.00161940826668976,0.271700632399965,0.0195275834938294,0.440631619815556,0.0346678008686976,0.634690952272467,0.0406858974261102,0.817119369831652,0.0318154308964919,0.941373135519368,0.0150498026728938,1,0],"CDpres":0.00524,"clcd":103.825477687469,"alpha":3.2,"CL":1.24474428917426,"CD":0.0119888135060754,"n":4,"CDp":0.00203594864534915,"CDf":0.00675,"Cpmin":-1.26264599883848,"id":385,"good":61.1350571421988,"cmt":"OPT s(0) optbs_spline_Re200000_N4_e62.dat-s17_n17s0_nsopt-Re200000-N4.dat (opt61.1350571420477>60.9786360408187) l1 Foil spline 17pts Re200000 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.21513423911588},
             {"Cm":-0.232719822456432,"r":6,"id":386,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt63.7435380081369>57.3151901348186) l1 Foil spline 17pts Re200000 N5","iver":1.2020052,"good":63.5082849325408,"Cpmin":-1.49168052453614,"CDf":0.00624,"CDp":0.00227355596149056,"CL":1.36157602751944,"CD":0.0122801405898298,"n":5,"alpha":3.7,"clcd":110.876257283819,"CDpres":0.00604,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0243959621460075,0.854728633619417,0.0516024888058894,0.691363149797408,0.082367805797447,0.513763139089403,0.0985337617328064,0.327229099655296,0.0956432411284427,0.155573716106985,0.0725278594131216,0.0401397957317501,0.0347570404834215,0,0,0.0290164970646396,-0.00474425518297073,0.113543374367374,0.00737275629679732,0.264712879181914,0.0290727116350751,0.449425033656063,0.0457911472269591,0.653083287629906,0.0485976624285004,0.83008632648885,0.0367001413829206,0.943258507857798,0.017985327172423,1,0],"sym":7.70406222321084,"src":"retestc_11.txt","Re":200000,"Top_Xtr":0.702967007918305,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re200000-N5.dat","diter":3},
             {"clcd":109.905502610419,"CDpres":0.00724,"alpha":4.2,"sym":8.79716927451602,"xy":[1,0,0.946714574040677,0.0261771777620387,0.854728633619417,0.0553701270050726,0.691363149797408,0.0883817035509589,0.513763139089403,0.10572797994213,0.327229099655296,0.102626414558792,0.155573716106985,0.0778233158911563,0.0401397957317501,0.0372947466376438,0,0,0.0290164970646396,-0.00502121593245771,0.113543374367374,0.00780316402804148,0.264712879181914,0.0307699221968028,0.449425033656063,0.0484643488079722,0.653083287629906,0.0514347031209626,0.83008632648885,0.0388426270359219,0.943258507857798,0.019035276954071,1,0],"Bot_Xtr":1,"Re":200000,"src":"retestc_4.txt","diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re225000-N5.dat","Top_Xtr":0.702849586675029,"Cm":-0.245289663201707,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt66.5797323062414>62.9097813352963) l1 Foil spline 17pts Re225000 N5","iver":1.2020052,"good":64.4352837105184,"id":387,"r":6,"CDf":0.00612,"Cpmin":-1.61872389067162,"n":6,"CL":1.46774968259475,"CD":0.0133546514754358,"CDp":0.00273494075645307},
             {"r":6,"id":388,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt69.5030938951343>64.0781273588492) l1 Foil spline 17pts Re225000 N6","good":64.8564132226128,"iver":1.2020052,"Cm":-0.235732250790808,"CDp":0.00278116546000653,"CL":1.43907412640081,"CD":0.0130034636638705,"n":7,"Cpmin":-1.65631766472658,"CDf":0.00589,"xy":[1,0,0.946714574040677,0.0251274317777605,0.854728633619417,0.0531496978587022,0.691363149797408,0.084837458283968,0.513763139089403,0.101488121719864,0.327229099655296,0.0985109339847103,0.155573716106985,0.074702478569326,0.0401397957317501,0.0357991686623009,0,0,0.0290164970646396,-0.00470859065981672,0.113543374367374,0.00731733224654812,0.264712879181914,0.0288541600695985,0.449425033656063,0.0454469162850008,0.653083287629906,0.0482323337541211,0.83008632648885,0.0364242512818137,0.943258507857798,0.0178501240493541,1,0],"Bot_Xtr":1,"sym":7.99420356608291,"alpha":4.3,"CDpres":0.00711,"clcd":110.668523679519,"Top_Xtr":0.718151104433884,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re225000-N6.dat","diter":5,"src":"retestc_5.txt","Re":200000},
             {"diter":5,"Top_Xtr":0.718181600014616,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re100000-N6.dat","Re":200000,"src":"retest_93.txt","sym":7.33932698105929,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0238223586461992,0.854728633619417,0.0503891991639097,0.691363149797408,0.0804311549125921,0.513763139089403,0.0962170131560968,0.327229099655296,0.0933944551401733,0.155573716106985,0.0708225676216361,0.0401397957317501,0.0339398249153306,0,0,0.0290164970646396,-0.00462569859696641,0.113543374367374,0.00718851477051356,0.264712879181914,0.028346198978312,0.449425033656063,0.0446468491495842,0.653083287629906,0.047383230927009,0.83008632648885,0.0357830230365355,0.943258507857798,0.0175358827590223,1,0],"clcd":112.527288728766,"CDpres":0.00716,"alpha":4.5,"CL":1.43441836271872,"CD":0.0127472933803303,"n":8,"CDp":0.00281236477677095,"CDf":0.00559,"Cpmin":-1.72257768533592,"id":389,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt35.8742221908171>34.3046598556064) l1 Foil spline 17pts Re100000 N6","iver":1.2020052,"xver":6.991,"good":63.4005340852055,"r":6,"Cm":-0.229482074116862},
             {"CDf":0.00555,"Cpmin":-1.78328838691429,"CL":1.43980659142992,"CD":0.0130910016081523,"n":9,"CDp":0.00336614357090605,"Cm":-0.231864500952547,"id":390,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.3015001155412>53.2562181669305) l1 Foil spline 17pts Re225000 N7","iver":1.2020052,"xver":6.991,"good":61.5012285341514,"r":6,"Re":200000,"src":"retest_56.txt","diter":4,"Top_Xtr":0.711114755220822,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N7.dat","clcd":109.984448442302,"CDpres":0.00754,"alpha":4.5,"sym":6.6604913419274,"xy":[1,0,0.936135138855638,0.0281409440425883,0.833474960203591,0.0569970217733746,0.683294039292584,0.0844005715755939,0.512919921681868,0.0993242619303931,0.327643312365742,0.0975582554020971,0.159685519883032,0.0761598738344922,0.0454559935430201,0.0393187383177299,0,-3.89682436008516e-11,0.0261984228078157,-0.0129952681600761,0.134241453700877,-0.00304509180028705,0.290009257938815,0.0176330989629277,0.464856398032139,0.0344953840267635,0.654716626975926,0.0421932982759772,0.826995021496349,0.0354888550253118,0.941457504275826,0.0188463394739241,1,0],"Bot_Xtr":1},
             {"alpha":4.9,"CDpres":0.009,"clcd":108.170813297837,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0306155393255545,0.833474960203591,0.0620090981632092,0.683294039292584,0.091822399925934,0.512919921681868,0.108058416324257,0.327643312365742,0.106137114670893,0.159685519883032,0.0828570501714663,0.0454559935430201,0.0427762614280416,0,-4.30099248451158e-11,0.0261984228078157,-0.014527513253385,0.134241453700877,-0.00340413225348827,0.290009257938815,0.0197121810590387,0.464856398032139,0.0385626631521914,0.654716626975926,0.0471682224912777,0.826995021496349,0.0396732722539415,0.941457504275826,0.0210684722402544,1,0],"sym":7.98909117761437,"src":"retest_114.txt","Re":200000,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re200000-N8.dat","Top_Xtr":0.703709094079261,"diter":4,"Cm":-0.25281748297126,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt63.3965991866639>49.3184568808761) l1 Foil spline 17pts Re200000 N8","xver":6.991,"good":60.1800213499574,"id":391,"Cpmin":-1.93318988527154,"CDf":0.0055,"CDp":0.0040489326617361,"n":10,"CD":0.0145066775571187,"CL":1.569199109603},
             {"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N8.dat","Top_Xtr":0.706321462562638,"diter":4,"src":"retest_58.txt","Re":200000,"xy":[1,0,0.936135138855638,0.0284404938213681,0.833474960203591,0.0576037336604201,0.683294039292584,0.085298983956717,0.512919921681868,0.100381531389573,0.327643312365742,0.0985967263851462,0.159685519883032,0.076970567083606,0.0454559935430201,0.0397372715178653,0,-3.9147945884078e-11,0.0261984228078157,-0.0132146034867473,0.134241453700877,-0.00309648713869275,0.290009257938815,0.0179307120228214,0.464856398032139,0.0350776002789378,0.654716626975926,0.0429054406301558,0.826995021496349,0.0360878391720244,0.941457504275826,0.0191644297183232,1,0],"Bot_Xtr":1,"sym":6.82339555248322,"alpha":5,"clcd":109.878817178852,"CDpres":0.00847,"CDp":0.00384688579117955,"n":11,"CD":0.0137494724769038,"CL":1.51077577259538,"Cpmin":-1.93589317760774,"CDf":0.00528,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.0723457488308>47.8203421756439) l1 Foil spline 17pts Re225000 N8","iver":1.2020052,"good":59.177138881968,"id":392,"Cm":-0.235815387273427},
             {"CDp":0.00418069797720726,"CD":0.0156491697127861,"CL":1.66953441017711,"n":12,"Cpmin":-2.76964192113191,"CDf":0.00504,"r":6,"id":393,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt88.2253908824173>86.3705075262062) l1 Foil spline 17pts Re350000 N7","good":55.7731481835991,"iver":1.2020052,"Cm":-0.247378833856585,"Top_Xtr":0.690959823108981,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re350000-N7.dat","diter":5,"src":"retest_95.txt","Re":200000,"xy":[1,0,0.946714574040677,0.0267440757142718,0.854728633619417,0.0565692330316811,0.691363149797408,0.0902957145728259,0.513763139089403,0.108017645232551,0.327229099655296,0.104848911757966,0.155573716106985,0.0795086724569304,0.0401397957317501,0.0381024087809858,0,0,0.0290164970646396,-0.00493939242046591,0.113543374367374,0.00767600712142545,0.264712879181914,0.0302685091662294,0.449425033656063,0.047674595234494,0.653083287629906,0.0505965459685469,0.83008632648885,0.0382096647809982,0.943258507857798,0.0187250865075597,1,0],"Bot_Xtr":1,"sym":8.97944120697462,"alpha":6,"CDpres":0.01061,"clcd":106.685175048809},
             {"Re":200000,"src":"retest_60.txt","diter":5,"Top_Xtr":0.709201684684967,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N7.dat","CDpres":0.00906,"clcd":109.308194132886,"alpha":5.3,"sym":6.6604913419274,"xy":[1,0,0.936135138855638,0.0281409440425883,0.833474960203591,0.0569970217733746,0.683294039292584,0.0844005715755939,0.512919921681868,0.0993242619303931,0.327643312365742,0.0975582554020971,0.159685519883032,0.0761598738344922,0.0454559935430201,0.0393187383177299,0,-3.89682436008516e-11,0.0261984228078157,-0.0129952681600761,0.134241453700877,-0.00304509180028705,0.290009257938815,0.0176330989629277,0.464856398032139,0.0344953840267635,0.654716626975926,0.0421932982759772,0.826995021496349,0.0354888550253118,0.941457504275826,0.0188463394739241,1,0],"Bot_Xtr":1,"CDf":0.00503,"Cpmin":-2.02474545612029,"CL":1.54015676482888,"CD":0.0140900394251917,"n":13,"CDp":0.00428811919135186,"Cm":-0.235012564695185,"id":394,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.3015001155412>53.2562181669305) l1 Foil spline 17pts Re225000 N7","iver":1.2020052,"good":55.5761045668462,"r":6},
             {"Cm":-0.153317443532819,"cmt":"OPT s(0) foildb2020_spline/spline_foil_ah6407.dat-s17_n17s0.dat (opt34.6833752315299>34.1226333063206) l1 Foil spline 17pts Re100000 N9","iver":1.2020052,"xver":6.991,"good":62.8118038692685,"id":395,"r":6,"CDf":0.00627,"Cpmin":-1.36846997281154,"n":14,"CL":1.10108851514285,"CD":0.0117820357293785,"CDp":0.00296438760233091,"clcd":93.4548613188538,"CDpres":0.00551,"alpha":3.6,"sym":5.61297001690894,"xy":[1,0,0.868523950462083,0.0382142948127925,0.641452589715019,0.0783359622580598,0.416262776127718,0.0952996189464428,0.233866556084622,0.0911809258987044,0.132025845000493,0.0753062380701371,0.0665475051364794,0.0528690884726973,0.0222714169962174,0.0288328848709956,0,0,0.0219899769144022,-0.00882839495931409,0.0671574276679874,-0.00640099717170999,0.108585510576379,-0.00195232284101492,0.25711939037162,0.0177798251035011,0.414690606933141,0.0303280008806885,0.609466583507779,0.0326535228426414,0.764025880785643,0.0241449282894411,1,0],"Bot_Xtr":1,"Re":200000,"src":"retest_9.txt","diter":4,"Foil_fn":"optbs_spline_ah6407.dat-s17_n17s0_nsopt-Re100000-N9.dat","Top_Xtr":0.657736705920486},
             {"alpha":2.8,"clcd":111.019960375868,"CDpres":0.00494,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0260556482335768,0.854728633619417,0.0551130670008592,0.691555011261055,0.0878645417414586,0.516159070249535,0.105059605208279,0.323702591682963,0.101358620191483,0.162837067505129,0.0764667171897211,0.0484320448643716,0.0366145511645788,0,0,0.0290628904959806,-0.00481324656358515,0.112660630004776,0.00753420185591148,0.292228965625459,0.032345828539994,0.453875285172211,0.0465459935519156,0.648361212442096,0.0495722905966673,0.83008632648885,0.0370300098723954,0.943278981389669,0.0180299268156232,1,0],"sym":8.38584277034114,"src":"retest_97.txt","Re":225000,"Top_Xtr":0.680534095358465,"Foil_fn":"opt_spline_e61_nsopt-Re275000-N4.dat","diter":3,"Cm":-0.2421301073138,"r":6,"id":396,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re275000_N4_e61.dat-s17_n17s0_nsopt-Re275000-N4.dat (opt75.5452262403251>67.1718747466489) l1 Foil spline 17pts Re275000 N4","good":56.2072715534896,"iver":1.2020052,"Cpmin":-1.19593006167197,"CDf":0.00666,"CDp":0.00146402123747234,"CL":1.28687554421646,"CD":0.0115913889705926,"n":3},
             {"r":6,"id":397,"cmt":"OPT s(0) optbs_spline_Re225000_N4_e61.dat-s17_n17s0_nsopt-Re225000-N4.dat (opt68.4779120673342>64.9173059822234) l1 Foil spline 17pts Re225000 N4","xver":6.991,"iver":1.2020052,"good":68.4779124238085,"Cm":-0.245363594534231,"CDp":0.00158595629072761,"CL":1.26665840046406,"CD":0.0113017327461727,"n":4,"Cpmin":-1.20671020438914,"CDf":0.00648,"xy":[1,0,0.946714574040677,0.0256266548959289,0.85468910054093,0.0541982848311226,0.691334552186636,0.0864547445589628,0.516815063604724,0.104052171419548,0.331711376660578,0.100214632403637,0.16615514319047,0.0725331887255239,0.046743729211783,0.0364528614018829,0,0,0.0312263666338618,-0.00212279544773905,0.104321621532363,0.0063925612045415,0.265025957465459,0.0308178647118593,0.449425033656063,0.0465281411092268,0.653197993163179,0.0494154422439151,0.845906621289806,0.0356984087783008,0.944111842424813,0.0182499018740087,1,0],"Bot_Xtr":1,"sym":8.23673983849691,"alpha":2.5,"CDpres":0.00482,"clcd":112.076477909373,"Top_Xtr":0.710390722246113,"Foil_fn":"opt_spline_e61_nsopt-Re225000-N4.dat","diter":5,"src":"retestc_23.txt","Re":225000},
             {"Cpmin":-1.33027762643253,"CDf":0.00629,"CDp":0.00241851490561312,"n":5,"CL":1.34890181852834,"CD":0.0117761885007944,"Cm":-0.241007701312632,"r":6,"cmt":"OPT s(0) optbs_spline_Re150000_N4_e62.dat-s17_n17s0_nsopt-Re150000-N4.dat (opt55.5967572198397>51.1472182421528) l1 Foil spline 17pts Re150000 N4","xver":6.991,"good":68.2743941433594,"iver":1.2020052,"id":398,"src":"retest_94.txt","Re":225000,"Foil_fn":"opt_spline_e62_nsopt-Re150000-N4.dat","Top_Xtr":0.695635756187929,"diter":3,"alpha":3.1,"clcd":114.544856210253,"CDpres":0.00548,"Bot_Xtr":1,"xy":[1,0,0.953236148199186,0.0211830567317856,0.866850564998859,0.0494966423305079,0.698195158425591,0.085105436925536,0.497241313912823,0.106048760012916,0.28552715888499,0.0991254352066964,0.125732819683231,0.0696503704537445,0.0360765344716023,0.0332977169792488,0,0,0.0212271582440712,-0.00961392973046943,0.110798788227509,0.00523014671733095,0.292707809747911,0.0293818522657211,0.425671945921368,0.0407572171717382,0.682030032261522,0.0457747803875271,0.853333640927775,0.0327739380488424,0.932619737877224,0.0224831014198225,1,0],"sym":8.01052865769782},
             {"CDp":0.00222467317242341,"CD":0.0117212551115863,"CL":1.37636283472335,"n":6,"Cpmin":-1.5003443783774,"CDf":0.00587,"r":6,"id":399,"good":69.5826158143994,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt43.8869396157404>41.237567542513) l1 Foil spline 17pts Re200000 N5","xver":6.991,"iver":1.2020052,"Cm":-0.23598506025745,"Top_Xtr":0.721368445798426,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re200000-N5-sq1.dat","diter":3,"src":"retest_158.txt","Re":225000,"xy":[1,0,0.946714574040677,0.0247630255204258,0.854728633619417,0.0523789035074743,0.691363149797408,0.0836071176375986,0.513763139089403,0.100016307690998,0.327229099655296,0.0970822961088853,0.155573716106985,0.0736191187230098,0.0401397957317501,0.0352799973763811,0,0,0.0290164970646396,-0.0047028269819762,0.113543374367374,0.00730837526795979,0.264712879181914,0.0288188403539946,0.449425033656063,0.0453912857570496,0.653083287629906,0.0481732936605263,0.83008632648885,0.0363796651911684,0.943258507857798,0.0178282741218775,1,0],"Bot_Xtr":1,"sym":7.82568940638834,"alpha":3.7,"CDpres":0.00585,"clcd":117.424526778095},
             {"Cm":-0.241257455878715,"id":400,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re150000_N4_e62.dat-s17_n17s0_nsopt-Re150000-N4.dat (opt55.5967572198397>51.1472182421528) l1 Foil spline 17pts Re150000 N4","iver":1.2020052,"good":69.9985677113183,"r":6,"CDf":0.00597,"Cpmin":-1.56497745446047,"CD":0.0126567492150932,"CL":1.46920573057593,"n":7,"CDp":0.00288668763036767,"clcd":116.080812348237,"CDpres":0.00668,"alpha":4.2,"sym":8.01052865769782,"xy":[1,0,0.953236148199186,0.0211830567317856,0.866850564998859,0.0494966423305079,0.698195158425591,0.085105436925536,0.497241313912823,0.106048760012916,0.28552715888499,0.0991254352066964,0.125732819683231,0.0696503704537445,0.0360765344716023,0.0332977169792488,0,0,0.0212271582440712,-0.00961392973046943,0.110798788227509,0.00523014671733095,0.292707809747911,0.0293818522657211,0.425671945921368,0.0407572171717382,0.682030032261522,0.0457747803875271,0.853333640927775,0.0327739380488424,0.932619737877224,0.0224831014198225,1,0],"Bot_Xtr":1,"Re":225000,"src":"retest_96.txt","diter":3,"Top_Xtr":0.685870657900456,"Foil_fn":"opt_spline_e62_nsopt-Re150000-N4.dat"},
             {"CDf":0.00566,"Cpmin":-1.71786285624655,"n":8,"CD":0.0130686137951974,"CL":1.51620965024107,"CDp":0.00282489085223248,"Cm":-0.248825095531311,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt60.3861086843755>55.9500040958589) l1 Foil spline 17pts Re200000 N4","xver":6.991,"good":70.6992969191893,"iver":1.2020052,"id":401,"r":6,"Re":225000,"src":"retest_149.txt","diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re200000-N4.dat","Top_Xtr":0.714838056626089,"clcd":116.01916423594,"CDpres":0.00741,"alpha":4.5,"sym":8.92830605092233,"xy":[1,0,0.946714574040677,0.0265967244509286,0.854728633619417,0.0562575547354248,0.691363149797408,0.0897982142008208,0.513763139089403,0.107422502717311,0.327229099655296,0.104271227945942,0.155573716106985,0.0790706052207157,0.0401397957317501,0.0378924767522898,0,0,0.0290164970646396,-0.00495728719384385,0.113543374367374,0.00770381629230975,0.264712879181914,0.0303781680201754,0.449425033656063,0.0478473140640552,0.653083287629906,0.0507798506438471,0.83008632648885,0.0383480934041766,0.943258507857798,0.0187929250494311,1,0],"Bot_Xtr":1},
             {"n":9,"CD":0.0136660733765518,"CL":1.58344799350886,"CDp":0.00304079776184157,"CDf":0.00546,"Cpmin":-1.8744982796737,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt50.7230036716741>46.8748251068646) l1 Foil spline 17pts Re150000 N7","xver":6.991,"iver":1.2020052,"good":68.1952932977738,"id":402,"r":6,"Cm":-0.252062933809882,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re150000-N7.dat","Top_Xtr":0.701223718692313,"Re":225000,"src":"retest_31.txt","sym":9.18265999670702,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0268499726500349,0.854728633619417,0.0567932268799084,0.691363149797408,0.0906532531764387,0.513763139089403,0.108445356317454,0.327229099655296,0.105264075796233,0.155573716106985,0.0798234982474992,0.0401397957317501,0.0382532806368019,0,0,0.0290164970646396,-0.00508268209637528,0.113543374367374,0.00789868482732098,0.264712879181914,0.0311465857593583,0.449425033656063,0.0490576149905184,0.653083287629906,0.0520643302741484,0.83008632648885,0.0393181109251818,0.943258507857798,0.0192682933129,1,0],"clcd":115.867078265929,"CDpres":0.00821,"alpha":5},
             {"alpha":5.3,"CDpres":0.00893,"clcd":114.464490449497,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0275043489152914,0.854728633619417,0.0581773675709228,0.691363149797408,0.0928626162182618,0.513763139089403,0.11108834103019,0.327229099655296,0.107829527675199,0.155573716106985,0.0817689230471344,0.0401397957317501,0.0391855735386677,0,0,0.0290164970646396,-0.00515351842657319,0.113543374367374,0.00800876722790164,0.264712879181914,0.0315806695347257,0.449425033656063,0.0497413212204769,0.653083287629906,0.0527899404974324,0.83008632648885,0.0398660796227009,0.943258507857798,0.0195368316872429,1,0],"sym":9.57762848620105,"src":"retest_63.txt","Re":225000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re400000-N6.dat","Top_Xtr":0.701762396775065,"diter":3,"Cm":-0.256752219112293,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt87.3907202488104>81.1919110648486) l1 Foil spline 17pts Re400000 N6","xver":6.991,"good":67.2400724831334,"id":403,"Cpmin":-1.96366531414516,"CDf":0.00535,"CDp":0.00336567809052872,"n":10,"CD":0.0142817105083184,"CL":1.63474871608189},
             {"CDp":0.00314328854248015,"CL":1.52725774685012,"CD":0.0129915975126294,"n":11,"Cpmin":-2.20054869104233,"CDf":0.00504,"r":6,"id":404,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt43.6103416186371>40.1529667618564) l1 Foil spline 17pts Re125000 N7","iver":1.2020052,"good":65.0050276364285,"Cm":-0.235868580845389,"Top_Xtr":0.718975426607179,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re125000-N7.dat","diter":5,"src":"retest_97.txt","Re":225000,"xy":[1,0,0.946714574040677,0.0246952640325922,0.854728633619417,0.052235573992677,0.691363149797408,0.083378335307268,0.513763139089403,0.0997426232895841,0.327229099655296,0.0968166403302241,0.155573716106985,0.0734176675306443,0.0401397957317501,0.0351834572702048,0,0,0.0290164970646396,-0.00462120848467796,0.113543374367374,0.00718153696211766,0.264712879181914,0.028318683649828,0.449425033656063,0.0446035109679441,0.653083287629906,0.0473372365711313,0.83008632648885,0.0357482888686933,0.943258507857798,0.017518860879837,1,0],"Bot_Xtr":1,"sym":7.71530305119011,"alpha":5.1,"CDpres":0.00795,"clcd":117.557347767696},
             {"Cpmin":-2.83369917147336,"CDf":0.00485,"CDp":0.00330486172041837,"n":12,"CL":1.61150281890021,"CD":0.0138615631050948,"Cm":-0.240381846568234,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt50.0579280705428>46.6668934683521) l1 Foil spline 17pts Re150000 N8","xver":6.991,"iver":1.2020052,"good":61.3944055236181,"id":405,"src":"retest_37.txt","Re":225000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re150000-N8.dat","Top_Xtr":0.689428336379868,"diter":4,"alpha":5.7,"CDpres":0.00901,"clcd":116.256933412358,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.025449108193758,0.854728633619417,0.0538301097873765,0.691363149797408,0.0859235306595491,0.513763139089403,0.102787352598288,0.327229099655296,0.0997720514940937,0.155573716106985,0.0756588049374501,0.0401397957317501,0.0362574625449719,0,0,0.0290164970646396,-0.00478068209056194,0.113543374367374,0.00742936512198867,0.264712879181914,0.0292959350788642,0.449425033656063,0.0461427366386162,0.653083287629906,0.0489708005692956,0.83008632648885,0.0369819290623731,0.943258507857798,0.0181234204717166,1,0],"sym":8.21214876919899},
             {"Cm":-0.205344982314093,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e471.dat-s17_n17s0.dat (opt58.8092008746011>54.9020685488652) l1 Foil spline 17pts Re400000 N11","iver":1.2020052,"xver":6.991,"good":72.5308453421581,"id":406,"Cpmin":-2.30459058194373,"CDf":0.00485,"CDp":0.00383552653698645,"n":13,"CL":1.51597768464747,"CD":0.0135738730500731,"alpha":6.1,"clcd":111.683502494471,"CDpres":0.00872,"Bot_Xtr":1,"xy":[1,0,0.935011565234699,0.0252569246914108,0.832759572625176,0.0543032359963142,0.677881347208709,0.0853939929107694,0.498330361581256,0.101963794518755,0.303479831718183,0.0976071245509511,0.141254493802371,0.0730138548766269,0.0392201876478182,0.0366886788366575,0,0,0.0273249029632743,-0.0120351858446321,0.11517941993719,-0.00804475643501822,0.26070204557751,0.00723254890638712,0.441896057434714,0.0230929997455443,0.644540807381952,0.0316963972509029,0.824582122291211,0.0274566208014625,0.941862196267766,0.0144188671554793,1,0],"sym":5.80178663121179,"src":"retest_52.txt","Re":225000,"Foil_fn":"optbs-spline_foil_e471.dat-s17_n17s0-Re400000-N11-sq1.dat","Top_Xtr":0.662521283799232,"diter":5},
             {"Foil_fn":"optbs_spline_e216.dat-s17_n17s0_nsopt-Re275000-N10.dat","Top_Xtr":0.691181638638001,"diter":5,"src":"retest_26.txt","Re":225000,"xy":[1,0,0.950508917839312,0.0212422549403279,0.84680754955893,0.0489429131768747,0.678208612492409,0.0779264796814762,0.479439484117614,0.0943331417481682,0.288549787301318,0.0907884295152504,0.136575629319395,0.0676288928171758,0.0420515725310539,0.0340684382624506,0,0,0.0172835986897574,-0.0190508075538267,0.125431438213165,-0.0255585176705266,0.312414658831194,-0.0130042260286477,0.391315360311591,-0.00560736354520115,0.641500437307113,0.0151085056596827,0.828871327794504,0.0208478621266697,0.941481064043605,0.0135561819813591,1,0],"Bot_Xtr":1,"sym":3.42418960949059,"alpha":4.7,"clcd":101.51917789142,"CDpres":0.00746,"CDp":0.00386235790591525,"n":14,"CD":0.0127005938872832,"CL":1.28935385016979,"Cpmin":-1.66884098164532,"CDf":0.00524,"r":6,"good":57.0856258578257,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e216.dat-s17_n17s0.dat (opt68.0411049458224>62.7911871427304) l1 Foil spline 17pts Re275000 N10","xver":6.991,"iver":1.2020052,"id":407,"Cm":-0.191790517613471},
             {"Cpmin":-0.962053314848102,"CDf":0.00599,"CDp":0.000942084288359758,"CL":1.0681759387993,"CD":0.00903568446362737,"n":3,"Cm":-0.216581298953389,"r":6,"id":408,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt64.8062967518512>61.9736441951258) l1 Foil spline 17pts Re500000 N8","iver":1.2020052,"xver":6.991,"good":62.2441466730698,"src":"retest_142.txt","Re":275000,"Top_Xtr":0.709309373884831,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re500000-N8-sq1.dat","diter":3,"alpha":1.6,"clcd":118.217490119225,"CDpres":0.00305,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0223621236083683,0.854728633619417,0.0473005010530232,0.691363149797408,0.0755009801855273,0.513763139089403,0.0903192153799569,0.327229099655296,0.08766967121931,0.155573716106985,0.0664813688240622,0.0401397957317501,0.0318594212804405,0,0,0.0290164970646396,-0.00419518862905253,0.113543374367374,0.00651948560695504,0.264712879181914,0.0257080415288325,0.449425033656063,0.0404916035813907,0.653083287629906,0.0429733125550207,0.83008632648885,0.032452726482103,0.943258507857798,0.015903832558242,1,0],"sym":6.33573166885975},
             {"Cpmin":-1.18605016365022,"CDf":0.00601,"CDp":0.00131556697373532,"n":4,"CL":1.28731850101977,"CD":0.010437036404243,"Cm":-0.247084914311772,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re275000_N4_e61.dat-s17_n17s0_nsopt-Re275000-N4.dat (opt75.5452262403251>67.1718747466489) l1 Foil spline 17pts Re275000 N4","good":74.9259768799344,"iver":1.2020052,"id":409,"src":"retestc_4.txt","Re":275000,"Foil_fn":"opt_spline_e61_nsopt-Re275000-N4.dat","Top_Xtr":0.71010800792732,"diter":3,"alpha":2.6,"CDpres":0.00442,"clcd":123.341382664569,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0260556482335768,0.854728633619417,0.0551130670008592,0.691555011261055,0.0878645417414586,0.516159070249535,0.105059605208279,0.323702591682963,0.101358620191483,0.162837067505129,0.0764667171897211,0.0484320448643716,0.0366145511645788,0,0,0.0290628904959806,-0.00481324656358515,0.112660630004776,0.00753420185591148,0.292228965625459,0.032345828539994,0.453875285172211,0.0465459935519156,0.648361212442096,0.0495722905966673,0.83008632648885,0.0370300098723954,0.943278981389669,0.0180299268156232,1,0],"sym":8.38584277034114},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt74.609632972952>67.1653353479748) l1 Foil spline 17pts Re275000 N5","xver":6.991,"iver":1.2020052,"good":74.6096331951958,"id":410,"r":6,"Cm":-0.243788869835753,"n":5,"CD":0.0107648862293251,"CL":1.34719894861783,"CDp":0.00157250630179704,"CDf":0.00585,"Cpmin":-1.32477574411366,"sym":8.51594225040609,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0260819105267589,0.854728633619417,0.055168617164523,0.691363149797408,0.088060053882566,0.513763139089403,0.105343201551106,0.327229099655296,0.10225292376958,0.155573716106985,0.0775400916179876,0.0401397957317501,0.0371590189654352,0,0,0.0290164970646396,-0.00479347926576429,0.113543374367374,0.00744925242788084,0.264712879181914,0.0293743559415818,0.449425033656063,0.0462662538844598,0.653083287629906,0.0491018881218274,0.83008632648885,0.0370809241882917,0.943258507857798,0.0181719341738723,1,0],"clcd":125.1475324419,"CDpres":0.00491,"alpha":3.1,"diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N5.dat","Top_Xtr":0.701090599473432,"Re":275000,"src":"retestc_7.txt"},
             {"diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N6.dat","Top_Xtr":0.736957013082209,"Re":275000,"src":"retest_31.txt","sym":7.55001889899939,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0242775177871525,0.854728633619417,0.0513519545713567,0.691363149797408,0.0819679034738745,0.513763139089403,0.0980553723926291,0.327229099655296,0.0951788854983397,0.155573716106985,0.072175730820861,0.0401397957317501,0.0345882922556976,0,0,0.0290164970646396,-0.00463967457572595,0.113543374367374,0.00721023398278806,0.264712879181914,0.0284318435283253,0.449425033656063,0.04478174410703,0.653083287629906,0.0475263935250712,0.83008632648885,0.0358911370347625,0.943258507857798,0.0175888652696275,1,0],"CDpres":0.00463,"clcd":129.198509178346,"alpha":3.1,"n":6,"CL":1.3146182308211,"CD":0.0101751811161103,"CDp":0.00172534405835635,"CDf":0.00555,"Cpmin":-1.35653465637652,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt78.3375914534621>70.3878384522264) l1 Foil spline 17pts Re275000 N6","iver":1.2020052,"good":79.8191585169172,"id":411,"r":6,"Cm":-0.236493671703666},
             {"Cpmin":-1.49627131065567,"CDf":0.00546,"CDp":0.0019880535087976,"CL":1.40668518706847,"CD":0.0108619906253556,"n":7,"Cm":-0.245405280869638,"r":6,"id":412,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt79.4500258662517>73.9928698575414) l1 Foil spline 17pts Re275000 N7","iver":1.2020052,"xver":6.991,"good":79.0426914096613,"src":"retest_108.txt","Re":275000,"Top_Xtr":0.729944190636714,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N7.dat","diter":3,"alpha":3.6,"CDpres":0.0054,"clcd":129.50528458244,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0254340377962062,0.854728633619417,0.0537982327900147,0.691363149797408,0.0858726486500015,0.513763139089403,0.102726484207335,0.327229099655296,0.0997129686975915,0.155573716106985,0.0756140014708603,0.0401397957317501,0.0362359916796429,0,0,0.0290164970646396,-0.00482106732170682,0.113543374367374,0.00749212533528616,0.264712879181914,0.0295434150592003,0.449425033656063,0.0465325314523075,0.653083287629906,0.0493844857010146,0.83008632648885,0.0372943371508164,0.943258507857798,0.0182765196552685,1,0],"sym":8.24621446846943},
             {"xy":[1,0,0.946714574040677,0.0252062014465842,0.854728633619417,0.0533163119454675,0.691363149797408,0.0851034074088916,0.513763139089403,0.101806267474198,0.327229099655296,0.0988197468277466,0.155573716106985,0.0749366564809112,0.0401397957317501,0.0359113921750194,0,0,0.0290164970646396,-0.00484939321278432,0.113543374367374,0.00753614486706718,0.264712879181914,0.0297169956174423,0.449425033656063,0.0468059305420782,0.653083287629906,0.0496746412764381,0.83008632648885,0.0375134577856155,0.943258507857798,0.0183839022472311,1,0],"Bot_Xtr":1,"sym":8.17122572908883,"alpha":3.7,"clcd":130.494016377191,"CDpres":0.00559,"Top_Xtr":0.742453527232367,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re125000-N9.dat","diter":3,"src":"retest_105.txt","Re":275000,"r":6,"id":413,"good":81.2876463615544,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt38.5717404824928>34.525803407296) l1 Foil spline 17pts Re125000 N9","xver":6.991,"iver":1.2020052,"Cm":-0.246566032376076,"CDp":0.00219448681002708,"CD":0.0108919187844047,"CL":1.42133022823114,"n":8,"Cpmin":-1.53856453214394,"CDf":0.0053},
             {"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re400000-N6.dat","Top_Xtr":0.718282386446464,"Re":275000,"src":"retest_72.txt","sym":9.57762848620105,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0275043489152914,0.854728633619417,0.0581773675709228,0.691363149797408,0.0928626162182618,0.513763139089403,0.11108834103019,0.327229099655296,0.107829527675199,0.155573716106985,0.0817689230471344,0.0401397957317501,0.0391855735386677,0,0,0.0290164970646396,-0.00515351842657319,0.113543374367374,0.00800876722790164,0.264712879181914,0.0315806695347257,0.449425033656063,0.0497413212204769,0.653083287629906,0.0527899404974324,0.83008632648885,0.0398660796227009,0.943258507857798,0.0195368316872429,1,0],"CDpres":0.00686,"clcd":127.729278100966,"alpha":4.4,"n":9,"CD":0.0122032583969314,"CL":1.5587133855196,"CDp":0.00248663541986217,"CDf":0.00534,"Cpmin":-1.73438483024263,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt87.3907202488104>81.1919110648486) l1 Foil spline 17pts Re400000 N6","xver":6.991,"good":80.155790884472,"iver":1.2020052,"id":414,"r":6,"Cm":-0.261071861026503},
             {"sym":7.98909117761437,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0306155393255545,0.833474960203591,0.0620090981632092,0.683294039292584,0.091822399925934,0.512919921681868,0.108058416324257,0.327643312365742,0.106137114670893,0.159685519883032,0.0828570501714663,0.0454559935430201,0.0427762614280416,0,-4.30099248451158e-11,0.0261984228078157,-0.014527513253385,0.134241453700877,-0.00340413225348827,0.290009257938815,0.0197121810590387,0.464856398032139,0.0385626631521914,0.654716626975926,0.0471682224912777,0.826995021496349,0.0396732722539415,0.941457504275826,0.0210684722402544,1,0],"CDpres":0.00684,"clcd":128.190204705622,"alpha":4.2,"diter":4,"Top_Xtr":0.723019989640987,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re200000-N8.dat","Re":275000,"src":"retest_138.txt","id":415,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt63.3965991866639>49.3184568808761) l1 Foil spline 17pts Re200000 N8","iver":1.2020052,"good":78.1068019607208,"r":6,"Cm":-0.259355745904012,"CD":0.0118914070744752,"CL":1.52436190711486,"n":10,"CDp":0.00295404988372478,"CDf":0.00505,"Cpmin":-1.78178721392715},
             {"Cm":-0.247199362318161,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt38.5717404824928>34.525803407296) l1 Foil spline 17pts Re125000 N9","good":77.0617696291938,"xver":6.991,"iver":1.2020052,"id":416,"Cpmin":-1.8450621280941,"CDf":0.00487,"CDp":0.00268683172431678,"n":11,"CL":1.53235128287076,"CD":0.0117462365988005,"alpha":4.7,"CDpres":0.00687,"clcd":130.454658390521,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0252062014465842,0.854728633619417,0.0533163119454675,0.691363149797408,0.0851034074088916,0.513763139089403,0.101806267474198,0.327229099655296,0.0988197468277466,0.155573716106985,0.0749366564809112,0.0401397957317501,0.0359113921750194,0,0,0.0290164970646396,-0.00484939321278432,0.113543374367374,0.00753614486706718,0.264712879181914,0.0297169956174423,0.449425033656063,0.0468059305420782,0.653083287629906,0.0496746412764381,0.83008632648885,0.0375134577856155,0.943258507857798,0.0183839022472311,1,0],"sym":8.17122572908883,"src":"retest_108.txt","Re":275000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re125000-N9.dat","Top_Xtr":0.729546472851082,"diter":4},
             {"src":"retest_37.txt","Re":275000,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N6.dat","Top_Xtr":0.732497060783925,"diter":5,"alpha":4.8,"clcd":130.958982321319,"CDpres":0.00682,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0242775177871525,0.854728633619417,0.0513519545713567,0.691363149797408,0.0819679034738745,0.513763139089403,0.0980553723926291,0.327229099655296,0.0951788854983397,0.155573716106985,0.072175730820861,0.0401397957317501,0.0345882922556976,0,0,0.0290164970646396,-0.00463967457572595,0.113543374367374,0.00721023398278806,0.264712879181914,0.0284318435283253,0.449425033656063,0.04478174410703,0.653083287629906,0.0475263935250712,0.83008632648885,0.0358911370347625,0.943258507857798,0.0175888652696275,1,0],"sym":7.55001889899939,"Cpmin":-2.03864586793876,"CDf":0.0047,"CDp":0.00266970736331554,"n":12,"CD":0.011521678938635,"CL":1.50886734843662,"Cm":-0.238909463996178,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt78.3375914534621>70.3878384522264) l1 Foil spline 17pts Re275000 N6","iver":1.2020052,"xver":6.991,"good":75.5176777277229,"id":417},
             {"xy":[1,0,0.936135138855638,0.0281409440425883,0.833474960203591,0.0569970217733746,0.683294039292584,0.0844005715755939,0.512919921681868,0.0993242619303931,0.327643312365742,0.0975582554020971,0.159685519883032,0.0761598738344922,0.0454559935430201,0.0393187383177299,0,-3.89682436008516e-11,0.0261984228078157,-0.0129952681600761,0.134241453700877,-0.00304509180028705,0.290009257938815,0.0176330989629277,0.464856398032139,0.0344953840267635,0.654716626975926,0.0421932982759772,0.826995021496349,0.0354888550253118,0.941457504275826,0.0188463394739241,1,0],"Bot_Xtr":1,"sym":6.6604913419274,"alpha":4.6,"clcd":129.891992353437,"CDpres":0.0068,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N7.dat","Top_Xtr":0.737741557131024,"diter":5,"src":"retest_82.txt","Re":275000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.3015001155412>53.2562181669305) l1 Foil spline 17pts Re225000 N7","xver":6.991,"iver":1.2020052,"good":72.8522998180968,"id":418,"Cm":-0.240796804977262,"CDp":0.00312285556643927,"n":13,"CL":1.49108617968679,"CD":0.0114794311232792,"Cpmin":-1.86914492954681,"CDf":0.00468},
             {"CD":0.0126884015834568,"CL":1.62437110607011,"n":14,"CDp":0.00304208867395697,"CDf":0.00448,"Cpmin":-2.85884320479391,"id":419,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt50.0579280705428>46.6668934683521) l1 Foil spline 17pts Re150000 N8","good":68.5774190504583,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.245680893680145,"diter":4,"Top_Xtr":0.703270443760535,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re150000-N8.dat","Re":275000,"src":"retest_51.txt","sym":8.21214876919899,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.025449108193758,0.854728633619417,0.0538301097873765,0.691363149797408,0.0859235306595491,0.513763139089403,0.102787352598288,0.327229099655296,0.0997720514940937,0.155573716106985,0.0756588049374501,0.0401397957317501,0.0362574625449719,0,0,0.0290164970646396,-0.00478068209056194,0.113543374367374,0.00742936512198867,0.264712879181914,0.0292959350788642,0.449425033656063,0.0461427366386162,0.653083287629906,0.0489708005692956,0.83008632648885,0.0369819290623731,0.943258507857798,0.0181234204717166,1,0],"CDpres":0.00821,"clcd":128.020152529533,"alpha":5.6},
             {"Cm":-0.223765678670715,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","iver":1.2020052,"xver":6.991,"good":72.15391188971,"id":420,"r":6,"CDf":0.00553,"Cpmin":-1.41743602842382,"n":3,"CD":0.0110664225240897,"CL":1.4063309867754,"CDp":0.00217293983362531,"CDpres":0.00554,"clcd":127.080904756172,"alpha":4.2,"sym":8.455684584572,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":1,"Re":350000,"src":"retest_105.txt","diter":3,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Top_Xtr":0.646694568543603},
             {"Cm":-0.198823646238512,"r":6,"cmt":"OPT s(0) optbs_spline_Re350000_N4_e62.dat-s17_n17s0_nsopt-Re350000-N4.dat (opt73.250050869416>66.9114186410697) l1 Foil spline 17pts Re350000 N4","iver":1.2020052,"xver":6.991,"good":73.2500508694069,"id":421,"Cpmin":-1.07386603005712,"CDf":0.00536,"CDp":0.00099247402029529,"n":4,"CD":0.00832444629927638,"CL":1.1121387956045,"alpha":2.6,"clcd":133.599131476309,"CDpres":0.00296,"Bot_Xtr":1,"xy":[1,0,0.945294878207789,0.0209159793971536,0.882434244596128,0.0361801913386899,0.697306331153388,0.0742480880218608,0.497078182093437,0.0921653473902473,0.28552715888499,0.0860103102148512,0.125732819683231,0.0604350433046187,0.0360765344716023,0.0288921502423631,0,0,0.0353574619928979,-0.00652511694044839,0.14731276362677,0.00658843971866712,0.2566455950386,0.0187276925271496,0.442886208915018,0.0322168054206756,0.588201568372747,0.0351875929921941,0.783823813220591,0.0278215952843263,0.932607739015943,0.0154798410044655,1,0],"sym":5.52689328597546,"src":"retestc_8.txt","Re":350000,"Foil_fn":"opt_spline_e62_nsopt-Re350000-N4.dat","Top_Xtr":0.690868842489311,"diter":3},
             {"Re":350000,"src":"retestc_17.txt","diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re350000-N5.dat","Top_Xtr":0.697368126185047,"CDpres":0.004,"clcd":138.224432160277,"alpha":2.7,"sym":8.25628062661208,"xy":[1,0,0.946714574040677,0.0255694042975508,0.854728633619417,0.0540845608441624,0.691363149797408,0.0863296850082111,0.513763139089403,0.103273221020184,0.327229099655296,0.10024366680457,0.155573716106985,0.0760164386659997,0.0401397957317501,0.036428848962302,0,0,0.0290164970646396,-0.00477012425282998,0.113543374367374,0.00741295783325379,0.264712879181914,0.0292312368364566,0.449425033656063,0.0460408332874394,0.653083287629906,0.0488626516156064,0.83008632648885,0.0369002567824224,0.943258507857798,0.0180833960298349,1,0],"Bot_Xtr":1,"CDf":0.00546,"Cpmin":-1.24047529382999,"n":5,"CD":0.00946316900119292,"CL":1.30804116162663,"CDp":0.00118478117393625,"Cm":-0.244556721208302,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt80.8321342025858>72.2904961194383) l1 Foil spline 17pts Re350000 N5","good":80.8321329863089,"xver":6.991,"iver":1.2020052,"id":422,"r":6},
             {"CDpres":0.00348,"clcd":142.358389043868,"alpha":2.7,"sym":6.59497137519219,"xy":[1,0,0.946714574040677,0.022825493303486,0.854728633619417,0.0482806234750121,0.691363149797408,0.0770654499461969,0.513763139089403,0.0921907365300418,0.327229099655296,0.0894862906752883,0.155573716106985,0.0678589415511658,0.0401397957317501,0.0325195862354279,0,0,0.0290164970646396,-0.00427545235451517,0.113543374367374,0.00664421854489506,0.264712879181914,0.0261998962152136,0.449425033656063,0.0412663022280479,0.653083287629906,0.0437954920721108,0.83008632648885,0.0330736226942149,0.943258507857798,0.016208109901439,1,0],"Bot_Xtr":1,"Re":350000,"src":"retest_3.txt","diter":3,"Top_Xtr":0.737474910284861,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re200000-N6.dat","Cm":-0.224598100375378,"id":423,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt63.8195182425294>62.6554040709851) l1 Foil spline 17pts Re200000 N6","xver":6.991,"good":84.7950524807351,"r":6,"CDf":0.00511,"Cpmin":-1.22945287724187,"CL":1.22332048803906,"CD":0.00859324481160073,"n":6,"CDp":0.0011294182431748},
             {"CDf":0.00489,"Cpmin":-1.20441199905287,"CL":1.20488957864075,"CD":0.00831738916160158,"n":7,"CDp":0.00123420523089677,"Cm":-0.223206224143577,"id":424,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt28.9133985367929>28.820494056944) l1 Foil spline 17pts Re100000 N6","xver":6.991,"good":91.2609401428544,"iver":1.2020052,"r":6,"Re":350000,"src":"retest_93.txt","diter":3,"Top_Xtr":0.77033348567029,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re100000-N6-sq1.dat","clcd":144.863917658596,"CDpres":0.00343,"alpha":2.6,"sym":6.33696934919669,"xy":[1,0,0.946714574040677,0.0222476564524401,0.854728633619417,0.0470583794225222,0.691363149797408,0.0751145060463538,0.513763139089403,0.0898568897130713,0.327229099655296,0.0872209080293111,0.155573716106985,0.066141064238291,0.0401397957317501,0.0316963393921833,0,0,0.0290164970646396,-0.00424803420877436,0.113543374367374,0.00660160968452374,0.264712879181914,0.0260318783042985,0.449425033656063,0.0410016646190057,0.653083287629906,0.0435146349639371,0.83008632648885,0.0328615241062727,0.943258507857798,0.0161041685444522,1,0],"Bot_Xtr":1},
             {"id":425,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt91.7282121616257>87.7815947481439) l1 Foil spline 17pts Re350000 N8","iver":1.2020052,"xver":6.991,"good":91.7281962524156,"r":6,"Cm":-0.253784414590928,"CD":0.00966371253905388,"CL":1.39969408846976,"n":8,"CDp":0.00170559362060564,"CDf":0.005,"Cpmin":-1.4074585846914,"sym":8.52502637823471,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0258610193354982,0.854728633619417,0.0547013867615518,0.691363149797408,0.0873142614995793,0.513763139089403,0.104451035877201,0.327229099655296,0.101386930071834,0.155573716106985,0.0768833942034948,0.0401397957317501,0.0368443142601595,0,0,0.0290164970646396,-0.00490163051719016,0.113543374367374,0.00761732366123666,0.264712879181914,0.0300371048925579,0.449425033656063,0.0473101205581156,0.653083287629906,0.0502097328319686,0.83008632648885,0.0379175499735817,0.943258507857798,0.01858193228021,1,0],"clcd":144.840203266931,"CDpres":0.00466,"alpha":3.2,"diter":4,"Top_Xtr":0.747440525230116,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re350000-N8.dat","Re":350000,"src":"retest_125.txt"},
             {"src":"retest_83.txt","Re":350000,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re400000-N6-sq1.dat","Top_Xtr":0.759521123183916,"diter":6,"alpha":3.3,"CDpres":0.00462,"clcd":146.258885849761,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0250322704767424,0.854728633619417,0.0529484120909529,0.691363149797408,0.0845161662802018,0.513763139089403,0.101103771190682,0.327229099655296,0.0981378585058708,0.155573716106985,0.074419569232916,0.0401397957317501,0.0356635919151267,0,0,0.0290164970646396,-0.0047556040611719,0.113543374367374,0.0073903928930579,0.264712879181914,0.0291422573594511,0.449425033656063,0.0459006856334166,0.653083287629906,0.0487139143859714,0.83008632648885,0.0367879329157233,0.943258507857798,0.0180283504246756,1,0],"sym":7.99843265572694,"Cpmin":-1.44899215600552,"CDf":0.00487,"CDp":0.00176927608313647,"n":9,"CD":0.0094848221873782,"CL":1.38723952560903,"Cm":-0.248359408593253,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt59.1896065964545>58.6499184975971) l1 Foil spline 17pts Re400000 N6","good":94.8163836121277,"xver":6.991,"iver":1.2020052,"id":426},
             {"id":427,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt43.8869396157404>41.237567542513) l1 Foil spline 17pts Re200000 N5","iver":1.2020052,"xver":6.991,"good":93.9371031529707,"r":6,"Cm":-0.24616740910604,"CL":1.41048580731274,"CD":0.00961112342132008,"n":10,"CDp":0.00188052701075608,"CDf":0.00476,"Cpmin":-1.53619684433682,"sym":7.82568940638834,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0247630255204258,0.854728633619417,0.0523789035074743,0.691363149797408,0.0836071176375986,0.513763139089403,0.100016307690998,0.327229099655296,0.0970822961088853,0.155573716106985,0.0736191187230098,0.0401397957317501,0.0352799973763811,0,0,0.0290164970646396,-0.0047028269819762,0.113543374367374,0.00730837526795979,0.264712879181914,0.0288188403539946,0.449425033656063,0.0453912857570496,0.653083287629906,0.0481732936605263,0.83008632648885,0.0363796651911684,0.943258507857798,0.0178282741218775,1,0],"CDpres":0.00485,"clcd":146.755560768672,"alpha":3.6,"diter":3,"Top_Xtr":0.757740868456588,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re200000-N5-sq1.dat","Re":350000,"src":"retest_75.txt"},
             {"CDp":0.00202404858317466,"n":11,"CL":1.43022485338471,"CD":0.00972256430378359,"Cpmin":-1.59811779447565,"CDf":0.00465,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt100.615586552006>95.1584530942127) l1 Foil spline 17pts Re400000 N8","good":94.0320616839659,"xver":6.991,"iver":1.2020052,"id":428,"Cm":-0.24580159185744,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re400000-N8.dat","Top_Xtr":0.76056164648012,"diter":4,"src":"retest_71.txt","Re":350000,"xy":[1,0,0.946714574040677,0.0245948413868519,0.854728633619417,0.0520231593962918,0.691363149797408,0.0830392794859604,0.513763139089403,0.099337022518902,0.327229099655296,0.0964229379927712,0.155573716106985,0.0731191165045132,0.0401397957317501,0.0350403846607886,0,0,0.0290164970646396,-0.00468716973493408,0.113543374367374,0.00728404329965954,0.264712879181914,0.0287228930217581,0.449425033656063,0.0452401633412385,0.653083287629906,0.0480129090317558,0.83008632648885,0.0362585454035617,0.943258507857798,0.017768917974324,1,0],"Bot_Xtr":1,"sym":7.73574651566147,"alpha":3.8,"clcd":147.103666141671,"CDpres":0.00507},
             {"Cpmin":-1.64369057326402,"CDf":0.0044,"CDp":0.00229851055742042,"CL":1.39193703785783,"CD":0.00939885839254164,"n":12,"Cm":-0.24067372763852,"r":6,"id":429,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt44.1579096849345>35.3384359801793) l1 Foil spline 17pts Re125000 N6","good":90.3828129319781,"xver":6.991,"iver":1.2020052,"src":"retest_64.txt","Re":350000,"Top_Xtr":0.765706786011248,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re125000-N6.dat","diter":4,"alpha":3.7,"CDpres":0.005,"clcd":148.096394234686,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0271611804843209,0.833474960203591,0.0550125963476031,0.683294039292584,0.0814620559308607,0.512919921681868,0.0958661586008128,0.327643312365742,0.0941616378861224,0.159685519883032,0.073508268796923,0.0454559935430201,0.0379498053173848,0,-3.88679901713498e-11,0.0261984228078157,-0.0129869382031543,0.134241453700877,-0.00304313989877899,0.290009257938815,0.0176217961600189,0.464856398032139,0.0344732725120641,0.654716626975926,0.0421662524041492,0.826995021496349,0.0354661066964644,0.941457504275826,0.0188342589847785,1,0],"sym":6.31184147101943},
             {"CDf":0.00449,"Cpmin":-1.86917014044628,"CD":0.0106681604115591,"CL":1.55253385689269,"n":13,"CDp":0.00229614352345848,"Cm":-0.251475378191804,"id":430,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt79.4500258662517>73.9928698575414) l1 Foil spline 17pts Re275000 N7","good":87.1542105072224,"xver":6.991,"iver":1.2020052,"r":6,"Re":350000,"src":"retestd_1.txt","diter":4,"Top_Xtr":0.731159589828833,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N7.dat","clcd":145.529669314917,"CDpres":0.00618,"alpha":4.7,"sym":8.24621446846943,"xy":[1,0,0.946714574040677,0.0254340377962062,0.854728633619417,0.0537982327900147,0.691363149797408,0.0858726486500015,0.513763139089403,0.102726484207335,0.327229099655296,0.0997129686975915,0.155573716106985,0.0756140014708603,0.0401397957317501,0.0362359916796429,0,0,0.0290164970646396,-0.00482106732170682,0.113543374367374,0.00749212533528616,0.264712879181914,0.0295434150592003,0.449425033656063,0.0465325314523075,0.653083287629906,0.0493844857010146,0.83008632648885,0.0372943371508164,0.943258507857798,0.0182765196552685,1,0],"Bot_Xtr":1},
             {"id":431,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt63.3965991866639>49.3184568808761) l1 Foil spline 17pts Re200000 N8","xver":6.991,"good":86.9365137693463,"iver":1.2020052,"r":6,"Cm":-0.266043527259471,"CD":0.0109250978087749,"CL":1.57600135301332,"n":14,"CDp":0.0029017263947158,"CDf":0.00443,"Cpmin":-1.88099796573369,"sym":7.98909117761437,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0306155393255545,0.833474960203591,0.0620090981632092,0.683294039292584,0.091822399925934,0.512919921681868,0.108058416324257,0.327643312365742,0.106137114670893,0.159685519883032,0.0828570501714663,0.0454559935430201,0.0427762614280416,0,-4.30099248451158e-11,0.0261984228078157,-0.014527513253385,0.134241453700877,-0.00340413225348827,0.290009257938815,0.0197121810590387,0.464856398032139,0.0385626631521914,0.654716626975926,0.0471682224912777,0.826995021496349,0.0396732722539415,0.941457504275826,0.0210684722402544,1,0],"CDpres":0.00649,"clcd":144.255125271966,"alpha":4.4,"diter":4,"Top_Xtr":0.737618673326195,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re200000-N8.dat","Re":350000,"src":"retestd_2.txt"},
             {"diter":3,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Top_Xtr":0.64776972987106,"Re":400000,"src":"retestc_2.txt","sym":8.455684584572,"Bot_Xtr":1,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"clcd":136.51869092971,"CDpres":0.00483,"alpha":3.9,"n":3,"CL":1.38749385928828,"CD":0.0101633985049173,"CDp":0.00184813590237463,"CDf":0.00533,"Cpmin":-1.40228951594593,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","xver":6.991,"good":76.3652666263628,"id":432,"r":6,"Cm":-0.226090452157689},
             {"Cpmin":-0.861976234449876,"CDf":0.00513,"CDp":0.000511052489192647,"n":4,"CL":0.919597859794851,"CD":0.00714487130919511,"Cm":-0.178909247192513,"r":6,"cmt":"OPT s(0) optbs_spline_Re400000_N4_e62.dat-s17_n17s0_nsopt-Re400000-N4.dat (opt70.478632985121>67.892240257193) l1 Foil spline 17pts Re400000 N4","iver":1.2020052,"xver":6.991,"good":70.4786329851329,"id":433,"src":"retestc_6.txt","Re":400000,"Foil_fn":"opt_spline_e62_nsopt-Re400000-N4.dat","Top_Xtr":0.707661331083905,"diter":3,"alpha":1.6,"clcd":128.707407033542,"CDpres":0.00202,"Bot_Xtr":1,"xy":[1,0,0.945658308212258,0.0186567591932687,0.863764979138046,0.0378554164257436,0.698352344711599,0.0647599617665645,0.4937620422082,0.0803766730645657,0.275165873870139,0.0741767846359742,0.124671587262013,0.0529191162594283,0.0360765344716023,0.0253432757884756,0,0,0.0192507166066205,-0.00874845664353558,0.113363722509556,-0.00138962202264738,0.286719240090845,0.0157245975974789,0.440775378221921,0.0263534494944985,0.649782492839302,0.0301337157558234,0.819763946742976,0.0240021300291535,0.939515187720928,0.0119039687742121,1,0],"sym":4.10954681894914},
             {"src":"retest_100.txt","Re":400000,"Top_Xtr":0.703045490213488,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re100000-N7.dat","diter":3,"alpha":2,"clcd":136.927275124542,"CDpres":0.00283,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.022012410909568,0.863082022377036,0.045011902197907,0.698195158425591,0.0760723125035419,0.497241313912823,0.0947927030722412,0.28552715888499,0.088604222673708,0.125732819683231,0.0622576528427986,0.0360765344716023,0.0297634842520839,0,0,0.0192507166066205,-0.0106019702137114,0.113363722509556,-0.00168403775576932,0.268607859414087,0.0176512536649854,0.440775378221921,0.0319368887511916,0.638477319107758,0.0364030394284592,0.818181208003633,0.0289247731095269,0.939515187720928,0.0144260327862975,1,0],"sym":5.7883206190984,"Cpmin":-1.03928319506094,"CDf":0.00516,"CDp":0.000922753001774235,"CD":0.00798766086195509,"CL":1.09372863644646,"n":5,"Cm":-0.209653478491045,"r":6,"id":434,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt34.8445832442148>27.453250923595) l1 Foil spline 17pts Re100000 N7","iver":1.2020052,"good":79.7713940142048},
             {"Cm":-0.263212386000102,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt87.3907202488104>81.1919110648486) l1 Foil spline 17pts Re400000 N6","iver":1.2020052,"xver":6.991,"good":87.3907202494318,"id":435,"r":6,"CDf":0.00514,"Cpmin":-1.30715323145614,"n":6,"CL":1.37626705863317,"CD":0.00937091905988953,"CDp":0.0012335679457554,"clcd":146.865750289534,"CDpres":0.00423,"alpha":2.6,"sym":9.57762848620105,"xy":[1,0,0.946714574040677,0.0275043489152914,0.854728633619417,0.0581773675709228,0.691363149797408,0.0928626162182618,0.513763139089403,0.11108834103019,0.327229099655296,0.107829527675199,0.155573716106985,0.0817689230471344,0.0401397957317501,0.0391855735386677,0,0,0.0290164970646396,-0.00515351842657319,0.113543374367374,0.00800876722790164,0.264712879181914,0.0315806695347257,0.449425033656063,0.0497413212204769,0.653083287629906,0.0527899404974324,0.83008632648885,0.0398660796227009,0.943258507857798,0.0195368316872429,1,0],"Bot_Xtr":1,"Re":400000,"src":"retest_89.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re400000-N6.dat","Top_Xtr":0.713524927605082},
             {"CD":0.00892968675181345,"CL":1.35524064550532,"n":7,"CDp":0.00134063345898256,"CDf":0.00494,"Cpmin":-1.29004630801168,"id":436,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt95.4996395750029>87.9200180130103) l1 Foil spline 17pts Re400000 N7","iver":1.2020052,"good":95.4937047150846,"r":6,"Cm":-0.255980083517202,"diter":3,"Top_Xtr":0.737388579232619,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re400000-N7.dat","Re":400000,"src":"retest_69.txt","sym":8.63693956314832,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0259217881830336,0.854728633619417,0.0548299254006892,0.691363149797408,0.0875194346590708,0.513763139089403,0.104696477442818,0.327229099655296,0.101625171527659,0.155573716106985,0.0770640566592064,0.0401397957317501,0.0369308919192524,0,0,0.0290164970646396,-0.00498242235923215,0.113543374367374,0.00774287731279466,0.264712879181914,0.0305321958679727,0.449425033656063,0.048089916541047,0.653083287629906,0.051037322098378,0.83008632648885,0.0385425315378473,0.943258507857798,0.0188882116973046,1,0],"CDpres":0.00399,"clcd":151.767994015031,"alpha":2.7},
             {"CDf":0.00465,"Cpmin":-1.22192712312245,"n":8,"CD":0.00796976269363796,"CL":1.22783766236315,"CDp":0.00117827159981152,"Cm":-0.228381527729954,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt63.8195182425294>62.6554040709851) l1 Foil spline 17pts Re200000 N6","iver":1.2020052,"xver":6.991,"good":97.63455194487,"id":437,"r":6,"Re":400000,"src":"retest_153.txt","diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re200000-N6.dat","Top_Xtr":0.774543734409283,"clcd":154.062010320998,"CDpres":0.00332,"alpha":2.6,"sym":6.59497137519219,"xy":[1,0,0.946714574040677,0.022825493303486,0.854728633619417,0.0482806234750121,0.691363149797408,0.0770654499461969,0.513763139089403,0.0921907365300418,0.327229099655296,0.0894862906752883,0.155573716106985,0.0678589415511658,0.0401397957317501,0.0325195862354279,0,0,0.0290164970646396,-0.00427545235451517,0.113543374367374,0.00664421854489506,0.264712879181914,0.0261998962152136,0.449425033656063,0.0412663022280479,0.653083287629906,0.0437954920721108,0.83008632648885,0.0330736226942149,0.943258507857798,0.016208109901439,1,0],"Bot_Xtr":1},
             {"src":"retest_24.txt","Re":400000,"Top_Xtr":0.787081261786412,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re500000-N8-sq1.dat","diter":5,"alpha":2.7,"CDpres":0.00336,"clcd":155.366001875941,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0223621236083683,0.854728633619417,0.0473005010530232,0.691363149797408,0.0755009801855273,0.513763139089403,0.0903192153799569,0.327229099655296,0.08766967121931,0.155573716106985,0.0664813688240622,0.0401397957317501,0.0318594212804405,0,0,0.0290164970646396,-0.00419518862905253,0.113543374367374,0.00651948560695504,0.264712879181914,0.0257080415288325,0.449425033656063,0.0404916035813907,0.653083287629906,0.0429733125550207,0.83008632648885,0.032452726482103,0.943258507857798,0.015903832558242,1,0],"sym":6.33573166885975,"Cpmin":-1.24480148308202,"CDf":0.00453,"CDp":0.00124094076886812,"CD":0.00788575032636117,"CL":1.22517749999864,"n":9,"Cm":-0.225296710637696,"r":6,"id":438,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt64.8062967518512>61.9736441951258) l1 Foil spline 17pts Re500000 N8","good":103.247511526933,"iver":1.2020052},
             {"diter":3,"Top_Xtr":0.772753964397445,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N4.dat","Re":400000,"src":"retest_114.txt","sym":7.88888383337012,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0248265984612703,0.854728633619417,0.0525133733819828,0.691363149797408,0.0838217582250087,0.513763139089403,0.100273074813702,0.327229099655296,0.0973315308828223,0.155573716106985,0.073808117594563,0.0401397957317501,0.0353705700402243,0,0,0.0290164970646396,-0.00473805041952575,0.113543374367374,0.00736311385409665,0.264712879181914,0.0290346889547085,0.449425033656063,0.0457312593782958,0.653083287629906,0.0485341040852582,0.83008632648885,0.0366521431857545,0.943258507857798,0.017961805102829,1,0],"CDpres":0.00421,"clcd":155.930957883392,"alpha":3.1,"CL":1.37164320266061,"CD":0.00879647775707467,"n":10,"CDp":0.00164865291766694,"CDf":0.00458,"Cpmin":-1.40971237225257,"id":439,"good":102.411598659401,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt67.2716838978204>64.4956545666036) l1 Foil spline 17pts Re275000 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.249807719003423},
             {"sym":6.96599032733421,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0235667149933877,0.854728633619417,0.0498484601410522,0.691363149797408,0.07956802819424,0.513763139089403,0.0951844844686086,0.327229099655296,0.0923922160244348,0.155573716106985,0.0700625530421742,0.0401397957317501,0.0335756082168082,0,0,0.0290164970646396,-0.00434551558463484,0.113543374367374,0.00675309951801238,0.264712879181914,0.0266292424470105,0.449425033656063,0.0419425465618524,0.653083287629906,0.044513183063571,0.83008632648885,0.0336156109203891,0.943258507857798,0.0164737174768878,1,0],"clcd":156.012806536617,"CDpres":0.00428,"alpha":3.6,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re350000-N6.dat","Top_Xtr":0.761054500563193,"Re":400000,"src":"retest_1.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt82.0483882406687>81.3916409513884) l1 Foil spline 17pts Re350000 N6","good":98.3518390168955,"xver":6.991,"iver":1.2020052,"id":440,"r":6,"Cm":-0.233962721534549,"n":11,"CD":0.00872336652364022,"CL":1.36095689380069,"CDp":0.00154958972073956,"CDf":0.00445,"Cpmin":-1.50656902627191},
             {"alpha":3.8,"clcd":156.461171625847,"CDpres":0.00475,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0245600634388115,0.854728633619417,0.0519495968672263,0.691363149797408,0.0829218591008539,0.513763139089403,0.0991965565669849,0.327229099655296,0.0962865926561751,0.155573716106985,0.0730157235696063,0.0401397957317501,0.0349908363568219,0,0,0.0290164970646396,-0.00468004868105237,0.113543374367374,0.00727297690613276,0.264712879181914,0.0286792553298431,0.449425033656063,0.0451714315352684,0.653083287629906,0.0479399646897397,0.83008632648885,0.0362034590571964,0.943258507857798,0.0177419222755398,1,0],"sym":7.713400638604,"src":"retest_119.txt","Re":400000,"Top_Xtr":0.759889861864705,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re620000-N7.dat","diter":5,"Cm":-0.24721315149622,"r":6,"id":441,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt104.206537090843>91.9050623580118) l1 Foil spline 17pts Re620000 N7","iver":1.2020052,"good":100.760465782049,"Cpmin":-1.61068592024747,"CDf":0.00443,"CDp":0.00183423849064121,"CL":1.43710429413685,"CD":0.00918505389678064,"n":12},
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt43.6103416186371>40.1529667618564) l1 Foil spline 17pts Re125000 N7","good":99.1171045116255,"iver":1.2020052,"id":442,"r":6,"Cm":-0.247073806539034,"n":13,"CD":0.009375237184021,"CL":1.45828349808192,"CDp":0.00199701642581192,"CDf":0.00435,"Cpmin":-1.6645680502301,"sym":7.71530305119011,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0246952640325922,0.854728633619417,0.052235573992677,0.691363149797408,0.083378335307268,0.513763139089403,0.0997426232895841,0.327229099655296,0.0968166403302241,0.155573716106985,0.0734176675306443,0.0401397957317501,0.0351834572702048,0,0,0.0290164970646396,-0.00462120848467796,0.113543374367374,0.00718153696211766,0.264712879181914,0.028318683649828,0.449425033656063,0.0446035109679441,0.653083287629906,0.0473372365711313,0.83008632648885,0.0357482888686933,0.943258507857798,0.017518860879837,1,0],"CDpres":0.00502,"clcd":155.546304531623,"alpha":4,"diter":4,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re125000-N7.dat","Top_Xtr":0.761142159980485,"Re":400000,"src":"retest_132.txt"},
             {"alpha":5,"clcd":144.809034198577,"CDpres":0.00607,"Bot_Xtr":1,"xy":[1,0,0.945514649029338,0.0248715318546031,0.863082022377036,0.0508583527697509,0.698195158425591,0.0859530994336819,0.497241313912823,0.107105021059751,0.28552715888499,0.100112738933271,0.125732819683231,0.0703440982559267,0.0360765344716023,0.0336293670748221,0,0,0.0192507166066205,-0.0120852719221262,0.113363722509556,-0.00191964831020543,0.268607859414087,0.0201208073601161,0.440775378221921,0.0364051187774212,0.638477319107758,0.041496120194324,0.818181208003633,0.0329715837026546,0.939515187720928,0.0164443518955032,1,0],"sym":7.42098933227772,"src":"retest_75.txt","Re":400000,"Foil_fn":"optbs_spline_e62.dat-s17_n17s0_nsopt-Re225000-N9.dat","Top_Xtr":0.697362487295103,"diter":4,"Cm":-0.238838643528306,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e62.dat-s17_n17s0.dat (opt66.5220776290349>55.8462314365911) l1 Foil spline 17pts Re225000 N9","xver":6.991,"good":87.6527637584764,"id":443,"Cpmin":-1.79559241313972,"CDf":0.00459,"CDp":0.00251231812128079,"n":14,"CL":1.54423233299311,"CD":0.0106639226035822},
             {"Cm":-0.228915601237377,"id":444,"good":81.478773599522,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.005,"Cpmin":-1.36452160346992,"CL":1.33965433870629,"CD":0.00884978018634026,"n":3,"CDp":0.00143473501628707,"clcd":151.377131465261,"CDpres":0.00385,"alpha":3.3,"sym":8.455684584572,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":1,"Re":500000,"src":"retestc_7.txt","diter":3,"Top_Xtr":0.651304328829135,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat"},
             {"r":6,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","good":90.8667166665554,"xver":6.991,"iver":1.2020052,"id":445,"Cm":-0.230265881194713,"CDp":0.00162403047945696,"n":4,"CL":1.38730495932569,"CD":0.00897628568734823,"Cpmin":-1.39994036483822,"CDf":0.00481,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":1,"sym":8.455684584572,"alpha":3.7,"clcd":154.552228800054,"CDpres":0.00417,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Top_Xtr":0.664722933142719,"diter":3,"src":"retestc_12.txt","Re":500000},
             {"Cpmin":-1.56761458892147,"CDf":0.00461,"CDp":0.00175470708339386,"n":5,"CD":0.00993008724165259,"CL":1.54305658207907,"Cm":-0.23028623051963,"r":6,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","xver":6.991,"good":83.5605464964753,"iver":1.2020052,"id":446,"src":"retestc_13.txt","Re":500000,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Top_Xtr":0.64144438139611,"diter":3,"alpha":5.2,"CDpres":0.00532,"clcd":155.392046870101,"Bot_Xtr":1,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"sym":8.455684584572},
             {"Cpmin":-1.15448917470208,"CDf":0.00469,"CDp":0.000872964912116137,"CD":0.00773721481406725,"CL":1.25184381857201,"n":6,"Cm":-0.244093843036297,"r":6,"id":447,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt104.206537090843>91.9050623580118) l1 Foil spline 17pts Re620000 N7","xver":6.991,"good":87.879287928717,"src":"retestc_17.txt","Re":500000,"Top_Xtr":0.722118692776735,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re620000-N7.dat","diter":3,"alpha":2.2,"CDpres":0.00305,"clcd":161.795148338909,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0245600634388115,0.854728633619417,0.0519495968672263,0.691363149797408,0.0829218591008539,0.513763139089403,0.0991965565669849,0.327229099655296,0.0962865926561751,0.155573716106985,0.0730157235696063,0.0401397957317501,0.0349908363568219,0,0,0.0290164970646396,-0.00468004868105237,0.113543374367374,0.00727297690613276,0.264712879181914,0.0286792553298431,0.449425033656063,0.0451714315352684,0.653083287629906,0.0479399646897397,0.83008632648885,0.0362034590571964,0.943258507857798,0.0177419222755398,1,0],"sym":7.713400638604},
             {"src":"retest_111.txt","Re":500000,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re225000-N3-sq1.dat","Top_Xtr":0.763225870162909,"diter":4,"alpha":2.1,"clcd":164.96304156599,"CDpres":0.00257,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0220841055744264,0.854728633619417,0.0467124356019267,0.691363149797408,0.074562311102059,0.513763139089403,0.0891963179697253,0.327229099655296,0.0865797143773038,0.155573716106985,0.0656548364348342,0.0401397957317501,0.0314633276972889,0,0,0.0290164970646396,-0.00411840245794338,0.113543374367374,0.00640015692316417,0.264712879181914,0.0252374972338648,0.449425033656063,0.0397504699933674,0.653083287629906,0.0421867552812607,0.83008632648885,0.0318587315920148,0.943258507857798,0.0156127385178808,1,0],"sym":6.15756464957842,"Cpmin":-1.07956663995619,"CDf":0.00439,"CDp":0.000742427775260063,"n":7,"CL":1.14842683899293,"CD":0.0069617220202231,"Cm":-0.222185611014025,"r":6,"good":96.0327889546337,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt42.8171284514582>40.6654726530704) l1 Foil spline 17pts Re225000 N3","xver":6.991,"iver":1.2020052,"id":448},
             {"Cm":-0.211124277831127,"r":6,"id":449,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt55.4243192909171>53.3827904050026) l1 Foil spline 17pts Re350000 N6","good":105.380993463417,"xver":6.991,"iver":1.2020052,"Cpmin":-1.02587009566866,"CDf":0.00415,"CDp":0.000710335068891012,"CL":1.07826981358023,"CD":0.00643509151284576,"n":8,"alpha":1.9,"CDpres":0.00229,"clcd":167.560913691404,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0206228450085758,0.854728633619417,0.0436215682878809,0.691363149797408,0.0696286738965616,0.513763139089403,0.0832943781502035,0.327229099655296,0.080850909921276,0.155573716106985,0.0613105887986205,0.0401397957317501,0.0293814629878699,0,0,0.0290164970646396,-0.00387777757058577,0.113543374367374,0.00602621652893749,0.264712879181914,0.0237629521909504,0.449425033656063,0.0374279790609628,0.653083287629906,0.0397219201076225,0.83008632648885,0.0299973293179609,0.943258507857798,0.0147005368849483,1,0],"sym":5.39578565389811,"src":"retest_82.txt","Re":500000,"Top_Xtr":0.804871585106593,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re350000-N6-sq1.dat","diter":3},
             {"Re":500000,"src":"retest_137.txt","diter":3,"Top_Xtr":0.792612364363848,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re620000-N10.dat","CDpres":0.0028,"clcd":169.419493821376,"alpha":2.2,"sym":6.46135009337477,"xy":[1,0,0.946714574040677,0.0226941763751042,0.854728633619417,0.0480028611024405,0.691363149797408,0.076622086114505,0.513763139089403,0.0916603556885234,0.327229099655296,0.0889714687317923,0.155573716106985,0.0674685435146697,0.0401397957317501,0.0323324983981618,0,0,0.0290164970646396,-0.00418644376558859,0.113543374367374,0.00650589575044821,0.264712879181914,0.0256544531605913,0.449425033656063,0.0404071989035407,0.653083287629906,0.0428837347590941,0.83008632648885,0.0323850788297059,0.943258507857798,0.0158706810466957,1,0],"Bot_Xtr":1,"CDf":0.0042,"Cpmin":-1.12357234604861,"CD":0.00699860623667333,"CL":1.18570032607232,"n":9,"CDp":0.000960447330969659,"Cm":-0.228574929135833,"id":450,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt118.138344114588>117.536663766734) l1 Foil spline 17pts Re620000 N10","good":110.85603308101,"iver":1.2020052,"r":6},
             {"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt43.8869396157404>41.237567542513) l1 Foil spline 17pts Re200000 N5","good":116.236024904711,"xver":6.991,"iver":1.2020052,"id":451,"Cm":-0.250504545022697,"CDp":0.0012830734158461,"n":10,"CD":0.00772057211305536,"CL":1.32121181782279,"Cpmin":-1.28009931980813,"CDf":0.00428,"xy":[1,0,0.946714574040677,0.0247630255204258,0.854728633619417,0.0523789035074743,0.691363149797408,0.0836071176375986,0.513763139089403,0.100016307690998,0.327229099655296,0.0970822961088853,0.155573716106985,0.0736191187230098,0.0401397957317501,0.0352799973763811,0,0,0.0290164970646396,-0.0047028269819762,0.113543374367374,0.00730837526795979,0.264712879181914,0.0288188403539946,0.449425033656063,0.0453912857570496,0.653083287629906,0.0481732936605263,0.83008632648885,0.0363796651911684,0.943258507857798,0.0178282741218775,1,0],"Bot_Xtr":1,"sym":7.82568940638834,"alpha":2.6,"clcd":171.128745185689,"CDpres":0.00344,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re200000-N5-sq1.dat","Top_Xtr":0.778234628035435,"diter":4,"src":"retest_95.txt","Re":500000},
             {"id":452,"good":119.166787187741,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt46.8294006719653>46.5862258260816) l1 Foil spline 17pts Re225000 N9","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.246788926608426,"CD":0.00754393047668787,"CL":1.29417605451159,"n":11,"CDp":0.00135787604347072,"CDf":0.00417,"Cpmin":-1.25312820987999,"sym":7.48411108354097,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0243360148250625,0.854728633619417,0.0514756878648364,0.691363149797408,0.0821654063487135,0.513763139089403,0.0982916382615875,0.327229099655296,0.0954082204296142,0.155573716106985,0.0723496393109722,0.0401397957317501,0.0346716332570744,0,0,0.0290164970646396,-0.00454534292454515,0.113543374367374,0.00706363894343879,0.264712879181914,0.0278537808425988,0.449425033656063,0.0438712630387082,0.653083287629906,0.0465601095534874,0.83008632648885,0.0351614155502086,0.943258507857798,0.0172312568477004,1,0],"clcd":171.55195935472,"CDpres":0.00337,"alpha":2.5,"diter":3,"Top_Xtr":0.79878183136528,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re225000-N9-sq1.dat","Re":500000,"src":"retest_126.txt"},
             {"Cm":-0.248554497308807,"id":453,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt78.3375914534621>70.3878384522264) l1 Foil spline 17pts Re275000 N6","xver":6.991,"good":116.698980732016,"iver":1.2020052,"r":6,"CDf":0.00414,"Cpmin":-1.37237407668502,"CD":0.00777483194350099,"CL":1.34495695517173,"n":12,"CDp":0.00142143763162034,"clcd":172.988556530277,"CDpres":0.00363,"alpha":2.9,"sym":7.55001889899939,"xy":[1,0,0.946714574040677,0.0242775177871525,0.854728633619417,0.0513519545713567,0.691363149797408,0.0819679034738745,0.513763139089403,0.0980553723926291,0.327229099655296,0.0951788854983397,0.155573716106985,0.072175730820861,0.0401397957317501,0.0345882922556976,0,0,0.0290164970646396,-0.00463967457572595,0.113543374367374,0.00721023398278806,0.264712879181914,0.0284318435283253,0.449425033656063,0.04478174410703,0.653083287629906,0.0475263935250712,0.83008632648885,0.0358911370347625,0.943258507857798,0.0175888652696275,1,0],"Bot_Xtr":1,"Re":500000,"src":"retest_67.txt","diter":6,"Top_Xtr":0.787034195762584,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N6.dat"},
             {"alpha":3.1,"clcd":172.85264413723,"CDpres":0.00388,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0245600634388115,0.854728633619417,0.0519495968672263,0.691363149797408,0.0829218591008539,0.513763139089403,0.0991965565669849,0.327229099655296,0.0962865926561751,0.155573716106985,0.0730157235696063,0.0401397957317501,0.0349908363568219,0,0,0.0290164970646396,-0.00468004868105237,0.113543374367374,0.00727297690613276,0.264712879181914,0.0286792553298431,0.449425033656063,0.0451714315352684,0.653083287629906,0.0479399646897397,0.83008632648885,0.0362034590571964,0.943258507857798,0.0177419222755398,1,0],"sym":7.713400638604,"src":"retest_131.txt","Re":500000,"Top_Xtr":0.787893793595237,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re620000-N7.dat","diter":3,"Cm":-0.251549398410684,"r":6,"id":454,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt104.206537090843>91.9050623580118) l1 Foil spline 17pts Re620000 N7","good":115.955575544988,"iver":1.2020052,"Cpmin":-1.43349940857287,"CDf":0.00409,"CDp":0.00159081972670127,"CL":1.37902720083185,"CD":0.0079780509445781,"n":13},
             {"good":109.609364321327,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt68.0723457488308>47.8203421756439) l1 Foil spline 17pts Re225000 N8","xver":6.991,"iver":1.2020052,"id":455,"r":6,"Cm":-0.253090130429409,"n":14,"CD":0.00809911658433408,"CL":1.40296427526107,"CDp":0.00191337211779276,"CDf":0.00391,"Cpmin":-1.56935355144364,"sym":6.82339555248322,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0284404938213681,0.833474960203591,0.0576037336604201,0.683294039292584,0.085298983956717,0.512919921681868,0.100381531389573,0.327643312365742,0.0985967263851462,0.159685519883032,0.076970567083606,0.0454559935430201,0.0397372715178653,0,-3.9147945884078e-11,0.0261984228078157,-0.0132146034867473,0.134241453700877,-0.00309648713869275,0.290009257938815,0.0179307120228214,0.464856398032139,0.0350776002789378,0.654716626975926,0.0429054406301558,0.826995021496349,0.0360878391720244,0.941457504275826,0.0191644297183232,1,0],"clcd":173.224358564586,"CDpres":0.00419,"alpha":3.3,"diter":5,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re225000-N8.dat","Top_Xtr":0.781380225735977,"Re":500000,"src":"retest_121.txt"},
             {"r":6,"id":456,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","xver":6.991,"good":83.8091083549883,"iver":1.2020052,"Cm":-0.230934860507051,"CDp":0.00119558206670186,"CL":1.33918512298929,"CD":0.00819400687973172,"n":3,"Cpmin":-1.36371990221532,"CDf":0.00476,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":0.957557098624352,"sym":8.455684584572,"alpha":3.2,"CDpres":0.00344,"clcd":163.434708152593,"Top_Xtr":0.63980650954827,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","diter":3,"src":"retestc_4.txt","Re":620000},
             {"Re":620000,"src":"retestc_11.txt","diter":3,"Top_Xtr":0.666660178075698,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","clcd":169.903585839364,"CDpres":0.00339,"alpha":3.2,"sym":8.455684584572,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":1,"CDf":0.00453,"Cpmin":-1.36705731964293,"CL":1.34534484133423,"CD":0.00791828397669129,"n":4,"CDp":0.00126709307785394,"Cm":-0.232242055317959,"id":457,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","iver":1.2020052,"xver":6.991,"good":95.5563980321032,"r":6},
             {"CDf":0.00443,"Cpmin":-1.42652188582247,"CL":1.42310426743891,"CD":0.00822653457151225,"n":5,"CDp":0.00136331138598818,"Cm":-0.233274303518247,"id":458,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","xver":6.991,"good":99.1540874075342,"iver":1.2020052,"r":6,"Re":620000,"src":"retestc_10.txt","diter":3,"Top_Xtr":0.664086527648683,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","clcd":172.989520078963,"CDpres":0.00379,"alpha":3.9,"sym":8.455684584572,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":1},
             {"diter":3,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re225000-N9-sq1.dat","Top_Xtr":0.712819839607689,"Re":620000,"src":"retest_133.txt","sym":7.48411108354097,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0243360148250625,0.854728633619417,0.0514756878648364,0.691363149797408,0.0821654063487135,0.513763139089403,0.0982916382615875,0.327229099655296,0.0954082204296142,0.155573716106985,0.0723496393109722,0.0401397957317501,0.0346716332570744,0,0,0.0290164970646396,-0.00454534292454515,0.113543374367374,0.00706363894343879,0.264712879181914,0.0278537808425988,0.449425033656063,0.0438712630387082,0.653083287629906,0.0465601095534874,0.83008632648885,0.0351614155502086,0.943258507857798,0.0172312568477004,1,0],"CDpres":0.00266,"clcd":172.24482590735,"alpha":2,"n":6,"CD":0.00707330750950744,"CL":1.21834062056426,"CDp":0.000660542072211494,"CDf":0.00441,"Cpmin":-1.1189611593384,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt46.8294006719653>46.5862258260816) l1 Foil spline 17pts Re225000 N9","xver":6.991,"good":96.0157609738306,"iver":1.2020052,"id":459,"r":6,"Cm":-0.241031938482835},
             {"Cm":-0.246419799253339,"r":6,"id":460,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt104.206537090843>91.9050623580118) l1 Foil spline 17pts Re620000 N7","xver":6.991,"good":104.208613368771,"iver":1.2020052,"Cpmin":-1.16282908941288,"CDf":0.0043,"CDp":0.000762970785134644,"CD":0.00710883888257094,"CL":1.26221240838795,"n":7,"alpha":2.2,"clcd":177.555354571697,"CDpres":0.0028,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0245600634388115,0.854728633619417,0.0519495968672263,0.691363149797408,0.0829218591008539,0.513763139089403,0.0991965565669849,0.327229099655296,0.0962865926561751,0.155573716106985,0.0730157235696063,0.0401397957317501,0.0349908363568219,0,0,0.0290164970646396,-0.00468004868105237,0.113543374367374,0.00727297690613276,0.264712879181914,0.0286792553298431,0.449425033656063,0.0451714315352684,0.653083287629906,0.0479399646897397,0.83008632648885,0.0362034590571964,0.943258507857798,0.0177419222755398,1,0],"sym":7.713400638604,"src":"retest_136.txt","Re":620000,"Top_Xtr":0.728226218485031,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re620000-N7.dat","diter":3},
             {"id":461,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt79.9143835264741>75.6620080747209) l1 Foil spline 17pts Re275000 N8","xver":6.991,"good":103.780935606538,"r":6,"Cm":-0.241464350895555,"CL":1.2303631735676,"CD":0.00679670125384904,"n":8,"CDp":0.000764231427321364,"CDf":0.00414,"Cpmin":-1.1371032000395,"sym":7.28188221095675,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0239475329738808,0.854728633619417,0.0506539686697943,0.691363149797408,0.0808537795523422,0.513763139089403,0.0967225844184654,0.327229099655296,0.0938851953017582,0.155573716106985,0.071194704042651,0.0401397957317501,0.0341181613608735,0,0,0.0290164970646396,-0.00450933920104222,0.113543374367374,0.00700768776271032,0.264712879181914,0.0276331506633987,0.449425033656063,0.0435237581638526,0.653083287629906,0.0461913062885946,0.83008632648885,0.0348829014964933,0.943258507857798,0.0170947678264205,1,0],"CDpres":0.00266,"clcd":181.023577117036,"alpha":2.1,"diter":3,"Top_Xtr":0.754513212274057,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re275000-N8.dat","Re":620000,"src":"retest_70.txt"},
             {"Cm":-0.21332294856199,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt55.4243192909171>53.3827904050026) l1 Foil spline 17pts Re350000 N6","iver":1.2020052,"xver":6.991,"good":114.31300414294,"id":462,"r":6,"CDf":0.00376,"Cpmin":-0.960166038280754,"n":9,"CL":1.05483986098828,"CD":0.00573034619142364,"CDp":0.000568646767099652,"CDpres":0.00197,"clcd":184.079604573807,"alpha":1.6,"sym":5.39578565389811,"xy":[1,0,0.946714574040677,0.0206228450085758,0.854728633619417,0.0436215682878809,0.691363149797408,0.0696286738965616,0.513763139089403,0.0832943781502035,0.327229099655296,0.080850909921276,0.155573716106985,0.0613105887986205,0.0401397957317501,0.0293814629878699,0,0,0.0290164970646396,-0.00387777757058577,0.113543374367374,0.00602621652893749,0.264712879181914,0.0237629521909504,0.449425033656063,0.0374279790609628,0.653083287629906,0.0397219201076225,0.83008632648885,0.0299973293179609,0.943258507857798,0.0147005368849483,1,0],"Bot_Xtr":1,"Re":620000,"src":"retest_94.txt","diter":3,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re350000-N6-sq1.dat","Top_Xtr":0.817931548757535},
             {"CDp":0.000801993336796652,"CD":0.00619648187029997,"CL":1.15824346506531,"n":10,"Cpmin":-1.04627924654917,"CDf":0.00383,"r":6,"id":463,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt56.295038797978>54.298978804918) l1 Foil spline 17pts Re400000 N5","iver":1.2020052,"good":119.364404877125,"Cm":-0.232645533530375,"Top_Xtr":0.807171249563522,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re400000-N5-sq1.dat","diter":3,"src":"retest_95.txt","Re":620000,"xy":[1,0,0.946714574040677,0.0225559485816892,0.854728633619417,0.0477104808257508,0.691363149797408,0.0761553892088582,0.513763139089403,0.0911020622963754,0.327229099655296,0.0884295530616039,0.155573716106985,0.0670575998549038,0.0401397957317501,0.0321355646194116,0,0,0.0290164970646396,-0.00428011716141177,0.113543374367374,0.00665146783547784,0.264712879181914,0.0262284820691586,0.449425033656063,0.0413113265471769,0.653083287629906,0.0438432759079527,0.83008632648885,0.033109708247379,0.943258507857798,0.0162257940425731,1,0],"Bot_Xtr":1,"sym":6.48967807273685,"alpha":1.8,"clcd":186.919527775402,"CDpres":0.00237},
             {"Re":620000,"src":"retest_64.txt","diter":4,"Top_Xtr":0.79312808889386,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re225000-N8.dat","CDpres":0.00279,"clcd":187.367520768841,"alpha":2.2,"sym":7.24839213804871,"xy":[1,0,0.946714574040677,0.0239367647604668,0.854728633619417,0.0506311916787156,0.691363149797408,0.0808174229575104,0.513763139089403,0.0966790922795419,0.327229099655296,0.0938429790191653,0.155573716106985,0.0711626907338932,0.0401397957317501,0.0341028198372506,0,0,0.0290164970646396,-0.0044790101491718,0.113543374367374,0.00696055524147576,0.264712879181914,0.0274472947713382,0.449425033656063,0.0432310247366041,0.653083287629906,0.0458806313843724,0.83008632648885,0.0346482850079769,0.943258507857798,0.0169797913127884,1,0],"Bot_Xtr":1,"CDf":0.00389,"Cpmin":-1.17501655516682,"CD":0.00667585315476626,"CL":1.2508380546254,"n":11,"CDp":0.000985786399888528,"Cm":-0.24397487727002,"id":464,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt68.1313821665281>66.6313891522784) l1 Foil spline 17pts Re225000 N8","good":126.057671073651,"iver":1.2020052,"r":6},
             {"CDf":0.00385,"Cpmin":-1.19320302890511,"CD":0.00683056347668204,"CL":1.28975572785205,"n":12,"CDp":0.00117146941551767,"Cm":-0.25348669770042,"id":465,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt100.615586552006>95.1584530942127) l1 Foil spline 17pts Re400000 N8","iver":1.2020052,"xver":6.991,"good":130.076827519315,"r":6,"Re":620000,"src":"retest_108.txt","diter":3,"Top_Xtr":0.802703931258546,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re400000-N8.dat","CDpres":0.00298,"clcd":188.821278398917,"alpha":2.2,"sym":7.73574651566147,"xy":[1,0,0.946714574040677,0.0245948413868519,0.854728633619417,0.0520231593962918,0.691363149797408,0.0830392794859604,0.513763139089403,0.099337022518902,0.327229099655296,0.0964229379927712,0.155573716106985,0.0731191165045132,0.0401397957317501,0.0350403846607886,0,0,0.0290164970646396,-0.00468716973493408,0.113543374367374,0.00728404329965954,0.264712879181914,0.0287228930217581,0.449425033656063,0.0452401633412385,0.653083287629906,0.0480129090317558,0.83008632648885,0.0362585454035617,0.943258507857798,0.017768917974324,1,0],"Bot_Xtr":1},
             {"xy":[1,0,0.946714574040677,0.0234704594116751,0.854728633619417,0.0496448597440643,0.691363149797408,0.0792430415831782,0.513763139089403,0.0947957142083025,0.327229099655296,0.0920148504687499,0.155573716106985,0.0697763904691878,0.0401397957317501,0.0334384724428503,0,0,0.0290164970646396,-0.004474228544696,0.113543374367374,0.00695312444293139,0.264712879181914,0.0274179931838989,0.449425033656063,0.0431848730971817,0.653083287629906,0.0458316511353724,0.83008632648885,0.0346112959436177,0.943258507857798,0.0169616643955823,1,0],"Bot_Xtr":1,"sym":7.0458719066706,"alpha":2.2,"clcd":190.482040045045,"CDpres":0.00284,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re150000-N7-sq1.dat","Top_Xtr":0.817929266830267,"diter":4,"src":"retest_81.txt","Re":620000,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt37.4974907883664>37.2906307656138) l1 Foil spline 17pts Re150000 N7","iver":1.2020052,"xver":6.991,"good":130.768395231838,"id":466,"Cm":-0.243810232364197,"CDp":0.00116406017804749,"n":13,"CD":0.00655114044693886,"CL":1.24787459695452,"Cpmin":-1.1828321867808,"CDf":0.00371},
             {"Cpmin":-1.25959314034564,"CDf":0.00364,"CDp":0.0011091351487214,"CD":0.00647452309643796,"CL":1.24414614274261,"n":14,"Cm":-0.232543140547666,"r":6,"id":467,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt28.9133985367929>28.820494056944) l1 Foil spline 17pts Re100000 N6","good":129.705126223924,"xver":6.991,"iver":1.2020052,"src":"retestd_10.txt","Re":620000,"Top_Xtr":0.815659399877122,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re100000-N6-sq1.dat","diter":4,"alpha":2.6,"clcd":192.160275623558,"CDpres":0.00283,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0222476564524401,0.854728633619417,0.0470583794225222,0.691363149797408,0.0751145060463538,0.513763139089403,0.0898568897130713,0.327229099655296,0.0872209080293111,0.155573716106985,0.066141064238291,0.0401397957317501,0.0316963393921833,0,0,0.0290164970646396,-0.00424803420877436,0.113543374367374,0.00660160968452374,0.264712879181914,0.0260318783042985,0.449425033656063,0.0410016646190057,0.653083287629906,0.0435146349639371,0.83008632648885,0.0328615241062727,0.943258507857798,0.0161041685444522,1,0],"sym":6.33696934919669},
             {"Cpmin":-1.24304062057446,"CDf":0.00439,"CDp":0.00019176261541373,"CL":1.14479959975732,"CD":0.00753934086589259,"n":3,"Cm":-0.181638772286794,"r":6,"id":468,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","good":84.0787532925856,"xver":6.991,"iver":1.2020052,"src":"retestc_21.txt","Re":750000,"Top_Xtr":0.68220218970117,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","diter":3,"alpha":3.3,"clcd":151.843459543832,"CDpres":0.00315,"Bot_Xtr":1,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"sym":5.47077716158967},
             {"n":4,"CL":1.33037185107251,"CD":0.0072949839788678,"CDp":0.00101032449652516,"CDf":0.00433,"Cpmin":-1.35542816015543,"good":97.6061415972545,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","xver":6.991,"iver":1.2020052,"id":469,"r":6,"Cm":-0.23339622635888,"diter":11,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Top_Xtr":0.659588224455606,"Re":750000,"src":"retest_152.txt","sym":8.455684584572,"Bot_Xtr":1,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"CDpres":0.00296,"clcd":182.368029172695,"alpha":3},
             {"Cpmin":-1.27354748055257,"CDf":0.00415,"CDp":0.000380683461580765,"n":5,"CL":1.21814187461583,"CD":0.00772662632447888,"Cm":-0.182114950860118,"r":6,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","xver":6.991,"good":93.1322316334367,"id":470,"src":"retestc_7.txt","Re":750000,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","Top_Xtr":0.698139679203603,"diter":3,"alpha":4,"CDpres":0.00358,"clcd":157.655077838644,"Bot_Xtr":1,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"sym":5.47077716158967},
             {"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","good":110.102579199932,"xver":6.991,"iver":1.2020052,"id":471,"r":6,"Cm":-0.235807890448889,"n":6,"CD":0.00759390340747829,"CL":1.44578685295179,"CDp":0.0012048939760199,"CDf":0.0041,"Cpmin":-1.44302624274181,"sym":8.455684584572,"Bot_Xtr":1,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"CDpres":0.00349,"clcd":190.387838160808,"alpha":4,"diter":3,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Top_Xtr":0.667881335404345,"Re":750000,"src":"retest_154.txt"},
             {"CDf":0.00397,"Cpmin":-1.49467064542345,"CL":1.50216539729195,"CD":0.00779771314063375,"n":7,"CDp":0.00131136250674861,"Cm":-0.236773430459306,"id":472,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","iver":1.2020052,"xver":6.991,"good":108.879128551881,"r":6,"Re":750000,"src":"retest_155.txt","diter":3,"Top_Xtr":0.670211760319314,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","clcd":192.641787431778,"CDpres":0.00382,"alpha":4.5,"sym":8.455684584572,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"Bot_Xtr":1},
             {"sym":8.455684584572,"Bot_Xtr":1,"xy":[1,0,0.976945036273593,0.00939462486134211,0.851587448517823,0.0496390744878245,0.698540191794841,0.104268363253013,0.518781216857077,0.131891298315886,0.327066076343497,0.126506814697001,0.150680323221142,0.0905868417616979,0.0395735702112627,0.0422057839630234,0,0,0.0572978334471142,-0.00364596812263481,0.162662166368623,0.00417792129992324,0.31244663898479,0.0140082041081467,0.472099215454883,0.0216480338049078,0.578263018146512,0.0257475498551808,0.759908593228447,0.0266643873940281,0.928047066206695,0.0171322432434142,1,0],"clcd":193.949345886643,"CDpres":0.00404,"alpha":4.8,"diter":3,"Top_Xtr":0.675614997806245,"Foil_fn":"opt_spline_uag8814320_nsopt-Re500000-N4.dat","Re":750000,"src":"retest_156.txt","id":473,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re500000_N4_uag8814320.dat-s17_n17s0_nsopt-Re500000-N4.dat (opt90.8667166659173>71.4626960300354) l1 Foil spline 17pts Re500000 N4","good":110.596012449071,"iver":1.2020052,"r":6,"Cm":-0.237587130592131,"CL":1.53691503321482,"CD":0.0079243115061244,"n":8,"CDp":0.00141392149284861,"CDf":0.00388,"Cpmin":-1.53971488445347},
             {"clcd":194.263302626144,"CDpres":0.00272,"alpha":1.9,"sym":8.52502637823471,"xy":[1,0,0.946714574040677,0.0258610193354982,0.854728633619417,0.0547013867615518,0.691363149797408,0.0873142614995793,0.513763139089403,0.104451035877201,0.327229099655296,0.101386930071834,0.155573716106985,0.0768833942034948,0.0401397957317501,0.0368443142601595,0,0,0.0290164970646396,-0.00490163051719016,0.113543374367374,0.00761732366123666,0.264712879181914,0.0300371048925579,0.449425033656063,0.0473101205581156,0.653083287629906,0.0502097328319686,0.83008632648885,0.0379175499735817,0.943258507857798,0.01858193228021,1,0],"Bot_Xtr":1,"Re":750000,"src":"retest_26.txt","diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re350000-N8.dat","Top_Xtr":0.752434007544476,"Cm":-0.260497963318353,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt91.7282121616257>87.7815947481439) l1 Foil spline 17pts Re350000 N8","iver":1.2020052,"good":112.547821813542,"id":474,"r":6,"CDf":0.00392,"Cpmin":-1.18130016928135,"n":9,"CL":1.2895348815906,"CD":0.00663807762020955,"CDp":0.000759766404486024},
             {"Cpmin":-0.993711087996465,"CDf":0.0036,"CDp":0.000582501599940613,"n":10,"CD":0.00561908786466561,"CL":1.11927945976224,"Cm":-0.230915082617697,"r":6,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt61.2634444592245>60.7433902801687) l1 Foil spline 17pts Re400000 N8","good":123.031739836109,"xver":6.991,"iver":1.2020052,"id":475,"src":"retest_157.txt","Re":750000,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re400000-N8-sq1.dat","Top_Xtr":0.804447583267758,"diter":3,"alpha":1.5,"clcd":199.192375474422,"CDpres":0.00202,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0223990440604109,0.854728633619417,0.0473785954196989,0.691363149797408,0.0756256342822011,0.513763139089403,0.0904683347712259,0.327229099655296,0.0878144161437425,0.155573716106985,0.0665911313060331,0.0401397957317501,0.0319120220198018,0,0,0.0290164970646396,-0.00419518862905253,0.113543374367374,0.00651948560695504,0.264712879181914,0.0257080415288325,0.449425033656063,0.0404916035813907,0.653083287629906,0.0429733125550207,0.83008632648885,0.032452726482103,0.943258507857798,0.015903832558242,1,0],"sym":6.35050232304342},
             {"clcd":201.011033225373,"CDpres":0.00214,"alpha":1.7,"sym":6.46135009337477,"xy":[1,0,0.946714574040677,0.0226941763751042,0.854728633619417,0.0480028611024405,0.691363149797408,0.076622086114505,0.513763139089403,0.0916603556885234,0.327229099655296,0.0889714687317923,0.155573716106985,0.0674685435146697,0.0401397957317501,0.0323324983981618,0,0,0.0290164970646396,-0.00418644376558859,0.113543374367374,0.00650589575044821,0.264712879181914,0.0256544531605913,0.449425033656063,0.0404071989035407,0.653083287629906,0.0428837347590941,0.83008632648885,0.0323850788297059,0.943258507857798,0.0158706810466957,1,0],"Bot_Xtr":1,"Re":750000,"src":"retestc_15.txt","diter":3,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re620000-N10.dat","Top_Xtr":0.806649899152331,"Cm":-0.232619471023716,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt118.138344114588>117.536663766734) l1 Foil spline 17pts Re620000 N10","good":129.955109041661,"iver":1.2020052,"id":476,"r":6,"CDf":0.00358,"Cpmin":-1.02934455323178,"n":11,"CL":1.14887419155935,"CD":0.0057154782656693,"CDp":0.000653311755152978},
             {"clcd":202.196094112221,"CDpres":0.00256,"alpha":2,"sym":7.48411108354097,"xy":[1,0,0.946714574040677,0.0243360148250625,0.854728633619417,0.0514756878648364,0.691363149797408,0.0821654063487135,0.513763139089403,0.0982916382615875,0.327229099655296,0.0954082204296142,0.155573716106985,0.0723496393109722,0.0401397957317501,0.0346716332570744,0,0,0.0290164970646396,-0.00454534292454515,0.113543374367374,0.00706363894343879,0.264712879181914,0.0278537808425988,0.449425033656063,0.0438712630387082,0.653083287629906,0.0465601095534874,0.83008632648885,0.0351614155502086,0.943258507857798,0.0172312568477004,1,0],"Bot_Xtr":1,"Re":750000,"src":"retest_3.txt","diter":3,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re225000-N9-sq1.dat","Top_Xtr":0.795403151739256,"Cm":-0.249219342646988,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt46.8294006719653>46.5862258260816) l1 Foil spline 17pts Re225000 N9","iver":1.2020052,"good":132.131375802637,"id":477,"r":6,"CDf":0.00363,"Cpmin":-1.14219779631613,"n":12,"CD":0.00619087190524211,"CL":1.25177011838904,"CDp":0.000869020743514734},
             {"CDpres":0.00211,"clcd":208.331499612616,"alpha":1.6,"sym":6.24596020262754,"xy":[1,0,0.946714574040677,0.0219377108792972,0.854728633619417,0.0464027806446254,0.691363149797408,0.0740680403802891,0.513763139089403,0.0886050389735342,0.327229099655296,0.0860057807467148,0.155573716106985,0.0652196130235331,0.0401397957317501,0.0312547584957665,0,0,0.0290164970646396,-0.00428462403371444,0.113543374367374,0.00665847168958494,0.264712879181914,0.0262561001027125,0.449425033656063,0.0413548264950476,0.653083287629906,0.0438894419446279,0.83008632648885,0.0331445720656863,0.943258507857798,0.0162428794584627,1,0],"Bot_Xtr":1,"Re":750000,"src":"retestd_11.txt","diter":3,"Top_Xtr":0.842193342320956,"Foil_fn":"optbs-spline_foil_e61.dat-s17_n17s0-Re100000-N3-sq1.dat","Cm":-0.233176455624195,"id":478,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt29.2471977733992>28.9582923648431) l1 Foil spline 17pts Re100000 N3","good":138.487911907657,"xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00335,"Cpmin":-1.0076394667342,"CD":0.00545414105419925,"CL":1.13626938492006,"n":13,"CDp":0.00079027727535578},
             {"src":"retestd_0.txt","Re":750000,"Top_Xtr":0.828361093357824,"Foil_fn":"optbs_spline_e61.dat-s17_n17s0_nsopt-Re100000-N6.dat","diter":3,"alpha":1.8,"clcd":207.3058223369,"CDpres":0.00252,"Bot_Xtr":1,"xy":[1,0,0.946714574040677,0.0238223586461992,0.854728633619417,0.0503891991639097,0.691363149797408,0.0804311549125921,0.513763139089403,0.0962170131560968,0.327229099655296,0.0933944551401733,0.155573716106985,0.0708225676216361,0.0401397957317501,0.0339398249153306,0,0,0.0290164970646396,-0.00462569859696641,0.113543374367374,0.00718851477051356,0.264712879181914,0.028346198978312,0.449425033656063,0.0446468491495842,0.653083287629906,0.047383230927009,0.83008632648885,0.0357830230365355,0.943258507857798,0.0175358827590223,1,0],"sym":7.33932698105929,"Cpmin":-1.11098025142029,"CDf":0.00344,"CDp":0.00103691145253556,"CD":0.00596420899186037,"CL":1.23641524964675,"n":14,"Cm":-0.251553217290936,"r":6,"id":479,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e61.dat-s17_n17s0.dat (opt35.8742221908171>34.3046598556064) l1 Foil spline 17pts Re100000 N6","iver":1.2020052,"good":142.743751298732},
             #{"Re":1000000,"n":3,"diter":7,"Top_Xtr":0.671418917834274,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","src":"retestc_22.txt","sym":5.39797390759795,"Bot_Xtr":0.984247955918084,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"clcd":171.159831169389,"CDpres":0.00232,"alpha":3,"CL":1.06389317681794,"CD":0.00621578772045561,"CDp":7.12508361239673e-05,"CDf":0.00389,"Cpmin":-1.22403541610329,"id":480,"good":86.5688646283842,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.166459470172631},        #dud
             {"Bot_Xtr":1,"CD":0.00719357960493408,"CDf":0.00421,"CDp":0.000254668283367812,"CDpres":0.00299,"CL":1.2777701950727,"Cm":-0.166088401636264,"Cpmin":-1.52477224665049,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1000000-ncrit3_n17sopt-Re1000000-N3.dat","Re":1000000,"Top_Xtr":0.593970388306135,"alpha":4.7,"clcd":177.626476003168,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt88.0766859921049>47.4333997076569) l2 Foil spline 17pts Re1000000 N3","diter":3,"good":88.0764662478367,"id":17,"iver":1.2020062,"n":3,"r":6,"src":"","sym":6.24052695561728,"xver":6.991,"xy":[1,0,0.95524915648976,0.0173122960562593,0.898367040337738,0.0320293572897214,0.786682745711219,0.0667917874780359,0.585895338336926,0.127961465868532,0.36305117086393,0.135870676860945,0.173506805006988,0.0988865738448878,0.0500628994590385,0.0459302749098317,0,0,0.0410722652432177,-0.00879740789200183,0.176986979610049,-0.00762527092647245,0.292775850160075,-0.00438185205912251,0.672339083972041,0.000177764414965521,0.735580739593866,0.00076715446029341,0.849789731414699,0.00218839295403486,0.937537905999206,0.000142396331954261,1,0]},        #1000000 3
             #{"Re":1000000,"n":4,"CDf":0.00383,"Cpmin":-1.26498829396257,"CL":1.14428200289225,"CD":0.00638009983802096,"CDp":0.000168449326276935,"Cm":-0.173050207184152,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","good":97.3225166382001,"iver":1.2020052,"id":481,"r":6,"src":"retestc_1.txt","diter":4,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","Top_Xtr":0.672303848512723,"clcd":179.351739305572,"CDpres":0.00255,"alpha":3.5,"sym":5.39797390759795,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"Bot_Xtr":0.997766862246349},        #dud
             {"Bot_Xtr":1,"CD":0.00825121991910988,"CDf":0.00402,"CDp":0.000325659458483126,"CDpres":0.00423,"CL":1.42124575942928,"Cm":-0.201961833363288,"Cpmin":-1.65864246813605,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1000000-ncrit4_n17sopt-Re1000000-N4.dat","Re":1000000,"Top_Xtr":0.647908355902355,"alpha":5.2,"clcd":172.246743313394,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt100.766376513733>0) l2 Foil spline 17pts Re1000000 N4","diter":3,"good":100.766379946483,"id":29,"iver":1.2020062,"n":4,"r":6,"src":"","sym":8.30104606126311,"xver":6.991,"xy":[1,0,0.967748287014899,0.012056730125342,0.873249595675918,0.0491200402344488,0.756589038310868,0.0970121548836017,0.586128583834448,0.151280942042285,0.351734583373168,0.150800642655194,0.161561336669608,0.105761085857559,0.0416998179790635,0.0475074992677272,0,0,0.0483609380751577,-0.0109225008537937,0.133038796379359,-0.00858896492101406,0.301617029146633,-0.00158966266965628,0.631644027985941,0.00637636372453732,0.720703990538066,0.00690128846080893,0.785992355388838,0.00786983713229759,0.932382938996565,0.00675341527994209,1,0]},        #1000000 4
             #{"Re":1000000,"n":5,"alpha":4,"clcd":184.774999911617,"CDpres":0.00276,"Bot_Xtr":1,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"sym":5.39797390759795,"src":"retestc_0.txt","Top_Xtr":0.672446951443017,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","diter":4,"Cm":-0.174514391661943,"r":6,"id":482,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","iver":1.2020052,"good":103.778763182885,"Cpmin":-1.29298882819731,"CDf":0.00374,"CDp":0.000206757370969955,"CD":0.00650622978918558,"CL":1.20218860872173,},        #dud
             {"Bot_Xtr":1,"CD":0.00723254057038924,"CDf":0.00387,"CDp":0.000279751708682535,"CDpres":0.00337,"CL":1.31964322673886,"Cm":-0.181184525839021,"Cpmin":-1.47581973678933,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1000000-ncrit5_n17sopt-Re1000000-N5.dat","Re":1000000,"Top_Xtr":0.649416239219114,"alpha":4.6,"clcd":182.459153031455,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt107.16026952531>0) l2 Foil spline 17pts Re1000000 N5","diter":3,"good":107.160059668485,"id":34,"iver":1.2020062,"n":5,"r":6,"src":"","sym":6.69024467622922,"xver":6.991,"xy":[1,0,0.971718837915907,0.0121273139437602,0.817097873189241,0.0590466365381136,0.67050889559577,0.1172723850963,0.509375779442253,0.143080255204919,0.322812087182674,0.133650139927477,0.152606950309203,0.0945713234606137,0.0436430793985976,0.0439855630673426,0,0,0.0286637181700279,-0.0141082134347082,0.143987659882344,-0.0126084143734705,0.442192507002639,-0.00468789968018373,0.559259513113155,-0.00234816598085463,0.676948453953218,-0.000839322480185672,0.797774466345378,0.000836445057362905,0.968221726521253,0.000231396070318953,1,0]},        #1000000 5
             {"Re":1000000,"src":"retest_154.txt","diter":3,"Top_Xtr":0.619166414175911,"Foil_fn":"opt_spline_gu255118_nsopt-Re1000000-N4.dat","clcd":184.236331990583,"CDpres":0.00382,"alpha":5.8,"sym":5.18149799114981,"xy":[1,0,0.946983963670502,0.0161095300715229,0.797160348096083,0.0580655913284881,0.638459452814558,0.120493550622759,0.465525023726078,0.143178615231889,0.297463223171926,0.130052757474549,0.151647407370497,0.0961035643233716,0.0445917027294438,0.0459741047541366,0,0,0.0255242023469062,-0.0187365739013537,0.0988910949794272,-0.0255522240928956,0.245269513084109,-0.021948624309048,0.310886781502862,-0.0193312699553359,0.453623322192463,-0.0131260042220296,0.644127620559591,-0.00409595569270047,0.95,-0.002316937826832,1,0],"Bot_Xtr":1,"CDf":0.00368,"Cpmin":-1.61358407115913,"CL":1.3810712351087,"CD":0.0074961937213301,"n":6,"CDp":0.00088211968204051,"Cm":-0.163485318318872,"id":483,"good":95.368814048761,"cmt":"OPT s(0) optbs_spline_Re1000000_N4_gu255118.dat-s17_n17s0_nsopt-Re1000000-N4.dat (opt91.6317038859991>73.3183058546927) l1 Foil spline 17pts Re1000000 N4","xver":6.991,"iver":1.2020052,"r":6},
             #{"Re":1000000,"n":7,"CD":0.00675820605213102,"CL":1.29104742931142,"CDp":0.00026217151941438,"CDf":0.00353,"Cpmin":-1.36516358078321,"id":484,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","good":104.553843013834,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.171253295404308,"diter":3,"Top_Xtr":0.677255391965004,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","src":"retest_152.txt","sym":5.39797390759795,"Bot_Xtr":1,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"CDpres":0.00323,"clcd":191.034043554255,"alpha":5},        #dud
             {"Bot_Xtr":1,"CD":0.00629191375636692,"CDf":0.00361,"CDp":0.000390513829714716,"CDpres":0.00269,"CL":1.31982685554909,"Cm":-0.221913772155841,"Cpmin":-1.35389604107704,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1000000-ncrit7_n17sopt-Re1000000-N7.dat","Re":1000000,"Top_Xtr":0.708717138514135,"alpha":3.5,"clcd":209.76556682989,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt126.069727951886>98.2743433143009) l2 Foil spline 17pts Re1000000 N7","diter":3,"good":126.069727686401,"id":59,"iver":1.2020062,"n":7,"r":6,"src":"","sym":7.72527606985026,"xver":6.991,"xy":[1,0,0.960766105989991,0.0173956012122018,0.816908528331504,0.0678427063533107,0.700014668515284,0.106030518467835,0.525474040386457,0.128405615050912,0.330112429516344,0.121759777104146,0.153277893353738,0.0877277374684573,0.0392210858496869,0.0382038047052069,0,0,0.0236026348114983,-0.00946376122044155,0.1017245557943,-0.00683210053032802,0.229195530509162,0.00169746916934149,0.3449990202837,0.00867787789536275,0.675790058470148,0.022559099083479,0.88911372507322,0.0147219550597572,0.962598354411699,0.00687892171615299,1,0]},        #1000000 7
             {"CDf":0.0037,"Cpmin":-1.34412659158732,"n":8,"CL":1.18292266562292,"CD":0.00644800548153134,"CDp":0.000557516477135901,"Cm":-0.166712843929494,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt100.927846482551>98.2743433305579) l1 Foil spline 17pts Re1000000 N7","xver":6.991,"iver":1.2020052,"good":106.570434544942,"id":485,"r":6,"Re":1000000,"src":"retest_47.txt","diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N7.dat","Top_Xtr":0.67485662508277,"CDpres":0.00275,"clcd":183.455592432591,"alpha":3.8,"sym":4.95570466627733,"xy":[1,0,0.974015496570672,0.00926165417126666,0.851331789830318,0.0475314059877612,0.697513982916721,0.101458998737539,0.517583389683761,0.128370735285468,0.322588496821194,0.124157860471527,0.151415119479181,0.0914730553111074,0.0381239248266517,0.041817855140091,0,0,0.0275601175941499,-0.011995843221396,0.097301530937469,-0.0158483908208169,0.317910524511779,-0.0121493153360578,0.602597711978496,-0.00702019581847944,0.688842293451116,-0.00544920291651817,0.843265058193578,-0.00264705242043093,0.975484799558879,-0.000246056620186703,1,0],"Bot_Xtr":1},
             {"CDf":0.00365,"Cpmin":-1.39559630406523,"CL":1.21971341528992,"CD":0.00656547964088833,"n":9,"CDp":0.000610886596917974,"Cm":-0.165836612338563,"id":486,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt93.9332068608814>92.5265462092186) l1 Foil spline 17pts Re1125000 N6","xver":6.991,"iver":1.2020052,"good":109.083359261746,"r":6,"Re":1000000,"src":"retest_5.txt","diter":3,"Top_Xtr":0.67586963814157,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N6.dat","CDpres":0.00292,"clcd":185.776741685988,"alpha":4.2,"sym":4.95516801967671,"xy":[1,0,0.974015496570672,0.00930154228822966,0.851331789830318,0.0477361143742325,0.697513982916721,0.101895962624741,0.517583389683761,0.128923602711632,0.322588496821194,0.124692583877172,0.151415119479181,0.0918670117104439,0.0381239248266517,0.0419979563904858,0,0,0.0275601175941499,-0.0125429205102774,0.097301530937469,-0.0165711657457109,0.317910524511779,-0.0127033918084779,0.602597711978496,-0.00734035586266376,0.688842293451116,-0.0056977169311742,0.843265058193578,-0.00276777275954918,0.975484799558879,-0.00025727817303619,1,0],"Bot_Xtr":1},
             {"alpha":2.6,"CDpres":0.0021,"clcd":205.064076791682,"Bot_Xtr":1,"xy":[1,0,0.935011565234699,0.0239659577401647,0.832759572625176,0.0515276137115949,0.677881347208709,0.0810292167541444,0.498330361581256,0.0967520796898261,0.303479831718183,0.0926180938775419,0.141254493802371,0.0692818694991334,0.0392201876478182,0.0348133962184568,0,0,0.0273249029632743,-0.0111039008055791,0.11517941993719,-0.00742225160563915,0.26070204557751,0.00667289285473238,0.441896057434714,0.0213060588999675,0.644540807381952,0.0292437238204537,0.824582122291211,0.0253320221034907,0.941862196267766,0.0133031323894906,1,0],"sym":5.17261467644512,"src":"retest_107.txt","Re":1000000,"Foil_fn":"optbs_spline_e471.dat-s17_n17s0_nsopt-Re750000-N8.dat","Top_Xtr":0.713235610230239,"diter":3,"Cm":-0.208278724507038,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e471.dat-s17_n17s0.dat (opt99.8007359883384>90.848561338805) l1 Foil spline 17pts Re750000 N8","iver":1.2020052,"good":111.71042596293,"id":487,"Cpmin":-1.198999032608,"CDf":0.00354,"CDp":0.000659992894811778,"n":10,"CL":1.15523041212425,"CD":0.00563350943860251},
             {"sym":5.80178663121179,"Bot_Xtr":1,"xy":[1,0,0.935011565234699,0.0252569246914108,0.832759572625176,0.0543032359963142,0.677881347208709,0.0853939929107694,0.498330361581256,0.101963794518755,0.303479831718183,0.0976071245509511,0.141254493802371,0.0730138548766269,0.0392201876478182,0.0366886788366575,0,0,0.0273249029632743,-0.0120351858446321,0.11517941993719,-0.00804475643501822,0.26070204557751,0.00723254890638712,0.441896057434714,0.0230929997455443,0.644540807381952,0.0316963972509029,0.824582122291211,0.0274566208014625,0.941862196267766,0.0144188671554793,1,0],"CDpres":0.00236,"clcd":209.190900415689,"alpha":2.8,"diter":4,"Foil_fn":"optbs-spline_foil_e471.dat-s17_n17s0-Re400000-N11-sq1.dat","Top_Xtr":0.71318015320159,"Re":1000000,"src":"retest_156.txt","xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_e471.dat-s17_n17s0.dat (opt58.8092008746011>54.9020685488652) l1 Foil spline 17pts Re400000 N11","iver":1.2020052,"good":120.062556015301,"id":488,"r":6,"Cm":-0.2211853358871,"n":11,"CD":0.00588503265584297,"CL":1.23109528025153,"CDp":0.000795645688609619,"CDf":0.00352,"Cpmin":-1.27644474633569},
             {"Cpmin":-0.93646252187167,"CDf":0.00286,"CDp":0.000530801058589681,"CL":0.984459319535263,"CD":0.00436967122608138,"n":12,"Cm":-0.208716809246155,"r":6,"id":489,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt83.485024160884>69.099244588729) l1 Foil spline 17pts Re500000 N6","good":125.994218910715,"iver":1.2020052,"src":"retest_80.txt","Re":1000000,"Top_Xtr":0.846014730524267,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re500000-N6.dat","diter":3,"alpha":1.2,"clcd":225.293681972981,"CDpres":0.00151,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0225648070901571,0.833474960203591,0.0457030439022681,0.683294039292584,0.0676765716537456,0.512919921681868,0.0796431280499932,0.327643312365742,0.0782270562732025,0.159685519883032,0.0610687707734753,0.0454559935430201,0.0315277178983488,0,-3.0718568604681e-11,0.0261984228078157,-0.010357664370665,0.134241453700877,-0.00242704024701346,0.290009257938815,0.0140541709969343,0.464856398032139,0.0274939774759001,0.654716626975926,0.0336294731936775,0.826995021496349,0.0282858071663843,0.941457504275826,0.0150211643562865,1,0],"sym":4.26999689989288},
             {"src":"retest_151.txt","Re":1000000,"Top_Xtr":0.684351748153711,"Foil_fn":"optbs-spline_foil_uag8814320.dat-s17_n17s0-Re1700000-N12-sq1.dat","diter":3,"alpha":5.2,"clcd":195.537419447013,"CDpres":0.00315,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00868794597397609,0.851331789830318,0.0445870985519983,0.697513982916721,0.0951741755096107,0.517583389683761,0.120418878979499,0.322588496821194,0.116466968435031,0.151415119479181,0.0858068059896841,0.0381239248266517,0.0392274705453595,0,0,0.0275601175941499,-0.0114843553337143,0.097301530937469,-0.0151726350782248,0.317910524511779,-0.0116312835876155,0.602597711978496,-0.00672086336939399,0.688842293451116,-0.00521685565773212,0.843265058193578,-0.00253418538589901,0.975484799558879,-0.000235565070856939,1,0],"sym":4.34182009922866,"Cpmin":-1.47507884549551,"CDf":0.00337,"CDp":0.000829558879220432,"CD":0.00651180829793618,"CL":1.27330219051208,"n":13,"Cm":-0.154710846108059,"r":6,"id":490,"xver":6.991,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt93.1064966059663>90.8851999406142) l1 Foil spline 17pts Re1700000 N12","good":113.306089579884,"iver":1.2020052},
             {"diter":3,"Foil_fn":"optbs_spline_e471.dat-s17_n17s0_nsopt-Re750000-N8.dat","Top_Xtr":0.72866347144541,"Re":1000000,"src":"retest_111.txt","sym":5.17261467644512,"Bot_Xtr":1,"xy":[1,0,0.935011565234699,0.0239659577401647,0.832759572625176,0.0515276137115949,0.677881347208709,0.0810292167541444,0.498330361581256,0.0967520796898261,0.303479831718183,0.0926180938775419,0.141254493802371,0.0692818694991334,0.0392201876478182,0.0348133962184568,0,0,0.0273249029632743,-0.0111039008055791,0.11517941993719,-0.00742225160563915,0.26070204557751,0.00667289285473238,0.441896057434714,0.0213060588999675,0.644540807381952,0.0292437238204537,0.824582122291211,0.0253320221034907,0.941862196267766,0.0133031323894906,1,0],"clcd":212.383414769768,"CDpres":0.00235,"alpha":3.1,"n":14,"CL":1.21573884429454,"CD":0.00572426451289732,"CDp":0.000815556222880346,"CDf":0.00338,"Cpmin":-1.33995332677455,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e471.dat-s17_n17s0.dat (opt99.8007359883384>90.848561338805) l1 Foil spline 17pts Re750000 N8","good":128.4180525808,"iver":1.2020052,"id":491,"r":6,"Cm":-0.209583088885789},
             {"Cpmin":-1.95792045185105,"CDf":0.00395,"CDp":0.000486335683414497,"n":3,"CL":1.57561168267017,"CD":0.00853551044726811,"Cm":-0.192604500059888,"r":6,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","iver":1.2020052,"xver":6.991,"good":89.7824119639439,"id":492,"src":"retestc_20.txt","Re":1125000,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","Top_Xtr":0.564743857267867,"diter":3,"alpha":6.4,"clcd":184.594898266977,"CDpres":0.00459,"Bot_Xtr":1,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"sym":7.45853331327074},
             #{"Re":1125000,"n":4,"Top_Xtr":0.672366898154359,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","diter":3,"src":"retest_158.txt","xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"Bot_Xtr":0.993674460771877,"sym":5.39797390759795,"alpha":3.3,"CDpres":0.00232,"clcd":185.29767930299,"CDp":6.35000198589084e-05,"CL":1.11556913709167,"CD":0.00602041612872843,"Cpmin":-1.25142182178103,"CDf":0.0037,"r":6,"id":493,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","xver":6.991,"iver":1.2020052,"good":99.9477004673153,"Cm":-0.171104665146808},        #dud
             {"Bot_Xtr":1,"CD":0.00747598891375613,"CDf":0.00364,"CDp":0.000589509274632897,"CDpres":0.00384,"CL":1.39697496449509,"Cm":-0.194907218316018,"Cpmin":-1.57925741907206,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1125000-ncrit4_n17sopt-Re1125000-N4.dat","Re":1125000,"Top_Xtr":0.67548243547227,"alpha":5,"clcd":186.861561809514,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt109.741014438418>0) l2 Foil spline 17pts Re1125000 N4","diter":3,"good":109.741014437841,"id":37,"iver":1.2020062,"n":4,"r":6,"src":"","sym":7.56872862887804,"xver":6.991,"xy":[1,0,0.965158423600067,0.0149571047397598,0.8403576456426,0.0595944392116787,0.668862720066367,0.129487475183182,0.506638513976242,0.151734574759275,0.325335887730018,0.140651111192,0.16454894539179,0.1004289307331,0.0487532746531385,0.0467895228999731,0,0,0.0443864570410116,-0.0103019433388788,0.178541522058289,-0.00675415920419843,0.344928787694695,-0.0026690717442548,0.642658614091303,-0.00208707037043963,0.691089118976268,-0.00217033899527855,0.791462627705708,-0.00184385144509581,0.975411174326617,-0.000284413842191085,1,0]},        #1125000 4
             #{"Re":1125000,"n":5,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"Bot_Xtr":1,"sym":5.39797390759795,"alpha":3.7,"CDpres":0.0025,"clcd":193.888183900523,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","Top_Xtr":0.674805422601087,"diter":3,"src":"retest_159.txt","r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","good":107.131214434548,"iver":1.2020052,"id":494,"Cm":-0.178587335663268,"CDp":0.000160823961065116,"CL":1.18922242702775,"CD":0.00613354771344858,"Cpmin":-1.289498698298,"CDf":0.00364},        #dud
             {"Bot_Xtr":1,"CD":0.00666827218848517,"CDf":0.00379,"CDp":0.000458570591190991,"CDpres":0.00288,"CL":1.32871693787358,"Cm":-0.181944106500519,"Cpmin":-1.50881535287935,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1125000-ncrit5_n17sopt-Re1125000-N5.dat","Re":1125000,"Top_Xtr":0.632774517497807,"alpha":4.4,"clcd":199.25955334697,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt112.664142800553>82.2113188374566) l2 Foil spline 17pts Re1125000 N5","diter":3,"good":112.664131714709,"id":40,"iver":1.2020062,"n":5,"r":6,"src":"","sym":7.09403352273627,"xver":6.991,"xy":[1,0,0.970293223087358,0.0106632200144808,0.822802299108702,0.0524007679283714,0.649475352382161,0.119659812432002,0.463530174394041,0.143552307306452,0.278933375752121,0.128190849324522,0.136326867987191,0.0897307137102031,0.0408436805155184,0.0424933709281444,0,0,0.0390904541180655,-0.0100623330669058,0.182331078944503,-0.00565636363495558,0.378121633730518,0.00189631214914321,0.570612465487076,0.00397273405789167,0.636228004504316,0.00429770858469292,0.784689041776111,0.00433618738927428,0.951056909020799,-0.00136384022211298,1,0]},        #1125000 5
             {"Cpmin":-1.58211961451581,"CDf":0.00359,"CDp":0.000727126800882476,"CL":1.36296472702611,"CD":0.0069814143652876,"n":6,"Cm":-0.166208832909225,"r":6,"id":495,"cmt":"OPT s(0) optbs_spline_Re1000000_N4_gu255118.dat-s17_n17s0_nsopt-Re1000000-N4.dat (opt91.6317038859991>73.3183058546927) l1 Foil spline 17pts Re1000000 N4","xver":6.991,"iver":1.2020052,"good":99.3869848147912,"src":"retest_99.txt","Re":1125000,"Top_Xtr":0.620009904156281,"Foil_fn":"opt_spline_gu255118_nsopt-Re1000000-N4.dat","diter":3,"alpha":5.5,"clcd":195.22759368115,"CDpres":0.0034,"Bot_Xtr":1,"xy":[1,0,0.946983963670502,0.0161095300715229,0.797160348096083,0.0580655913284881,0.638459452814558,0.120493550622759,0.465525023726078,0.143178615231889,0.297463223171926,0.130052757474549,0.151647407370497,0.0961035643233716,0.0445917027294438,0.0459741047541366,0,0,0.0255242023469062,-0.0187365739013537,0.0988910949794272,-0.0255522240928956,0.245269513084109,-0.021948624309048,0.310886781502862,-0.0193312699553359,0.453623322192463,-0.0131260042220296,0.644127620559591,-0.00409595569270047,0.95,-0.002316937826832,1,0],"sym":5.18149799114981},
             {"n":7,"CD":0.00615630977980281,"CL":1.14382080182695,"CDp":0.00039602006212056,"CDf":0.00367,"Cpmin":-1.28700556986728,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt103.852584292449>97.657112351132) l1 Foil spline 17pts Re1125000 N7","iver":1.2020052,"good":103.852584292497,"id":496,"r":6,"Cm":-0.167597284471912,"diter":4,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N7.dat","Top_Xtr":0.662973491269311,"Re":1125000,"src":"retest_1.txt","sym":4.82916418083256,"Bot_Xtr":0.999939464898981,"xy":[1,0,0.974015496570672,0.00920396648269282,0.851331789830318,0.0472353490528558,0.697513982916721,0.10082704519944,0.517583389683761,0.127571157708698,0.322588496821194,0.123384523456732,0.151415119479181,0.0909033008126015,0.0381239248266517,0.0415573859669241,0,0,0.0275601175941499,-0.0126737272651912,0.097301530937469,-0.0167439819901063,0.317910524511779,-0.012835872075534,0.602597711978496,-0.00741690646581244,0.688842293451116,-0.0057571368933412,0.843265058193578,-0.00279663711954563,0.975484799558879,-0.00025996125811972,1,0],"CDpres":0.00249,"clcd":185.796498671902,"alpha":3.4},
             {"src":"retest_68.txt","Re":1125000,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N10.dat","Top_Xtr":0.673676141020157,"diter":3,"alpha":3.6,"clcd":192.19257750064,"CDpres":0.00249,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00911283727017547,0.851331789830318,0.0467676680622456,0.697513982916721,0.0998287485143365,0.517583389683761,0.126308065414329,0.322588496821194,0.122162883364866,0.151415119479181,0.0900032599189436,0.0381239248266517,0.0411459229455662,0,0,0.0275601175941499,-0.012088157393246,0.097301530937469,-0.0159703523242125,0.317910524511779,-0.0122428105546175,0.602597711978496,-0.00707421982923445,0.688842293451116,-0.00549113733039781,0.843265058193578,-0.0026674228477136,0.975484799558879,-0.000247950152196211,1,0],"sym":4.77327603275279,"Cpmin":-1.31258153095802,"CDf":0.00357,"CDp":0.000449428194575171,"n":8,"CD":0.00605258678086341,"CL":1.16326225396044,"Cm":-0.167129665231076,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt111.597104473288>111.089101822978) l1 Foil spline 17pts Re1000000 N10","iver":1.2020052,"good":109.212829058978,"id":497},
             {"Cpmin":-1.36259625227366,"CDf":0.00352,"CDp":0.000487439194314537,"n":9,"CL":1.20279802594934,"CD":0.00611250134840006,"Cm":-0.166034295068565,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt110.605064440281>108.64341190758) l1 Foil spline 17pts Re1000000 N9","iver":1.2020052,"xver":6.991,"good":113.529660194065,"id":498,"src":"retestc_10.txt","Re":1125000,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N9.dat","Top_Xtr":0.674892902498134,"diter":3,"alpha":4,"CDpres":0.00259,"clcd":196.776729753061,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00912943962192423,0.851331789830318,0.0468528724012037,0.697513982916721,0.10001062293482,0.517583389683761,0.126538181553632,0.322588496821194,0.122385447545498,0.151415119479181,0.0901672336337601,0.0381239248266517,0.0412208852284992,0,0,0.0275601175941499,-0.0107529390000682,0.097301530937469,-0.0142063193558187,0.317910524511779,-0.0108905096782366,0.602597711978496,-0.00629282460694401,0.688842293451116,-0.00488460423155603,0.843265058193578,-0.00237278803011601,0.975484799558879,-0.000220562388037167,1,0],"sym":4.9081464737037},
             {"Cm":-0.208726455624741,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e471.dat-s17_n17s0.dat (opt96.6296489035803>89.1233068119133) l1 Foil spline 17pts Re620000 N8","good":116.440332023592,"xver":6.991,"iver":1.2020052,"id":499,"r":6,"CDf":0.00341,"Cpmin":-1.1522163911806,"n":10,"CD":0.00533356343292465,"CL":1.13415212774111,"CDp":0.00059494686995294,"CDpres":0.00193,"clcd":212.64434969309,"alpha":2.4,"sym":5.11582491393606,"xy":[1,0,0.935011565234699,0.0237572277083639,0.832759572625176,0.0510788371358682,0.677881347208709,0.0803234977850442,0.498330361581256,0.0959094234150632,0.303479831718183,0.0918114422974136,0.141254493802371,0.0686784633269052,0.0392201876478182,0.0345101910898091,0,0,0.0273249029632743,-0.0112123825803761,0.11517941993719,-0.00749476477387321,0.26070204557751,0.00673808501310862,0.441896057434714,0.0215142126941941,0.644540807381952,0.0295294262161488,0.824582122291211,0.0255795083486489,0.941862196267766,0.0134330999961218,1,0],"Bot_Xtr":1,"Re":1125000,"src":"retest_28.txt","diter":3,"Foil_fn":"optbs_spline_e471.dat-s17_n17s0_nsopt-Re620000-N8.dat","Top_Xtr":0.71344302357633},
             {"Cpmin":-1.06211495457605,"CDf":0.00328,"CDp":0.000476548706752705,"CL":1.03740996975364,"CD":0.00493287869036762,"n":11,"Cm":-0.190512746444034,"r":6,"id":500,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e471.dat-s17_n17s0.dat (opt72.6473383692547>64.3538781515534) l1 Foil spline 17pts Re500000 N5","xver":6.991,"iver":1.2020052,"good":119.501829378897,"src":"retest_92.txt","Re":1125000,"Top_Xtr":0.741827003608662,"Foil_fn":"optbs_spline_e471.dat-s17_n17s0_nsopt-Re500000-N5.dat","diter":4,"alpha":2.2,"clcd":210.305185850077,"CDpres":0.00165,"Bot_Xtr":1,"xy":[1,0,0.935011565234699,0.0220181437859741,0.832759572625176,0.0473397483192854,0.677881347208709,0.0744436322846221,0.498330361581256,0.088888632171475,0.303479831718183,0.0850906327336513,0.141254493802371,0.0636510412365656,0.0392201876478182,0.031983965419894,0,0,0.0273249029632743,-0.00970526371897624,0.11517941993719,-0.00648735165079368,0.26070204557751,0.00583238143582034,0.441896057434714,0.0186223674055454,0.644540807381952,0.0255602113862371,0.824582122291211,0.0221412240035307,0.941862196267766,0.0116274821244432,1,0],"sym":4.29289316132425},
             {"sym":4.26999689989288,"Bot_Xtr":1,"xy":[1,0,0.936135138855638,0.0225648070901571,0.833474960203591,0.0457030439022681,0.683294039292584,0.0676765716537456,0.512919921681868,0.0796431280499932,0.327643312365742,0.0782270562732025,0.159685519883032,0.0610687707734753,0.0454559935430201,0.0315277178983488,0,-3.0718568604681e-11,0.0261984228078157,-0.010357664370665,0.134241453700877,-0.00242704024701346,0.290009257938815,0.0140541709969343,0.464856398032139,0.0274939774759001,0.654716626975926,0.0336294731936775,0.826995021496349,0.0282858071663843,0.941457504275826,0.0150211643562865,1,0],"clcd":234.798170707516,"CDpres":0.00137,"alpha":0.9,"diter":4,"Foil_fn":"optbs_spline_e71.dat-s17_n17s0_nsopt-Re500000-N6.dat","Top_Xtr":0.854438773696567,"Re":1125000,"src":"retest_90.txt","good":123.462538967003,"cmt":"OPT s(0) foildb2020_spline/spline_foil_e71.dat-s17_n17s0.dat (opt83.485024160884>69.099244588729) l1 Foil spline 17pts Re500000 N6","xver":6.991,"iver":1.2020052,"id":501,"r":6,"Cm":-0.209505030404077,"n":12,"CL":0.954428443591853,"CD":0.00406488875409837,"CDp":0.000466196712212249,"CDf":0.00269,"Cpmin":-0.869532267760647},
             {"Cpmin":-1.47801575477545,"CDf":0.0033,"CDp":0.000721928303030283,"n":13,"CD":0.00626477424298585,"CL":1.28454319543833,"Cm":-0.161539556711833,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt118.729498545856>117.637000763685) l1 Foil spline 17pts Re1125000 N11","xver":6.991,"good":119.722830901469,"iver":1.2020052,"id":502,"src":"retest_5.txt","Re":1125000,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N11.dat","Top_Xtr":0.684426772494174,"diter":3,"alpha":5,"CDpres":0.00297,"clcd":205.042216305963,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00895966283727706,0.851331789830318,0.0459815670027149,0.697513982916721,0.0981507626700499,0.517583389683761,0.12418499817229,0.322588496821194,0.120109491010118,0.151415119479181,0.0884904272096169,0.0381239248266517,0.0404543157955191,0,0,0.0275601175941499,-0.0113810594753383,0.097301530937469,-0.0150361650441053,0.317910524511779,-0.0115266661853073,0.602597711978496,-0.00666041266662517,0.688842293451116,-0.00516993272931945,0.843265058193578,-0.00251139169421027,0.975484799558879,-0.000233446284430491,1,0],"sym":4.6567204509656},
             {"n":14,"CL":1.30316950353082,"CD":0.00633584449719123,"CDp":0.000775526209145614,"CDf":0.00326,"Cpmin":-1.50383402824988,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt118.729498545856>117.637000763685) l1 Foil spline 17pts Re1125000 N11","xver":6.991,"good":120.316819549883,"iver":1.2020052,"id":503,"r":6,"Cm":-0.161069686757314,"diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N11.dat","Top_Xtr":0.684782213006967,"Re":1125000,"src":"retest_6.txt","sym":4.6567204509656,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00895966283727706,0.851331789830318,0.0459815670027149,0.697513982916721,0.0981507626700499,0.517583389683761,0.12418499817229,0.322588496821194,0.120109491010118,0.151415119479181,0.0884904272096169,0.0381239248266517,0.0404543157955191,0,0,0.0275601175941499,-0.0113810594753383,0.097301530937469,-0.0150361650441053,0.317910524511779,-0.0115266661853073,0.602597711978496,-0.00666041266662517,0.688842293451116,-0.00516993272931945,0.843265058193578,-0.00251139169421027,0.975484799558879,-0.000233446284430491,1,0],"CDpres":0.00308,"clcd":205.682052977868,"alpha":5.2},
             {"Top_Xtr":0.561225389345513,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","diter":3,"src":"retestc_8.txt","Re":1400000,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"Bot_Xtr":1,"sym":7.45853331327074,"alpha":6.1,"clcd":201.966922553314,"CDpres":0.00395,"CDp":0.000324546531119167,"CL":1.55659216256165,"CD":0.00770716384090442,"n":3,"Cpmin":-1.95236120605576,"CDf":0.00376,"r":6,"id":504,"good":93.1706329028445,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","xver":6.991,"iver":1.2020052,"Cm":-0.194760366341242},
             {"diter":3,"Top_Xtr":0.475731633596815,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1700000-N4.dat","Re":1400000,"src":"retestc_12.txt","sym":14.7711420790784,"Bot_Xtr":1,"xy":[1,0,0.901061808611718,0.0309279022744031,0.678863215861058,0.0984103025323746,0.479050155772191,0.173757247262926,0.304112968064473,0.182329022083014,0.152671216420827,0.14331280171584,0.0512040607733385,0.0862059176432184,0.00202369805924237,0.0312902778334109,0,0,0.0230604239713358,-0.00527464897977672,0.0605603309266164,-0.0039058324312531,0.116429252189166,0.00154220450855022,0.334370367152041,0.0242735394021568,0.52103326718557,0.0338874168032558,0.687642492864678,0.036426309273113,0.866866720476992,0.0245013467517712,1,0],"clcd":205.781572203055,"CDpres":0.00502,"alpha":7.6,"CD":0.00919398740891835,"CL":1.89195318382231,"n":4,"CDp":0.00181297259556037,"CDf":0.00417,"Cpmin":-2.62181005146217,"id":505,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re1700000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1700000-N4.dat (opt97.8132923084178>86.4551928921508) l1 Foil spline 17pts Re1700000 N4","good":89.5211082658386,"iver":1.2020052,"r":6,"Cm":-0.207326417857074},
             {"id":506,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re1000000_N4_gu255118.dat-s17_n17s0_nsopt-Re1000000-N4.dat (opt91.6317038859991>73.3183058546927) l1 Foil spline 17pts Re1000000 N4","iver":1.2020052,"good":96.600071090913,"r":6,"Cm":-0.167436295722412,"CL":1.31664976693617,"CD":0.00650861582327427,"n":5,"CDp":0.000444544061262701,"CDf":0.00359,"Cpmin":-1.54921460576059,"sym":5.18149799114981,"Bot_Xtr":1,"xy":[1,0,0.946983963670502,0.0161095300715229,0.797160348096083,0.0580655913284881,0.638459452814558,0.120493550622759,0.465525023726078,0.143178615231889,0.297463223171926,0.130052757474549,0.151647407370497,0.0961035643233716,0.0445917027294438,0.0459741047541366,0,0,0.0255242023469062,-0.0187365739013537,0.0988910949794272,-0.0255522240928956,0.245269513084109,-0.021948624309048,0.310886781502862,-0.0193312699553359,0.453623322192463,-0.0131260042220296,0.644127620559591,-0.00409595569270047,0.95,-0.002316937826832,1,0],"clcd":202.293360475808,"CDpres":0.00291,"alpha":5,"diter":6,"Top_Xtr":0.59648495600099,"Foil_fn":"opt_spline_gu255118_nsopt-Re1000000-N4.dat","Re":1400000,"src":"retest_107.txt"},
             {"Cpmin":-1.55680895843209,"CDf":0.00343,"CDp":0.000482698960085367,"CD":0.00622797616898044,"CL":1.32949490671249,"n":6,"Cm":-0.170144949050584,"r":6,"id":507,"cmt":"OPT s(0) optbs_spline_Re1000000_N4_gu255118.dat-s17_n17s0_nsopt-Re1000000-N4.dat (opt91.6317038859991>73.3183058546927) l1 Foil spline 17pts Re1000000 N4","good":107.568829348826,"xver":6.991,"iver":1.2020052,"src":"retest_108.txt","Re":1400000,"Top_Xtr":0.618664006896542,"Foil_fn":"opt_spline_gu255118_nsopt-Re1000000-N4.dat","diter":3,"alpha":5,"clcd":213.471418425504,"CDpres":0.0028,"Bot_Xtr":1,"xy":[1,0,0.946983963670502,0.0161095300715229,0.797160348096083,0.0580655913284881,0.638459452814558,0.120493550622759,0.465525023726078,0.143178615231889,0.297463223171926,0.130052757474549,0.151647407370497,0.0961035643233716,0.0445917027294438,0.0459741047541366,0,0,0.0255242023469062,-0.0187365739013537,0.0988910949794272,-0.0255522240928956,0.245269513084109,-0.021948624309048,0.310886781502862,-0.0193312699553359,0.453623322192463,-0.0131260042220296,0.644127620559591,-0.00409595569270047,0.95,-0.002316937826832,1,0],"sym":5.18149799114981},
             {"CD":0.0063307956185727,"CL":1.37996577719215,"n":7,"CDp":0.000553397225337871,"CDf":0.00333,"Cpmin":-1.59625274605057,"id":508,"cmt":"OPT s(0) optbs_spline_Re1000000_N4_gu255118.dat-s17_n17s0_nsopt-Re1000000-N4.dat (opt91.6317038859991>73.3183058546927) l1 Foil spline 17pts Re1000000 N4","xver":6.991,"iver":1.2020052,"good":110.930500067595,"r":6,"Cm":-0.169753808328956,"diter":3,"Top_Xtr":0.622254427067892,"Foil_fn":"opt_spline_gu255118_nsopt-Re1000000-N4.dat","Re":1400000,"src":"retest_109.txt","sym":5.18149799114981,"Bot_Xtr":1,"xy":[1,0,0.946983963670502,0.0161095300715229,0.797160348096083,0.0580655913284881,0.638459452814558,0.120493550622759,0.465525023726078,0.143178615231889,0.297463223171926,0.130052757474549,0.151647407370497,0.0961035643233716,0.0445917027294438,0.0459741047541366,0,0,0.0255242023469062,-0.0187365739013537,0.0988910949794272,-0.0255522240928956,0.245269513084109,-0.021948624309048,0.310886781502862,-0.0193312699553359,0.453623322192463,-0.0131260042220296,0.644127620559591,-0.00409595569270047,0.95,-0.002316937826832,1,0],"CDpres":0.003,"clcd":217.976674707952,"alpha":5.5},
             {"sym":4.95570466627733,"Bot_Xtr":0.999925605102248,"xy":[1,0,0.974015496570672,0.00926165417126666,0.851331789830318,0.0475314059877612,0.697513982916721,0.101458998737539,0.517583389683761,0.128370735285468,0.322588496821194,0.124157860471527,0.151415119479181,0.0914730553111074,0.0381239248266517,0.041817855140091,0,0,0.0275601175941499,-0.011995843221396,0.097301530937469,-0.0158483908208169,0.317910524511779,-0.0121493153360578,0.602597711978496,-0.00702019581847944,0.688842293451116,-0.00544920291651817,0.843265058193578,-0.00264705242043093,0.975484799558879,-0.000246056620186703,1,0],"clcd":203.404902659108,"CDpres":0.00236,"alpha":3.6,"diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N7.dat","Top_Xtr":0.655735228700072,"Re":1400000,"src":"retest_69.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt100.927846482551>98.2743433305579) l1 Foil spline 17pts Re1000000 N7","xver":6.991,"good":112.101198009233,"iver":1.2020052,"id":509,"r":6,"Cm":-0.170327263907693,"n":8,"CD":0.00579669045257385,"CL":1.17907525725077,"CDp":0.000303365038509817,"CDf":0.00343,"Cpmin":-1.33073034467098},
             {"Cpmin":-1.32515688744281,"CDf":0.00332,"CDp":0.000331490937501098,"CD":0.00558840029626427,"CL":1.17900907925922,"n":9,"Cm":-0.17053428439567,"r":6,"id":510,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt111.597104473288>111.089101822978) l1 Foil spline 17pts Re1000000 N10","good":118.58486609136,"iver":1.2020052,"src":"retest_158.txt","Re":1400000,"Top_Xtr":0.672500931144399,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N10.dat","diter":3,"alpha":3.6,"CDpres":0.00227,"clcd":210.974342701857,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00911283727017547,0.851331789830318,0.0467676680622456,0.697513982916721,0.0998287485143365,0.517583389683761,0.126308065414329,0.322588496821194,0.122162883364866,0.151415119479181,0.0900032599189436,0.0381239248266517,0.0411459229455662,0,0,0.0275601175941499,-0.012088157393246,0.097301530937469,-0.0159703523242125,0.317910524511779,-0.0122428105546175,0.602597711978496,-0.00707421982923445,0.688842293451116,-0.00549113733039781,0.843265058193578,-0.0026674228477136,0.975484799558879,-0.000247950152196211,1,0],"sym":4.77327603275279},
             #{"Re":1400000,"n":10,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"Bot_Xtr":1,"sym":5.39797390759795,"alpha":5.2,"CDpres":0.00287,"clcd":228.634741920421,"Top_Xtr":0.68597761642742,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","diter":3,"src":"retest_111.txt","r":6,"id":511,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","xver":6.991,"good":122.67948982004,"Cm":-0.179604078222832,"CDp":0.000162936231180199,"CD":0.00589925476807967,"CL":1.34877459142271,"Cpmin":-1.44408556542262,"CDf":0.00303},        #dud
             {"Bot_Xtr":1,"CD":0.00580351232697291,"CDf":0.00311,"CDp":0.000463345746595799,"CDpres":0.0027,"CL":1.35041599133129,"Cm":-0.186376114090969,"Cpmin":-1.51322539982993,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re1400000-ncrit10_n17sblowsuck-Re1400000-N10.dat","Re":1400000,"Top_Xtr":0.68484854045959,"alpha":4.6,"clcd":232.689432751779,"cmt":"SPLN 8(B1) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat -opt_clcd(61)=(134.454171119986>134.44827428697 aoa=4.6 pa=1.34950131053357 Cl=1.34950131053357 Cd=0.00580190721730563 x=0.685206272170539,1 s=YB u=0.907733216892973 Foil spline 17pts Re1400000 N10","diter":3,"good":134.118644798454,"id":77,"iver":1.2020062,"n":10,"r":6,"src":"","sym":6.78146828999578,"xver":6.991,"xy":[1,0,0.974015496570672,0.00996764374476311,0.848046721820775,0.0475028610808983,0.697513982916721,0.109192929838996,0.517583389683761,0.138156071573966,0.322588496821194,0.133622061287021,0.151415119479181,0.0984457863277604,0.0381239248266517,0.0450055113804288,0,0,0.0590434446255189,-0.00953105312129477,0.159821773121151,-0.00667654704049775,0.325802313853219,0.00109844572309203,0.516830597864966,0.00541526812924467,0.680437804882521,0.00381220822489398,0.836004436173584,0.00446163705088958,0.975484799558879,-0.000265801019427204,1,0]},        #1400000 10
             {"diter":3,"Foil_fn":"optbs-spline_foil_uag8814320.dat-s17_n17s0-Re1700000-N12-sq1.dat","Top_Xtr":0.684502675208722,"Re":1400000,"src":"retestc_7.txt","sym":4.34182009922866,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00868794597397609,0.851331789830318,0.0445870985519983,0.697513982916721,0.0951741755096107,0.517583389683761,0.120418878979499,0.322588496821194,0.116466968435031,0.151415119479181,0.0858068059896841,0.0381239248266517,0.0392274705453595,0,0,0.0275601175941499,-0.0114843553337143,0.097301530937469,-0.0151726350782248,0.317910524511779,-0.0116312835876155,0.602597711978496,-0.00672086336939399,0.688842293451116,-0.00521685565773212,0.843265058193578,-0.00253418538589901,0.975484799558879,-0.000235565070856939,1,0],"CDpres":0.00225,"clcd":220.803768620681,"alpha":4.1,"n":11,"CL":1.1954428314197,"CD":0.00541405085106745,"CDp":0.000411744898560785,"CDf":0.00317,"Cpmin":-1.34706164733832,"good":126.034010773383,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt93.1064966059663>90.8851999406142) l1 Foil spline 17pts Re1700000 N12","xver":6.991,"iver":1.2020052,"id":512,"r":6,"Cm":-0.162839864202121},
             {"CDpres":0.00241,"clcd":222.52952918787,"alpha":4.3,"sym":4.6567204509656,"xy":[1,0,0.974015496570672,0.00895966283727706,0.851331789830318,0.0459815670027149,0.697513982916721,0.0981507626700499,0.517583389683761,0.12418499817229,0.322588496821194,0.120109491010118,0.151415119479181,0.0884904272096169,0.0381239248266517,0.0404543157955191,0,0,0.0275601175941499,-0.0113810594753383,0.097301530937469,-0.0150361650441053,0.317910524511779,-0.0115266661853073,0.602597711978496,-0.00666041266662517,0.688842293451116,-0.00516993272931945,0.843265058193578,-0.00251139169421027,0.975484799558879,-0.000233446284430491,1,0],"Bot_Xtr":1,"Re":1400000,"src":"retestc_5.txt","diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N11.dat","Top_Xtr":0.686029308070479,"Cm":-0.167315227089743,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt118.729498545856>117.637000763685) l1 Foil spline 17pts Re1125000 N11","xver":6.991,"good":129.318506029586,"id":513,"r":6,"CDf":0.00315,"Cpmin":-1.40280756136303,"n":12,"CL":1.23796926457676,"CD":0.00556316848867104,"CDp":0.000479659937696718},
             {"xy":[1,0,0.974015496570672,0.00879729845240936,0.851331789830318,0.0451483025175172,0.697513982916721,0.0963721033058923,0.517583389683761,0.121934554020068,0.322588496821194,0.117932902004615,0.151415119479181,0.0868868296143155,0.0381239248266517,0.0397212145372826,0,0,0.0275601175941499,-0.0115322688158462,0.097301530937469,-0.0152359363048578,0.317910524511779,-0.0116798100640394,0.602597711978496,-0.00674890325126829,0.688842293451116,-0.00523862072099233,0.843265058193578,-0.0025447581731977,0.975484799558879,-0.000236547863750873,1,0],"Bot_Xtr":1,"sym":4.45980267114393,"alpha":4.5,"clcd":224.75132307144,"CDpres":0.00243,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re750000-N9.dat","Top_Xtr":0.687569459107327,"diter":3,"src":"retest_142.txt","Re":1400000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt97.3534546799217>96.2578482600252) l1 Foil spline 17pts Re750000 N9","good":130.958298320713,"xver":6.991,"iver":1.2020052,"id":514,"Cm":-0.164082209419354,"CDp":0.000514366426871844,"n":13,"CD":0.00553157041499075,"CL":1.243227769432,"Cpmin":-1.41147922457342,"CDf":0.0031},
             {"CDpres":0.00275,"clcd":223.06838964957,"alpha":4.8,"sym":4.89170132608821,"xy":[1,0,0.974015496570672,0.0092724657961171,0.851331789830318,0.0475868919431478,0.697513982916721,0.101577437259618,0.517583389683761,0.128520589318669,0.322588496821194,0.12430279659037,0.151415119479181,0.0915798367067047,0.0381239248266517,0.0418666713616281,0,0,0.0275601175941499,-0.0128791513501293,0.097301530937469,-0.0170153794335391,0.317910524511779,-0.0130439243099182,0.602597711978496,-0.00753712455098425,0.688842293451116,-0.00585045234454443,0.843265058193578,-0.00284196684845375,0.975484799558879,-0.000264174880714808,1,0],"Bot_Xtr":1,"Re":1400000,"src":"retest_138.txt","diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N12.dat","Top_Xtr":0.683930695357785,"Cm":-0.170856658157348,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt119.239524084292>118.719041369408) l1 Foil spline 17pts Re1125000 N12","xver":6.991,"good":131.70125416043,"iver":1.2020052,"id":515,"r":6,"CDf":0.0031,"Cpmin":-1.49644873621504,"n":14,"CD":0.00584782470056951,"CL":1.30446483890902,"CDp":0.000588537375392597},
             {"CDp":0.00141016794971218,"CL":1.69673533527607,"CD":0.00794302326212871,"n":3,"Cpmin":-2.5430310801019,"CDf":0.00409,"r":6,"id":516,"good":83.5459242374406,"cmt":"OPT s(0) optbs_spline_Re1400000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1400000-N4.dat (opt86.2246580453185>79.3717073908791) l1 Foil spline 17pts Re1400000 N4","xver":6.991,"iver":1.2020052,"Cm":-0.171967834784156,"Top_Xtr":0.450513655010174,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1400000-N4.dat","diter":3,"src":"retestc_13.txt","Re":1700000,"xy":[1,0,0.765635949746012,0.0602400933292464,0.621358513547463,0.103789806117722,0.461002187731606,0.167010956266978,0.306366541357937,0.177060923970921,0.154893360815706,0.140995273436856,0.053110314474444,0.0855511184984756,0.00373230419095964,0.0326938587334048,0,0,0.0316932348546144,-0.00108105707892218,0.0662544378174111,0.00376781766486534,0.154080154125155,0.0140941160325535,0.300990909766017,0.0251610277943201,0.456034212256774,0.0310538729392919,0.568022360188196,0.0303827857662242,0.87958991122884,0.0178956071773471,1,0],"Bot_Xtr":1,"sym":13.4527364991675,"alpha":6.6,"clcd":213.613290466601,"CDpres":0.00386},
             {"Re":1700000,"src":"retestc_15.txt","diter":3,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1700000-N4.dat","Top_Xtr":0.477183376468142,"clcd":221.040046958255,"CDpres":0.00428,"alpha":7,"sym":14.7711420790784,"xy":[1,0,0.901061808611718,0.0309279022744031,0.678863215861058,0.0984103025323746,0.479050155772191,0.173757247262926,0.304112968064473,0.182329022083014,0.152671216420827,0.14331280171584,0.0512040607733385,0.0862059176432184,0.00202369805924237,0.0312902778334109,0,0,0.0230604239713358,-0.00527464897977672,0.0605603309266164,-0.0039058324312531,0.116429252189166,0.00154220450855022,0.334370367152041,0.0242735394021568,0.52103326718557,0.0338874168032558,0.687642492864678,0.036426309273113,0.866866720476992,0.0245013467517712,1,0],"Bot_Xtr":1,"CDf":0.00401,"Cpmin":-2.56491160058872,"n":4,"CL":1.83303443373716,"CD":0.0082927707397897,"CDp":0.00153875112074037,"Cm":-0.207684536885271,"cmt":"OPT s(0) optbs_spline_Re1700000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1700000-N4.dat (opt97.8132923084178>86.4551928921508) l1 Foil spline 17pts Re1700000 N4","xver":6.991,"good":97.8132923084208,"iver":1.2020052,"id":517,"r":6},
             {"CDf":0.00388,"Cpmin":-2.68389425646807,"CL":1.95476504662916,"CD":0.00872336650821739,"n":5,"CDp":0.00168414631161812,"Cm":-0.209365087694566,"id":518,"cmt":"OPT s(0) optbs_spline_Re1700000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1700000-N4.dat (opt97.8132923084178>86.4551928921508) l1 Foil spline 17pts Re1700000 N4","xver":6.991,"good":96.582417034922,"iver":1.2020052,"r":6,"Re":1700000,"src":"retestc_16.txt","diter":3,"Top_Xtr":0.477746749134347,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1700000-N4.dat","CDpres":0.00485,"clcd":224.083792052963,"alpha":8.1,"sym":14.7711420790784,"xy":[1,0,0.901061808611718,0.0309279022744031,0.678863215861058,0.0984103025323746,0.479050155772191,0.173757247262926,0.304112968064473,0.182329022083014,0.152671216420827,0.14331280171584,0.0512040607733385,0.0862059176432184,0.00202369805924237,0.0312902778334109,0,0,0.0230604239713358,-0.00527464897977672,0.0605603309266164,-0.0039058324312531,0.116429252189166,0.00154220450855022,0.334370367152041,0.0242735394021568,0.52103326718557,0.0338874168032558,0.687642492864678,0.036426309273113,0.866866720476992,0.0245013467517712,1,0],"Bot_Xtr":1},
             {"r":6,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","good":103.156228456776,"xver":6.991,"iver":1.2020052,"id":519,"Cm":-0.199871697651012,"CDp":0.000257134132509517,"n":6,"CL":1.74295260079772,"CD":0.00767652080495529,"Cpmin":-2.0984343595839,"CDf":0.00327,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"Bot_Xtr":1,"sym":7.45853331327074,"alpha":7.7,"clcd":227.04981137713,"CDpres":0.0044,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","Top_Xtr":0.564962412610746,"diter":4,"src":"retest_157.txt","Re":1700000},
             {"CL":1.28882098074002,"CD":0.0056883876854642,"n":7,"CDp":-0.000206516265845693,"CDf":0.00317,"Cpmin":-1.32258432307157,"id":520,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","xver":6.991,"iver":1.2020052,"good":115.35621004481,"r":6,"Cm":-0.195573827582768,"diter":3,"Top_Xtr":0.678826285090423,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","Re":1700000,"src":"retest_152.txt","sym":5.47077716158967,"Bot_Xtr":1,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"CDpres":0.00251,"clcd":226.570524374315,"alpha":4.1},
             {"CDf":0.0031,"Cpmin":-1.32864329548319,"CL":1.30031998782224,"CD":0.00560557667610087,"n":8,"CDp":-0.000154144483046067,"Cm":-0.198257186543351,"id":521,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","xver":6.991,"good":120.500352626217,"r":6,"Re":1700000,"src":"retest_153.txt","diter":3,"Top_Xtr":0.691265092484301,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","CDpres":0.00251,"clcd":231.968994977108,"alpha":4.1,"sym":5.47077716158967,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"Bot_Xtr":1},
             {"CDf":0.00304,"Cpmin":-1.45457783228222,"n":9,"CD":0.00565647826332625,"CL":1.32686946347907,"CDp":-0.000153381079461722,"Cm":-0.197302627369826,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","xver":6.991,"iver":1.2020052,"good":121.071484369364,"id":522,"r":6,"Re":1700000,"src":"retest_154.txt","diter":3,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","Top_Xtr":0.691411148396308,"clcd":234.575190022707,"CDpres":0.00261,"alpha":4.4,"sym":5.47077716158967,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"Bot_Xtr":1},
             {"xy":[1,0,0.974015496570672,0.00877310613780405,0.851331789830318,0.045024146000115,0.697513982916721,0.0961070828277349,0.517583389683761,0.121599237546713,0.322588496821194,0.117608589957792,0.151415119479181,0.0866478933626402,0.0381239248266517,0.0396119823538129,0,0,0.0275601175941499,-0.0121713355402773,0.097301530937469,-0.0160802437055496,0.317910524511779,-0.012327052864116,0.602597711978496,-0.00712289726434266,0.688842293451116,-0.00552892163559654,0.843265058193578,-0.00268577728194239,0.975484799558879,-0.000249656287676158,1,0],"Bot_Xtr":1,"sym":4.3801761329303,"alpha":3.6,"CDpres":0.00199,"clcd":228.772965118314,"Top_Xtr":0.673503688557829,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re750000-N8.dat","diter":4,"src":"retest_154.txt","Re":1700000,"r":6,"id":523,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt95.705087633908>94.0113567061005) l1 Foil spline 17pts Re750000 N8","xver":6.991,"good":126.216308944728,"iver":1.2020052,"Cm":-0.1673828441779,"CDp":0.000227655577234133,"CL":1.16292164938097,"CD":0.00508330015646537,"n":10,"Cpmin":-1.3010382159272,"CDf":0.00309},
             {"Cpmin":-1.31222669198452,"CDf":0.00302,"CDp":0.000264444151986953,"CL":1.17461729749806,"CD":0.00501613566023377,"n":11,"Cm":-0.167458250435829,"r":6,"id":524,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt106.371097408006>103.435945796923) l1 Foil spline 17pts Re2500000 N8","iver":1.2020052,"xver":6.991,"good":132.006486121389,"src":"retest_98.txt","Re":1700000,"Top_Xtr":0.683767148098557,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2500000-N8.dat","diter":4,"alpha":3.7,"clcd":234.167769187352,"CDpres":0.002,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00873878842681854,0.851331789830318,0.0448480252960529,0.697513982916721,0.0957311412808829,0.517583389683761,0.121123578478574,0.322588496821194,0.11714854108386,0.151415119479181,0.0863089532751484,0.0381239248266517,0.0394570323804935,0,0,0.0275601175941499,-0.011592186073838,0.097301530937469,-0.0153150964025716,0.317910524511779,-0.0117404938899264,0.602597711978496,-0.0067839679712922,0.688842293451116,-0.00526583859063042,0.843265058193578,-0.0025579797633657,0.975484799558879,-0.000237776875977878,1,0],"sym":4.38945009394052},
             {"diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2000000-N11.dat","Top_Xtr":0.684423613313445,"Re":1700000,"src":"retestc_13.txt","sym":4.09319052874792,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00846320583389907,0.851331789830318,0.0434337176718432,0.697513982916721,0.0927122060636893,0.517583389683761,0.117303878516693,0.322588496821194,0.113454196155042,0.151415119479181,0.0835871520397808,0.0381239248266517,0.0382127327406311,0,0,0.0275601175941499,-0.0115263293704991,0.097301530937469,-0.0152280893657654,0.317910524511779,-0.0116737946307672,0.602597711978496,-0.00674542737478173,0.688842293451116,-0.00523592268282107,0.843265058193578,-0.00254344755060187,0.975484799558879,-0.000236426034895584,1,0],"clcd":238.179955192686,"CDpres":0.00198,"alpha":4,"n":12,"CD":0.00494451177599593,"CL":1.17768359325642,"CDp":0.000284032988922896,"CDf":0.00296,"Cpmin":-1.31769767739946,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt134.538590751088>132.347645675625) l1 Foil spline 17pts Re2000000 N11","good":133.280092891683,"xver":6.991,"iver":1.2020052,"id":525,"r":6,"Cm":-0.16145952721327},
             {"xy":[1,0,0.974015496570672,0.00921203515624374,0.851331789830318,0.0472767580054294,0.697513982916721,0.100915435407547,0.517583389683761,0.127682993190498,0.322588496821194,0.123492688718185,0.151415119479181,0.0909829913525809,0.0381239248266517,0.041593817323082,0,0,0.0275601175941499,-0.0128393743290965,0.097301530937469,-0.0169628277484777,0.317910524511779,-0.0130036383906428,0.602597711978496,-0.00751384628103916,0.688842293451116,-0.00583238333055164,0.843265058193578,-0.00283318948634095,0.975484799558879,-0.00026335898147573,1,0],"Bot_Xtr":1,"sym":4.82435726239435,"alpha":4.2,"CDpres":0.00231,"clcd":238.398260968944,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2500000-N12.dat","Top_Xtr":0.683355728289698,"diter":3,"src":"retest_78.txt","Re":1700000,"r":6,"good":138.959426343028,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt137.866783744327>137.509823571918) l1 Foil spline 17pts Re2500000 N12","xver":6.991,"iver":1.2020052,"id":526,"Cm":-0.174809150110385,"CDp":0.000372486209943752,"n":13,"CL":1.26006981845373,"CD":0.00528556631802729,"Cpmin":-1.42411448067525,"CDf":0.00298},
             {"r":6,"id":527,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt118.729498545856>117.637000763685) l1 Foil spline 17pts Re1125000 N11","xver":6.991,"iver":1.2020052,"good":141.027274175253,"Cm":-0.169750691760657,"CDp":0.000383784709777233,"CL":1.25961867380447,"CD":0.00519437815969317,"n":14,"Cpmin":-1.42567894790481,"CDf":0.00294,"xy":[1,0,0.974015496570672,0.00895966283727706,0.851331789830318,0.0459815670027149,0.697513982916721,0.0981507626700499,0.517583389683761,0.12418499817229,0.322588496821194,0.120109491010118,0.151415119479181,0.0884904272096169,0.0381239248266517,0.0404543157955191,0,0,0.0275601175941499,-0.0113810594753383,0.097301530937469,-0.0150361650441053,0.317910524511779,-0.0115266661853073,0.602597711978496,-0.00666041266662517,0.688842293451116,-0.00516993272931945,0.843265058193578,-0.00251139169421027,0.975484799558879,-0.000233446284430491,1,0],"Bot_Xtr":1,"sym":4.6567204509656,"alpha":4.4,"CDpres":0.00225,"clcd":242.496528954849,"Top_Xtr":0.685182359087024,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1125000-N11.dat","diter":3,"src":"retest_26.txt","Re":1700000},
             {"CDp":-0.00158810833514202,"CL":1.58554627822315,"CD":0.00839029064419461,"n":3,"Cpmin":-2.28314403095028,"CDf":0.00335,"r":6,"id":528,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","good":85.8173388965658,"iver":1.2020052,"Cm":-0.175659118604213,"Top_Xtr":0.55525908706271,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","diter":3,"src":"retest_88.txt","Re":2000000,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.999002367743125,"sym":8.18651951349902,"alpha":7,"CDpres":0.00504,"clcd":188.973939695429},
             {"CDp":0.00137493829782914,"n":4,"CD":0.00783069210468059,"CL":1.81488418454785,"Cpmin":-2.65215493754572,"CDf":0.00374,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re2000000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re2000000-N4.dat (opt94.7537669898666>90.8061159440826) l1 Foil spline 17pts Re2000000 N4","iver":1.2020052,"good":94.4626261374827,"id":529,"Cm":-0.168581830520217,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re2000000-N4.dat","Top_Xtr":0.452644427064176,"diter":3,"src":"retestc_20.txt","Re":2000000,"xy":[1,0,0.846850991762938,0.0397799700830096,0.618759529220692,0.0991669041274397,0.458819286826548,0.164195565712566,0.307104890650506,0.174088423797879,0.152671216420827,0.137857092081296,0.0512771566887826,0.0829192658360667,0.00313253787259379,0.0316019457448973,0,0,0.0270180988871576,-0.00706119981313042,0.0567597507633455,-0.00493855033216721,0.124449942112133,0.00161907508125432,0.363725211219444,0.021187685255305,0.478543031346716,0.0246549544741675,0.677672510229979,0.0243400469170023,0.885059558802994,0.0170758798547109,1,0],"Bot_Xtr":1,"sym":11.8500849605087,"alpha":8,"CDpres":0.00409,"clcd":231.765488961448},
             {"Cm":-0.209737662890894,"r":6,"id":530,"good":102.605018451325,"cmt":"OPT s(0) optbs_spline_Re1700000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1700000-N4.dat (opt97.8132923084178>86.4551928921508) l1 Foil spline 17pts Re1700000 N4","xver":6.991,"iver":1.2020052,"Cpmin":-2.64713543952828,"CDf":0.00376,"CDp":0.00147091717578316,"CL":1.9164555750336,"CD":0.00805659266686702,"n":5,"alpha":7.7,"CDpres":0.00429,"clcd":237.874204924754,"Bot_Xtr":1,"xy":[1,0,0.901061808611718,0.0309279022744031,0.678863215861058,0.0984103025323746,0.479050155772191,0.173757247262926,0.304112968064473,0.182329022083014,0.152671216420827,0.14331280171584,0.0512040607733385,0.0862059176432184,0.00202369805924237,0.0312902778334109,0,0,0.0230604239713358,-0.00527464897977672,0.0605603309266164,-0.0039058324312531,0.116429252189166,0.00154220450855022,0.334370367152041,0.0242735394021568,0.52103326718557,0.0338874168032558,0.687642492864678,0.036426309273113,0.866866720476992,0.0245013467517712,1,0],"sym":14.7711420790784,"src":"retestc_14.txt","Re":2000000,"Top_Xtr":0.477597524589009,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1700000-N4.dat","diter":3},
             {"r":6,"id":531,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","iver":1.2020052,"xver":6.991,"good":103.409631633546,"Cm":-0.190217253629682,"CDp":-0.000280600130362427,"CL":1.27602073987099,"CD":0.00569266428251931,"n":6,"Cpmin":-1.31582186416139,"CDf":0.00316,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"Bot_Xtr":0.999664652823548,"sym":5.47077716158967,"alpha":4.2,"CDpres":0.00253,"clcd":224.151763839177,"Top_Xtr":0.649747230846656,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","diter":3,"src":"retest_67.txt","Re":2000000},
             {"Cm":-0.196345335018995,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","good":115.590753698114,"xver":6.991,"iver":1.2020052,"id":532,"r":6,"CDf":0.00307,"Cpmin":-1.32613374817325,"n":7,"CL":1.29229512570639,"CD":0.00547652247230515,"CDp":-0.000268345790262529,"CDpres":0.00241,"clcd":235.970021531281,"alpha":4.1,"sym":5.47077716158967,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"Bot_Xtr":0.999979780711977,"Re":2000000,"src":"retest_68.txt","diter":3,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","Top_Xtr":0.668960508755499},
             {"CDp":0.000252544780444394,"CL":1.22106282323361,"CD":0.00572817179751177,"n":8,"Cpmin":-1.40228337051878,"CDf":0.00324,"r":6,"id":533,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt131.021662043647>125.133857198571) l1 Foil spline 17pts Re7000000 N12","good":107.287210912452,"iver":1.2020052,"Cm":-0.166135525182899,"Top_Xtr":0.612212085276839,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re7000000-N12.dat","diter":4,"src":"retest_108.txt","Re":2000000,"xy":[1,0,0.974015496570672,0.00937186721760034,0.851331789830318,0.0480970264431963,0.697513982916721,0.102666353830059,0.517583389683761,0.129898338188176,0.322588496821194,0.125635330454297,0.151415119479181,0.0925615783650736,0.0381239248266517,0.0423154847342113,0,0,0.0275601175941499,-0.0131711763913486,0.097301530937469,-0.0174011903263034,0.317910524511779,-0.0133396854537009,0.602597711978496,-0.00770802316439744,0.688842293451116,-0.00598310693805146,0.843265058193578,-0.00290640630284801,0.975484799558879,-0.000270164846849422,1,0],"Bot_Xtr":0.999261187157704,"sym":4.98370417057805,"alpha":4.2,"clcd":213.167982106267,"CDpres":0.00249},
             {"Cm":-0.201276167280771,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re620000_N4_uag8814320.dat-s17_n17s0_nsopt-Re620000-N4.dat (opt85.6177898533729>76.0163133941937) l1 Foil spline 17pts Re620000 N4","good":126.292900221857,"iver":1.2020052,"id":534,"Cpmin":-1.33754822190305,"CDf":0.00293,"CDp":-0.000211696398490796,"n":9,"CD":0.00529133899903261,"CL":1.31352025049982,"alpha":4.1,"CDpres":0.00236,"clcd":248.239670665586,"Bot_Xtr":1,"xy":[1,0,0.975684982545889,0.0102985151882063,0.865913525083068,0.0476301484000466,0.706049671675894,0.103688090926302,0.524315099840515,0.128716375259973,0.309608254395688,0.115983403024972,0.144281161889507,0.0803455575350707,0.0377167939490664,0.0331457871688432,0,0,0.0198788695435254,-0.00605839998968194,0.0587243586091532,-0.00797789840736628,0.174625375197006,-0.00564007898042913,0.514991895804876,-0.000515329035384242,0.729975461206267,-0.00127073449861878,0.77568531251942,-0.00201881735415783,0.949012427936236,-0.00245766727808756,1,0],"sym":5.47077716158967,"src":"retest_70.txt","Re":2000000,"Foil_fn":"opt_spline_uag8814320_nsopt-Re620000-N4.dat","Top_Xtr":0.691919646629643,"diter":3},
             {"Cm":-0.161609399858444,"r":6,"id":535,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt127.491795627993>124.9513903682) l1 Foil spline 17pts Re2000000 N10","xver":6.991,"iver":1.2020052,"good":127.491795628044,"Cpmin":-1.28393670650286,"CDf":0.003,"CDp":0.000163580618984881,"CL":1.1477424902296,"CD":0.00485834875171501,"n":10,"alpha":3.7,"CDpres":0.00186,"clcd":236.241272268575,"Bot_Xtr":0.999388409951989,"xy":[1,0,0.974015496570672,0.00856041540063014,0.851331789830318,0.0439326034320699,0.697513982916721,0.0937771114386754,0.517583389683761,0.118651247283361,0.322588496821194,0.114757346931298,0.151415119479181,0.0845472457670921,0.0381239248266517,0.038651649537201,0,0,0.0275601175941499,-0.0114820339463911,0.097301530937469,-0.0151695681613881,0.317910524511779,-0.011628932500986,0.602597711978496,-0.00671950484934008,0.688842293451116,-0.00521580114990481,0.843265058193578,-0.00253367313896318,0.975484799558879,-0.000235517454969639,1,0],"sym":4.20192614023206,"src":"retestc_16.txt","Re":2000000,"Top_Xtr":0.658523993414648,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2000000-N10.dat","diter":3},
             {"n":11,"CD":0.00467925556663291,"CL":1.14451161855494,"CDp":0.000152173338076615,"CDf":0.0029,"Cpmin":-1.27121211063479,"good":134.538590740005,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt134.538590751088>132.347645675625) l1 Foil spline 17pts Re2000000 N11","xver":6.991,"iver":1.2020052,"id":536,"r":6,"Cm":-0.163390368265698,"diter":3,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2000000-N11.dat","Top_Xtr":0.677034541872521,"Re":2000000,"src":"retestc_17.txt","sym":4.09319052874792,"Bot_Xtr":0.999889187032851,"xy":[1,0,0.974015496570672,0.00846320583389907,0.851331789830318,0.0434337176718432,0.697513982916721,0.0927122060636893,0.517583389683761,0.117303878516693,0.322588496821194,0.113454196155042,0.151415119479181,0.0835871520397808,0.0381239248266517,0.0382127327406311,0,0,0.0275601175941499,-0.0115263293704991,0.097301530937469,-0.0152280893657654,0.317910524511779,-0.0116737946307672,0.602597711978496,-0.00674542737478173,0.688842293451116,-0.00523592268282107,0.843265058193578,-0.00254344755060187,0.975484799558879,-0.000236426034895584,1,0],"CDpres":0.00177,"clcd":244.592671260848,"alpha":3.6},
             {"id":537,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt100.927846482551>98.2743433305579) l1 Foil spline 17pts Re1000000 N7","xver":6.991,"iver":1.2020052,"good":140.253748950257,"r":6,"Cm":-0.178150948299513,"CD":0.00500116893114621,"CL":1.23570194019871,"n":12,"CDp":0.000210492723549068,"CDf":0.00293,"Cpmin":-1.38653574105043,"sym":4.95570466627733,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00926165417126666,0.851331789830318,0.0475314059877612,0.697513982916721,0.101458998737539,0.517583389683761,0.128370735285468,0.322588496821194,0.124157860471527,0.151415119479181,0.0914730553111074,0.0381239248266517,0.041817855140091,0,0,0.0275601175941499,-0.011995843221396,0.097301530937469,-0.0158483908208169,0.317910524511779,-0.0121493153360578,0.602597711978496,-0.00702019581847944,0.688842293451116,-0.00544920291651817,0.843265058193578,-0.00264705242043093,0.975484799558879,-0.000246056620186703,1,0],"clcd":247.082623524877,"CDpres":0.00207,"alpha":3.8,"diter":3,"Top_Xtr":0.674482639376077,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N7.dat","Re":2000000,"src":"retest_95.txt"},
             {"r":6,"id":538,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt93.2846644991083>92.4081269018146) l1 Foil spline 17pts Re750000 N7","xver":6.991,"good":142.821929688221,"iver":1.2020052,"Cm":-0.175389075865034,"CDp":0.000247189045285625,"CL":1.23047895049278,"CD":0.00489433108416712,"n":13,"Cpmin":-1.37771665025736,"CDf":0.00285,"xy":[1,0,0.974015496570672,0.00906196062162419,0.851331789830318,0.0465065658236099,0.697513982916721,0.0992714081380192,0.517583389683761,0.12560289194719,0.322588496821194,0.121480852302674,0.151415119479181,0.0895007748983505,0.0381239248266517,0.0409162067113182,0,0,0.0275601175941499,-0.0130514143977781,0.097301530937469,-0.0172429659443609,0.317910524511779,-0.0132183912521755,0.602597711978496,-0.00763793616584642,0.688842293451116,-0.00592870414263243,0.843265058193578,-0.00287997912560791,0.975484799558879,-0.000267708309962359,1,0],"Bot_Xtr":1,"sym":4.6329875345695,"alpha":3.9,"clcd":251.409013679787,"CDpres":0.00205,"Top_Xtr":0.683315778163295,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re750000-N7.dat","diter":3,"src":"retest_4.txt","Re":2000000},
             {"Cm":-0.178308345312185,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt137.866783744327>137.509823571918) l1 Foil spline 17pts Re2500000 N12","good":147.170586579014,"iver":1.2020052,"id":539,"Cpmin":-1.40852132404145,"CDf":0.00282,"CDp":0.000291626643686462,"n":14,"CD":0.00494611326069111,"CL":1.25521436299253,"alpha":4,"CDpres":0.00213,"clcd":253.777925582144,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00921203515624374,0.851331789830318,0.0472767580054294,0.697513982916721,0.100915435407547,0.517583389683761,0.127682993190498,0.322588496821194,0.123492688718185,0.151415119479181,0.0909829913525809,0.0381239248266517,0.041593817323082,0,0,0.0275601175941499,-0.0128393743290965,0.097301530937469,-0.0169628277484777,0.317910524511779,-0.0130036383906428,0.602597711978496,-0.00751384628103916,0.688842293451116,-0.00583238333055164,0.843265058193578,-0.00283318948634095,0.975484799558879,-0.00026335898147573,1,0],"sym":4.82435726239435,"src":"retest_88.txt","Re":2000000,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2500000-N12.dat","Top_Xtr":0.687002357902575,"diter":4},
             {"alpha":7.2,"CDpres":0.0047,"clcd":204.657557037956,"Bot_Xtr":0.998077707184639,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"sym":8.18651951349902,"src":"retest_96.txt","Re":2500000,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.547979764634703,"diter":3,"Cm":-0.176389856579732,"r":6,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","good":93.5679015055435,"xver":6.991,"iver":1.2020052,"id":540,"Cpmin":-2.30452749290105,"CDf":0.00317,"CDp":-0.00179480919811954,"n":3,"CL":1.61026054625829,"CD":0.00786807274338594},
             {"Cm":-0.180492301327539,"r":6,"id":541,"good":103.689308581218,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"iver":1.2020052,"Cpmin":-2.30736228717105,"CDf":0.00313,"CDp":-0.00155873078299584,"CL":1.61058843647949,"CD":0.00758512070083966,"n":4,"alpha":7,"clcd":212.33524158702,"CDpres":0.00445,"Bot_Xtr":0.997965713542498,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"sym":8.18651951349902,"src":"retest_97.txt","Re":2500000,"Top_Xtr":0.557034214986299,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","diter":3},
             {"Re":2500000,"src":"retest_98.txt","diter":3,"Top_Xtr":0.557207895882518,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","CDpres":0.00473,"clcd":215.976853329273,"alpha":7.5,"sym":8.18651951349902,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":1,"CDf":0.00308,"Cpmin":-2.35277596561345,"CD":0.00781103630583971,"CL":1.68700304257596,"n":5,"CDp":-0.00146837732392875,"Cm":-0.186663502905172,"id":542,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"good":104.53234796262,"r":6},
             #{"Re":2500000,"n":6,"Cm":-0.16881655638389,"id":543,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","xver":6.991,"good":115.523532215484,"r":6,"CDf":0.0028,"Cpmin":-1.20498529493497,"CL":1.01310874720074,"CD":0.00419388345951768,"CDp":-0.000253976772385173,"clcd":241.568168734296,"CDpres":0.0014,"alpha":2.4,"sym":5.39797390759795,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"Bot_Xtr":0.979637622656368,"src":"retest_84.txt","diter":3,"Top_Xtr":0.690468054993355,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat"},        #dud
             {"Bot_Xtr":1,"CD":0.0051599407242987,"CDf":0.00305,"CDp":0.000326436297499276,"CDpres":0.00211,"CL":1.33028484985146,"Cm":-0.135981312895173,"Cpmin":-1.85927903878955,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re2500000-ncrit6_n17sopt-bs-Re2500000-N6.dat.dat","Re":2500000,"Top_Xtr":0.565497687075387,"alpha":5.4,"clcd":257.810103047697,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt119.22066506319>0) l2 Foil spline 17pts Re2500000 N6","diter":4,"good":119.220665062549,"id":54,"iver":1.2020062,"n":6,"r":6,"src":"","sym":6.87744458608145,"xver":6.991,"xy":[1,0,0.914540882437793,0.0135495624535303,0.860288441834584,0.0288134581157654,0.726679316478324,0.0715651546153428,0.565012036583547,0.137772495778621,0.364439119915556,0.150540383320422,0.152957635685567,0.103312844130738,0.0376183021737033,0.0445736744501754,0,0,0.025868909344491,-0.0116213894666829,0.113640001165314,-0.00972321570605014,0.304522358309845,-0.00366455897488807,0.488542070561214,-0.00166224571370216,0.699508183364542,-0.00270126118894728,0.901529132471467,-0.00238185829419947,0.97406909536564,-0.00319830858667064,1,0]},        #2500000 6
             {"diter":3,"Top_Xtr":0.5686052767503,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Re":2500000,"src":"retest_100.txt","sym":8.18651951349902,"Bot_Xtr":0.999927706101586,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"CDpres":0.00458,"clcd":218.987930589204,"alpha":7.1,"CD":0.00765107594548775,"CL":1.6754932880832,"n":7,"CDp":-0.00100851060723911,"CDf":0.00307,"Cpmin":-2.34761739015401,"id":544,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","iver":1.2020052,"good":113.96794596321,"r":6,"Cm":-0.192580889575162},
             #{"Re":2500000,"n":8,"src":"retest_86.txt","diter":3,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","Top_Xtr":0.695875789857475,"clcd":253.728285450552,"CDpres":0.00163,"alpha":3,"sym":5.39797390759795,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"Bot_Xtr":0.991792775402954,"CDf":0.00274,"Cpmin":-1.25431182464055,"CD":0.0043704596952398,"CL":1.10890924510394,"CDp":-0.00012687261823084,"Cm":-0.176429152548331,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","good":127.532884592549,"iver":1.2020052,"id":545,"r":6},        #dud
             {"Bot_Xtr":1,"CD":0.00472756575199643,"CDf":0.0027,"CDp":-0.000162565894637923,"CDpres":0.00202,"CL":1.41077693060731,"Cm":-0.223451724843004,"Cpmin":-1.51906703834548,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re2500000-ncrit8_n17sopt-bs-Re2500000-N8.dat.dat","Re":2500000,"Top_Xtr":0.691703838693966,"alpha":3.6,"clcd":298.415083917458,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt175.857140174206>103.435945818866) l2 Foil spline 17pts Re2500000 N8","diter":3,"good":164.554620164012,"id":114,"iver":1.2020062,"n":8,"r":6,"src":"","sym":8.95974233615012,"xver":6.991,"xy":[1,0,0.963469574752431,0.0151922014480626,0.851343610879711,0.0459278771482619,0.696716637822175,0.116685493426653,0.505990148139965,0.145316717725711,0.298155119435703,0.131590206337969,0.130079081674798,0.0869465023729029,0.0379697510815565,0.0370704139103626,0,0,0.00774054450909626,-0.0145307368349926,0.0605730252675436,-0.00998482091749702,0.253634518731201,0.0066980411649567,0.530932619789159,0.00900338322194188,0.787648975610836,0.00788887713643596,0.944386065798022,-0.000434500152362179,0.97964665211675,0.000735770683440852,1,0]},        #2500000 8
             #{"Re":2500000,"n":9,"alpha":4,"CDpres":0.00191,"clcd":265.70598209278,"Bot_Xtr":0.998319769072394,"xy":[1,0,0.978729034269986,0.00971453932802185,0.838508040895179,0.0539943469946864,0.687958728448683,0.107894286674946,0.501238958008392,0.13176676019561,0.309834288258803,0.120013868388113,0.14596664009541,0.0860132512421005,0.0381239248266517,0.0403318444365042,0,0,0.0626721694100601,-0.00841195200984046,0.144487210364279,-0.00936217631752345,0.246121873633498,-0.00811440263168432,0.488403057267002,-0.00673676678989927,0.697377306836287,-0.0026996453936463,0.823248300493309,-0.00109149494786857,0.975484799558879,-0.000250767408785219,1,0],"sym":5.39797390759795,"src":"retest_87.txt","Top_Xtr":0.669147762881901,"Foil_fn":"opt_spline_uag8814320_nsopt-Re750000-N4.dat","diter":9,"Cm":-0.185003544368096,"r":6,"id":546,"good":139.959882898225,"cmt":"OPT s(0) optbs_spline_Re750000_N4_uag8814320.dat-s17_n17s0_nsopt-Re750000-N4.dat (opt91.165687507783>75.6214681331835) l1 Foil spline 17pts Re750000 N4","xver":6.991,"iver":1.2020052,"Cpmin":-1.32604024308614,"CDf":0.00279,"CDp":-0.000158056348046255,"CD":0.00470235859017112,"CL":1.24944480735384,},        #dud
             {"Bot_Xtr":1,"CD":0.00493863798652575,"CDf":0.0027,"CDp":-1.69266993524396e-05,"CDpres":0.00223,"CL":1.45274899084512,"Cm":-0.211761238465783,"Cpmin":-1.57679013559863,"Foil_fn":"opt_spline_foil_uag8814320.dat-s17_n17s0.dat-re2500000-ncrit9_n17sopt-Re2500000-N9.dat","Re":2500000,"Top_Xtr":0.669061579542101,"alpha":4.6,"clcd":294.159846258968,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt170.082992042105>0) l2 Foil spline 17pts Re2500000 N9","diter":4,"good":170.083059785367,"id":121,"iver":1.2020062,"n":9,"r":6,"src":"","sym":7.7142125199217,"xver":6.991,"xy":[1,0,0.950536807209898,0.0193841702125242,0.843341653367678,0.0502466449140761,0.678972841830975,0.123071290933979,0.502017911838594,0.151068554362607,0.312205491622913,0.139926510910021,0.150593472579159,0.102375129572307,0.0433014332477702,0.0494636097482031,0,0,0.0481706741288547,-0.0137042201926486,0.151691298977404,-0.0120200088004133,0.313039327904467,-0.00374200421469612,0.529246780612986,0.00300686388142348,0.779896006319852,0.00692221440303021,0.921787715376045,0.00254399263832325,0.966127241664985,-0.000261817819029945,1,0]},        #2500000 9
             {"CL":1.15018544606611,"CD":0.00475653978064042,"n":10,"CDp":0.000147842597310959,"CDf":0.00291,"Cpmin":-1.29330957163953,"id":547,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt86.6346402153256>80.8406217418239) l1 Foil spline 17pts Re750000 N5","xver":6.991,"iver":1.2020052,"good":125.178309537003,"r":6,"Cm":-0.159357089039531,"diter":3,"Top_Xtr":0.636851047026266,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re750000-N5.dat","Re":2500000,"src":"retest_157.txt","sym":4.37405607693817,"Bot_Xtr":0.997813551982576,"xy":[1,0,0.974015496570672,0.00867432273463055,0.851331789830318,0.0445171832098545,0.697513982916721,0.0950249364862137,0.517583389683761,0.120230054691805,0.322588496821194,0.116284340988729,0.151415119479181,0.085672255583987,0.0381239248266517,0.0391659594330942,0,0,0.0275601175941499,-0.0109063284934043,0.097301530937469,-0.0144089709404827,0.317910524511779,-0.0110458616021809,0.602597711978496,-0.00638259105852583,0.688842293451116,-0.00495428257421387,0.843265058193578,-0.00240663559065095,0.975484799558879,-0.000223708686267799,1,0],"clcd":241.811379513207,"CDpres":0.00185,"alpha":3.8},
             {"Top_Xtr":0.647418312268261,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re2000000-N10.dat","diter":3,"src":"retestc_6.txt","Re":2500000,"xy":[1,0,0.974015496570672,0.00856041540063014,0.851331789830318,0.0439326034320699,0.697513982916721,0.0937771114386754,0.517583389683761,0.118651247283361,0.322588496821194,0.114757346931298,0.151415119479181,0.0845472457670921,0.0381239248266517,0.038651649537201,0,0,0.0275601175941499,-0.0114820339463911,0.097301530937469,-0.0151695681613881,0.317910524511779,-0.011628932500986,0.602597711978496,-0.00671950484934008,0.688842293451116,-0.00521580114990481,0.843265058193578,-0.00253367313896318,0.975484799558879,-0.000235517454969639,1,0],"Bot_Xtr":0.998508770677882,"sym":4.20192614023206,"alpha":3.8,"clcd":249.008692859325,"CDpres":0.00179,"CDp":0.0001318276374559,"CL":1.15305216842457,"CD":0.00463056994189347,"n":11,"Cpmin":-1.29407922348145,"CDf":0.00284,"r":6,"id":548,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt127.491795627993>124.9513903682) l1 Foil spline 17pts Re2000000 N10","xver":6.991,"good":132.20143174902,"iver":1.2020052,"Cm":-0.160402360387051},
             {"id":549,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt110.605064440281>108.64341190758) l1 Foil spline 17pts Re1000000 N9","good":139.872012920373,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.174647152749698,"CD":0.00483793370028088,"CL":1.25286721331803,"n":12,"CDp":0.000139961785358595,"CDf":0.00284,"Cpmin":-1.40812539391949,"sym":4.9081464737037,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00912943962192423,0.851331789830318,0.0468528724012037,0.697513982916721,0.10001062293482,0.517583389683761,0.126538181553632,0.322588496821194,0.122385447545498,0.151415119479181,0.0901672336337601,0.0381239248266517,0.0412208852284992,0,0,0.0275601175941499,-0.0107529390000682,0.097301530937469,-0.0142063193558187,0.317910524511779,-0.0108905096782366,0.602597711978496,-0.00629282460694401,0.688842293451116,-0.00488460423155603,0.843265058193578,-0.00237278803011601,0.975484799558879,-0.000220562388037167,1,0],"clcd":258.967420997376,"CDpres":0.002,"alpha":4.1,"diter":3,"Top_Xtr":0.648978480647889,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N9.dat","Re":2500000,"src":"retest_64.txt"},
             {"Cpmin":-1.3897029440052,"CDf":0.00276,"CDp":0.000119200726752488,"n":13,"CD":0.00466949569815186,"CL":1.24409740357873,"Cm":-0.177306027590188,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt110.605064440281>108.64341190758) l1 Foil spline 17pts Re1000000 N9","xver":6.991,"good":146.996249628904,"iver":1.2020052,"id":550,"src":"retest_65.txt","Re":2500000,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N9.dat","Top_Xtr":0.666740917320092,"diter":3,"alpha":3.9,"clcd":266.430784821395,"CDpres":0.0019,"Bot_Xtr":1,"xy":[1,0,0.974015496570672,0.00912943962192423,0.851331789830318,0.0468528724012037,0.697513982916721,0.10001062293482,0.517583389683761,0.126538181553632,0.322588496821194,0.122385447545498,0.151415119479181,0.0901672336337601,0.0381239248266517,0.0412208852284992,0,0,0.0275601175941499,-0.0107529390000682,0.097301530937469,-0.0142063193558187,0.317910524511779,-0.0108905096782366,0.602597711978496,-0.00629282460694401,0.688842293451116,-0.00488460423155603,0.843265058193578,-0.00237278803011601,0.975484799558879,-0.000220562388037167,1,0],"sym":4.9081464737037},
             {"r":6,"id":551,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt110.605064440281>108.64341190758) l1 Foil spline 17pts Re1000000 N9","iver":1.2020052,"xver":6.991,"good":152.20339193375,"Cm":-0.178574220460321,"CDp":0.000127859809044357,"CD":0.00458407210816008,"CL":1.24981291639833,"n":14,"Cpmin":-1.3939065470369,"CDf":0.0027,"xy":[1,0,0.974015496570672,0.00912943962192423,0.851331789830318,0.0468528724012037,0.697513982916721,0.10001062293482,0.517583389683761,0.126538181553632,0.322588496821194,0.122385447545498,0.151415119479181,0.0901672336337601,0.0381239248266517,0.0412208852284992,0,0,0.0275601175941499,-0.0107529390000682,0.097301530937469,-0.0142063193558187,0.317910524511779,-0.0108905096782366,0.602597711978496,-0.00629282460694401,0.688842293451116,-0.00488460423155603,0.843265058193578,-0.00237278803011601,0.975484799558879,-0.000220562388037167,1,0],"Bot_Xtr":1,"sym":4.9081464737037,"alpha":3.9,"clcd":272.642507994922,"CDpres":0.00188,"Top_Xtr":0.676108606044789,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N9.dat","diter":3,"src":"retest_66.txt","Re":2500000},
             {"Re":3000000,"n":3,"r":6,"id":552,"good":97.2552373370266,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"iver":1.2020052,"Cm":-0.156718144099726,"CDp":-0.00262968357478871,"CL":1.50658861648397,"CD":0.00695876181419754,"Cpmin":-2.36979717696649,"CDf":0.00295,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.970008237939602,"sym":7.61567438822719,"alpha":6,"clcd":216.502397511317,"CDpres":0.00401,"Top_Xtr":0.558736746281061,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":3,"src":"retest_159.txt",},        #dud
             {"Cm":-0.178451335761057,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"good":109.412954632038,"iver":1.2020052,"id":553,"r":6,"CDf":0.00301,"Cpmin":-2.28616410858732,"n":4,"CL":1.56401728571433,"CD":0.00689405064152703,"CDp":-0.00162690717946061,"clcd":226.86478052443,"CDpres":0.00389,"alpha":6.6,"sym":8.18651951349902,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.992869655555166,"Re":3000000,"src":"retest_105.txt","diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.555832458711091},
             {"r":6,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","good":115.301483878667,"xver":6.991,"iver":1.2020052,"id":554,"Cm":-0.184488901448766,"CDp":-0.00154395175496723,"n":5,"CL":1.64014753243169,"CD":0.00709720915908386,"Cpmin":-2.3318831433056,"CDf":0.00297,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.997585254489153,"sym":8.18651951349902,"alpha":7.1,"CDpres":0.00413,"clcd":231.097533645663,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.556080825267719,"diter":4,"src":"retestc_15.txt","Re":3000000},
             {"r":6,"id":555,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"good":115.974784646354,"iver":1.2020052,"Cm":-0.191571458287058,"CDp":-0.00148576152750266,"CD":0.00736868367450977,"CL":1.74014019943564,"n":6,"Cpmin":-2.39011218517405,"CDf":0.0029,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.999948523677758,"sym":8.18651951349902,"alpha":7.8,"clcd":236.153467335726,"CDpres":0.00447,"Top_Xtr":0.556576829637036,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","diter":3,"src":"retest_107.txt","Re":3000000},
             {"Cpmin":-2.05124751354623,"CDf":0.0029,"CDp":6.91148739937853e-05,"CL":1.69523101971339,"CD":0.0060387644544222,"n":7,"Cm":-0.204377487363846,"r":6,"id":556,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","good":125.374664144297,"xver":6.991,"iver":1.2020052,"src":"retest_152.txt","Re":3000000,"Top_Xtr":0.562055902689346,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","diter":3,"alpha":7,"CDpres":0.00314,"clcd":280.724812585125,"Bot_Xtr":1,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"sym":7.45853331327074},
             {"alpha":7.4,"clcd":284.856128024149,"CDpres":0.00328,"Bot_Xtr":1,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"sym":7.45853331327074,"src":"retest_153.txt","Re":3000000,"Top_Xtr":0.565126908773704,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","diter":3,"Cm":-0.205467395086187,"r":6,"id":557,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","good":124.772152659535,"iver":1.2020052,"Cpmin":-2.09309393181939,"CDf":0.00283,"CDp":7.63431447165798e-05,"CL":1.74080266738055,"CD":0.00611116453577918,"n":8},
             {"Cm":-0.204967751512212,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","good":133.259863086852,"iver":1.2020052,"id":558,"Cpmin":-2.05329315980481,"CDf":0.00282,"CDp":0.000132718925335391,"n":9,"CL":1.69824362869382,"CD":0.00590334107474626,"alpha":7,"clcd":287.674997461808,"CDpres":0.00308,"Bot_Xtr":1,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"sym":7.45853331327074,"src":"retest_154.txt","Re":3000000,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","Top_Xtr":0.574660170661387,"diter":2},
             {"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"Bot_Xtr":1,"sym":7.45853331327074,"alpha":7.4,"clcd":290.501543707905,"CDpres":0.00324,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","Top_Xtr":0.576015141014498,"diter":3,"src":"retest_155.txt","Re":3000000,"r":6,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","xver":6.991,"iver":1.2020052,"good":132.557665793952,"id":559,"Cm":-0.205998805210263,"CDp":0.000154898544449054,"n":10,"CL":1.74347739229821,"CD":0.00600161145460643,"Cpmin":-2.09485270341364,"CDf":0.00276},
             {"Cm":-0.221621101174264,"id":560,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt128.162697515514>122.029638202223) l1 Foil spline 17pts Re3000000 N11","iver":1.2020052,"xver":6.991,"good":128.162697515579,"r":6,"CDf":0.00312,"Cpmin":-2.26314761073135,"CD":0.00696362828355629,"CL":1.79676637571531,"n":11,"CDp":0.000795991753103921,"clcd":258.021580496786,"CDpres":0.00385,"alpha":6.8,"sym":10.8152942217779,"xy":[1,0,0.961949581813749,0.0147246089265681,0.875758074483928,0.0468985981683136,0.633981356955415,0.138742412802236,0.482035828487994,0.176446237792048,0.31379187525767,0.17241467553273,0.149809351404668,0.127553558549731,0.0348482227959868,0.0596295930279232,0,0,0.0373050544485358,-0.0175533236126329,0.146509500030206,-0.0134122347247411,0.314465462409945,-0.00253111992088943,0.501550924851073,0.00634824589401479,0.665300856013736,0.010103006926193,0.892216666431326,0.0114140333927232,0.964324033244839,0.00745309187906392,1,0],"Bot_Xtr":1,"Re":3000000,"src":"retestc_13.txt","diter":3,"Top_Xtr":0.542354535510502,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re3000000-N11.dat"},
             {"diter":3,"Foil_fn":"optbs-spline_foil_uag8814320.dat-s17_n17s0-Re1700000-N10-sq1.dat","Top_Xtr":0.664275777725981,"Re":3000000,"src":"retest_107.txt","sym":3.91053980082547,"Bot_Xtr":0.99565626280621,"xy":[1,0,0.974015496570672,0.00827498420643977,0.851331789830318,0.0424677521515369,0.697513982916721,0.0906502873708044,0.517583389683761,0.114695041232686,0.322588496821194,0.110930975774787,0.151415119479181,0.0817281744726043,0.0381239248266517,0.0373628818818348,0,0,0.0275601175941499,-0.0113037155920848,0.097301530937469,-0.0149339816405064,0.317910524511779,-0.0114483327818425,0.602597711978496,-0.0066151495537468,0.688842293451116,-0.00513479868276505,0.843265058193578,-0.00249432467277684,0.975484799558879,-0.000231859820340036,1,0],"CDpres":0.00151,"clcd":260.66635024008,"alpha":3.4,"n":12,"CD":0.00412780557781734,"CL":1.07598001447029,"CDp":7.31070517001943e-05,"CDf":0.00262,"Cpmin":-1.20013439642685,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt88.6273130329391>86.2201920365682) l1 Foil spline 17pts Re1700000 N10","xver":6.991,"iver":1.2020052,"good":136.382632597491,"id":561,"r":6,"Cm":-0.152818410096973},
             {"alpha":4,"clcd":270.021542941142,"CDpres":0.00189,"Bot_Xtr":0.998651098040266,"xy":[1,0,0.974015496570672,0.00912943962192423,0.851331789830318,0.0468528724012037,0.697513982916721,0.10001062293482,0.517583389683761,0.126538181553632,0.322588496821194,0.122385447545498,0.151415119479181,0.0901672336337601,0.0381239248266517,0.0412208852284992,0,0,0.0275601175941499,-0.0107529390000682,0.097301530937469,-0.0142063193558187,0.317910524511779,-0.0108905096782366,0.602597711978496,-0.00629282460694401,0.688842293451116,-0.00488460423155603,0.843265058193578,-0.00237278803011601,0.975484799558879,-0.000220562388037167,1,0],"sym":4.9081464737037,"src":"retest_76.txt","Re":3000000,"Top_Xtr":0.648597600374384,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N9.dat","diter":3,"Cm":-0.173036432350808,"r":6,"id":562,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt110.605064440281>108.64341190758) l1 Foil spline 17pts Re1000000 N9","good":146.822109446433,"iver":1.2020052,"Cpmin":-1.38976141384997,"CDf":0.00269,"CDp":0.000106710794198395,"CL":1.23561908942354,"CD":0.00457600188475657,"n":13},
             {"src":"retest_111.txt","Re":3000000,"Top_Xtr":0.645733109280803,"Foil_fn":"optbs_spline_uag8814320.dat-s17_n17s0_nsopt-Re1000000-N11.dat","diter":4,"alpha":4.2,"clcd":273.481888163545,"CDpres":0.00193,"Bot_Xtr":0.99975057241443,"xy":[1,0,0.974015496570672,0.00904902008131296,0.851331789830318,0.0464401541369004,0.697513982916721,0.0991296479039594,0.517583389683761,0.125423530178329,0.322588496821194,0.121307376833964,0.151415119479181,0.0893729671938351,0.0381239248266517,0.0408577780947706,0,0,0.0275601175941499,-0.0123955602783233,0.097301530937469,-0.0163764797612118,0.317910524511779,-0.0125541462829269,0.602597711978496,-0.00725411784962196,0.688842293451116,-0.00563077742630382,0.843265058193578,-0.00273525564078811,0.975484799558879,-0.000254255545951512,1,0],"sym":4.67341510278795,"Cpmin":-1.42140412932865,"CDf":0.00267,"CDp":0.000115611129791155,"CD":0.0046023213658725,"CL":1.25865153707424,"n":14,"Cm":-0.174347869308171,"r":6,"id":563,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_uag8814320.dat-s17_n17s0.dat (opt112.521751676841>111.955804802133) l1 Foil spline 17pts Re1000000 N11","iver":1.2020052,"good":150.18290130128},
             {"Re":4000000,"n":3,"Top_Xtr":0.55979523197211,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":6,"src":"retest_105.txt","xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.953974916027346,"sym":7.61567438822719,"alpha":5,"clcd":243.346736624669,"CDpres":0.00302,"CDp":-0.00258014353116517,"CL":1.40796540773806,"CD":0.00578584051410421,"Cpmin":-2.32165299819416,"CDf":0.00277,"r":6,"id":564,"good":103.861910339742,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"iver":1.2020052,"Cm":-0.156535122602848},        #dud
             {"Cpmin":-2.2986521755728,"CDf":0.00282,"CDp":-0.00167764517532318,"n":4,"CD":0.00631117029530803,"CL":1.57111133284303,"Cm":-0.179740244545887,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","iver":1.2020052,"good":119.102205392528,"id":565,"src":"retestc_12.txt","Re":4000000,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.547126314024863,"diter":3,"alpha":6.6,"clcd":248.941362588655,"CDpres":0.00349,"Bot_Xtr":0.986160963994466,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"sym":8.18651951349902},
             {"r":6,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"iver":1.2020052,"good":117.382017352165,"id":566,"Cm":-0.186776054726029,"CDp":-0.00176442555258858,"n":5,"CL":1.71046572342584,"CD":0.00671679443682619,"Cpmin":-2.37932711616068,"CDf":0.00275,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.997827002470591,"sym":8.18651951349902,"alpha":7.7,"CDpres":0.00396,"clcd":254.655064929167,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.545357373974115,"diter":3,"src":"retestc_13.txt","Re":4000000},
             #{"Re":4000000,"n":6,"CDp":-0.00269269617375462,"CL":1.6860428146137,"CD":0.00678376107925189,"Cpmin":-2.48230436466353,"CDf":0.0026,"r":6,"id":567,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"good":113.737394179864,"Cm":-0.165562862404475,"Top_Xtr":0.560289668096686,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":3,"src":"retest_108.txt","xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.981551718169017,"sym":7.61567438822719,"alpha":7.4,"CDpres":0.00418,"clcd":248.541007697111},        #dud
             {"Bot_Xtr":0.982915179452719,"CD":0.0055343818826539,"CDf":0.00243,"CDp":-0.000291974953128749,"CDpres":0.0031,"CL":1.58890247051145,"Cm":-0.171782103286142,"Cpmin":-2.2111743037591,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re4000000-ncrit6_n17sopt-Re4000000-N6.dat","Re":4000000,"Top_Xtr":0.593154141030676,"alpha":7.2,"clcd":287.09664497339,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt146.606452318157>0) l2 Foil spline 17pts Re4000000 N6","diter":3,"good":146.606452621246,"id":92,"iver":1.2020062,"n":6,"r":6,"src":"","sym":7.00721087375995,"xver":6.991,"xy":[1,0,0.919827083757589,0.0250164222110382,0.785103795349473,0.071320571863642,0.604771540322834,0.163307123772834,0.460103636102453,0.186943609474452,0.306004858531156,0.17161566459391,0.151660152824606,0.123838597896869,0.0456809249194365,0.0608084681814085,0,0,0.0455552587490602,-0.0285881171628368,0.147857189198213,-0.037320715671361,0.282156630881908,-0.0376798800357604,0.408211254394084,-0.0344368338119864,0.535405925178742,-0.0276842615319615,0.749657628323859,-0.0150034527643307,0.942129734163041,-0.00411522562392067,1,0]},        #4000000 6
             {"diter":3,"Top_Xtr":0.457380122201298,"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re6000000-N9.dat","Re":4000000,"src":"retest_70.txt","sym":15.1742724409482,"Bot_Xtr":1,"xy":[1,0,0.868661556886963,0.0519317830051054,0.620673721871338,0.114830004405135,0.458819286826548,0.187063560875754,0.307104890650506,0.198334226150094,0.152671216420827,0.157056851229756,0.0512771566887826,0.0944676737473603,0.00313253787259379,0.0360032408670003,0,0,0.0270184392679959,-0.0072566067513566,0.0616968952329497,-0.00556685533673372,0.131064062193512,0.0022790560621164,0.371929606347149,0.0199989741905834,0.479146297313775,0.0253536082353589,0.695690242780121,0.0229338297286667,0.878350726809458,0.0159228469407132,1,0],"clcd":282.221866795088,"CDpres":0.0037,"alpha":8.2,"CL":1.96327349291889,"CD":0.00695648964133724,"n":7,"CDp":9.35723450695204e-06,"CDf":0.00325,"Cpmin":-3.06621522048274,"id":568,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt135.600565624712>111.833597520828) l1 Foil spline 17pts Re6000000 N9","good":117.528659666381,"iver":1.2020052,"r":6,"Cm":-0.198086664691096},
             {"r":6,"id":569,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt128.162697515514>122.029638202223) l1 Foil spline 17pts Re3000000 N11","iver":1.2020052,"xver":6.991,"good":121.216260280154,"Cm":-0.227443948838646,"CDp":0.000719155167277468,"CD":0.00627825148297792,"CL":1.73253562839156,"n":8,"Cpmin":-2.19966922646877,"CDf":0.00309,"xy":[1,0,0.961949581813749,0.0147246089265681,0.875758074483928,0.0468985981683136,0.633981356955415,0.138742412802236,0.482035828487994,0.176446237792048,0.31379187525767,0.17241467553273,0.149809351404668,0.127553558549731,0.0348482227959868,0.0596295930279232,0,0,0.0373050544485358,-0.0175533236126329,0.146509500030206,-0.0134122347247411,0.314465462409945,-0.00253111992088943,0.501550924851073,0.00634824589401479,0.665300856013736,0.010103006926193,0.892216666431326,0.0114140333927232,0.964324033244839,0.00745309187906392,1,0],"Bot_Xtr":0.944875963237284,"sym":10.8152942217779,"alpha":5.9,"clcd":275.958303532272,"CDpres":0.00318,"Top_Xtr":0.530474159611531,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re3000000-N11.dat","diter":3,"src":"retest_81.txt","Re":4000000},
             {"Cpmin":-2.376449001945,"CDf":0.00302,"CDp":0.000522443574496386,"n":9,"CD":0.00672561052312609,"CL":1.84945980294887,"Cm":-0.232509076385051,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt105.585227131506>101.243646320523) l1 Foil spline 17pts Re2500000 N6","xver":6.991,"good":124.482410222154,"iver":1.2020052,"id":570,"src":"retest_153.txt","Re":4000000,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re2500000-N6.dat","Top_Xtr":0.52829611487858,"diter":4,"alpha":6.8,"CDpres":0.00371,"clcd":274.987645595813,"Bot_Xtr":0.963405510416518,"xy":[1,0,0.961949581813749,0.0153950944786205,0.875758074483928,0.0490341273793225,0.633981356955415,0.145060053135145,0.482035828487994,0.184480723036687,0.31379187525767,0.180265583457213,0.149809351404668,0.133361714036032,0.0348482227959868,0.0623448285088365,0,0,0.0373050544485358,-0.0179767582998012,0.146509500030206,-0.0137357749009623,0.314465462409945,-0.00259217753000887,0.501550924851073,0.00650138313306536,0.665300856013736,0.0103467193804073,0.892216666431326,0.0116893714293044,0.964324033244839,0.00763288105733537,1,0],"sym":11.8220315593656},
             {"CDf":0.00302,"Cpmin":-2.17770040248794,"n":10,"CL":1.70809542142662,"CD":0.00615957678278026,"CDp":0.000788551384403384,"Cm":-0.226457402881938,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt128.162697515514>122.029638202223) l1 Foil spline 17pts Re3000000 N11","xver":6.991,"good":130.572315478553,"iver":1.2020052,"id":571,"r":6,"Re":4000000,"src":"retestc_5.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re3000000-N11.dat","Top_Xtr":0.541868293293452,"CDpres":0.00314,"clcd":277.307269908832,"alpha":5.7,"sym":10.8152942217779,"xy":[1,0,0.961949581813749,0.0147246089265681,0.875758074483928,0.0468985981683136,0.633981356955415,0.138742412802236,0.482035828487994,0.176446237792048,0.31379187525767,0.17241467553273,0.149809351404668,0.127553558549731,0.0348482227959868,0.0596295930279232,0,0,0.0373050544485358,-0.0175533236126329,0.146509500030206,-0.0134122347247411,0.314465462409945,-0.00253111992088943,0.501550924851073,0.00634824589401479,0.665300856013736,0.010103006926193,0.892216666431326,0.0114140333927232,0.964324033244839,0.00745309187906392,1,0],"Bot_Xtr":0.953806726077757},
             {"src":"retest_82.txt","Re":4000000,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re2000000-N5.dat","Top_Xtr":0.531534326448184,"diter":3,"alpha":7,"clcd":286.195725779375,"CDpres":0.00348,"Bot_Xtr":1,"xy":[1,0,0.961949581813749,0.0147335477631039,0.875758074483928,0.0469270687990024,0.633981356955415,0.138826638859092,0.482035828487994,0.1765533526285,0.31379187525767,0.172519342937388,0.149809351404668,0.127630992213004,0.0348482227959868,0.0596657922361624,0,0,0.0373050544485358,-0.0172947824365333,0.146509500030206,-0.0132146872393542,0.314465462409945,-0.00249383930465759,0.501550924851073,0.00625474320496127,0.665300856013736,0.0099542007313958,0.892216666431326,0.0112459172181162,0.964324033244839,0.0073433160222225,1,0],"sym":10.8279853803519,"Cpmin":-2.29852492528943,"CDf":0.00293,"CDp":0.000596661138776485,"n":11,"CD":0.00640276653028666,"CL":1.83244441413128,"Cm":-0.224497958694388,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt95.1739440785903>93.4062250080713) l1 Foil spline 17pts Re2000000 N5","iver":1.2020052,"good":133.337861246556,"id":572},
             {"Cpmin":-2.37996383837561,"CDf":0.0029,"CDp":0.000530679451789666,"CD":0.00661791931773069,"CL":1.85217410782628,"n":12,"Cm":-0.230781312987532,"r":6,"id":573,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt105.585227131506>101.243646320523) l1 Foil spline 17pts Re2500000 N6","iver":1.2020052,"good":136.895942372315,"src":"retest_156.txt","Re":4000000,"Top_Xtr":0.539598421280413,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re2500000-N6.dat","diter":4,"alpha":6.9,"CDpres":0.00372,"clcd":279.872573070503,"Bot_Xtr":1,"xy":[1,0,0.961949581813749,0.0153950944786205,0.875758074483928,0.0490341273793225,0.633981356955415,0.145060053135145,0.482035828487994,0.184480723036687,0.31379187525767,0.180265583457213,0.149809351404668,0.133361714036032,0.0348482227959868,0.0623448285088365,0,0,0.0373050544485358,-0.0179767582998012,0.146509500030206,-0.0137357749009623,0.314465462409945,-0.00259217753000887,0.501550924851073,0.00650138313306536,0.665300856013736,0.0103467193804073,0.892216666431326,0.0116893714293044,0.964324033244839,0.00763288105733537,1,0],"sym":11.8220315593656},
             {"Re":4000000,"src":"retest_109.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re1700000-N7.dat","Top_Xtr":0.539539534933639,"CDpres":0.00381,"clcd":282.223446188794,"alpha":7.2,"sym":11.6898596390504,"xy":[1,0,0.961949581813749,0.0153082409806209,0.875758074483928,0.0487574947487032,0.633981356955415,0.144241677317297,0.482035828487994,0.18343995020275,0.31379187525767,0.179248590900659,0.149809351404668,0.132609335973049,0.0348482227959868,0.0619931017658991,0,0,0.0373050544485358,-0.0183652608200186,0.146509500030206,-0.0140326239255287,0.314465462409945,-0.00264819805865282,0.501550924851073,0.00664188698197802,0.665300856013736,0.0105703262447948,0.892216666431326,0.0119419948547466,0.964324033244839,0.00779783813568287,1,0],"Bot_Xtr":1,"CDf":0.00287,"Cpmin":-2.40389719057488,"n":13,"CL":1.88716463157832,"CD":0.0066867748128761,"CDp":0.000587561750560608,"Cm":-0.232230051731116,"good":138.004460000367,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt100.388314047888>97.5488988203398) l1 Foil spline 17pts Re1700000 N7","xver":6.991,"iver":1.2020052,"id":574,"r":6},
             {"Cm":-0.225379614854225,"r":6,"id":575,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt110.110218990747>105.900174401369) l1 Foil spline 17pts Re2000000 N9","good":135.745122946726,"xver":6.991,"iver":1.2020052,"Cpmin":-2.36074442945313,"CDf":0.00283,"CDp":0.000673808601707279,"CL":1.92502085465882,"CD":0.00658571349006793,"n":14,"alpha":7.9,"clcd":292.302551206029,"CDpres":0.00375,"Bot_Xtr":1,"xy":[1,0,0.961949581813749,0.0144883457396684,0.875758074483928,0.0461460883855664,0.633981356955415,0.136516226370374,0.482035828487994,0.173615075982244,0.31379187525767,0.169648202011241,0.149809351404668,0.125506902479364,0.0348482227959868,0.0586728085216206,0,0,0.0373050544485358,-0.0175563327146053,0.146509500030206,-0.0134145339350135,0.314465462409945,-0.00253155382150644,0.501550924851073,0.00634933415055596,0.665300856013736,0.010104738847665,0.892216666431326,0.0114159900586603,0.964324033244839,0.00745436953530546,1,0],"sym":10.4715149928697,"src":"retest_77.txt","Re":4000000,"Top_Xtr":0.531961559226617,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re2000000-N9.dat","diter":3},
             #{"Re":5000000,"n":3,"CDf":0.00253,"Cpmin":-2.62554629804988,"CL":1.58970525788521,"CD":0.00622532205575119,"CDp":-0.00409169938237818,"Cm":-0.173528417766844,"id":576,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"good":111.077010276601,"iver":1.2020052,"r":6,"src":"retest_94.txt","diter":3,"Top_Xtr":0.573212742222895,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","clcd":255.361127287637,"CDpres":0.0037,"alpha":6.8,"sym":7.99886704162969,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"Bot_Xtr":0.958725911434378},        #dud
             {"Bot_Xtr":0.981319874060936,"CD":0.00626835852785933,"CDf":0.00277,"CDp":-0.000663175522250547,"CDpres":0.00349,"CL":1.62931984041164,"Cm":-0.145497026761926,"Cpmin":-2.93388578350776,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re5000000-ncrit3_n17sopt-Re5000000-N3.dat","Re":5000000,"Top_Xtr":0.49903714862066,"alpha":8.2,"clcd":259.92767216014,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt102.918074380205>54.3696967055257) l2 Foil spline 17pts Re5000000 N3","diter":3,"good":102.918074379441,"id":31,"iver":1.2020062,"n":3,"r":6,"src":"","sym":6.84628973540028,"xver":6.991,"xy":[1,0,0.895140677825453,0.0355730906500397,0.804733398266158,0.0590745023901412,0.592621464489179,0.146909357797104,0.464212554326353,0.190499239622141,0.300719048572926,0.17605742219451,0.151647407370497,0.127936236875527,0.0445917027294438,0.0612022456958459,0,0,0.0343915043215309,-0.0323510875437213,0.151602375817869,-0.0434380522224392,0.238834442163128,-0.0433195666750187,0.358850523629566,-0.0375457356504894,0.516039005306004,-0.0299374525711502,0.742128096369342,-0.0170728614010439,0.920893667759824,-0.00696882261090827,1,0]},        #5000000 3
             #{"Re":5000000,"n":4,"src":"retestc_12.txt","diter":5,"Top_Xtr":0.561351478731043,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","CDpres":0.00274,"clcd":265.044713766095,"alpha":5,"sym":7.61567438822719,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.959698726257735,"CDf":0.00259,"Cpmin":-2.32798047341657,"CD":0.00532588513164693,"CL":1.41159770026846,"CDp":-0.00253384135371115,"Cm":-0.157076667941652,"id":577,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"xver":6.991,"good":127.324366505294,"r":6},        #dud
             {"Bot_Xtr":0.97544119252343,"CD":0.00589963106847629,"CDf":0.00259,"CDp":-0.000310863305321118,"CDpres":0.00331,"CL":1.54450496210277,"Cm":-0.144129824537795,"Cpmin":-2.56489101193989,"Foil_fn":"optB_Re5000000-N4-optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4_n17sopt-Re5000000-N4.dat","Re":5000000,"Top_Xtr":0.529892741321974,"alpha":7.2,"clcd":261.796872410476,"cmt":"OPT s(0) ../foildb2020_spline_opt/optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt117.16739472575>86.9396948643363) l2 Foil spline 17pts Re5000000 N4","diter":4,"good":117.167394722735,"id":47,"iver":1.2020062,"n":4,"r":6,"src":"","sym":7.69210922314909,"xver":6.991,"xy":[1,0,0.912705741790392,0.0240179070239408,0.808983879455377,0.0530267478876999,0.589834864925574,0.158906155281128,0.464059197046803,0.191650943133135,0.300743781983627,0.177177208186288,0.149588302541854,0.127572440204915,0.0446387693936279,0.061481992132661,0,0,0.0251575020700872,-0.0247941491303903,0.11192818177731,-0.0345597010011298,0.23806159220794,-0.0380479503103431,0.38799842347467,-0.035948200931974,0.529590978122237,-0.0294367420777264,0.742367239267483,-0.0166396092896024,0.920936730844689,-0.00677624509573308,1,0]},        #5000000 4
             #{"Re":5000000,"n":5,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"good":122.261393801378,"iver":1.2020052,"id":578,"r":6,"Cm":-0.161388109296571,"CL":1.56049736116654,"CD":0.00576351152064193,"CDp":-0.00264074911198518,"CDf":0.00253,"Cpmin":-2.41561794274583,"sym":7.61567438822719,"Bot_Xtr":0.973645582648383,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"CDpres":0.00323,"clcd":270.754618183314,"alpha":6.3,"diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.559617361689045,"src":"retestc_13.txt"},        #dud
             {"Bot_Xtr":0.976422836996825,"CD":0.00471384828426829,"CDf":0.00233,"CDp":-0.000410676040356977,"CDpres":0.00238,"CL":1.41378634292976,"Cm":-0.140794568012048,"Cpmin":-2.07738889759634,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re5000000-ncrit5_n17sopt-Re5000000-N5.dat","Re":5000000,"Top_Xtr":0.585179876300736,"alpha":6.2,"clcd":299.921901951754,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt140.423119007514>87.8682011781151) l2 Foil spline 17pts Re5000000 N5","diter":3,"good":140.423119006883,"id":83,"iver":1.2020062,"n":5,"r":6,"src":"","sym":7.00207799193128,"xver":6.991,"xy":[1,0,0.834925092953723,0.0461396489127812,0.759404837041487,0.0690636259657112,0.601308229556069,0.154271227763318,0.464880421332937,0.178795072805196,0.301233103363117,0.165342206697335,0.151729401576482,0.120003787474724,0.0445607921828468,0.0573033059223187,0,0,0.0318824549190234,-0.0289295402514964,0.148704165203284,-0.0352444786735102,0.263945179643353,-0.0343900601810072,0.391982479398065,-0.0315797597081171,0.54604895293536,-0.0263987429469594,0.792378268754013,-0.0143669205813233,0.916958872346009,-0.00778336942115381,1,0]},        #5000000 5
             {"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"Bot_Xtr":1,"sym":7.45853331327074,"alpha":6.7,"clcd":308.190891526227,"CDpres":0.00273,"Top_Xtr":0.538495545187021,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","diter":4,"src":"retest_81.txt","Re":5000000,"r":6,"id":579,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","xver":6.991,"good":117.990348232423,"Cm":-0.206174333525759,"CDp":3.61464696318645e-05,"CL":1.67309909209594,"CD":0.00542877527564295,"n":6,"Cpmin":-2.03662049157313,"CDf":0.00269},
             #{"Re":5000000,"n":7,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.981365190697354,"sym":7.61567438822719,"alpha":7.3,"CDpres":0.00375,"clcd":270.683917562324,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.559747559044012,"diter":3,"src":"retest_148.txt","r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"good":125.404854301965,"id":580,"Cm":-0.166259611268323,"CDp":-0.00267490190251505,"CD":0.00620985578076784,"CL":1.68090809023528,"Cpmin":-2.48586545014585,"CDf":0.00246},        #dud
             {"Bot_Xtr":0.988443343120478,"CD":0.00527936466375914,"CDf":0.00232,"CDp":-0.000116108655849733,"CDpres":0.00296,"CL":1.65927549636648,"Cm":-0.184196876935204,"Cpmin":-2.33470828517735,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re5000000-ncrit7_n17sopt-Re5000000-N7.dat","Re":5000000,"Top_Xtr":0.593510786215658,"alpha":7,"clcd":314.294541492234,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt159.891783004994>99.5824623619964) l2 Foil spline 17pts Re5000000 N7","diter":7,"good":159.891783021156,"id":107,"iver":1.2020062,"n":7,"r":6,"src":"","sym":8.25021121588763,"xver":6.991,"xy":[1,0,0.870236734186943,0.0398201009311485,0.777001502794522,0.0729901105786203,0.605674165884466,0.162967426058643,0.470992018658819,0.187311145246316,0.310282764196356,0.172723091121273,0.154032029032598,0.123874771844211,0.0445917027294438,0.0589158794900552,0,0,0.0257190564914736,-0.0242221202354021,0.116418130587446,-0.0322751546332649,0.234342796267777,-0.0313710031624172,0.404051138181221,-0.0279720106395088,0.508477998073065,-0.0241657361402714,0.705704228833818,-0.0148405483496742,0.954143297101516,-0.00496799362448554,1,0]},        #5000000 7
             {"r":6,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","good":145.028660086909,"xver":6.991,"iver":1.2020052,"id":581,"Cm":-0.205156535576107,"CDp":1.47144976855169e-05,"n":8,"CL":1.58771328589155,"CD":0.00487290473283912,"Cpmin":-1.98606762851901,"CDf":0.00261,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"Bot_Xtr":1,"sym":7.45853331327074,"alpha":5.9,"CDpres":0.00227,"clcd":325.824815574937,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","Top_Xtr":0.563819927595081,"diter":6,"src":"retest_83.txt","Re":5000000},
             {"Re":5000000,"src":"retest_84.txt","diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re1125000-N4.dat","Top_Xtr":0.563099167758876,"CDpres":0.00245,"clcd":333.154745390954,"alpha":6.6,"sym":7.45853331327074,"xy":[1,0,0.84737544827212,0.0511344211765325,0.774276848233302,0.0669765371697747,0.608188854824062,0.13841052135476,0.464690332398495,0.163061191816092,0.300741605037935,0.150051944545958,0.154718278499416,0.107563445975053,0.0459168061863883,0.050561053689432,0,0,0.0241091064136707,-0.0197060164005901,0.118021359303582,-0.0220159895255109,0.202848047867585,-0.0200382448598521,0.27696147068953,-0.016061841564623,0.404566939475095,-0.00748813617331449,0.659243629402816,0.00533607362063808,0.921424214398924,0.00641157195297171,1,0],"Bot_Xtr":1,"CDf":0.00256,"Cpmin":-2.03397829953071,"n":9,"CL":1.66879919100828,"CD":0.00500908125756983,"CDp":1.8864622649958e-06,"Cm":-0.207257264142785,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re1125000_N4_gu255118.dat-s17_n17s0_nsopt-Re1125000-N4.dat (opt97.4992255426094>73.999090925686) l1 Foil spline 17pts Re1125000 N4","good":143.881685175997,"iver":1.2020052,"id":582,"r":6},
             {"CDpres":0.00284,"clcd":328.793140623217,"alpha":8.1,"sym":13.4527364991675,"xy":[1,0,0.765635949746012,0.0602400933292464,0.621358513547463,0.103789806117722,0.461002187731606,0.167010956266978,0.306366541357937,0.177060923970921,0.154893360815706,0.140995273436856,0.053110314474444,0.0855511184984756,0.00373230419095964,0.0326938587334048,0,0,0.0316932348546144,-0.00108105707892218,0.0662544378174111,0.00376781766486534,0.154080154125155,0.0140941160325535,0.300990909766017,0.0251610277943201,0.456034212256774,0.0310538729392919,0.568022360188196,0.0303827857662242,0.87958991122884,0.0178956071773471,1,0],"Bot_Xtr":1,"Re":5000000,"src":"retest_158.txt","diter":3,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1400000-N4.dat","Top_Xtr":0.461626102976399,"Cm":-0.179332983943518,"good":135.324274113003,"cmt":"OPT s(0) optbs_spline_Re1400000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1400000-N4.dat (opt86.2246580453185>79.3717073908791) l1 Foil spline 17pts Re1400000 N4","xver":6.991,"iver":1.2020052,"id":583,"r":6,"CDf":0.00292,"Cpmin":-2.74461511697972,"n":10,"CD":0.00575817312376056,"CL":1.89324782561344,"CDp":0.000869182874240919},
             {"Foil_fn":"opt_spline_gu255118_nsopt-Re3000000-N4.dat","Top_Xtr":0.624715082528334,"diter":3,"src":"retest_150.txt","Re":5000000,"xy":[1,0,0.917759454508978,0.0333891343417255,0.814043880650166,0.053278215894168,0.62602974191967,0.1442347588982,0.476685480425156,0.16985443041005,0.30077007408928,0.157426736972695,0.151551207663296,0.114292665949139,0.0472997976058213,0.0570435440099726,0,0,0.0253113999411171,-0.0223016901675586,0.123323412357534,-0.0293943476368431,0.24172981191821,-0.0343262572857237,0.388748038237508,-0.0324169237325311,0.529623920394006,-0.0264750375369872,0.743504779228206,-0.0145018304907469,0.919942664098322,-0.00600777253207695,1,0],"Bot_Xtr":0.983951894600651,"sym":6.01123935004043,"alpha":6,"CDpres":0.00273,"clcd":297.817580634538,"CDp":-0.000688876577218122,"n":11,"CL":1.48299637451325,"CD":0.00497954610790115,"Cpmin":-1.92434042591554,"CDf":0.00225,"r":6,"cmt":"OPT s(0) optbs_spline_Re3000000_N4_gu255118.dat-s17_n17s0_nsopt-Re3000000-N4.dat (opt108.370262390478>86.6122327989122) l1 Foil spline 17pts Re3000000 N4","good":149.515431297836,"xver":6.991,"iver":1.2020052,"id":584,"Cm":-0.171878161214919},
             {"xy":[1,0,0.961949581813749,0.0147246089265681,0.875758074483928,0.0468985981683136,0.633981356955415,0.138742412802236,0.482035828487994,0.176446237792048,0.31379187525767,0.17241467553273,0.149809351404668,0.127553558549731,0.0348482227959868,0.0596295930279232,0,0,0.0373050544485358,-0.0175533236126329,0.146509500030206,-0.0134122347247411,0.314465462409945,-0.00253111992088943,0.501550924851073,0.00634824589401479,0.665300856013736,0.010103006926193,0.892216666431326,0.0114140333927232,0.964324033244839,0.00745309187906392,1,0],"Bot_Xtr":0.968321859412273,"sym":10.8152942217779,"alpha":6.9,"CDpres":0.00321,"clcd":306.324637894402,"Top_Xtr":0.530043295901495,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re3000000-N11.dat","diter":3,"src":"retest_95.txt","Re":5000000,"r":6,"id":585,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt128.162697515514>122.029638202223) l1 Foil spline 17pts Re3000000 N11","good":139.852828610084,"iver":1.2020052,"Cm":-0.22949722921719,"CDp":0.000625431387120006,"CD":0.00602335737137398,"CL":1.84510276569471,"n":12,"Cpmin":-2.30498305370547,"CDf":0.00281},
             {"Re":5000000,"src":"retest_153.txt","diter":5,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re1700000-N8.dat","Top_Xtr":0.532872023344171,"CDpres":0.00314,"clcd":311.816475520956,"alpha":7,"sym":10.5562920782159,"xy":[1,0,0.961949581813749,0.0145474017310024,0.875758074483928,0.0463341846006042,0.633981356955415,0.137072680587186,0.482035828487994,0.174322748935863,0.31379187525767,0.170339705577473,0.149809351404668,0.126018481556668,0.0348482227959868,0.058911964939741,0,0,0.0373050544485358,-0.0171920861076947,0.146509500030206,-0.0131362184947364,0.314465462409945,-0.00247903089973885,0.501550924851073,0.00621760257209498,0.665300856013736,0.00989509273883283,0.892216666431326,0.0111791390197225,0.964324033244839,0.00729971144958614,1,0],"Bot_Xtr":1,"CDf":0.00275,"Cpmin":-2.28411169229286,"n":13,"CD":0.00588594827002297,"CL":1.83533564465723,"CDp":0.000583360059651287,"Cm":-0.225013706047403,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt103.294104919855>99.5755735705944) l1 Foil spline 17pts Re1700000 N8","xver":6.991,"good":143.956843380831,"id":586,"r":6},
             {"r":6,"id":587,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt103.294104919855>99.5755735705944) l1 Foil spline 17pts Re1700000 N8","good":145.862776649298,"xver":6.991,"iver":1.2020052,"Cm":-0.225951961987296,"CDp":0.000591940105936761,"CD":0.00596278821914176,"CL":1.86985505088038,"n":14,"Cpmin":-2.31592511359074,"CDf":0.00272,"xy":[1,0,0.961949581813749,0.0145474017310024,0.875758074483928,0.0463341846006042,0.633981356955415,0.137072680587186,0.482035828487994,0.174322748935863,0.31379187525767,0.170339705577473,0.149809351404668,0.126018481556668,0.0348482227959868,0.058911964939741,0,0,0.0373050544485358,-0.0171920861076947,0.146509500030206,-0.0131362184947364,0.314465462409945,-0.00247903089973885,0.501550924851073,0.00621760257209498,0.665300856013736,0.00989509273883283,0.892216666431326,0.0111791390197225,0.964324033244839,0.00729971144958614,1,0],"Bot_Xtr":1,"sym":10.5562920782159,"alpha":7.3,"CDpres":0.00324,"clcd":313.587365869841,"Top_Xtr":0.533373587793906,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re1700000-N8.dat","diter":3,"src":"retest_154.txt","Re":5000000},
             #{"Re":6000000,"n":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.548380313850763,"diter":3,"src":"retestc_10.txt","xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.951585593830677,"sym":7.61567438822719,"alpha":5.3,"clcd":279.411509065042,"CDpres":0.00259,"CDp":-0.0027566698564844,"CD":0.00512119399089941,"CL":1.43092054121203,"Cpmin":-2.34005296271529,"CDf":0.00253,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"good":99.2915502015147,"id":588,"Cm":-0.154712208093898},        #dud
             {"Bot_Xtr":0.890354778575665,"CD":0.00530648958375444,"CDf":0.00262,"CDp":-0.000416823452413777,"CDpres":0.00268,"CL":1.56080949661855,"Cm":-0.195606311406894,"Cpmin":-2.4472627552156,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re6000000-ncrit3_n17sopt-Re6000000-N3.dat","Re":6000000,"Top_Xtr":0.564773024458899,"alpha":5.7,"clcd":294.132207739914,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt129.063335440864>0) l2 Foil spline 17pts Re6000000 N3","diter":3,"good":129.063268792857,"id":69,"iver":1.2020062,"n":3,"r":6,"src":"","sym":8.70917041512526,"xver":6.991,"xy":[1,0,0.825043836783417,0.0622655181865649,0.771095143031137,0.0786046680833014,0.602318307374638,0.169972078036717,0.468599363799123,0.196811094933359,0.301908140157573,0.179799566112097,0.158146762490613,0.131148912272084,0.0448592772405301,0.0602290581677149,0,0,0.0441206596416849,-0.0196123648538455,0.142771030893781,-0.0232823072827017,0.280985134456101,-0.0250425602248178,0.534433793239648,-0.0243586099345226,0.720677765228333,-0.0201745075967043,0.863589998006799,-0.00993160599032081,0.942935573842467,0.00449472090666333,1,0]},        #6000000 3
             #{"Re":6000000,"n":4,"diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","Top_Xtr":0.573605007068111,"src":"retestc_13.txt","sym":7.99886704162969,"Bot_Xtr":0.963370802924239,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"clcd":278.305945674385,"CDpres":0.00351,"alpha":7.2,"CL":1.63753722500199,"CD":0.00588394624855729,"CDp":-0.00408956781537741,"CDf":0.00237,"Cpmin":-2.65866023166151,"good":123.369199007176,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"iver":1.2020052,"id":589,"r":6,"Cm":-0.175360014739955},        #dud
             {"Bot_Xtr":0.9486341366124,"CD":0.00421098033651413,"CDf":0.00234,"CDp":-0.000493897928671755,"CDpres":0.00187,"CL":1.11341261004095,"Cm":-0.102042644900549,"Cpmin":-1.78965506551578,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re6000000-ncrit4_n17sopt-Re6000000-N4.dat","Re":6000000,"Top_Xtr":0.591577120985393,"alpha":5,"clcd":264.406983900248,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt127.883990956147>0) l2 Foil spline 17pts Re6000000 N4","diter":5,"good":127.883986297065,"id":66,"iver":1.2020062,"n":4,"r":6,"src":"","sym":5.65145017209471,"xver":6.991,"xy":[1,0,0.843146976245184,0.0402535908061592,0.774628986743101,0.0670004410027087,0.600813296382054,0.149789202145452,0.452277712249608,0.170378922982048,0.293144827087695,0.153697391216658,0.140146044181889,0.10307091447541,0.0380710840900393,0.045809317574435,0,0,0.0341140248987332,-0.0185551751275229,0.137079929053538,-0.0252512836233876,0.25861087448108,-0.0276440597937276,0.441480227408857,-0.0296057325498978,0.64211366652124,-0.0281365573239812,0.712979312495024,-0.0277585701273196,0.896885333727276,-0.024183969008063,1,0]},        #6000000 4
             #{"Re":6000000,"n":5,"Cm":-0.157846522948186,"id":590,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"xver":6.991,"good":126.385402837494,"r":6,"CDf":0.00244,"Cpmin":-2.37937835879268,"CD":0.00522060287314881,"CL":1.4958001768097,"CDp":-0.00262891087835234,"CDpres":0.00278,"clcd":286.518667126179,"alpha":5.8,"sym":7.61567438822719,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.97046968235796,"src":"retestc_14.txt","diter":6,"Top_Xtr":0.558460168878975,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat"},        #dud
             {"Bot_Xtr":0.967099801405396,"CD":0.00477647671572771,"CDf":0.00226,"CDp":-0.000906215610806805,"CDpres":0.00251,"CL":1.53485956588773,"Cm":-0.177402224247583,"Cpmin":-2.37420238545795,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re6000000-ncrit5_n17sopt-Re6000000-N5.dat","Re":6000000,"Top_Xtr":0.592966729093909,"alpha":6,"clcd":321.337181616279,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt155.08756688289>0) l2 Foil spline 17pts Re6000000 N5","diter":6,"good":155.087559643142,"id":101,"iver":1.2020062,"n":5,"r":6,"src":"","sym":9.2419935528889,"xver":6.991,"xy":[1,0,0.864613933922077,0.0478507158275032,0.755261050922825,0.0835703513738914,0.606366445171139,0.17205712250598,0.468871570579908,0.197921336689963,0.303983413452863,0.181009400079417,0.158947142712848,0.131169661471683,0.0526439459824956,0.0648340569467639,0,0,0.0168215005708888,-0.0230841864620184,0.0950336343390462,-0.0331927264077367,0.204921465455011,-0.0360438088101388,0.367113627066156,-0.034074765906004,0.514187188867369,-0.0290656913229985,0.742535685000346,-0.0174224162753979,0.920904715917442,-0.00709931657670451,1,0]},        #6000000 5
             #{"Re":6000000,"n":6,"diter":3,"Top_Xtr":0.575164231673844,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","src":"retest_104.txt","sym":7.99886704162969,"Bot_Xtr":0.970443743623932,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"CDpres":0.00407,"clcd":278.393681597458,"alpha":8.3,"CD":0.00632642039984644,"CL":1.76123546644651,"CDp":-0.00437834726948961,"CDf":0.00226,"Cpmin":-2.73099346453542,"id":591,"good":115.448018635468,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.179399490522064},        #dud
             {"Bot_Xtr":0.976269809571877,"CD":0.00407353668981393,"CDf":0.0023,"CDp":-0.000249267535333121,"CDpres":0.00178,"CL":1.28622675626546,"Cm":-0.134846751636764,"Cpmin":-1.82223383716391,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re6000000-ncrit6_n17sopt-Re6000000-N6.dat","Re":6000000,"Top_Xtr":0.587418119576865,"alpha":5.4,"clcd":315.75185255646,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt145.279874926927>0) l2 Foil spline 17pts Re6000000 N6","diter":3,"good":145.279874930547,"id":89,"iver":1.2020062,"n":6,"r":6,"src":"","sym":6.26831062476063,"xver":6.991,"xy":[1,0,0.801118536316997,0.0555233321718755,0.755072917370256,0.0720623992559388,0.602281739541019,0.14489764462692,0.461978471711749,0.166670572426507,0.300550924896369,0.1541594622571,0.151365529868804,0.111862620424032,0.0480270254445232,0.0551796031173399,0,0,0.0268366921802928,-0.0243124971455811,0.125061444860696,-0.0323631768921401,0.246150085921271,-0.0326730735834225,0.371037717580919,-0.0283830418353493,0.513172191349295,-0.0230174829900948,0.780831498568891,-0.0143976806957138,0.923839671651158,-0.00789243539290925,1,0]},        #6000000 6
             {"alpha":5.2,"clcd":289.350616316126,"CDpres":0.00334,"Bot_Xtr":0.901601238195528,"xy":[1,0,0.961949581813749,0.0171814997684778,0.875758074483928,0.0547239154254823,0.633981356955415,0.161892430918046,0.482035828487994,0.205887369158092,0.31379187525767,0.201183116137143,0.149809351404668,0.148836648064481,0.0348482227959868,0.0695791544558512,0,0,0.0373050544485358,-0.0200080396464208,0.146509500030206,-0.0152878469081828,0.314465462409945,-0.00288508027565527,0.501550924851073,0.00723600603143123,0.665300856013736,0.0115158455223748,0.892216666431326,0.0130102103559932,0.964324033244839,0.00849535740897563,1,0],"sym":14.7247089357957,"src":"retest_159.txt","Re":6000000,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re10000000-N8.dat","Top_Xtr":0.53071179309333,"diter":3,"Cm":-0.25839606803021,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt119.080054617626>78.4081168953089) l1 Foil spline 17pts Re10000000 N8","good":118.717946681303,"iver":1.2020052,"id":592,"Cpmin":-2.5069469747239,"CDf":0.00293,"CDp":0.000213054958371492,"n":7,"CL":1.8132324723555,"CD":0.00626655818273593},
             {"Top_Xtr":0.545556828711976,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","diter":3,"src":"retest_153.txt","Re":6000000,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.997897976345358,"sym":8.18651951349902,"alpha":8.2,"CDpres":0.00353,"clcd":302.613851402808,"CDp":-0.00166282179555677,"CD":0.00596209680732443,"CL":1.80421307730083,"n":8,"Cpmin":-2.44506854378019,"CDf":0.00244,"r":6,"id":593,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","iver":1.2020052,"xver":6.991,"good":135.216758786183,"Cm":-0.196222063135119},
             {"n":9,"CL":1.76913351887956,"CD":0.00521081279014455,"CDp":0.000709804177317169,"CDf":0.00285,"Cpmin":-2.62185963131981,"cmt":"OPT s(0) optbs_spline_Re1400000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1400000-N4.dat (opt86.2246580453185>79.3717073908791) l1 Foil spline 17pts Re1400000 N4","iver":1.2020052,"xver":6.991,"good":136.439517918194,"id":594,"r":6,"Cm":-0.177182263388029,"diter":4,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1400000-N4.dat","Top_Xtr":0.46252618874159,"Re":6000000,"src":"retest_85.txt","sym":13.4527364991675,"Bot_Xtr":1,"xy":[1,0,0.765635949746012,0.0602400933292464,0.621358513547463,0.103789806117722,0.461002187731606,0.167010956266978,0.306366541357937,0.177060923970921,0.154893360815706,0.140995273436856,0.053110314474444,0.0855511184984756,0.00373230419095964,0.0326938587334048,0,0,0.0316932348546144,-0.00108105707892218,0.0662544378174111,0.00376781766486534,0.154080154125155,0.0140941160325535,0.300990909766017,0.0251610277943201,0.456034212256774,0.0310538729392919,0.568022360188196,0.0303827857662242,0.87958991122884,0.0178956071773471,1,0],"CDpres":0.00236,"clcd":339.512008995142,"alpha":7},
             {"r":6,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","good":154.012145617985,"xver":6.991,"iver":1.2020052,"id":595,"Cm":-0.19760975124795,"CDp":-0.00144110128482209,"n":10,"CD":0.00575310586439887,"CL":1.7620731890107,"Cpmin":-2.42170877298859,"CDf":0.00242,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.996807486835001,"sym":8.18651951349902,"alpha":7.7,"clcd":306.282072769544,"CDpres":0.00333,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.554977784066142,"diter":3,"src":"retest_155.txt","Re":6000000},
             {"CDf":0.00279,"Cpmin":-2.31160843146037,"n":11,"CD":0.0057648288652808,"CL":1.81753531468889,"CDp":0.000569298379333228,"Cm":-0.236333973570345,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt99.4898119274805>93.0076856591624) l1 Foil spline 17pts Re2500000 N5","iver":1.2020052,"xver":6.991,"good":141.342229649534,"id":596,"r":6,"Re":6000000,"src":"retest_76.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re2500000-N5.dat","Top_Xtr":0.529096952165791,"CDpres":0.00297,"clcd":315.280012150086,"alpha":6.3,"sym":11.363739895529,"xy":[1,0,0.961949581813749,0.0150937100146643,0.875758074483928,0.0480742031504519,0.633981356955415,0.142220262420232,0.482035828487994,0.180869207439956,0.31379187525767,0.176736586196724,0.149809351404668,0.130750937677832,0.0348482227959868,0.0611243252669322,0,0,0.0373050544485358,-0.0176564279512418,0.146509500030206,-0.0134910152235845,0.314465462409945,-0.00254598715920521,0.501550924851073,0.00638553408562303,0.665300856013736,0.010162349753231,0.892216666431326,0.0114810768991148,0.964324033244839,0.00749686969150221,1,0],"Bot_Xtr":0.945373939604809},
             {"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re6000000-N12.dat","Top_Xtr":0.461201002806806,"diter":3,"src":"retestc_20.txt","Re":6000000,"xy":[1,0,0.868661556886963,0.0524245093375965,0.620673721871338,0.115919506125592,0.458819286826548,0.188838411207467,0.307104890650506,0.200216012027709,0.152671216420827,0.158546999301341,0.0512771566887826,0.0953639786252406,0.00313253787259379,0.0363448379353784,0,0,0.0270184392679959,-0.00790171138482936,0.0616968952329497,-0.00606174286401059,0.131064062193512,0.00248166172561616,0.371929606347149,0.0217768617566466,0.479146297313775,0.027607517081229,0.695690242780121,0.0249726228351655,0.878350726809458,0.0173383711232261,1,0],"Bot_Xtr":1,"sym":15.6797654047398,"alpha":9.6,"clcd":334.024842707131,"CDpres":0.00364,"CDp":-0.000118786320582754,"n":12,"CD":0.00646383145953479,"CL":2.15908028655652,"Cpmin":-3.29094947539505,"CDf":0.00283,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt140.971515681167>117.176074081744) l1 Foil spline 17pts Re6000000 N12","good":140.973814893794,"xver":6.991,"iver":1.2020052,"id":597,"Cm":-0.209586377256023},
             {"CL":1.80282417470668,"CD":0.00557411452486931,"n":13,"CDp":0.000623948137067855,"CDf":0.00272,"Cpmin":-2.25044443557634,"id":598,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt103.294104919855>99.5755735705944) l1 Foil spline 17pts Re1700000 N8","xver":6.991,"iver":1.2020052,"good":149.268869840035,"r":6,"Cm":-0.229017546646587,"diter":3,"Top_Xtr":0.532545367117707,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re1700000-N8.dat","Re":6000000,"src":"retest_138.txt","sym":10.5562920782159,"Bot_Xtr":0.958024183508245,"xy":[1,0,0.961949581813749,0.0145474017310024,0.875758074483928,0.0463341846006042,0.633981356955415,0.137072680587186,0.482035828487994,0.174322748935863,0.31379187525767,0.170339705577473,0.149809351404668,0.126018481556668,0.0348482227959868,0.058911964939741,0,0,0.0373050544485358,-0.0171920861076947,0.146509500030206,-0.0131362184947364,0.314465462409945,-0.00247903089973885,0.501550924851073,0.00621760257209498,0.665300856013736,0.00989509273883283,0.892216666431326,0.0111791390197225,0.964324033244839,0.00729971144958614,1,0],"CDpres":0.00285,"clcd":323.427903510639,"alpha":6.5},
             {"sym":9.71560766900043,"Bot_Xtr":0.959570043462468,"xy":[1,0,0.961949581813749,0.0139562877204819,0.875758074483928,0.0444514576236562,0.633981356955415,0.131502917446459,0.482035828487994,0.167239379606148,0.31379187525767,0.163418181832089,0.149809351404668,0.120897890855312,0.0348482227959868,0.0565181568558577,0,0,0.0373050544485358,-0.0163391057430332,0.146509500030206,-0.0124844688250499,0.314465462409945,-0.00235603450083645,0.501550924851073,0.00590911802426037,0.665300856013736,0.009404150583247,0.892216666431326,0.0106244892804232,0.964324033244839,0.00693753838372388,1,0],"clcd":324.186600403651,"CDpres":0.00254,"alpha":5.9,"diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re10000000-N11.dat","Top_Xtr":0.541112766240643,"Re":6000000,"src":"retest_73.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt136.070248064424>124.148199205938) l1 Foil spline 17pts Re10000000 N11","good":142.704239687717,"xver":6.991,"iver":1.2020052,"id":599,"r":6,"Cm":-0.218659528437229,"n":14,"CL":1.69279950058906,"CD":0.00522168250779436,"CDp":0.000671108016089407,"CDf":0.00268,"Cpmin":-2.09616597943717},
             #{"Re":7000000,"n":3,"r":6,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"good":109.431788050642,"id":600,"Cm":-0.17548233293283,"CDp":-0.00422606205663734,"CD":0.00567234087093537,"CL":1.6476219840287,"Cpmin":-2.66722828340896,"CDf":0.00233,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"Bot_Xtr":0.957965632883652,"sym":7.99886704162969,"alpha":7.3,"clcd":290.465968374888,"CDpres":0.00335,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","Top_Xtr":0.564141694725486,"diter":3,"src":"retestc_6.txt",},        #dud
             {"Bot_Xtr":0.952059379821833,"CD":0.00528024058188751,"CDf":0.00261,"CDp":-0.000739651693623024,"CDpres":0.00267,"CL":1.56096415353112,"Cm":-0.111818777135956,"Cpmin":-2.87850682766016,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re7000000-ncrit3_n17sopt-Re7000000-N3.dat","Re":7000000,"Top_Xtr":0.474176953580316,"alpha":8,"clcd":295.623680270479,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt118.926944253328>51.3614331162008) l2 Foil spline 17pts Re7000000 N3","diter":8,"good":118.926944527057,"id":53,"iver":1.2020062,"n":3,"r":6,"src":"","sym":6.78831646940149,"xver":6.991,"xy":[1,0,0.899679346322925,0.032030422047469,0.82355094510085,0.0474798034953301,0.62163999514544,0.120700595925457,0.469323923039483,0.190722614626736,0.312238544124437,0.193012197130775,0.151332715342803,0.13745821779865,0.0413886889400662,0.0620232949178248,0,0,0.029425363268095,-0.0262142254748997,0.118576788699016,-0.0373351437940295,0.255234389138951,-0.0410149896771483,0.403351136966376,-0.040709610084355,0.612918102625111,-0.034414024158528,0.862350589871016,-0.0183887209684307,0.979514192550172,-0.00462534048536986,1,0]},        #7000000 3
             #{"Re":7000000,"n":4,"r":6,"id":601,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"iver":1.2020052,"good":103.960273875389,"Cm":-0.15580206248194,"CDp":-0.00274244958483447,"CL":1.48667536731152,"CD":0.00498403380501638,"Cpmin":-2.37479169772337,"CDf":0.00239,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.966863728353207,"sym":7.61567438822719,"alpha":5.8,"clcd":298.287576985372,"CDpres":0.0026,"Top_Xtr":0.549636589668018,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":3,"src":"retest_153.txt",},        #dud
             {"Bot_Xtr":0.978794461906869,"CD":0.00606264210117187,"CDf":0.00243,"CDp":-0.000816847807372535,"CDpres":0.00363,"CL":1.70075973947571,"Cm":-0.156199816650266,"Cpmin":-3.06566287694683,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re7000000-ncrit4_n17sopt-Re7000000-N4.dat","Re":7000000,"Top_Xtr":0.511291445751945,"alpha":8,"clcd":280.531113513524,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt130.243426260274>67.0987159872204) l2 Foil spline 17pts Re7000000 N4","diter":12,"good":130.243424348813,"id":71,"iver":1.2020062,"n":4,"r":6,"src":"","sym":9.37809401775728,"xver":6.991,"xy":[1,0,0.861568354319776,0.0421891636989169,0.786003208964654,0.0657367253434922,0.583424430648107,0.169917810334769,0.465425317513328,0.208654043270043,0.311946222809499,0.194880265334618,0.15188458883648,0.13965337684477,0.0446294227602288,0.0666984060857288,0,0,0.0279617097322432,-0.031900801185181,0.147460801480606,-0.036623406114946,0.287755158464802,-0.0347881358829035,0.386169578161,-0.0335267068900793,0.538967003755783,-0.0291761189416755,0.740744618276471,-0.0178856109682142,0.92069953800845,-0.00748686166887296,1,0]},        #7000000 4
             #{"Re":7000000,"n":5,"src":"retest_154.txt","Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.550541572854902,"diter":3,"alpha":6.3,"CDpres":0.00282,"clcd":300.201504114686,"Bot_Xtr":0.972154741184129,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"sym":7.61567438822719,"Cpmin":-2.41597743156126,"CDf":0.00236,"CDp":-0.00274309973265858,"CL":1.553663135306,"CD":0.00517540090243004,"Cm":-0.159672805077695,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"good":120.604341428266,"id":602},        #dud
             {"Bot_Xtr":0.976223614741875,"CD":0.00509200927525989,"CDf":0.00222,"CDp":-0.00215954887284575,"CDpres":0.00288,"CL":1.67738443049286,"Cm":-0.1928190123882,"Cpmin":-2.57688545596702,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re7000000-ncrit5_n17sblowsuck-Re7000000-N5.dat","Re":7000000,"Top_Xtr":0.585757333381692,"alpha":7.1,"clcd":329.415038311619,"cmt":"SPLN 2(B1) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat -opt_clcd(3)=(161.724236694459>161.723631155776 aoa=7.1 pa=1.67741432505942 Cl=1.67741432505942 Cd=0.00509217622161769 x=0.585742516628638,0.976231658703768 s=YB u=0.999763951329166 Foil spline 17pts Re7000000 N5","diter":3,"good":161.724205292074,"id":111,"iver":1.2020062,"n":5,"r":6,"src":"","sym":9.94770606276922,"xver":6.991,"xy":[1,0,0.818370378415343,0.0744010400111935,0.762086234733876,0.091264225941459,0.597763011030517,0.184360732018229,0.463927468500016,0.206881285066038,0.307664739249405,0.188805949226882,0.163586470503353,0.137687049647511,0.0468247280119234,0.0624413836472157,0,0,0.0263652728772251,-0.0242393219116736,0.108018464884118,-0.0298621739315714,0.249783094040781,-0.0316318981160054,0.343156271664923,-0.0331167725386661,0.505634438096874,-0.0292992325596143,0.735950685472496,-0.0174478674593098,0.920135258890314,-0.0073611440320139,1,0]},        #7000000 5
             #{"Re":7000000,"n":6,"r":6,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"good":137.845697345725,"iver":1.2020052,"id":603,"Cm":-0.158772336399132,"CDp":-0.00257652666644439,"CD":0.00493404084011026,"CL":1.50058174057282,"Cpmin":-2.38517993986558,"CDf":0.00233,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.971479338105861,"sym":7.61567438822719,"alpha":5.8,"clcd":304.128358317214,"CDpres":0.00261,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.5600482907419,"diter":4,"src":"retest_155.txt",},        #dud
             {"Bot_Xtr":0.968605272058727,"CD":0.0044695918576089,"CDf":0.00216,"CDp":-0.000621731898017354,"CDpres":0.00231,"CL":1.48461320220204,"Cm":-0.158413262986062,"Cpmin":-2.10980228784027,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re7000000-ncrit6_n17sblowsuck-Re7000000-N6.dat","Re":7000000,"Top_Xtr":0.587470163926762,"alpha":6.4,"clcd":332.158561564111,"cmt":"SPLN 8(B0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat -opt_clcd(6)=(132.065344892868>130.581229400582 aoa=6.3 pa=1.52493482434295 Cl=1.52493482434295 Cd=0.00495200420390635 x=0.590024501909524,0.959589625053321 s=Y u=1.09088518592311 Foil spline 17pts Re7000000 N6","diter":3,"good":130.581229399911,"id":72,"iver":1.2020062,"n":6,"r":6,"src":"","sym":7.69709778126376,"xver":6.991,"xy":[1,0,0.831445790266293,0.0506393007949056,0.787158961173885,0.0709561447202448,0.609627412448822,0.162175426963701,0.464110894666417,0.186317983298381,0.297178219569468,0.170980769799213,0.151647407370497,0.125155042799952,0.0445917027294438,0.0598717757109672,0,0,0.0289533717488074,-0.023481773577564,0.116778598923228,-0.0302901290578133,0.251977818281419,-0.0315864253336734,0.413795561015081,-0.0314250697822135,0.545298902134769,-0.0284345931074117,0.742367239267483,-0.0168257478200677,0.920936730844689,-0.0068520473746352,1,0]},        #7000000 6
             #{"Re":7000000,"n":7,"id":604,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","good":144.074362487686,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.161844083722416,"CD":0.00504837731101472,"CL":1.54423248431267,"CDp":-0.00253625302619054,"CDf":0.0023,"Cpmin":-2.41239301908486,"sym":7.61567438822719,"Bot_Xtr":0.974189784737905,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"clcd":305.886899725862,"CDpres":0.00275,"alpha":6.1,"diter":3,"Top_Xtr":0.562004595076808,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","src":"retest_156.txt"},        #dud
             {"Bot_Xtr":0.972742470919203,"CD":0.00442369523494091,"CDf":0.00205,"CDp":-0.000593588376883785,"CDpres":0.00238,"CL":1.61881524693013,"Cm":-0.181214211808048,"Cpmin":-2.35613757495854,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re7000000-ncrit7_n17sopt-bs-Re7000000-N7.dat.dat","Re":7000000,"Top_Xtr":0.603632662387459,"alpha":7,"clcd":365.941856514841,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt181.658007785407>0) l2 Foil spline 17pts Re7000000 N7","diter":4,"good":181.658007786014,"id":126,"iver":1.2020062,"n":7,"r":6,"src":"","sym":7.38632366755177,"xver":6.991,"xy":[1,0,0.904580632729899,0.0329373232651889,0.754513805075878,0.0843017172590147,0.606442416336649,0.169560361695026,0.466372786349895,0.194241940481958,0.300777767764757,0.177133020131843,0.151647407370497,0.128610212049892,0.0447581531723819,0.0616441200496228,0,0,0.0375624904559413,-0.0312980004510143,0.133527015487591,-0.0394821646978558,0.23557424661141,-0.0404005525649168,0.31989377765649,-0.03883264030351,0.524696483035393,-0.0295000355408325,0.729206346807199,-0.0192271945344255,0.947237618699017,-0.00648086698697492,1,0]},        #7000000 7
             {"xy":[1,0,0.901061808611718,0.0309279022744031,0.678863215861058,0.0984103025323746,0.479050155772191,0.173757247262926,0.304112968064473,0.182329022083014,0.152671216420827,0.14331280171584,0.0512040607733385,0.0862059176432184,0.00202369805924237,0.0312902778334109,0,0,0.0230604239713358,-0.00527464897977672,0.0605603309266164,-0.0039058324312531,0.116429252189166,0.00154220450855022,0.334370367152041,0.0242735394021568,0.52103326718557,0.0338874168032558,0.687642492864678,0.036426309273113,0.866866720476992,0.0245013467517712,1,0],"Bot_Xtr":1,"sym":14.7711420790784,"alpha":6.5,"CDpres":0.00232,"clcd":355.198099492145,"Top_Xtr":0.482102704786667,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1700000-N4.dat","diter":3,"src":"retest_65.txt","Re":7000000,"r":6,"id":605,"cmt":"OPT s(0) optbs_spline_Re1700000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1700000-N4.dat (opt97.8132923084178>86.4551928921508) l1 Foil spline 17pts Re1700000 N4","xver":6.991,"iver":1.2020052,"good":128.523054469243,"Cm":-0.212829954398054,"CDp":0.000713654432694082,"CL":1.81080929589406,"CD":0.00509802642098344,"n":8,"Cpmin":-2.54532668832916,"CDf":0.00278},
             {"Cm":-0.213923465832407,"r":6,"id":606,"good":142.792450489769,"cmt":"OPT s(0) optbs_spline_Re1700000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re1700000-N4.dat (opt97.8132923084178>86.4551928921508) l1 Foil spline 17pts Re1700000 N4","xver":6.991,"iver":1.2020052,"Cpmin":-2.60227474177656,"CDf":0.00275,"CDp":0.000737923480945707,"CL":1.86850160256459,"CD":0.00518029724101147,"n":9,"alpha":7,"clcd":360.693897595682,"CDpres":0.00243,"Bot_Xtr":1,"xy":[1,0,0.901061808611718,0.0309279022744031,0.678863215861058,0.0984103025323746,0.479050155772191,0.173757247262926,0.304112968064473,0.182329022083014,0.152671216420827,0.14331280171584,0.0512040607733385,0.0862059176432184,0.00202369805924237,0.0312902778334109,0,0,0.0230604239713358,-0.00527464897977672,0.0605603309266164,-0.0039058324312531,0.116429252189166,0.00154220450855022,0.334370367152041,0.0242735394021568,0.52103326718557,0.0338874168032558,0.687642492864678,0.036426309273113,0.866866720476992,0.0245013467517712,1,0],"sym":14.7711420790784,"src":"retest_66.txt","Re":7000000,"Top_Xtr":0.48268263218922,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re1700000-N4.dat","diter":3},
             {"diter":4,"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re6000000-N9.dat","Top_Xtr":0.459955088511948,"Re":7000000,"src":"retestc_0.txt","sym":15.1742724409482,"Bot_Xtr":1,"xy":[1,0,0.868661556886963,0.0519317830051054,0.620673721871338,0.114830004405135,0.458819286826548,0.187063560875754,0.307104890650506,0.198334226150094,0.152671216420827,0.157056851229756,0.0512771566887826,0.0944676737473603,0.00313253787259379,0.0360032408670003,0,0,0.0270184392679959,-0.0072566067513566,0.0616968952329497,-0.00556685533673372,0.131064062193512,0.0022790560621164,0.371929606347149,0.0199989741905834,0.479146297313775,0.0253536082353589,0.695690242780121,0.0229338297286667,0.878350726809458,0.0159228469407132,1,0],"CDpres":0.003,"clcd":342.248049210319,"alpha":8.3,"n":10,"CL":1.9916021648173,"CD":0.00581917755093883,"CDp":-0.00015496339361994,"CDf":0.00282,"Cpmin":-3.09818031157222,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt135.600565624712>111.833597520828) l1 Foil spline 17pts Re6000000 N9","iver":1.2020052,"xver":6.991,"good":143.301215439235,"id":607,"r":6,"Cm":-0.201576682089804},
             {"id":608,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt138.301211723912>113.912301194553) l1 Foil spline 17pts Re6000000 N10","xver":6.991,"good":144.915367345035,"iver":1.2020052,"r":6,"Cm":-0.200215177814375,"CL":2.02032978693532,"CD":0.00581023526833502,"n":11,"CDp":-3.8503679856193e-05,"CDf":0.00279,"Cpmin":-3.06070925867417,"sym":14.4995122841615,"Bot_Xtr":1,"xy":[1,0,0.868661556886963,0.0505258193728787,0.620673721871338,0.111721179698189,0.458819286826548,0.181999136966406,0.307104890650506,0.192964668379172,0.152671216420827,0.152804807332103,0.0512771566887826,0.0919101240923293,0.00313253787259379,0.0350285150946092,0,0,0.0270184392679959,-0.00743629775886004,0.0616968952329497,-0.00570470404183222,0.131064062193512,0.00233549096261337,0.371929606347149,0.0204941968124609,0.479146297313775,0.0259814244535668,0.695690242780121,0.0235017264207516,0.878350726809458,0.0163171348644132,1,0],"clcd":347.719101487307,"CDpres":0.00302,"alpha":8.7,"diter":3,"Top_Xtr":0.459711106461562,"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re6000000-N10.dat","Re":7000000,"src":"retest_150.txt"},
             {"alpha":6.3,"CDpres":0.00325,"clcd":321.22490613311,"Bot_Xtr":0.937299242360873,"xy":[1,0,0.961949581813749,0.0164874921645682,0.875758074483928,0.0525134673311509,0.633981356955415,0.155353154394663,0.482035828487994,0.197571017170776,0.31379187525767,0.193056781750808,0.149809351404668,0.142824730194152,0.0348482227959868,0.0667686627690574,0,0,0.0373050544485358,-0.019202315263664,0.146509500030206,-0.0146722048347236,0.314465462409945,-0.00276889800265972,0.501550924851073,0.00694461184207883,0.665300856013736,0.0110521020627751,0.892216666431326,0.0124862887777743,0.964324033244839,0.00815324910023534,1,0],"sym":13.5591951908997,"src":"retest_159.txt","Re":7000000,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re5000000-N5.dat","Top_Xtr":0.533718682953642,"diter":3,"Cm":-0.255916212492189,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt98.1622350598839>70.6871790286362) l1 Foil spline 17pts Re5000000 N5","iver":1.2020052,"good":147.88936946733,"id":609,"Cpmin":-2.53516824016302,"CDf":0.0027,"CDp":0.000369468423260037,"n":12,"CD":0.00594941202274992,"CL":1.91109931855504},
             {"CDp":9.00125662589896e-05,"n":13,"CD":0.00598954886418475,"CL":1.89319880542778,"Cpmin":-2.5523602665224,"CDf":0.00263,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt154.967047004421>122.398150564611) l1 Foil spline 17pts Re13000000 N12","xver":6.991,"good":149.79019175547,"iver":1.2020052,"id":610,"Cm":-0.248574887723024,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N12.dat","Top_Xtr":0.536808727452147,"diter":3,"src":"retest_159.txt","Re":7000000,"xy":[1,0,0.961949581813749,0.0167687799796483,0.875758074483928,0.0534093827523938,0.633981356955415,0.158003584728719,0.482035828487994,0.200941712919311,0.31379187525767,0.196350461576887,0.149809351404668,0.145261417101701,0.0348482227959868,0.0679077815069871,0,0,0.0373050544485358,-0.0179652841217529,0.146509500030206,-0.0137270076513716,0.314465462409945,-0.00259052299886281,0.501550924851073,0.0064972334400904,0.665300856013736,0.010340115292039,0.892216666431326,0.0116819103550208,0.964324033244839,0.00762800915357981,1,0],"Bot_Xtr":0.95398130187356,"sym":14.0238952701483,"alpha":6.4,"CDpres":0.00336,"clcd":316.083706528951},
             {"src":"retest_136.txt","Re":7000000,"Top_Xtr":0.526231240128108,"Foil_fn":"optbs-spline_foil_fx72ls160.dat-s17_n17s0-Re3000000-N9-sq1.dat","diter":3,"alpha":6.7,"CDpres":0.00263,"clcd":340.531296725655,"Bot_Xtr":0.960335742365709,"xy":[1,0,0.961949581813749,0.0140161738151385,0.875758074483928,0.0446421977582958,0.633981356955415,0.13206719329972,0.482035828487994,0.167956999758297,0.31379187525767,0.164119405316572,0.149809351404668,0.121416660794751,0.0348482227959868,0.0567606749064364,0,0,0.0373050544485358,-0.0163645598530019,0.146509500030206,-0.0125039179336713,0.314465462409945,-0.00235970488293799,0.501550924851073,0.00591832362843314,0.665300856013736,0.00941880097396438,0.892216666431326,0.0106410407932635,0.964324033244839,0.00694834612728761,1,0],"sym":9.79910060234566,"Cpmin":-2.19032931879008,"CDf":0.00263,"CDp":0.000589065760232483,"CL":1.79142211420592,"CD":0.00526066805439371,"n":14,"Cm":-0.222177812356765,"r":6,"id":611,"iver":1.2020052,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt99.781203524509>96.495896217837) l1 Foil spline 17pts Re3000000 N9","xver":6.991,"good":148.625736912295},
             #{"Re":8192000,"n":3,"CD":0.00509302764357956,"CL":1.53936335592286,"CDp":-0.00391452796795111,"CDf":0.00229,"Cpmin":-2.60073614910725,"id":612,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","good":99.6947887327607,"iver":1.2020052,"r":6,"Cm":-0.168194372373774,"diter":3,"Top_Xtr":0.565052336225239,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","src":"retestc_2.txt","sym":7.99886704162969,"Bot_Xtr":0.952919935724195,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"clcd":302.249165653643,"CDpres":0.00281,"alpha":6.5},        #dud
             {"Bot_Xtr":0.805948349026437,"CD":0.00427893987130204,"CDf":0.00281,"CDp":-0.000156005351945803,"CDpres":0.00147,"CL":1.11753431674565,"Cm":-0.109338812789401,"Cpmin":-1.88087772800583,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re8192000-ncrit3_n17sopt-bs-Re8192000-N3.dat.dat","Re":8192000,"Top_Xtr":0.516765476485013,"alpha":4.8,"clcd":261.170839123196,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt70.587392700393>0) l2 Foil spline 17pts Re8192000 N3","diter":3,"good":70.5873768465048,"id":11,"iver":1.2020062,"n":3,"r":6,"src":"","sym":3.63666510961183,"xver":6.991,"xy":[1,0,0.879788957837577,0.034859047756835,0.754698861825828,0.0506945761554906,0.570733742690243,0.123524729203739,0.461321631295989,0.148138325615842,0.299009310568114,0.139704365430761,0.151578589479844,0.101196702687497,0.0445917027294438,0.047637626907875,0,0,0.0348337808425599,-0.0167384297080398,0.114271401163628,-0.0255164758673285,0.269342001682685,-0.0283558797267776,0.542292933533747,-0.0358161421152998,0.758678163879147,-0.0297421178424538,0.83535575523683,-0.0113283074881218,0.928880038712883,0.000937608169548115,1,0]},        #8192000 3
             #{"Re":8192000,"n":4,"CDp":-0.00266285859340415,"CL":1.44099469964055,"CD":0.00462997855668963,"Cpmin":-2.35176147841126,"CDf":0.00232,"r":6,"id":613,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"good":115.97009361206,"Cm":-0.156711299213673,"Top_Xtr":0.549361124095259,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":3,"src":"retest_153.txt","xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.957867647619783,"sym":7.61567438822719,"alpha":5.3,"clcd":311.231398158104,"CDpres":0.00231},        #dud
             {"Bot_Xtr":0.9388699394933,"CD":0.00513738946990158,"CDf":0.00233,"CDp":-0.00148656644437646,"CDpres":0.0028,"CL":1.44959404944308,"Cm":-0.0945680460095943,"Cpmin":-2.82940878559666,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re8192000-ncrit4_n17sblowsuck-Re8192000-N4.dat","Re":8192000,"Top_Xtr":0.502110357209079,"alpha":7.2,"clcd":282.165496296478,"cmt":"SPLN 1(B0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat -opt_clcd(7)=(115.508983545188>115.459380541307 aoa=7.2 pa=1.44965118535863 Cl=1.44965118535863 Cd=0.00513772840686033 x=0.502109305338966,0.938870983612912 s=YT u=1.00005938121255 Foil spline 17pts Re8192000 N4","diter":4,"good":114.466101970063,"id":44,"iver":1.2020062,"n":4,"r":6,"src":"","sym":6.95779698906909,"xver":6.991,"xy":[1,0,0.82668112664586,0.0328158092293522,0.784883636828248,0.048222151942098,0.58478253527998,0.143907651188579,0.472374501202811,0.190775025659578,0.321773048583224,0.187022229887012,0.158563277280715,0.132094858452817,0.0473204176592266,0.0610985399948879,0,0,0.0227020892458445,-0.026980996419742,0.137147663093309,-0.0387869970886303,0.230185139189825,-0.0433835548532373,0.366724814174794,-0.042077466982313,0.674329303280588,-0.0400652954210755,0.789626382493842,-0.0364480890065392,0.947795586628629,-0.0200147401846835,1,0]},        #8192000 4
             #{"Re":8192000,"n":5,"Cm":-0.156569565666991,"r":6,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"good":117.212925073798,"id":614,"Cpmin":-2.38552339622497,"CDf":0.00228,"CDp":-0.00270691296113734,"CL":1.50068910057462,"CD":0.00475332750888718,"alpha":5.9,"clcd":315.713381366804,"CDpres":0.00247,"Bot_Xtr":0.969261762601101,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"sym":7.61567438822719,"src":"retest_154.txt","Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.550018434043033,"diter":4},        #dud
             {"Bot_Xtr":0.951951418302038,"CD":0.00436179932450089,"CDf":0.00222,"CDp":-0.000329402030087378,"CDpres":0.00214,"CL":1.39729888079343,"Cm":-0.125171454045029,"Cpmin":-2.26460335298968,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re8192000-ncrit5_n17sopt-Re8192000-N5.dat","Re":8192000,"Top_Xtr":0.545138503761939,"alpha":6.7,"clcd":320.349190056632,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt126.928768830856>0) l2 Foil spline 17pts Re8192000 N5","diter":4,"good":126.928765234469,"id":64,"iver":1.2020062,"n":5,"r":6,"src":"","sym":6.70266407600577,"xver":6.991,"xy":[1,0,0.884240506967539,0.0280145930929153,0.779136675500956,0.065072378117347,0.588296344483766,0.157600860775657,0.464120766590855,0.183308458534012,0.30072239904641,0.170169225008811,0.151637010145491,0.12356917427124,0.0446063466839438,0.0591667048573795,0,0,0.033399556440834,-0.0291838113378566,0.127214538069158,-0.0366320576099516,0.246486331961702,-0.0380048334628898,0.400506516826346,-0.0348090169587249,0.537736151102406,-0.0286526147732617,0.722147440960918,-0.0206881023669325,0.85859121908028,-0.0126318247656802,1,0]},        #8192000 5
             {"Re":8192000,"n":6,"src":"retest_155.txt","diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.550231779640434,"clcd":317.220709305562,"CDpres":0.00268,"alpha":6.4,"sym":7.61567438822719,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.973732435526996,"CDf":0.00226,"Cpmin":-2.42746939850807,"CD":0.00494440508869334,"CL":1.56846768932933,"CDp":-0.00271471709754047,"Cm":-0.160638924096619,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","good":131.785544100307,"iver":1.2020052,"id":615,"r":6},        #dud
             #{"Re":8192000,"n":7,"Cm":-0.158940439219093,"r":6,"id":616,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"xver":6.991,"good":147.344301315339,"Cpmin":-2.3825130435603,"CDf":0.00223,"CDp":-0.00252022408032187,"CL":1.49191378880788,"CD":0.00465657054151457,"alpha":5.7,"CDpres":0.00243,"clcd":320.388959107796,"Bot_Xtr":0.972113212474907,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"sym":7.61567438822719,"src":"retest_156.txt","Top_Xtr":0.561056224432743,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":3},        #dud
             {"Bot_Xtr":0.970696114660987,"CD":0.00426700166081596,"CDf":0.00203,"CDp":-0.00119509117618251,"CDpres":0.00223,"CL":1.55960016582694,"Cm":-0.184561790426674,"Cpmin":-2.32792055977176,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re8192000-ncrit7_n17sopt-Re8192000-N7.dat","Re":8192000,"Top_Xtr":0.602257913685353,"alpha":6.2,"clcd":365.502591702462,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt183.258967850258>104.647081239621) l2 Foil spline 17pts Re8192000 N7","diter":4,"good":183.258966871421,"id":128,"iver":1.2020062,"n":7,"r":6,"src":"","sym":8.50437474328212,"xver":6.991,"xy":[1,0,0.821221469651477,0.0661341606539009,0.762059459804304,0.0849559830073381,0.612414674478645,0.173963482090259,0.471244620724495,0.201001478482092,0.300352161921532,0.184844213265315,0.151510500090357,0.134100536911692,0.0446073628398342,0.0642369471515231,0,0,0.0351840404613808,-0.026386876519168,0.118175022987373,-0.035030109018592,0.244456361209785,-0.0361406058739702,0.442984534330562,-0.032619932752115,0.586354651924033,-0.0258594853557801,0.71474073881658,-0.0184918097381065,0.918780952486089,-0.00787756531179152,1,0]},        #8192000 7
             {"alpha":5.6,"clcd":318.379503246328,"CDpres":0.00307,"Bot_Xtr":0.9061689205394,"xy":[1,0,0.961949581813749,0.0170108717689419,0.875758074483928,0.0541804569182714,0.633981356955415,0.160284691081607,0.482035828487994,0.203842719366017,0.31379187525767,0.19918518387806,0.149809351404668,0.147358564087,0.0348482227959868,0.0688881698448348,0,0,0.0373050544485358,-0.0189456164806907,0.146509500030206,-0.014476065094651,0.314465462409945,-0.00273188305223836,0.501550924851073,0.00685177546356897,0.665300856013736,0.0109043562774438,0.892216666431326,0.0123193706176933,0.964324033244839,0.00804425551833804,1,0],"sym":14.4324468575052,"src":"retest_157.txt","Re":8192000,"Top_Xtr":0.521990872245605,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re10000000-N9.dat","diter":4,"Cm":-0.258356695289957,"r":6,"id":617,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt135.251996683871>93.2858616611881) l1 Foil spline 17pts Re10000000 N9","xver":6.991,"good":126.298368770794,"Cpmin":-2.53237049962953,"CDf":0.00277,"CDp":0.000142133155775912,"CD":0.00583125156609931,"CL":1.85655097691907,"n":8},
             {"Cpmin":-2.61860141795045,"CDf":0.0026,"CDp":0.000597863418481998,"n":9,"CL":1.7725525268364,"CD":0.00469416790665918,"Cm":-0.171794215677045,"r":6,"cmt":"OPT s(0) optbs_spline_Re2000000_N4_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re2000000-N4.dat (opt94.7537669898666>90.8061159440826) l1 Foil spline 17pts Re2000000 N4","xver":6.991,"good":140.044768637343,"iver":1.2020052,"id":618,"src":"retest_85.txt","Re":8192000,"Foil_fn":"opt_spline_optcndR1419574_jn153_nsopt-Re2000000-N4.dat","Top_Xtr":0.464799383632487,"diter":3,"alpha":7.4,"CDpres":0.00209,"clcd":377.607397537238,"Bot_Xtr":1,"xy":[1,0,0.846850991762938,0.0397799700830096,0.618759529220692,0.0991669041274397,0.458819286826548,0.164195565712566,0.307104890650506,0.174088423797879,0.152671216420827,0.137857092081296,0.0512771566887826,0.0829192658360667,0.00313253787259379,0.0316019457448973,0,0,0.0270180988871576,-0.00706119981313042,0.0567597507633455,-0.00493855033216721,0.124449942112133,0.00161907508125432,0.363725211219444,0.021187685255305,0.478543031346716,0.0246549544741675,0.677672510229979,0.0243400469170023,0.885059558802994,0.0170758798547109,1,0],"sym":11.8500849605087},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt83.2447436343458>56.2335539381475) l1 Foil spline 17pts Re3000000 N3","xver":6.991,"good":137.553197430203,"id":619,"r":6,"Cm":-0.240473075065385,"n":10,"CD":0.00515507641492145,"CL":1.7359648635611,"CDp":0.0004740279741869,"CDf":0.00269,"Cpmin":-2.25068963866852,"sym":11.6361064358207,"Bot_Xtr":0.914973584961208,"xy":[1,0,0.961949581813749,0.0152736475123997,0.875758074483928,0.0486473128638434,0.633981356955415,0.143915720867646,0.482035828487994,0.183025413738641,0.31379187525767,0.178843526044359,0.149809351404668,0.132309666216372,0.0348482227959868,0.0618530101382206,0,0,0.0373050544485358,-0.0177438469118382,0.146509500030206,-0.0135578107572843,0.314465462409945,-0.00255859262797636,0.501550924851073,0.00641714958305883,0.665300856013736,0.0102126646898138,0.892216666431326,0.0115379210021134,0.964324033244839,0.00753398753651409,1,0],"CDpres":0.00246,"clcd":336.748618999386,"alpha":5.3,"diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re3000000-N3.dat","Top_Xtr":0.529297815504886,"Re":8192000,"src":"retest_85.txt"},
             {"Re":8192000,"src":"retest_104.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re4000000-N5.dat","Top_Xtr":0.526240600852437,"CDpres":0.00283,"clcd":338.442968999357,"alpha":6.1,"sym":12.5054735137668,"xy":[1,0,0.961949581813749,0.0158341110403722,0.875758074483928,0.0504324165577656,0.633981356955415,0.149196680283705,0.482035828487994,0.189741495736036,0.31379187525767,0.185406154485305,0.149809351404668,0.137164743711927,0.0348482227959868,0.0641226943279101,0,0,0.0373050544485358,-0.0182164814328723,0.146509500030206,-0.0139189437982408,0.314465462409945,-0.0026267446587763,0.501550924851073,0.0065880801842223,0.665300856013736,0.0104846946452194,0.892216666431326,0.0118452511878199,0.964324033244839,0.00773466682598775,1,0],"Bot_Xtr":0.929007467661987,"CDf":0.00266,"Cpmin":-2.4198448057831,"n":11,"CD":0.00549021087747161,"CL":1.85812326980406,"CDp":0.000413859914339153,"Cm":-0.248846444013064,"good":146.359640051527,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt104.930607575316>74.5995792539018) l1 Foil spline 17pts Re4000000 N5","xver":6.991,"iver":1.2020052,"id":620,"r":6},
             {"CDp":0.000378405313240414,"n":12,"CD":0.0055722536393348,"CL":1.8718505885886,"Cpmin":-2.49397150167479,"CDf":0.00265,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt98.1622350598839>70.6871790286362) l1 Foil spline 17pts Re5000000 N5","iver":1.2020052,"good":151.615018417507,"id":621,"Cm":-0.258135998097925,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re5000000-N5.dat","Top_Xtr":0.534060239969102,"diter":3,"src":"retest_65.txt","Re":8192000,"xy":[1,0,0.961949581813749,0.0164874921645682,0.875758074483928,0.0525134673311509,0.633981356955415,0.155353154394663,0.482035828487994,0.197571017170776,0.31379187525767,0.193056781750808,0.149809351404668,0.142824730194152,0.0348482227959868,0.0667686627690574,0,0,0.0373050544485358,-0.019202315263664,0.146509500030206,-0.0146722048347236,0.314465462409945,-0.00276889800265972,0.501550924851073,0.00694461184207883,0.665300856013736,0.0110521020627751,0.892216666431326,0.0124862887777743,0.964324033244839,0.00815324910023534,1,0],"Bot_Xtr":0.924026122873175,"sym":13.5591951908997,"alpha":5.8,"CDpres":0.00293,"clcd":335.923435964063},
             {"CDf":0.00261,"Cpmin":-2.38392843652984,"CD":0.00539516761992904,"CL":1.86538812639716,"n":13,"CDp":0.000477422644887657,"Cm":-0.244217422495032,"id":622,"good":153.882623691346,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt105.585227131506>101.243646320523) l1 Foil spline 17pts Re2500000 N6","xver":6.991,"iver":1.2020052,"r":6,"Re":8192000,"src":"retest_86.txt","diter":3,"Top_Xtr":0.527847042036655,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re2500000-N6.dat","clcd":345.751653666266,"CDpres":0.00278,"alpha":6.4,"sym":11.8220315593656,"xy":[1,0,0.961949581813749,0.0153950944786205,0.875758074483928,0.0490341273793225,0.633981356955415,0.145060053135145,0.482035828487994,0.184480723036687,0.31379187525767,0.180265583457213,0.149809351404668,0.133361714036032,0.0348482227959868,0.0623448285088365,0,0,0.0373050544485358,-0.0179767582998012,0.146509500030206,-0.0137357749009623,0.314465462409945,-0.00259217753000887,0.501550924851073,0.00650138313306536,0.665300856013736,0.0103467193804073,0.892216666431326,0.0116893714293044,0.964324033244839,0.00763288105733537,1,0],"Bot_Xtr":0.939451512632775},
             {"CDpres":0.00334,"clcd":331.477363183452,"alpha":6.6,"sym":14.4324468575052,"xy":[1,0,0.961949581813749,0.0170108717689419,0.875758074483928,0.0541804569182714,0.633981356955415,0.160284691081607,0.482035828487994,0.203842719366017,0.31379187525767,0.19918518387806,0.149809351404668,0.147358564087,0.0348482227959868,0.0688881698448348,0,0,0.0373050544485358,-0.0189456164806907,0.146509500030206,-0.014476065094651,0.314465462409945,-0.00273188305223836,0.501550924851073,0.00685177546356897,0.665300856013736,0.0109043562774438,0.892216666431326,0.0123193706176933,0.964324033244839,0.00804425551833804,1,0],"Bot_Xtr":0.945242565580748,"Re":8192000,"src":"retest_102.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re10000000-N9.dat","Top_Xtr":0.534518154067436,"Cm":-0.25780925232461,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt135.251996683871>93.2858616611881) l1 Foil spline 17pts Re10000000 N9","xver":6.991,"good":154.757179258229,"id":623,"r":6,"CDf":0.00256,"Cpmin":-2.63226828128762,"n":14,"CL":1.95380386372236,"CD":0.00589423013673803,"CDp":7.96581435953117e-05},
             {"r":6,"id":624,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"xver":6.991,"good":105.457256820866,"Cm":-0.170400857862044,"CDp":0.000182711822796797,"CD":0.00588494102038456,"CL":1.87372217693727,"n":3,"Cpmin":-3.37076026789723,"CDf":0.00272,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.845307873672459,"sym":6.4243025225839,"alpha":8,"CDpres":0.00317,"clcd":318.392685746037,"Top_Xtr":0.436986735897419,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","diter":5,"src":"retest_98.txt","Re":10000000},
             {"diter":8,"Top_Xtr":0.445536411078625,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Re":10000000,"src":"retest_99.txt","sym":6.4243025225839,"Bot_Xtr":0.84759107360919,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"clcd":348.667703416342,"CDpres":0.00354,"alpha":10,"CL":2.11501682456504,"CD":0.00606599580013156,"n":4,"CDp":6.15953533783802e-05,"CDf":0.00252,"Cpmin":-3.63059220061902,"id":625,"good":92.6686595276047,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.179951342837055},
             {"r":6,"id":626,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt93.901902038521>63.8049882748146) l1 Foil spline 17pts Re10000000 N5","good":93.9018975535367,"iver":1.2020052,"Cm":-0.155920407515974,"CDp":-0.00306360855630923,"CL":1.49859130815714,"CD":0.00629981458377958,"n":5,"Cpmin":-2.35673622876078,"CDf":0.00238,"xy":[1,0,0.850203906919876,0.0636970525732378,0.786878980256792,0.0915963945688357,0.603993922289437,0.16871532146376,0.464110894666417,0.200378147793961,0.300719048572926,0.1852271748092,0.151647407370497,0.134599651731772,0.0445917027294438,0.0643898957562584,0,0,0.0255348494188518,-0.0267302094452239,0.113212321059693,-0.0376393887538898,0.241812094300539,-0.040958382450667,0.388474534135911,-0.0387998348299053,0.529590978122237,-0.0317732285345386,0.742367239267483,-0.0179603472180438,0.920936730844689,-0.00731409690190153,1,0],"Bot_Xtr":0.975587070330269,"sym":8.11502713891323,"alpha":7,"clcd":237.878637256346,"CDpres":0.00392,"Top_Xtr":0.512029069834646,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re10000000-N5.dat","diter":6,"src":"retestc_19.txt","Re":10000000},
             {"diter":22,"Top_Xtr":0.516178875673601,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat","Re":10000000,"src":"retest_88.txt","sym":7.2841406812624,"Bot_Xtr":0.9791719011747,"xy":[1,0,0.850203906919876,0.0602587253399253,0.786878980256792,0.0866520782277121,0.603993922289437,0.159608173471332,0.464110894666417,0.189561860152887,0.300719048572926,0.17522872725523,0.151647407370497,0.127334046347416,0.0445917027294438,0.0609141692793647,0,0,0.0255348494188518,-0.0251438920859591,0.113212321059693,-0.0354056608104269,0.241812094300539,-0.038527687202205,0.388474534135911,-0.0364972396462269,0.529590978122237,-0.0298876307397472,0.742367239267483,-0.0168944816239567,0.920936730844689,-0.00688003824229367,1,0],"CDpres":0.00303,"clcd":268.578404635444,"alpha":6.6,"CL":1.45341470093956,"CD":0.00541150991984021,"n":6,"CDp":-0.00206967384013442,"CDf":0.00238,"Cpmin":-2.22671800109764,"id":627,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt86.9397983812463>81.7010241598956) l1 Foil spline 17pts Re5000000 N4","iver":1.2020052,"xver":6.991,"good":101.384279604514,"r":6,"Cm":-0.153367442210632},
             {"CDp":-0.00180449403036515,"n":7,"CD":0.00528010402238526,"CL":1.47249581948801,"Cpmin":-2.20529244347163,"CDf":0.00235,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt115.691719933531>104.532170942892) l1 Foil spline 17pts Re10000000 N7","iver":1.2020052,"good":115.691719933456,"id":628,"Cm":-0.15520336006842,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re10000000-N7.dat","Top_Xtr":0.520156843579455,"diter":2,"src":"retestc_21.txt","Re":10000000,"xy":[1,0,0.850203906919876,0.0593404359924485,0.786878980256792,0.0853315776707494,0.603993922289437,0.157175886949469,0.464110894666417,0.186673106103008,0.300719048572926,0.172558397395069,0.151647407370497,0.125393588800856,0.0445917027294438,0.0599858915495572,0,0,0.0255348494188518,-0.0245827156423111,0.113212321059693,-0.0346154560660429,0.241812094300539,-0.0376678032028542,0.388474534135911,-0.0356826723915784,0.529590978122237,-0.0292205806955354,0.742367239267483,-0.0165174204640297,0.920936730844689,-0.0067264854279651,1,0],"Bot_Xtr":0.984102178336539,"sym":7.09022245011389,"alpha":6.7,"CDpres":0.00293,"clcd":278.87628979378},
             {"sym":6.43003678073749,"Bot_Xtr":0.98210523070699,"xy":[1,0,0.850203906919876,0.0568895174591879,0.786878980256792,0.0818071555513666,0.603993922289437,0.150684102926259,0.464110894666417,0.178963008127533,0.300719048572926,0.165431274596391,0.151647407370497,0.120214498596948,0.0445917027294438,0.0575083139774666,0,0,0.0255348494188518,-0.0241782333733513,0.113212321059693,-0.0340458957939234,0.241812094300539,-0.0370480198262773,0.388474534135911,-0.0350955522173266,0.529590978122237,-0.0287397873221739,0.742367239267483,-0.0162456439929569,0.920936730844689,-0.00661580831126178,1,0],"clcd":287.842909108484,"CDpres":0.00243,"alpha":6,"diter":12,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re10000000-N8.dat","Top_Xtr":0.525298223473122,"Re":10000000,"src":"retest_100.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt126.809636465881>118.259492718218) l1 Foil spline 17pts Re10000000 N8","iver":1.2020052,"good":126.809636434161,"id":629,"r":6,"Cm":-0.149717313128284,"n":8,"CD":0.00478698228291459,"CL":1.3778989061649,"CDp":-0.00124726402769316,"CDf":0.00235,"Cpmin":-2.06248374772896},
             {"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re10000000-N9.dat","Top_Xtr":0.521345127172098,"diter":3,"src":"retest_158.txt","Re":10000000,"xy":[1,0,0.961949581813749,0.0170108717689419,0.875758074483928,0.0541804569182714,0.633981356955415,0.160284691081607,0.482035828487994,0.203842719366017,0.31379187525767,0.19918518387806,0.149809351404668,0.147358564087,0.0348482227959868,0.0688881698448348,0,0,0.0373050544485358,-0.0189456164806907,0.146509500030206,-0.014476065094651,0.314465462409945,-0.00273188305223836,0.501550924851073,0.00685177546356897,0.665300856013736,0.0109043562774438,0.892216666431326,0.0123193706176933,0.964324033244839,0.00804425551833804,1,0],"Bot_Xtr":0.902049074647124,"sym":14.4324468575052,"alpha":5.6,"CDpres":0.00287,"clcd":339.133557257475,"CDp":0.000171466879479966,"n":9,"CL":1.87548168911731,"CD":0.00553021560085079,"Cpmin":-2.5481935330744,"CDf":0.00266,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt135.251996683871>93.2858616611881) l1 Foil spline 17pts Re10000000 N9","iver":1.2020052,"good":135.251996684012,"id":630,"Cm":-0.262320351439967},
             {"src":"retest_110.txt","Re":10000000,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re10000000-N9.dat","Top_Xtr":0.521256422911215,"diter":3,"alpha":6.1,"CDpres":0.003,"clcd":343.188697810311,"Bot_Xtr":0.916242984734457,"xy":[1,0,0.961949581813749,0.0170108717689419,0.875758074483928,0.0541804569182714,0.633981356955415,0.160284691081607,0.482035828487994,0.203842719366017,0.31379187525767,0.19918518387806,0.149809351404668,0.147358564087,0.0348482227959868,0.0688881698448348,0,0,0.0373050544485358,-0.0189456164806907,0.146509500030206,-0.014476065094651,0.314465462409945,-0.00273188305223836,0.501550924851073,0.00685177546356897,0.665300856013736,0.0109043562774438,0.892216666431326,0.0123193706176933,0.964324033244839,0.00804425551833804,1,0],"sym":14.4324468575052,"Cpmin":-2.60008202252921,"CDf":0.00262,"CDp":0.000121678244199318,"n":10,"CL":1.92624025179722,"CD":0.0056127729849131,"Cm":-0.262568837329838,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt135.251996683871>93.2858616611881) l1 Foil spline 17pts Re10000000 N9","iver":1.2020052,"good":138.747852268443,"id":631},
             {"r":6,"id":632,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt154.967047004421>122.398150564611) l1 Foil spline 17pts Re13000000 N12","xver":6.991,"iver":1.2020052,"good":146.248896632288,"Cm":-0.257454492183924,"CDp":0.00014443259716093,"CL":1.90488729182209,"CD":0.00546437908018445,"n":11,"Cpmin":-2.55690947691772,"CDf":0.00257,"xy":[1,0,0.961949581813749,0.0167687799796483,0.875758074483928,0.0534093827523938,0.633981356955415,0.158003584728719,0.482035828487994,0.200941712919311,0.31379187525767,0.196350461576887,0.149809351404668,0.145261417101701,0.0348482227959868,0.0679077815069871,0,0,0.0373050544485358,-0.0179652841217529,0.146509500030206,-0.0137270076513716,0.314465462409945,-0.00259052299886281,0.501550924851073,0.0064972334400904,0.665300856013736,0.010340115292039,0.892216666431326,0.0116819103550208,0.964324033244839,0.00762800915357981,1,0],"Bot_Xtr":0.924167164087332,"sym":14.0238952701483,"alpha":6.1,"CDpres":0.00289,"clcd":348.600868254145,"Top_Xtr":0.525021621369399,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N12.dat","diter":3,"src":"retestc_18.txt","Re":10000000},
             {"CDf":0.00259,"Cpmin":-2.42828723903895,"n":12,"CL":1.80741138461178,"CD":0.00513683867243965,"CDp":0.00035811788410219,"Cm":-0.259321081851013,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt98.1622350598839>70.6871790286362) l1 Foil spline 17pts Re5000000 N5","xver":6.991,"good":151.053552752224,"id":633,"r":6,"Re":10000000,"src":"retest_66.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re5000000-N5.dat","Top_Xtr":0.534541388062582,"clcd":351.852861237199,"CDpres":0.00255,"alpha":5.1,"sym":13.5591951908997,"xy":[1,0,0.961949581813749,0.0164874921645682,0.875758074483928,0.0525134673311509,0.633981356955415,0.155353154394663,0.482035828487994,0.197571017170776,0.31379187525767,0.193056781750808,0.149809351404668,0.142824730194152,0.0348482227959868,0.0667686627690574,0,0,0.0373050544485358,-0.019202315263664,0.146509500030206,-0.0146722048347236,0.314465462409945,-0.00276889800265972,0.501550924851073,0.00694461184207883,0.665300856013736,0.0110521020627751,0.892216666431326,0.0124862887777743,0.964324033244839,0.00815324910023534,1,0],"Bot_Xtr":0.903290105436937},
             {"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re5000000-N12.dat","Top_Xtr":0.466002612372574,"diter":3,"src":"retest_145.txt","Re":10000000,"xy":[1,0,0.868661556886963,0.05258717614282,0.620673721871338,0.116279190097131,0.458819286826548,0.18942435357379,0.307104890650506,0.200837257690142,0.152671216420827,0.159038951141806,0.0512771566887826,0.0956598813228983,0.00313253787259379,0.0364576114977448,0,0,0.0270184392679959,-0.00848361440850959,0.0616968952329497,-0.00650814571644987,0.131064062193512,0.00266441788963654,0.371929606347149,0.0233805677242916,0.479146297313775,0.0296406080008383,0.695690242780121,0.0268116731407623,0.878350726809458,0.0186152148461778,1,0],"Bot_Xtr":1,"sym":15.9893172386101,"alpha":8.2,"CDpres":0.00271,"clcd":386.597786239097,"CDp":-6.65543823449719e-05,"n":13,"CD":0.00527695363682681,"CL":2.0400585940836,"Cpmin":-3.16983027535097,"CDf":0.00257,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt132.216496894764>113.531663510978) l1 Foil spline 17pts Re5000000 N12","xver":6.991,"good":160.967087988387,"id":634,"Cm":-0.214842495342006},
             {"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt109.027646649367>94.1630434534958) l1 Foil spline 17pts Re3000000 N9","iver":1.2020052,"good":158.372109408308,"id":635,"Cm":-0.218905300559589,"CDp":-0.000159048751191429,"n":14,"CD":0.00542813595249021,"CL":2.11269484990172,"Cpmin":-3.28509477068248,"CDf":0.00255,"xy":[1,0,0.868661556886963,0.053442055836459,0.620673721871338,0.118169474491503,0.458819286826548,0.192503717122635,0.307104890650506,0.204102154304083,0.152671216420827,0.161624356554326,0.0512771566887826,0.0972149693887941,0.00313253787259379,0.0370502820694324,0,0,0.0270184392679959,-0.00857943311426484,0.0616968952329497,-0.00658165236932076,0.131064062193512,0.00269451132169069,0.371929606347149,0.023644640987324,0.479146297313775,0.0299753856745608,0.695690242780121,0.0271144992353693,0.878350726809458,0.0188254655374548,1,0],"Bot_Xtr":1,"sym":16.4970411678021,"alpha":8.7,"clcd":389.211852538899,"CDpres":0.00287,"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re3000000-N9.dat","Top_Xtr":0.464891595421508,"diter":3,"src":"retest_85.txt","Re":10000000},
             {"Re":13000000,"src":"retest_152.txt","diter":3,"Top_Xtr":0.445194903774226,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","clcd":331.418909138238,"CDpres":0.00238,"alpha":6,"sym":6.4243025225839,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.840891782898575,"CDf":0.00259,"Cpmin":-3.18866955337511,"CL":1.64858245285303,"CD":0.00497431621249285,"n":3,"CDp":0.000151638995307914,"Cm":-0.164975322050235,"id":636,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"xver":6.991,"good":109.039922618631,"r":6},
             {"Cpmin":-3.49083103480742,"CDf":0.00247,"CDp":3.96284145521902e-05,"n":4,"CD":0.00539406989784789,"CL":1.98750509100144,"Cm":-0.177651932369011,"r":6,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","good":117.515975881229,"xver":6.991,"iver":1.2020052,"id":637,"src":"retest_153.txt","Re":13000000,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.445564199163473,"diter":3,"alpha":8.8,"CDpres":0.00292,"clcd":368.461130211607,"Bot_Xtr":0.846633725638573,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"sym":6.4243025225839},
             {"Cm":-0.184402348265313,"r":6,"good":99.350131550719,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"iver":1.2020052,"id":638,"Cpmin":-3.68599681379854,"CDf":0.00236,"CDp":-3.06713240124765e-05,"n":5,"CL":2.16550181808053,"CD":0.00562498005693767,"alpha":10.3,"CDpres":0.00327,"clcd":384.979465911113,"Bot_Xtr":0.847994052913916,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"sym":6.4243025225839,"src":"retestc_4.txt","Re":13000000,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.4482292204857,"diter":3},
             {"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.848542614957359,"sym":6.4243025225839,"alpha":10,"CDpres":0.00331,"clcd":376.118013047937,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.451005003071541,"diter":9,"src":"retest_155.txt","Re":13000000,"r":6,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"good":95.837995677506,"id":639,"Cm":-0.182046306753902,"CDp":0.000113392958044138,"n":6,"CL":2.12554963229814,"CD":0.00565128379540607,"Cpmin":-3.64223763640549,"CDf":0.00235},
             {"Cm":-0.155411867564739,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt97.4795743828944>88.9471160911265) l1 Foil spline 17pts Re7000000 N5","xver":6.991,"good":104.881821855838,"iver":1.2020052,"id":640,"r":6,"CDf":0.00224,"Cpmin":-2.24638668426408,"n":7,"CL":1.4539553713778,"CD":0.0050142445900679,"CDp":-0.0020768541712626,"CDpres":0.00277,"clcd":289.964987798513,"alpha":6.5,"sym":7.33779697396074,"xy":[1,0,0.850203906919876,0.060707159748726,0.786878980256792,0.0872969271396697,0.603993922289437,0.160795948295752,0.464110894666417,0.190972544833144,0.300719048572926,0.17653274738291,0.151647407370497,0.128281643022783,0.0445917027294438,0.06136748138204,0,0,0.0255348494188518,-0.0256958484478228,0.113212321059693,-0.0361828825573025,0.241812094300539,-0.039373443379747,0.388474534135911,-0.037298423629372,0.529590978122237,-0.0305437212078195,0.742367239267483,-0.01726534770073,0.920936730844689,-0.00703106819679382,1,0],"Bot_Xtr":0.976259465231994,"Re":13000000,"src":"retest_104.txt","diter":3,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re7000000-N5.dat","Top_Xtr":0.515713874486317},
             {"Cm":-0.187999313887088,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"good":137.012398489592,"iver":1.2020052,"id":641,"r":6,"CDf":0.00213,"Cpmin":-2.3828302623107,"n":8,"CL":1.68171275947966,"CD":0.00460727695634021,"CDp":-0.00166906120032496,"clcd":365.012300197278,"CDpres":0.00248,"alpha":7.3,"sym":8.18651951349902,"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.985136228538774,"Re":13000000,"src":"retest_148.txt","diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.53321427943799},
             {"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.991858164492595,"sym":8.18651951349902,"alpha":7.6,"clcd":367.2666553873,"CDpres":0.00257,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","Top_Xtr":0.533459020711353,"diter":3,"src":"retest_149.txt","Re":13000000,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","good":141.546205171259,"iver":1.2020052,"id":642,"Cm":-0.189373885300565,"CDp":-0.0017248111009288,"n":9,"CL":1.71757657332425,"CD":0.00467664719388418,"Cpmin":-2.40346694259825,"CDf":0.00211},
             {"xy":[1,0,0.896012651964869,0.0445507499302086,0.799880215683011,0.0674535224643448,0.605689214099502,0.160495760661041,0.468064610484257,0.189977808592652,0.308384422411202,0.175924275380904,0.157023866654493,0.128128199314718,0.0476221089503731,0.0612583860500145,0,0,0.0239783553090483,-0.0258365748868897,0.10279905924252,-0.0332782841089383,0.231693396599955,-0.0317258079935075,0.315365066178733,-0.0279584119093288,0.513802885132155,-0.0181952549973467,0.752671534234119,-0.00959480374581283,0.957678548317355,-0.000601928529408325,1,0],"Bot_Xtr":0.994176603240413,"sym":8.18651951349902,"alpha":7.9,"CDpres":0.00266,"clcd":370.441209771406,"Top_Xtr":0.533138829655286,"Foil_fn":"opt_spline_gu255118_nsopt-Re4000000-N4.dat","diter":3,"src":"retest_150.txt","Re":13000000,"r":6,"id":643,"good":150.11317301152,"cmt":"OPT s(0) optbs_spline_Re4000000_N4_gu255118.dat-s17_n17s0_nsopt-Re4000000-N4.dat (opt120.185058490201>88.8266548305414) l1 Foil spline 17pts Re4000000 N4","xver":6.991,"iver":1.2020052,"Cm":-0.192830262124458,"CDp":-0.00169762675501389,"CD":0.00475746395730133,"CL":1.76236070378656,"n":10,"Cpmin":-2.43113583154536,"CDf":0.0021},
             #{"Re":13000000,"n":11,"Cm":-0.181179504242459,"r":6,"id":644,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"good":160.16181665515,"Cpmin":-2.72221405932066,"CDf":0.00188,"CDp":-0.0035299892345475,"CD":0.00458395633074609,"CL":1.71443285207883,"alpha":7.7,"clcd":374.007239244311,"CDpres":0.0027,"Bot_Xtr":0.971341291386192,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"sym":7.99886704162969,"src":"retest_98.txt","Top_Xtr":0.576407895907809,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","diter":3},        #dud
             {"Bot_Xtr":0.996666688621476,"CD":0.00289696382367883,"CDf":0.00164,"CDp":-0.000211827135629531,"CDpres":0.00126,"CL":1.36208189548498,"Cm":-0.119682118690585,"Cpmin":-1.95762502840218,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re13000000-ncrit11_n17sopt-Re13000000-N11.dat","Re":13000000,"Top_Xtr":0.592356455087697,"alpha":6.2,"clcd":470.175666106622,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt221.778495100268>0) l2 Foil spline 17pts Re13000000 N11","diter":3,"good":221.778647711857,"id":143,"iver":1.2020062,"n":11,"r":6,"src":"","sym":6.95980144790933,"xver":6.991,"xy":[1,0,0.869609677082848,0.0181248484683948,0.739096410665657,0.0626846443527904,0.600235223242148,0.142099977696259,0.462223886291732,0.167303524087917,0.301003948066303,0.15567668255192,0.151722994367624,0.113457677866128,0.0476727650522673,0.0546422788275083,0,0,0.0273682897687174,-0.0223326811907287,0.13933409502779,-0.0251427680049689,0.288245682947016,-0.0215205135690233,0.444211570493866,-0.0158076197496946,0.628050079959763,-0.0121112421140887,0.850689486438347,-0.00528171075617693,0.953870222825431,-0.00223568276002849,1,0]},        #13000000 11
             {"Cpmin":-2.52872983349388,"CDf":0.00247,"CDp":0.000166814335586073,"CD":0.00502268634907467,"CL":1.87918266686815,"n":12,"Cm":-0.26036343671015,"r":6,"id":645,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt154.967047004421>122.398150564611) l1 Foil spline 17pts Re13000000 N12","xver":6.991,"good":154.967047004526,"src":"retestc_12.txt","Re":13000000,"Top_Xtr":0.525151447027012,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N12.dat","diter":3,"alpha":5.7,"clcd":374.138963945927,"CDpres":0.00255,"Bot_Xtr":0.91033615695128,"xy":[1,0,0.961949581813749,0.0167687799796483,0.875758074483928,0.0534093827523938,0.633981356955415,0.158003584728719,0.482035828487994,0.200941712919311,0.31379187525767,0.196350461576887,0.149809351404668,0.145261417101701,0.0348482227959868,0.0679077815069871,0,0,0.0373050544485358,-0.0179652841217529,0.146509500030206,-0.0137270076513716,0.314465462409945,-0.00259052299886281,0.501550924851073,0.0064972334400904,0.665300856013736,0.010340115292039,0.892216666431326,0.0116819103550208,0.964324033244839,0.00762800915357981,1,0],"sym":14.0238952701483},
             {"n":13,"CL":1.90107953000609,"CD":0.00504851694545801,"CDp":0.000161794574717278,"CDf":0.00245,"Cpmin":-2.55040845865438,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt154.967047004421>122.398150564611) l1 Foil spline 17pts Re13000000 N12","xver":6.991,"iver":1.2020052,"good":158.086988094886,"id":646,"r":6,"Cm":-0.260783811321441,"diter":4,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N12.dat","Top_Xtr":0.525781848114382,"Re":13000000,"src":"retestc_18.txt","sym":14.0238952701483,"Bot_Xtr":0.91676470606107,"xy":[1,0,0.961949581813749,0.0167687799796483,0.875758074483928,0.0534093827523938,0.633981356955415,0.158003584728719,0.482035828487994,0.200941712919311,0.31379187525767,0.196350461576887,0.149809351404668,0.145261417101701,0.0348482227959868,0.0679077815069871,0,0,0.0373050544485358,-0.0179652841217529,0.146509500030206,-0.0137270076513716,0.314465462409945,-0.00259052299886281,0.501550924851073,0.0064972334400904,0.665300856013736,0.010340115292039,0.892216666431326,0.0116819103550208,0.964324033244839,0.00762800915357981,1,0],"CDpres":0.0026,"clcd":376.561978605702,"alpha":5.9},
             {"r":6,"id":647,"cmt":"OPT s(0) foildb2020_spline/spline_foil_optcndR1419574_jn153.dat-s17_n17s0.dat (opt146.862231388732>128.59873578144) l1 Foil spline 17pts Re10000000 N12","xver":6.991,"iver":1.2020052,"good":162.274839642728,"Cm":-0.209956722771756,"CDp":-4.87957082708735e-05,"CL":1.97308221781037,"CD":0.00475459061135835,"n":14,"Cpmin":-3.04558182123478,"CDf":0.00243,"xy":[1,0,0.868661556886963,0.0513469713228564,0.620673721871338,0.113536886315155,0.458819286826548,0.184957009754402,0.307104890650506,0.196100754358244,0.152671216420827,0.155288210215305,0.0512771566887826,0.093403858950227,0.00313253787259379,0.0355978029128331,0,0,0.0270184392679959,-0.00822049720499922,0.0616968952329497,-0.00630629718603662,0.131064062193512,0.00258178162750268,0.371929606347149,0.0226554251966055,0.479146297313775,0.0287213118716195,0.695690242780121,0.0259801157268427,0.878350726809458,0.0180378685598876,1,0],"Bot_Xtr":1,"sym":15.2204979042413,"alpha":7.8,"clcd":414.984670414489,"CDpres":0.00233,"Top_Xtr":0.466053547059485,"Foil_fn":"optbs_spline_optcndR1419574_jn153.dat-s17_n17s0_nsopt-Re10000000-N12.dat","diter":3,"src":"retest_87.txt","Re":13000000},
             {"Re":16000000,"src":"retestc_19.txt","diter":3,"Top_Xtr":0.35855670576886,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","clcd":269.877437967504,"CDpres":0.00393,"alpha":8.8,"sym":10.5670651208425,"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"Bot_Xtr":0.979718160261359,"CDf":0.0027,"Cpmin":-4.19575963645401,"CD":0.00663126749964105,"CL":1.78962948328031,"n":3,"CDp":-0.00097656079236227,"Cm":-0.111051656393254,"id":648,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","good":84.6040106867956,"iver":1.2020052,"r":6},
             {"alpha":7.6,"CDpres":0.00248,"clcd":378.318044546093,"Bot_Xtr":0.845217654370323,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"sym":6.4243025225839,"src":"retestc_22.txt","Re":16000000,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.446398524202453,"diter":3,"Cm":-0.174311097043965,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"good":129.099708946985,"id":649,"Cpmin":-3.34902185856946,"CDf":0.00242,"CDp":4.20906130757142e-05,"n":4,"CL":1.85329758284162,"CD":0.00489878188354777},
             {"sym":6.4243025225839,"Bot_Xtr":0.84750034973078,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"CDpres":0.003,"clcd":400.600313694521,"alpha":10,"diter":11,"Top_Xtr":0.442115205191136,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Re":16000000,"src":"retestc_23.txt","id":650,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"iver":1.2020052,"good":102.748990760991,"r":6,"Cm":-0.185175722682686,"CD":0.0053419523173841,"CL":2.13998777408524,"n":5,"CDp":-0.000123853369992386,"CDf":0.00234,"Cpmin":-3.65779452395377},
             {"Re":16000000,"n":6,"r":6,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","good":106.645778159107,"xver":6.991,"iver":1.2020052,"id":651,"Cm":-0.152160369220558,"CDp":-0.00255356388254437,"CL":1.39178941779933,"CD":0.00390056645764753,"Cpmin":-2.32538825064091,"CDf":0.00204,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.957677615696017,"sym":7.61567438822719,"alpha":5,"CDpres":0.00186,"clcd":356.81725536827,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.535487130578663,"diter":4,"src":"retest_154.txt",},        #dud
             #{"Re":16000000,"n":7,"src":"retest_155.txt","diter":10,"Top_Xtr":0.550865147765578,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","clcd":376.983839950121,"CDpres":0.00162,"alpha":4.6,"sym":7.61567438822719,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.956047188279255,"CDf":0.00197,"Cpmin":-2.30310992363781,"CD":0.00358790803191465,"CL":1.35258334725907,"CDp":-0.00245581464063682,"Cm":-0.152268492786841,"id":652,"good":117.33248333364,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","xver":6.991,"iver":1.2020052,"r":6},        #dud
             {"Bot_Xtr":0.981465891830574,"CD":0.00478303190617694,"CDf":0.00202,"CDp":-0.00090315713014249,"CDpres":0.00276,"CL":1.91140763403815,"Cm":-0.16509149391151,"Cpmin":-4.06065096591309,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re16000000-ncrit7_n17sblowsuck-Re16000000-N7.dat","Re":16000000,"Top_Xtr":0.491996387730234,"alpha":9.7,"clcd":399.622597451149,"cmt":"SPLN 2(B1) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat -opt_clcd(6)=(160.201780364559>160.19878726172 aoa=9.7 pa=1.91073083681669 Cl=1.91073083681669 Cd=0.00477939347188989 x=0.491983001169724,0.981471936002492 s=YT u=0.999292021131271 Foil spline 17pts Re16000000 N7","diter":3,"good":160.191248439067,"id":108,"iver":1.2020062,"n":7,"r":6,"src":"","sym":8.54406893408101,"xver":6.991,"xy":[1,0,0.823371099008729,0.0593035613672601,0.730063217703018,0.0896119677819752,0.574895650386223,0.163542310773872,0.464110894666417,0.212938850744211,0.300719048572926,0.196838139111978,0.151647407370497,0.143037030064804,0.0445917027294438,0.0684261759719214,0,0,0.0298283809683865,-0.0362015499071765,0.117039712566025,-0.0412178348812335,0.252671339663787,-0.0416526084667937,0.400424651559433,-0.0374961088507098,0.565868834048766,-0.0305554903260658,0.787776606054772,-0.0161689181837682,0.920086350816689,-0.00733947676622376,1,0]},        #16000000 7
             #{"Re":16000000,"n":8,"sym":7.61567438822719,"Bot_Xtr":0.971083085071083,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"clcd":382.691489125198,"CDpres":0.00184,"alpha":5.4,"diter":3,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","Top_Xtr":0.54976447343251,"src":"retest_156.txt","xver":6.991,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","good":144.420966720492,"iver":1.2020052,"id":653,"r":6,"Cm":-0.154787893282855,"CL":1.44455288223348,"CD":0.00377471912306075,"CDp":-0.00248750386661746,"CDf":0.00194,"Cpmin":-2.35889339776144},        #dud
             {"Bot_Xtr":0.979038151487294,"CD":0.00390095075383807,"CDf":0.00172,"CDp":-0.000581821224619181,"CDpres":0.00218,"CL":1.80673989638359,"Cm":-0.173901856606248,"Cpmin":-3.13865079426032,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re16000000-ncrit8_n17sopt-Re16000000-N8.dat","Re":16000000,"Top_Xtr":0.556953514398356,"alpha":8.2,"clcd":463.153731075936,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt222.510181462022>90.2149413161862) l2 Foil spline 17pts Re16000000 N8","diter":2,"good":222.5101814616,"id":145,"iver":1.2020062,"n":8,"r":6,"src":"","sym":10.2311691309155,"xver":6.991,"xy":[1,0,0.831477468257807,0.0503504426465105,0.678732987083849,0.122238271004312,0.568868480805935,0.194449983228717,0.46182220503342,0.216481210516041,0.301367705936055,0.198188677836058,0.147427952225101,0.141192150004692,0.0446023530403577,0.0686311696952262,0,0,0.0264580039734064,-0.033325949362926,0.109974390812936,-0.0374028226924907,0.225255343593619,-0.0364150634309231,0.359047817541032,-0.0343209972608749,0.531072029438071,-0.0299381808480835,0.741219658872223,-0.01922449460181,0.92626315378153,-0.00716058197215525,1,0]},        #16000000 8
             {"Re":16000000,"n":9,"r":6,"id":654,"cmt":"OPT s(0) optbs_spline_Re5000000_N4_gu255118.dat-s17_n17s0_nsopt-Re5000000-N4.dat (opt127.324365993284>86.9396948643363) l1 Foil spline 17pts Re5000000 N4","good":154.096197132806,"xver":6.991,"iver":1.2020052,"Cm":-0.156978833994938,"CDp":-0.00250861587800054,"CD":0.00389481086995692,"CL":1.50441217752865,"Cpmin":-2.39521106898525,"CDf":0.00192,"xy":[1,0,0.796482743407607,0.0627515404061505,0.769301638099816,0.0662721958979984,0.59393537388615,0.161131190154518,0.46417663969898,0.189535442818225,0.300719048572926,0.17523401451217,0.151565885210148,0.127129224091402,0.0445917027294438,0.0609160072705967,0,0,0.0187190218564837,-0.0232089580815062,0.0950515325472864,-0.0280596447701543,0.251819685490336,-0.0274940569796913,0.396128421734845,-0.0269918016303411,0.587367457971533,-0.0225910690318774,0.767300654461791,-0.0189718629633473,0.948992749046747,-0.0100332495971475,1,0],"Bot_Xtr":0.974900081552969,"sym":7.61567438822719,"alpha":5.9,"clcd":386.260649813091,"CDpres":0.00197,"Top_Xtr":0.549881114581197,"Foil_fn":"opt_spline_gu255118_nsopt-Re5000000-N4.dat","diter":4,"src":"retest_157.txt",},        #dud
             {"Cpmin":-2.0107105958676,"CDf":0.00215,"CDp":-0.000936148748856559,"CL":1.37712972017162,"CD":0.00411203595141998,"n":10,"Cm":-0.149291156067608,"r":6,"id":655,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt133.164668519546>113.606532586973) l1 Foil spline 17pts Re10000000 N9","iver":1.2020052,"xver":6.991,"good":128.08654103299,"src":"retest_150.txt","Re":16000000,"Top_Xtr":0.516869067191141,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re10000000-N9.dat","diter":7,"alpha":6,"CDpres":0.00196,"clcd":334.902159524182,"Bot_Xtr":0.981572385145443,"xy":[1,0,0.850203906919876,0.0549803892813511,0.786878980256792,0.0790618282435047,0.603993922289437,0.145627366998503,0.464110894666417,0.172957273910297,0.300719048572926,0.159879645369547,0.151647407370497,0.116180277585659,0.0445917027294438,0.0555784199024635,0,0,0.0255348494188518,-0.0230333041287001,0.113212321059693,-0.0324336960457906,0.241812094300539,-0.0352936583433463,0.388474534135911,-0.0334336473349339,0.529590978122237,-0.0273788515382352,0.742367239267483,-0.0154763523487531,0.920936730844689,-0.00630252519021627,1,0],"sym":6.05132636298529},
             {"Re":16000000,"n":11,"r":6,"id":656,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"iver":1.2020052,"good":169.904587851241,"Cm":-0.17475829382713,"CDp":-0.00336278247769501,"CD":0.00405159089383194,"CL":1.63864365840106,"Cpmin":-2.6744834568368,"CDf":0.0018,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"Bot_Xtr":0.970021950280964,"sym":7.99886704162969,"alpha":7.2,"CDpres":0.00225,"clcd":404.444501268798,"Top_Xtr":0.577322042013757,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","diter":3,"src":"retest_99.txt",},        #dud
             {"CDp":0.000166799131902793,"n":12,"CD":0.00470910232013286,"CL":1.83368877764129,"Cpmin":-2.4822634156766,"CDf":0.00242,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt154.967047004421>122.398150564611) l1 Foil spline 17pts Re13000000 N12","xver":6.991,"iver":1.2020052,"good":144.76767948717,"id":657,"Cm":-0.261243736064808,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N12.dat","Top_Xtr":0.52451431049466,"diter":5,"src":"retestc_14.txt","Re":16000000,"xy":[1,0,0.961949581813749,0.0167687799796483,0.875758074483928,0.0534093827523938,0.633981356955415,0.158003584728719,0.482035828487994,0.200941712919311,0.31379187525767,0.196350461576887,0.149809351404668,0.145261417101701,0.0348482227959868,0.0679077815069871,0,0,0.0373050544485358,-0.0179652841217529,0.146509500030206,-0.0137270076513716,0.314465462409945,-0.00259052299886281,0.501550924851073,0.0064972334400904,0.665300856013736,0.010340115292039,0.892216666431326,0.0116819103550208,0.964324033244839,0.00762800915357981,1,0],"Bot_Xtr":0.887264641821855,"sym":14.0238952701483,"alpha":5.2,"clcd":389.392426195903,"CDpres":0.00229},
             {"CDf":0.00239,"Cpmin":-2.50475704564241,"n":13,"CL":1.85655551759601,"CD":0.00471733741354942,"CDp":0.000168891154555199,"Cm":-0.261857031875296,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt154.967047004421>122.398150564611) l1 Foil spline 17pts Re13000000 N12","good":158.990250279338,"iver":1.2020052,"id":658,"r":6,"Re":16000000,"src":"retestc_17.txt","diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N12.dat","Top_Xtr":0.525339961980731,"CDpres":0.00233,"clcd":393.560043482051,"alpha":5.4,"sym":14.0238952701483,"xy":[1,0,0.961949581813749,0.0167687799796483,0.875758074483928,0.0534093827523938,0.633981356955415,0.158003584728719,0.482035828487994,0.200941712919311,0.31379187525767,0.196350461576887,0.149809351404668,0.145261417101701,0.0348482227959868,0.0679077815069871,0,0,0.0373050544485358,-0.0179652841217529,0.146509500030206,-0.0137270076513716,0.314465462409945,-0.00259052299886281,0.501550924851073,0.0064972334400904,0.665300856013736,0.010340115292039,0.892216666431326,0.0116819103550208,0.964324033244839,0.00762800915357981,1,0],"Bot_Xtr":0.899550810932379},
             {"Cm":-0.283040474319025,"id":659,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt115.82353170479>55.6125640232347) l1 Foil spline 17pts Re13000000 N8","good":161.003283785497,"iver":1.2020052,"r":6,"CDf":0.00237,"Cpmin":-2.73847234618738,"CD":0.00506571301214551,"CL":1.98312232736432,"n":14,"CDp":3.05943869668411e-05,"clcd":391.479407264014,"CDpres":0.0027,"alpha":5.7,"sym":16.0623504654703,"xy":[1,0,0.961949581813749,0.0179452904791399,0.875758074483928,0.0571566261210719,0.633981356955415,0.169089237746783,0.482035828487994,0.215039938033024,0.31379187525767,0.210126560965489,0.149809351404668,0.155453069839622,0.0348482227959868,0.0726722436823581,0,0,0.0373050544485358,-0.0205392357058604,0.146509500030206,-0.0156937259537291,0.314465462409945,-0.00296167664894709,0.501550924851073,0.00742811570123912,0.665300856013736,0.0118215812101634,0.892216666431326,0.0133556201310493,0.964324033244839,0.00872090176309158,1,0],"Bot_Xtr":0.899156488236161,"Re":16000000,"src":"retest_73.txt","diter":3,"Top_Xtr":0.527948471742597,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N8.dat"},
             {"Top_Xtr":0.401850611290119,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","diter":2,"src":"retestc_16.txt","Re":20000000,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.837945319229119,"sym":6.4243025225839,"alpha":7,"CDpres":0.00313,"clcd":308.201828884706,"CDp":0.00033405068745817,"CD":0.00575774596655803,"CL":1.77454783714672,"n":3,"Cpmin":-3.26816863406574,"CDf":0.00263,"r":6,"id":660,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"xver":6.991,"good":96.1572312873029,"Cm":-0.170919467525675},
             {"Re":20000000,"src":"retest_72.txt","diter":3,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.355959980932534,"clcd":295.941350811423,"CDpres":0.0042,"alpha":10.7,"sym":10.2659657001272,"xy":[1,0,0.965270809535891,0.0140096469899251,0.874747959490912,0.0396014833204516,0.732361948126876,0.0866880505207448,0.552216966314442,0.155206432317525,0.344108992825163,0.222842670112971,0.156386775777539,0.175566771727465,0.0405273197421349,0.083728443218474,0,0,0.0363065817475381,-0.0247986639503844,0.157736576820271,-0.0285519665315355,0.290169024435699,-0.0291037509036429,0.500690663051727,-0.0256027028102622,0.675719681347116,-0.0197207094866888,0.866206159537903,-0.0116437606463249,0.973258770491703,-0.00425101562647741,1,0],"Bot_Xtr":0.98922224928704,"CDf":0.00254,"Cpmin":-4.30421334155178,"n":4,"CL":1.99460714896418,"CD":0.00673987309815033,"CDp":-0.00119226113807332,"Cm":-0.116987381941475,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt90.3063580259474>65.0448623343494) l1 Foil spline 17pts Re13000000 N7","iver":1.2020052,"xver":6.991,"good":89.7826760772645,"id":661,"r":6},
             {"Cm":-0.116447241833882,"r":6,"id":662,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","iver":1.2020052,"good":99.2063413788825,"Cpmin":-4.30418235521572,"CDf":0.00254,"CDp":-0.00105490281731302,"CD":0.00639427480601502,"CL":1.88371891776455,"n":5,"alpha":9.5,"clcd":294.59461391815,"CDpres":0.00386,"Bot_Xtr":0.985737125566284,"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"sym":10.5670651208425,"src":"retest_152.txt","Re":20000000,"Top_Xtr":0.361247444683391,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","diter":3},
             {"src":"retest_153.txt","Re":20000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","Top_Xtr":0.362824994851771,"diter":3,"alpha":9.8,"clcd":295.655027156587,"CDpres":0.00397,"Bot_Xtr":0.98843201079799,"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"sym":10.5670651208425,"Cpmin":-4.33506332828246,"CDf":0.00251,"CDp":-0.00112151140622615,"n":6,"CL":1.91426230063001,"CD":0.00647464823798234,"Cm":-0.116843095442043,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","xver":6.991,"good":101.651021412143,"id":663},
             {"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re20000000-N7.dat","Top_Xtr":0.362668675300265,"diter":4,"src":"retestc_3.txt","Re":20000000,"xy":[1,0,0.965270809535891,0.0114897616798588,0.874747959490912,0.0324784490178883,0.732361948126876,0.0710956558499443,0.552216966314442,0.12728978251857,0.344108992825163,0.182760434545049,0.156386775777539,0.143987951124066,0.0405273197421349,0.068668386797875,0,0,0.0363065817475381,-0.0203490022892985,0.157736576820271,-0.0234288441295316,0.290169024435699,-0.0238816209998371,0.500690663051727,-0.0210087712443145,0.675719681347116,-0.016182192850958,0.866206159537903,-0.00955450311848094,0.973258770491703,-0.00348824948344411,1,0],"Bot_Xtr":0.992937460208028,"sym":6.90368292788488,"alpha":10,"clcd":337.856925877031,"CDpres":0.00288,"CDp":6.05561382311861e-05,"n":7,"CL":1.81453549548475,"CD":0.00537072161766243,"Cpmin":-3.41149175966643,"CDf":0.00249,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt94.917308034069>54.7053286400838) l1 Foil spline 17pts Re20000000 N7","xver":6.991,"iver":1.2020052,"good":94.8228654569078,"id":664,"Cm":-0.102607663079013},
             {"Cm":-0.167831447206677,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt112.170180432322>65.6846617087947) l1 Foil spline 17pts Re20000000 N8","iver":1.2020052,"xver":6.991,"good":112.170227208531,"id":665,"r":6,"CDf":0.00208,"Cpmin":-2.53827823306285,"n":8,"CL":1.55454573827335,"CD":0.0056745293483661,"CDp":-0.00367047238659985,"clcd":273.951484403013,"CDpres":0.00359,"alpha":7,"sym":9.03874387264641,"xy":[1,0,0.850203906919876,0.0673144381970275,0.786878980256792,0.096798196968143,0.603993922289437,0.17829674405273,0.464110894666417,0.211757717206816,0.300719048572926,0.195746313328515,0.151647407370497,0.142243629364517,0.0445917027294438,0.0680466282708154,0,0,0.0255348494188518,-0.0283924371508222,0.113212321059693,-0.0399800077055186,0.241812094300539,-0.0435053942212071,0.388474534135911,-0.0412126165388952,0.529590978122237,-0.0337490581992722,0.742367239267483,-0.0190772178811478,0.920936730844689,-0.00776892665311186,1,0],"Bot_Xtr":0.959402332938988,"Re":20000000,"src":"retestc_4.txt","diter":13,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re20000000-N8.dat","Top_Xtr":0.508056858778737},
             {"clcd":294.70552744061,"CDpres":0.00321,"alpha":7,"sym":8.49768179952826,"xy":[1,0,0.850203906919876,0.0653672615034221,0.786878980256792,0.0939981558749127,0.603993922289437,0.17313922846077,0.464110894666417,0.205632289992683,0.300719048572926,0.190084041319992,0.151647407370497,0.13812900719235,0.0445917027294438,0.0660782718201601,0,0,0.0255348494188518,-0.0277293646009202,0.113212321059693,-0.039046320839767,0.241812094300539,-0.0424893760284923,0.388474534135911,-0.0402501435186533,0.529590978122237,-0.0329608879566788,0.742367239267483,-0.0186316915095196,0.920936730844689,-0.00758749235148723,1,0],"Bot_Xtr":0.97884759373033,"Re":20000000,"src":"retest_87.txt","diter":8,"Top_Xtr":0.510268443751553,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re13000000-N6.dat","Cm":-0.166092128431898,"id":666,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt94.9992443086098>72.6017692533683) l1 Foil spline 17pts Re13000000 N6","iver":1.2020052,"xver":6.991,"good":117.344824788754,"r":6,"CDf":0.00204,"Cpmin":-2.46450355201075,"CL":1.54956482728414,"CD":0.00525801073614548,"n":9,"CDp":-0.00311025767629886},
             {"Cm":-0.157987823945055,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt96.8523938055412>87.8682011822778) l1 Foil spline 17pts Re5000000 N5","iver":1.2020052,"xver":6.991,"good":117.010742737373,"id":667,"r":6,"CDf":0.00204,"Cpmin":-2.22428337432334,"n":10,"CD":0.00429376906811016,"CL":1.4478886377344,"CDp":-0.0017293226687307,"clcd":337.206918855483,"CDpres":0.00225,"alpha":6.3,"sym":7.11348159870995,"xy":[1,0,0.850203906919876,0.0599611199557787,0.786878980256792,0.0862241215312739,0.603993922289437,0.158819901706357,0.464110894666417,0.188625653323219,0.300719048572926,0.174363308805136,0.151647407370497,0.126705169822657,0.0445917027294438,0.060613326793134,0,0,0.0255348494188518,-0.0256831684386975,0.113212321059693,-0.036165027560923,0.241812094300539,-0.0393540139523684,0.388474534135911,-0.0372800181522017,0.529590978122237,-0.030528648941791,0.742367239267483,-0.0172568278510414,0.920936730844689,-0.00702759860873657,1,0],"Bot_Xtr":0.977117841638508,"Re":20000000,"src":"retest_68.txt","diter":3,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re5000000-N5.dat","Top_Xtr":0.515928121132826},
             {"CDp":-0.00223568871679678,"n":11,"CD":0.00470429238982953,"CL":1.54818718977849,"Cpmin":-2.35773296969479,"CDf":0.00202,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt118.597815397047>90.2149413161862) l1 Foil spline 17pts Re16000000 N8","good":136.101991151403,"xver":6.991,"iver":1.2020052,"id":668,"Cm":-0.164888842934784,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re16000000-N8.dat","Top_Xtr":0.515963195351347,"diter":2,"src":"retest_155.txt","Re":20000000,"xy":[1,0,0.850203906919876,0.0621020001083975,0.786878980256792,0.0893027082988232,0.603993922289437,0.164490482503626,0.464110894666417,0.195360432756496,0.300719048572926,0.180588858752188,0.151647407370497,0.131229111061706,0.0445917027294438,0.0627774936467772,0,0,0.0255348494188518,-0.0259400337823056,0.113212321059693,-0.0365267252328129,0.241812094300539,-0.0397476056675168,0.388474534135911,-0.0376528671912615,0.529590978122237,-0.0308339754407017,0.742367239267483,-0.0174294187455848,0.920936730844689,-0.00709788380488288,1,0],"Bot_Xtr":0.985916053407622,"sym":7.7324047307746,"alpha":7,"CDpres":0.00269,"clcd":329.100970238501},
             {"alpha":6,"CDpres":0.00203,"clcd":349.904703909355,"Bot_Xtr":0.982123084110596,"xy":[1,0,0.850203906919876,0.0583380146654219,0.786878980256792,0.0838900952836489,0.603993922289437,0.154520758814035,0.464110894666417,0.183519689724946,0.300719048572926,0.169643416828894,0.151647407370497,0.123275350106041,0.0445917027294438,0.0589725667229983,0,0,0.0255348494188518,-0.024306502495066,0.113212321059693,-0.0342265143314337,0.241812094300539,-0.0372445650779922,0.388474534135911,-0.035281739338176,0.529590978122237,-0.0288922561655819,0.742367239267483,-0.0163318295489688,0.920936730844689,-0.00665090615767656,1,0],"sym":6.83242147224051,"src":"retest_90.txt","Re":20000000,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re13000000-N10.dat","Top_Xtr":0.521932498560669,"diter":3,"Cm":-0.157333031277423,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt141.352288384673>129.05850302348) l1 Foil spline 17pts Re13000000 N10","iver":1.2020052,"good":141.56004303145,"id":669,"Cpmin":-2.14443600315263,"CDf":0.00202,"CDp":-0.0013235296629185,"n":12,"CL":1.41621585441154,"CD":0.00404743302558863},
             {"diter":3,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N8.dat","Top_Xtr":0.516691046585438,"Re":20000000,"src":"retest_84.txt","sym":16.0623504654703,"Bot_Xtr":0.884010806104611,"xy":[1,0,0.961949581813749,0.0179452904791399,0.875758074483928,0.0571566261210719,0.633981356955415,0.169089237746783,0.482035828487994,0.215039938033024,0.31379187525767,0.210126560965489,0.149809351404668,0.155453069839622,0.0348482227959868,0.0726722436823581,0,0,0.0373050544485358,-0.0205392357058604,0.146509500030206,-0.0156937259537291,0.314465462409945,-0.00296167664894709,0.501550924851073,0.00742811570123912,0.665300856013736,0.0118215812101634,0.892216666431326,0.0133556201310493,0.964324033244839,0.00872090176309158,1,0],"CDpres":0.00261,"clcd":399.767886103718,"alpha":5.7,"n":13,"CL":1.98923869797438,"CD":0.00497598423265615,"CDp":2.48612632357749e-05,"CDf":0.00237,"Cpmin":-2.74355229668329,"good":151.50982419388,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt115.82353170479>55.6125640232347) l1 Foil spline 17pts Re13000000 N8","xver":6.991,"iver":1.2020052,"id":670,"r":6,"Cm":-0.284364208931695},
             {"Cpmin":-2.67368030715325,"CDf":0.00234,"CDp":6.77512889236472e-05,"CD":0.00471402142124803,"CL":1.91800044129556,"n":14,"Cm":-0.2837389426217,"r":6,"id":671,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx72ls160.dat-s17_n17s0.dat (opt115.82353170479>55.6125640232347) l1 Foil spline 17pts Re13000000 N8","good":160.158806365937,"iver":1.2020052,"src":"retest_85.txt","Re":20000000,"Top_Xtr":0.527131683746234,"Foil_fn":"optbs_spline_fx72ls160.dat-s17_n17s0_nsopt-Re13000000-N8.dat","diter":3,"alpha":5,"clcd":406.871388545317,"CDpres":0.00237,"Bot_Xtr":0.866171280983635,"xy":[1,0,0.961949581813749,0.0179452904791399,0.875758074483928,0.0571566261210719,0.633981356955415,0.169089237746783,0.482035828487994,0.215039938033024,0.31379187525767,0.210126560965489,0.149809351404668,0.155453069839622,0.0348482227959868,0.0726722436823581,0,0,0.0373050544485358,-0.0205392357058604,0.146509500030206,-0.0156937259537291,0.314465462409945,-0.00296167664894709,0.501550924851073,0.00742811570123912,0.665300856013736,0.0118215812101634,0.892216666431326,0.0133556201310493,0.964324033244839,0.00872090176309158,1,0],"sym":16.0623504654703},
             {"Re":25000000,"src":"retest_82.txt","diter":3,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.354414253504513,"clcd":311.901767999907,"CDpres":0.0036,"alpha":9.7,"sym":10.2659657001272,"xy":[1,0,0.965270809535891,0.0140096469899251,0.874747959490912,0.0396014833204516,0.732361948126876,0.0866880505207448,0.552216966314442,0.155206432317525,0.344108992825163,0.222842670112971,0.156386775777539,0.175566771727465,0.0405273197421349,0.083728443218474,0,0,0.0363065817475381,-0.0247986639503844,0.157736576820271,-0.0285519665315355,0.290169024435699,-0.0291037509036429,0.500690663051727,-0.0256027028102622,0.675719681347116,-0.0197207094866888,0.866206159537903,-0.0116437606463249,0.973258770491703,-0.00425101562647741,1,0],"Bot_Xtr":0.976984029022109,"CDf":0.00249,"Cpmin":-4.20876289398493,"n":3,"CL":1.90066401143138,"CD":0.0060937904379944,"CDp":-0.000945169632856376,"Cm":-0.116754270776604,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt90.3063580259474>65.0448623343494) l1 Foil spline 17pts Re13000000 N7","xver":6.991,"good":64.7132756530516,"id":672,"r":6},
             #{"Re":25000000,"n":4,"Cm":-0.384627039181378,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re25000000_N4_fx73170.dat-s17_n17s0_nsopt-Re25000000-N4.dat (opt86.8284454624198>35.7127993226099) l1 Foil spline 17pts Re25000000 N4","good":78.8787892906646,"iver":1.2020052,"id":673,"Cpmin":-3.46216064705015,"CDf":0.00268,"CDp":-0.00353785785491892,"CD":0.00626424573094033,"CL":2.09401780656852,"alpha":4.2,"CDpres":0.00358,"clcd":334.28091689088,"Bot_Xtr":0.573471787628218,"xy":[1,0,0.867016413498341,0.0908959702976976,0.83232926198752,0.0931540590531492,0.652415198956389,0.195593796532841,0.489813315449129,0.250399937818975,0.298357904981702,0.231952682939792,0.14135987853692,0.165478546639838,0.0375467370518927,0.0790979348276393,0,0,0.0393014085828455,-0.0408284397770335,0.144981384257924,-0.0697017978538536,0.332825933902101,-0.0870837005948506,0.54694092629743,-0.0786744874133539,0.710158260375903,0.00280840519318497,0.831060808303591,0.042172943591403,0.914840231008468,0.0480282177021766,1,0],"sym":11.4556694919338,"src":"retest_110.txt","Foil_fn":"opt_spline_fx73170_nsopt-Re25000000-N4.dat","Top_Xtr":0.522798967900155,"diter":3},        #dud
             {"Bot_Xtr":0.745057885059502,"CD":0.00446811083673754,"CDf":0.00208,"CDp":-0.000221988647920753,"CDpres":0.00239,"CL":1.91742817823889,"Cm":-0.215715535288884,"Cpmin":-3.61870633689316,"Foil_fn":"optB_Re25000000-N4-optbs_spline_fx73170.dat-s17_n17s0_nsopt-Re25000000-N4_n17sopt-Re25000000-N4.dat","Re":25000000,"Top_Xtr":0.507964440136335,"alpha":7.6,"clcd":429.136216244566,"cmt":"OPT s(0) ../foildb2020_spline_opt/optbs_spline_fx73170.dat-s17_n17s0_nsopt-Re25000000-N4.dat (opt146.248974486749>35.7127993219627) l2 Foil spline 17pts Re25000000 N4","diter":2,"good":144.346123346855,"id":86,"iver":1.2020062,"n":4,"r":6,"src":"","sym":6.56948361143591,"xver":6.991,"xy":[1,0,0.971452343390178,0.0116179046401389,0.90672114592967,0.0351159984478855,0.715284950811819,0.10160658269202,0.505164022122993,0.225303870807,0.327204437634439,0.22951204536928,0.155750757880691,0.165664799169941,0.0419289905085576,0.0789039092942063,0,0,0.0471742070859235,-0.0391029846978354,0.202310378658467,-0.0689603396861874,0.433045587184628,-0.084342761459953,0.607507866077029,-0.0762024452856831,0.731576022110775,-0.0516744654699576,0.828364672112016,-0.00407999629887446,0.949714245770145,0.00843073912764728,1,0]},        #25000000 4
             {"CDpres":0.0025,"clcd":349.891290101275,"alpha":9,"sym":7.36908412042084,"xy":[1,0,0.965270809535891,0.0118376876547202,0.874747959490912,0.0334619416569344,0.732361948126876,0.0732485312584363,0.552216966314442,0.131144294292326,0.344108992825163,0.188294674864989,0.156386775777539,0.148348106683337,0.0405273197421349,0.0707477611212511,0,0,0.0363065817475381,-0.0206532578724908,0.157736576820271,-0.0237791490994171,0.290169024435699,-0.0242386958294322,0.500690663051727,-0.0213228916054122,0.675719681347116,-0.0164241468521027,0.866206159537903,-0.0096973607818247,0.973258770491703,-0.00354040532704848,1,0],"Bot_Xtr":0.979319295860934,"Re":25000000,"src":"retest_101.txt","diter":8,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re25000000-N5.dat","Top_Xtr":0.359850288249969,"Cm":-0.105645154682692,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt88.2228295665991>13.0381434970787) l1 Foil spline 17pts Re25000000 N5","good":85.5130412841476,"iver":1.2020052,"id":674,"r":6,"CDf":0.00246,"Cpmin":-3.43602195592568,"n":5,"CL":1.73593710840447,"CD":0.00496136130711343,"CDp":2.19133058728894e-05},
             {"sym":8.70050600401918,"Bot_Xtr":0.987865829066755,"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"clcd":332.232225854471,"CDpres":0.00327,"alpha":10,"diter":3,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat","Top_Xtr":0.357635047056411,"Re":25000000,"src":"retest_83.txt","iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","xver":6.991,"good":95.2321816636529,"id":675,"r":6,"Cm":-0.11569025494618,"n":6,"CL":1.90334153431444,"CD":0.00572894916927224,"CDp":-0.00027140046361778,"CDf":0.00246,"Cpmin":-3.90776964361459},
             {"Re":25000000,"src":"retest_94.txt","diter":3,"Top_Xtr":0.360491202135286,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re10000000-N5.dat","CDpres":0.00243,"clcd":349.872940931396,"alpha":8.9,"sym":6.98399910942688,"xy":[1,0,0.965270809535891,0.0115306826417841,0.874747959490912,0.0325941215107287,0.732361948126876,0.0713488641154546,0.552216966314442,0.127743127025536,0.344108992825163,0.183411338627469,0.156386775777539,0.144500766413871,0.0405273197421349,0.0689129503075384,0,0,0.0363065817475381,-0.0201786350983927,0.157736576820271,-0.0232326916939591,0.290169024435699,-0.0236816777974051,0.500690663051727,-0.020832880294459,0.675719681347116,-0.016046711282893,0.866206159537903,-0.00947451030931742,0.973258770491703,-0.00345904494273868,1,0],"Bot_Xtr":0.98534110346374,"CDf":0.00245,"Cpmin":-3.31726360437773,"CD":0.00488220022565939,"CL":1.70814975116738,"n":7,"CDp":0.000104272027065197,"Cm":-0.103367525796967,"id":676,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt83.0405187703348>56.9258465543802) l1 Foil spline 17pts Re10000000 N5","xver":6.991,"good":99.9238111574157,"r":6},
             {"diter":3,"Top_Xtr":0.362800890432173,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat","Re":25000000,"src":"retest_85.txt","sym":8.70050600401918,"Bot_Xtr":0.993240949112495,"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"clcd":340.310417087456,"CDpres":0.00348,"alpha":10.9,"CL":1.9913550366235,"CD":0.00585158413211825,"n":8,"CDp":-0.000484862804587164,"CDf":0.00237,"Cpmin":-3.99711216197421,"id":677,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","good":103.185944129822,"iver":1.2020052,"r":6,"Cm":-0.115627862325369},
             {"diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.450070452799155,"Re":25000000,"src":"retest_148.txt","sym":6.4243025225839,"Bot_Xtr":0.848494695416828,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"CDpres":0.00252,"clcd":461.561202633219,"alpha":9.8,"n":9,"CL":2.13113118665095,"CD":0.0046172234028614,"CDp":-9.16053486853044e-05,"CDf":0.00209,"Cpmin":-3.64852988612543,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"good":111.579866917098,"id":678,"r":6,"Cm":-0.187199947885672},
             {"Re":25000000,"n":10,"CL":1.5658653080736,"CD":0.00354151887152584,"CDp":-0.00307006543404118,"CDf":0.00172,"Cpmin":-2.63540612398358,"id":679,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","xver":6.991,"iver":1.2020052,"good":152.058139603361,"r":6,"Cm":-0.173742343441232,"diter":3,"Top_Xtr":0.566582643382642,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","src":"retest_98.txt","sym":7.99886704162969,"Bot_Xtr":0.962917575099871,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"clcd":442.145126110526,"CDpres":0.00183,"alpha":6.5},        #dud
             {"src":"retestc_17.txt","Re":25000000,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Top_Xtr":0.50912113123832,"diter":9,"alpha":7,"CDpres":0.00315,"clcd":307.612062885183,"Bot_Xtr":0.981153186440624,"xy":[1,0,0.850203906919876,0.0664233916379317,0.786878980256792,0.0955168715549726,0.603993922289437,0.175936615905762,0.464110894666417,0.208954663503436,0.300719048572926,0.193155203848606,0.151647407370497,0.140360739157106,0.0445917027294438,0.0671458896536215,0,0,0.0255348494188518,-0.0281695221161876,0.113212321059693,-0.0396661162014175,0.241812094300539,-0.0431638241612613,0.388474534135911,-0.0408890475619049,0.529590978122237,-0.0334840871988113,0.742367239267483,-0.0189274386049934,0.920936730844689,-0.00770793116530809,1,0],"sym":8.77578868728827,"Cpmin":-2.52089513885796,"CDf":0.00195,"CDp":-0.0032274337832163,"n":11,"CL":1.56904159894577,"CD":0.00510071544083568,"Cm":-0.170252894917482,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt126.802632817212>98.7461990861034) l1 Foil spline 17pts Re25000000 N11","good":126.802637016072,"iver":1.2020052,"id":680},
             {"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt140.73989317105>127.178619983984) l1 Foil spline 17pts Re20000000 N12","iver":1.2020052,"good":130.443186159793,"id":681,"Cm":-0.159292516027188,"CDp":-0.00151525742993752,"n":12,"CL":1.48455473520192,"CD":0.00412188041541122,"Cpmin":-2.20763186822025,"CDf":0.00198,"xy":[1,0,0.850203906919876,0.0588291163804143,0.786878980256792,0.0845962998039939,0.603993922289437,0.155821547160891,0.464110894666417,0.185064597190098,0.300719048572926,0.171071510901338,0.151647407370497,0.124313108010566,0.0445917027294438,0.0594690102310824,0,0,0.0255348494188518,-0.0246719444638693,0.113212321059693,-0.0347411011085767,0.241812094300539,-0.037804527466332,0.388474534135911,-0.0358121911499562,0.529590978122237,-0.0293266437529554,0.742367239267483,-0.0165773743757388,0.920936730844689,-0.00675090080894656,1,0],"Bot_Xtr":0.982444402803622,"sym":6.92433523250904,"alpha":6.6,"clcd":360.164436030543,"CDpres":0.00214,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re20000000-N12.dat","Top_Xtr":0.508239627831906,"diter":3,"src":"retest_98.txt","Re":25000000},
             {"sym":6.3524789065759,"Bot_Xtr":0.979034284097701,"xy":[1,0,0.850203906919876,0.05657182200566,0.786878980256792,0.0813503093247598,0.603993922289437,0.149842618298569,0.464110894666417,0.177963601970281,0.300719048572926,0.164507435440112,0.151647407370497,0.119543169301885,0.0445917027294438,0.057187162898908,0,0,0.0255348494188518,-0.0240855515891647,0.113212321059693,-0.0339153885596814,0.241812094300539,-0.0369060046291759,0.388474534135911,-0.0349610213628059,0.529590978122237,-0.0286296198535656,0.742367239267483,-0.0161833699943865,0.920936730844689,-0.00659044810778223,1,0],"CDpres":0.00183,"clcd":366.686004681179,"alpha":6,"diter":5,"Top_Xtr":0.512827632025835,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re7000000-N6.dat","Re":25000000,"src":"retest_151.txt","id":682,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt105.755336425449>96.5423702640879) l1 Foil spline 17pts Re7000000 N6","xver":6.991,"good":138.23472945375,"r":6,"Cm":-0.152946155488608,"CL":1.39498789669385,"CD":0.00380431180597346,"n":13,"CDp":-0.00110801110832445,"CDf":0.00197,"Cpmin":-2.07038707649347},
             {"CDpres":0.00177,"clcd":380.254991383678,"alpha":6.2,"sym":6.05132636298529,"xy":[1,0,0.850203906919876,0.0549803892813511,0.786878980256792,0.0790618282435047,0.603993922289437,0.145627366998503,0.464110894666417,0.172957273910297,0.300719048572926,0.159879645369547,0.151647407370497,0.116180277585659,0.0445917027294438,0.0555784199024635,0,0,0.0255348494188518,-0.0230333041287001,0.113212321059693,-0.0324336960457906,0.241812094300539,-0.0352936583433463,0.388474534135911,-0.0334336473349339,0.529590978122237,-0.0273788515382352,0.742367239267483,-0.0154763523487531,0.920936730844689,-0.00630252519021627,1,0],"Bot_Xtr":0.984287769794722,"Re":25000000,"src":"retest_90.txt","diter":3,"Top_Xtr":0.515142198033545,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re10000000-N9.dat","Cm":-0.153091991379462,"id":683,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt133.164668519546>113.606532586973) l1 Foil spline 17pts Re10000000 N9","iver":1.2020052,"good":146.358925329176,"r":6,"CDf":0.00195,"Cpmin":-2.03788174533941,"CD":0.00372198181018886,"CL":1.41530216116357,"n":14,"CDp":-0.000875252054271307},
             {"CDpres":0.00354,"clcd":292.972960141565,"alpha":7.2,"sym":6.4243025225839,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.835517447198225,"Re":30000000,"src":"retest_149.txt","diter":3,"Top_Xtr":0.374192443640857,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Cm":-0.172385004177014,"id":684,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"good":68.7361575140935,"r":6,"CDf":0.0026,"Cpmin":-3.28673753522925,"CL":1.79994789437354,"CD":0.00614373385688497,"n":3,"CDp":0.000551540660084885},
             {"alpha":5.5,"clcd":365.037939913537,"CDpres":0.00205,"Bot_Xtr":0.828090974533621,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"sym":6.4243025225839,"src":"retest_150.txt","Re":30000000,"Top_Xtr":0.425281634360491,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","diter":30,"Cm":-0.168425563153259,"r":6,"id":685,"good":85.5625947866697,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"iver":1.2020052,"Cpmin":-3.15334766322107,"CDf":0.00237,"CDp":9.38026169082463e-05,"CD":0.00441957249913361,"CL":1.61331164038226,"n":4},
             {"Cm":-0.171691950446835,"id":686,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"xver":6.991,"good":122.11339878641,"r":6,"CDf":0.00219,"Cpmin":-3.22346557538943,"CD":0.00395027336536959,"CL":1.68061080088386,"n":5,"CDp":-3.77790600329291e-05,"clcd":425.441645537009,"CDpres":0.00176,"alpha":6,"sym":6.4243025225839,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.836525400660332,"Re":30000000,"src":"retest_151.txt","diter":5,"Top_Xtr":0.449196670580717,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat"},
             {"Cm":-0.117152912856951,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","good":103.179058616347,"xver":6.991,"iver":1.2020052,"id":687,"Cpmin":-3.94779464882828,"CDf":0.00237,"CDp":-0.00034381525201828,"n":6,"CD":0.00531723373164914,"CL":1.86682172943805,"alpha":9.5,"clcd":351.088897658643,"CDpres":0.00294,"Bot_Xtr":0.979196640584957,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"sym":8.99060062933398,"src":"retest_67.txt","Re":30000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.36092188014449,"diter":2},
             {"Top_Xtr":0.362354451205978,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","diter":4,"src":"retestc_21.txt","Re":30000000,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"Bot_Xtr":0.988361514537353,"sym":8.99060062933398,"alpha":10.4,"clcd":355.894845690661,"CDpres":0.0032,"CDp":-0.000437225440857439,"CL":1.9664947861489,"CD":0.00552549386415715,"n":7,"Cpmin":-4.0542904710648,"CDf":0.00233,"r":6,"id":688,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","good":108.680965829411,"xver":6.991,"iver":1.2020052,"Cm":-0.11973189154651},
             {"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"Bot_Xtr":0.98704321970037,"sym":10.5670651208425,"alpha":9.9,"CDpres":0.00353,"clcd":331.381339318629,"Top_Xtr":0.361759323934478,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","diter":3,"src":"retest_158.txt","Re":30000000,"r":6,"id":689,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","good":112.661134014142,"xver":6.991,"iver":1.2020052,"Cm":-0.120722598436492,"CDp":-0.001107611839376,"CL":1.94435581973885,"CD":0.00586742700641124,"n":8,"Cpmin":-4.38023651947231,"CDf":0.00233},
             #{"Re":30000000,"n":9,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"Bot_Xtr":0.951637532422583,"sym":7.99886704162969,"alpha":5.7,"CDpres":0.0016,"clcd":447.339100516962,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","Top_Xtr":0.566170614839451,"diter":3,"src":"retest_105.txt","r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","iver":1.2020052,"good":125.387468993309,"id":690,"Cm":-0.170171166913407,"CDp":-0.00282324812052346,"CL":1.47188180558782,"CD":0.0032903043885206,"Cpmin":-2.57734285144457,"CDf":0.00169},        #dud
             {"Bot_Xtr":0.831647612100667,"CD":0.00373402267086005,"CDf":0.00215,"CDp":-5.7987177660044e-05,"CDpres":0.00158,"CL":1.58115578813935,"Cm":-0.135187998089342,"Cpmin":-2.93500196226327,"Foil_fn":"opt_spline_foil_gu255118.dat-s17_n17s0.dat-re30000000-ncrit9_n17sopt-Re30000000-N9.dat","Re":30000000,"Top_Xtr":0.47342987902716,"alpha":7.2,"clcd":423.445685126268,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt136.785660430418>52.5518884219758) l2 Foil spline 17pts Re30000000 N9","diter":3,"good":136.786040863854,"id":80,"iver":1.2020062,"n":9,"r":6,"src":"","sym":7.13042923143532,"xver":6.991,"xy":[1,0,0.857418399281838,0.040285344010761,0.743937683079447,0.0762365064510697,0.576639155839385,0.147804182405338,0.450749037665248,0.194585762375503,0.300796716616019,0.188208439359124,0.151647407370497,0.136175793875398,0.0445917027294438,0.0651438919740748,0,0,0.0288598138171643,-0.0250802259635456,0.125997163062769,-0.0362099911681745,0.239544611205689,-0.0404717973348824,0.381270756712713,-0.0422115736548902,0.480170893601059,-0.0402194209877159,0.764665470435402,-0.0291665459669854,0.922250399122356,-0.00287991640708432,1,0]},        #30000000 9
             {"Re":30000000,"n":10,"cmt":"OPT s(0) optbs_spline_Re7000000_N4_gu255118.dat-s17_n17s0_nsopt-Re7000000-N4.dat (opt138.292142474764>80.2736557982185) l1 Foil spline 17pts Re7000000 N4","iver":1.2020052,"xver":6.991,"good":134.555235041262,"id":691,"r":6,"Cm":-0.170875908505535,"CL":1.49469967793595,"CD":0.00329799181506627,"CDp":-0.00285597385008705,"CDf":0.00168,"Cpmin":-2.59171672213441,"sym":7.99886704162969,"Bot_Xtr":0.953854948488493,"xy":[1,0,0.850864572613195,0.0617635699131241,0.796001589480371,0.0650944528180031,0.596552104368938,0.175209089246297,0.46557472756347,0.199114079074736,0.296660534081533,0.178925339091291,0.151647407370497,0.128666060104102,0.0459149036676059,0.062228904659197,0,0,0.030463931799447,-0.0233160799893919,0.110560060287919,-0.0306994041083101,0.261055626239674,-0.0324204653211659,0.469995173145457,-0.0317411883917588,0.546912322917059,-0.0304242315786542,0.856405934845738,-0.0189975371882208,0.959581755945764,-0.00900660893946329,1,0],"CDpres":0.00162,"clcd":453.215096261818,"alpha":5.9,"diter":4,"Foil_fn":"opt_spline_gu255118_nsopt-Re7000000-N4.dat","Top_Xtr":0.566936831795526,"src":"retest_106.txt"},        #dud
             {"Cm":-0.173886044462436,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt114.4017354492>0) l1 Foil spline 17pts Re30000000 N11","xver":6.991,"good":114.423911070872,"iver":1.2020052,"id":692,"Cpmin":-2.58550834602678,"CDf":0.00189,"CDp":-0.00350971497022768,"n":11,"CL":1.58549495795167,"CD":0.00507013779490455,"alpha":7,"clcd":312.71239995589,"CDpres":0.00318,"Bot_Xtr":0.974013849718142,"xy":[1,0,0.850203906919876,0.0678293261036015,0.786878980256792,0.0975386060442937,0.603993922289437,0.17966053523562,0.464110894666417,0.213377451258438,0.300719048572926,0.197243576206863,0.151647407370497,0.143331650396982,0.0445917027294438,0.0685671166967491,0,0,0.0255348494188518,-0.0285056271214526,0.113212321059693,-0.0401393929627246,0.241812094300539,-0.0436788338688147,0.388474534135911,-0.0413769157440271,0.529590978122237,-0.0338836030037949,0.742367239267483,-0.0191532715753131,0.920936730844689,-0.00779989844236067,1,0],"sym":9.19510345467149,"src":"retestc_3.txt","Re":30000000,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re30000000-N11.dat","Top_Xtr":0.507598464290462,"diter":5},
             {"CDf":0.00187,"Cpmin":-2.56592871502947,"CL":1.6346808899391,"CD":0.0049644367479255,"n":12,"CDp":-0.00329872585665306,"Cm":-0.173969991464016,"id":693,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt126.802632817212>98.7461990861034) l1 Foil spline 17pts Re25000000 N11","iver":1.2020052,"good":127.40367017459,"r":6,"Re":30000000,"src":"retestc_6.txt","diter":3,"Top_Xtr":0.508422978825333,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re25000000-N11.dat","clcd":329.278218847725,"CDpres":0.0031,"alpha":7.5,"sym":8.77578868728827,"xy":[1,0,0.850203906919876,0.0664233916379317,0.786878980256792,0.0955168715549726,0.603993922289437,0.175936615905762,0.464110894666417,0.208954663503436,0.300719048572926,0.193155203848606,0.151647407370497,0.140360739157106,0.0445917027294438,0.0671458896536215,0,0,0.0255348494188518,-0.0281695221161876,0.113212321059693,-0.0396661162014175,0.241812094300539,-0.0431638241612613,0.388474534135911,-0.0408890475619049,0.529590978122237,-0.0334840871988113,0.742367239267483,-0.0189274386049934,0.920936730844689,-0.00770793116530809,1,0],"Bot_Xtr":0.983969981331351},
             {"alpha":7,"clcd":326.519080640026,"CDpres":0.00295,"Bot_Xtr":0.982458073988896,"xy":[1,0,0.850203906919876,0.0664233916379317,0.786878980256792,0.0955168715549726,0.603993922289437,0.175936615905762,0.464110894666417,0.208954663503436,0.300719048572926,0.193155203848606,0.151647407370497,0.140360739157106,0.0445917027294438,0.0671458896536215,0,0,0.0255348494188518,-0.0281695221161876,0.113212321059693,-0.0396661162014175,0.241812094300539,-0.0431638241612613,0.388474534135911,-0.0408890475619049,0.529590978122237,-0.0334840871988113,0.742367239267483,-0.0189274386049934,0.920936730844689,-0.00770793116530809,1,0],"sym":8.77578868728827,"src":"retest_80.txt","Re":30000000,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Top_Xtr":0.509139318845402,"diter":8,"Cm":-0.172275334077996,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt126.802632817212>98.7461990861034) l1 Foil spline 17pts Re25000000 N11","xver":6.991,"good":133.86898824502,"id":694,"Cpmin":-2.53084860646906,"CDf":0.00188,"CDp":-0.00311990798606822,"n":13,"CL":1.57958200871337,"CD":0.00483764074557957},
             {"diter":7,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re8192000-N7.dat","Top_Xtr":0.510383900927992,"Re":30000000,"src":"retest_82.txt","sym":6.15292820026485,"Bot_Xtr":0.978202389355714,"xy":[1,0,0.850203906919876,0.055471818663968,0.786878980256792,0.0797685039500634,0.603993922289437,0.146929023243422,0.464110894666417,0.174503212152056,0.300719048572926,0.161308692279618,0.151647407370497,0.117218727891895,0.0445917027294438,0.0560751946422662,0,0,0.0255348494188518,-0.0232902380701379,0.113212321059693,-0.0327954903117751,0.241812094300539,-0.0356873551701345,0.388474534135911,-0.0338065959461452,0.529590978122237,-0.0276842595768932,0.742367239267483,-0.0156489893349982,0.920936730844689,-0.00637282915655497,1,0],"clcd":385.403466446739,"CDpres":0.0017,"alpha":6,"n":14,"CD":0.00361647730179738,"CL":1.39380288843866,"CDp":-0.000923261984348692,"CDf":0.00192,"Cpmin":-2.0394635045172,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt118.552489786956>104.64708124158) l1 Foil spline 17pts Re8192000 N7","good":134.665673629846,"iver":1.2020052,"id":695,"r":6,"Cm":-0.152693933939844},
             {"xy":[1,0,0.973965755697248,0.0111560464881574,0.890072391735232,0.0387968682196289,0.67825918414735,0.114531526306371,0.470142329353297,0.19418686600279,0.28991275136068,0.198949617733599,0.141660118822593,0.146893463759914,0.0403733026176668,0.068482029964919,0,0,0.0403098296561238,-0.0216891798054186,0.134772684857098,-0.032844971598029,0.282435958408202,-0.0408204897100677,0.512264841811112,-0.0449603393695931,0.746315658275679,-0.0301574401003257,0.884813584248645,-0.00417920948801839,0.958527103144847,0.00403986920112717,1,0],"Bot_Xtr":0.651572584062039,"sym":7.62818205900875,"alpha":6.3,"CDpres":0.00339,"clcd":225.506479170807,"Top_Xtr":0.323607673752328,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N3.dat","diter":3,"src":"retest_98.txt","Re":36000000,"r":6,"id":696,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt41.0464752699348>10.0349890775965) l1 Foil spline 17pts Re36000000 N3","good":41.046475638684,"xver":6.991,"iver":1.2020052,"Cm":-0.144022403827102,"CDp":0.000487700792499953,"CD":0.00670304835899913,"CL":1.51158083514955,"n":3,"Cpmin":-2.71264500379496,"CDf":0.00331},
             {"Cm":-0.0326059098017222,"r":6,"id":697,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"iver":1.2020052,"good":65.7144745472851,"Cpmin":-4.63100216213854,"CDf":0.00253,"CDp":0.00033351259365499,"CL":1.56746176497357,"CD":0.00441381711299845,"n":4,"alpha":9.7,"clcd":355.126124360134,"CDpres":0.00189,"Bot_Xtr":0.817636568567818,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"sym":3.10397035932037,"src":"retestc_8.txt","Re":36000000,"Top_Xtr":0.279551559071893,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","diter":3},
             {"src":"retest_106.txt","Re":36000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.355336857279314,"diter":3,"alpha":11,"clcd":350.611961093824,"CDpres":0.00359,"Bot_Xtr":0.98645339992843,"xy":[1,0,0.965270809535891,0.0140096469899251,0.874747959490912,0.0396014833204516,0.732361948126876,0.0866880505207448,0.552216966314442,0.155206432317525,0.344108992825163,0.222842670112971,0.156386775777539,0.175566771727465,0.0405273197421349,0.083728443218474,0,0,0.0363065817475381,-0.0247986639503844,0.157736576820271,-0.0285519665315355,0.290169024435699,-0.0291037509036429,0.500690663051727,-0.0256027028102622,0.675719681347116,-0.0197207094866888,0.866206159537903,-0.0116437606463249,0.973258770491703,-0.00425101562647741,1,0],"sym":10.2659657001272,"Cpmin":-4.38590534452288,"CDf":0.00228,"CDp":-0.00116320622900891,"n":5,"CD":0.00587109798958163,"CL":2.05847717990122,"Cm":-0.12382242567439,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt90.3063580259474>65.0448623343494) l1 Foil spline 17pts Re13000000 N7","xver":6.991,"good":82.4954513844164,"iver":1.2020052,"id":698},
             {"Cpmin":-4.38311042995677,"CDf":0.00227,"CDp":-0.00117043651214721,"n":6,"CL":2.05688331133343,"CD":0.00587387968140331,"Cm":-0.12344455149061,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt90.3063580259474>65.0448623343494) l1 Foil spline 17pts Re13000000 N7","xver":6.991,"iver":1.2020052,"good":97.9780630063439,"id":699,"src":"retest_107.txt","Re":36000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.356001307534145,"diter":3,"alpha":11,"clcd":350.174573348092,"CDpres":0.0036,"Bot_Xtr":0.988171374580456,"xy":[1,0,0.965270809535891,0.0140096469899251,0.874747959490912,0.0396014833204516,0.732361948126876,0.0866880505207448,0.552216966314442,0.155206432317525,0.344108992825163,0.222842670112971,0.156386775777539,0.175566771727465,0.0405273197421349,0.083728443218474,0,0,0.0363065817475381,-0.0247986639503844,0.157736576820271,-0.0285519665315355,0.290169024435699,-0.0291037509036429,0.500690663051727,-0.0256027028102622,0.675719681347116,-0.0197207094866888,0.866206159537903,-0.0116437606463249,0.973258770491703,-0.00425101562647741,1,0],"sym":10.2659657001272},
             {"Cm":-0.103523234218554,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt99.7908753670349>23.3805835498805) l1 Foil spline 17pts Re45000000 N9","xver":6.991,"iver":1.2020052,"good":90.5512976335053,"id":700,"Cpmin":-3.26218115488999,"CDf":0.00235,"CDp":3.89526520472815e-05,"n":7,"CD":0.00433376924044756,"CL":1.61957170122653,"alpha":8,"CDpres":0.00199,"clcd":373.709722730709,"Bot_Xtr":0.955885265391237,"xy":[1,0,0.965270809535891,0.0116113979156926,0.874747959490912,0.0328222817617109,0.732361948126876,0.0718483092297682,0.552216966314442,0.128637334403201,0.344108992825163,0.184695225878133,0.156386775777539,0.145512277987246,0.0405273197421349,0.0693953439205374,0,0,0.0363065817475381,-0.0205845860066056,0.157736576820271,-0.0237000836779761,0.290169024435699,-0.0241581024199321,0.500690663051727,-0.0212519932143859,0.675719681347116,-0.0163695367360199,0.866206159537903,-0.00966511715889795,0.973258770491703,-0.00352863351645573,1,0],"sym":7.04803573100747,"src":"retest_151.txt","Re":36000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N9.dat","Top_Xtr":0.362109815159209,"diter":16},
             {"n":8,"CD":0.00522203431036259,"CL":1.95323500033591,"CDp":-0.000410556238429943,"CDf":0.00226,"Cpmin":-4.04277387477071,"good":115.327344349197,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"iver":1.2020052,"id":701,"r":6,"Cm":-0.120920506817029,"diter":3,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.362502499699572,"Re":36000000,"src":"retestc_10.txt","sym":8.99060062933398,"Bot_Xtr":0.985652449788807,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"CDpres":0.00296,"clcd":374.03718249417,"alpha":10.2},
             {"id":702,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","iver":1.2020052,"xver":6.991,"good":120.632161820206,"r":6,"Cm":-0.117441749639561,"CD":0.00503685108587003,"CL":1.87405141786328,"n":9,"CDp":-0.000275191079497392,"CDf":0.00228,"Cpmin":-3.87972654012588,"sym":8.70050600401918,"Bot_Xtr":0.984228258070191,"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"clcd":372.068061158407,"CDpres":0.00275,"alpha":9.6,"diter":3,"Top_Xtr":0.362064127707018,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat","Re":36000000,"src":"retest_106.txt"},
             {"src":"retest_107.txt","Re":36000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat","Top_Xtr":0.363570248388043,"diter":2,"alpha":9.9,"CDpres":0.00282,"clcd":375.456869388332,"Bot_Xtr":0.987323648076338,"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"sym":8.70050600401918,"Cpmin":-3.91345460612601,"CDf":0.00226,"CDp":-0.000304067602296282,"n":10,"CL":1.90722320992941,"CD":0.00507973981948054,"Cm":-0.118200045551585,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","good":107.923489339878,"xver":6.991,"iver":1.2020052,"id":703},
             {"CDp":1.37756774088007e-05,"n":11,"CD":0.00455784879445351,"CL":1.77006442579883,"Cpmin":-3.4153277092775,"CDf":0.00226,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt105.516895233202>67.2128918187047) l1 Foil spline 17pts Re30000000 N11","xver":6.991,"good":109.135569432691,"iver":1.2020052,"id":704,"Cm":-0.10698094135529,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re30000000-N11.dat","Top_Xtr":0.363806937152094,"diter":3,"src":"retestc_0.txt","Re":36000000,"xy":[1,0,0.965270809535891,0.0116636846315765,0.874747959490912,0.0329700821672778,0.732361948126876,0.0721718458236148,0.552216966314442,0.129216594868206,0.344108992825163,0.185526917882036,0.156386775777539,0.146167527182217,0.0405273197421349,0.0697078346867302,0,0,0.0363065817475381,-0.0198710956526855,0.157736576820271,-0.022878605845684,0.290169024435699,-0.0233207490216123,0.500690663051727,-0.0205153695992607,0.675719681347116,-0.0158021458467621,0.866206159537903,-0.00933011076818555,0.973258770491703,-0.00340632617562786,1,0],"Bot_Xtr":0.988889325132238,"sym":7.21620816271298,"alpha":9.3,"CDpres":0.0023,"clcd":388.355231957858},
             {"CDp":-0.000474245194330995,"n":12,"CL":2.00424992835383,"CD":0.00536836685630444,"Cpmin":-4.0156818444293,"CDf":0.00222,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","iver":1.2020052,"good":114.899348849393,"id":705,"Cm":-0.118040376417175,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat","Top_Xtr":0.363680782662752,"diter":3,"src":"retest_109.txt","Re":36000000,"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"Bot_Xtr":0.993073611353679,"sym":8.70050600401918,"alpha":10.9,"clcd":373.344441987996,"CDpres":0.00315},
             {"clcd":363.273910150743,"CDpres":0.00154,"alpha":4.7,"sym":7.79348096536387,"xy":[1,0,0.974148228191325,0.0111222124918652,0.856064947852657,0.058594837347043,0.67234140887639,0.142326644148853,0.498827790522426,0.191293087257922,0.311201173407236,0.183103374748167,0.143921381976221,0.129822702848414,0.0379433714121237,0.0603756842156652,0,0,0.0394616890845911,-0.0227074024456379,0.145547345355351,-0.0350375526715741,0.309284570367603,-0.0403504150558287,0.503361401668146,-0.037641524512966,0.68524552181652,-0.0253478501754983,0.835093703378512,-0.00445546498392266,0.923748161195394,0.00228921015547089,1,0],"Bot_Xtr":0.729911105395421,"Re":36000000,"src":"retest_104.txt","diter":3,"Foil_fn":"optbs_spline_fx73170a.dat-s17_n17s0_nsopt-Re25000000-N10.dat","Top_Xtr":0.527859924731479,"Cm":-0.182880114299725,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx73170a.dat-s17_n17s0.dat (opt106.410626085043>58.9833238862733) l1 Foil spline 17pts Re25000000 N10","good":115.986519520045,"iver":1.2020052,"id":706,"r":6,"CDf":0.00225,"Cpmin":-2.07514574593,"n":13,"CL":1.37700179149357,"CD":0.00379053312945643,"CDp":-0.00116658795931877},
             {"src":"retest_72.txt","Re":36000000,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re36000000-N10.dat","Top_Xtr":0.512137048228016,"diter":6,"alpha":6.6,"clcd":326.158073458817,"CDpres":0.00293,"Bot_Xtr":0.938853610438794,"xy":[1,0,0.850203906919876,0.069314942139302,0.786878980256792,0.0996749226725609,0.603993922289437,0.183595508313797,0.464110894666417,0.218050901246165,0.300719048572926,0.201563657749532,0.151647407370497,0.146470938526249,0.0445917027294438,0.0700688920192822,0,0,0.0255348494188518,-0.0294795674729708,0.113212321059693,-0.0415108195349337,0.241812094300539,-0.0451711911016814,0.388474534135911,-0.0427906242617447,0.529590978122237,-0.0350412905045685,0.742367239267483,-0.0198076737384827,0.920936730844689,-0.0080663944502679,1,0],"sym":9.54206439827725,"Cpmin":-2.63816645407377,"CDf":0.00189,"CDp":-0.00350897334359169,"n":14,"CL":1.572439237321,"CD":0.00482109555236733,"Cm":-0.179371500469959,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt87.5395810851192>54.7656903566742) l1 Foil spline 17pts Re36000000 N10","iver":1.2020052,"good":124.958913223927,"id":707},
             {"Cpmin":-3.45715478447928,"CDf":0.00292,"CDp":0.000631224665701198,"CL":1.83937636793659,"CD":0.00703814177027409,"n":3,"Cm":-0.157759360241864,"r":6,"id":708,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":54.2627264965673,"src":"retest_154.txt","Re":45000000,"Top_Xtr":0.315972890782824,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","diter":2,"alpha":8.7,"CDpres":0.00412,"clcd":261.344034828238,"Bot_Xtr":0.76928997225593,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"sym":8.38983867838026},
             {"Cm":-0.0544154580945084,"cmt":"OPT s(0) optbs_spline_Re45000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re45000000-N4.dat (opt56.6563190907928>24.2552684116183) l1 Foil spline 17pts Re45000000 N4","iver":1.2020052,"xver":6.991,"good":56.6563190923948,"id":709,"r":6,"CDf":0.00253,"Cpmin":-3.50355581141156,"n":4,"CD":0.00406224206591068,"CL":1.37096494430199,"CDp":0.000265003138568767,"CDpres":0.00153,"clcd":337.489721699941,"alpha":7.6,"sym":3.70419428911181,"xy":[1,0,0.975491182367988,0.00663101954328461,0.877883471935751,0.0189341187223974,0.703942011365911,0.0429261611437444,0.471305218674085,0.110481009165395,0.301500851404756,0.156952790647908,0.142990694507466,0.118039057373553,0.0403733026176668,0.0550877025517489,0,0,0.0252098692953265,-0.0202820733526579,0.121208699992809,-0.0206972889829668,0.399055444959476,-0.0282268396422317,0.602140286704946,-0.0321604247727597,0.771503363618663,-0.0211916557425706,0.876384497462278,0.00964964534210009,0.965073256449296,0.000113111156423343,1,0],"Bot_Xtr":0.790929657388079,"Re":45000000,"src":"retestc_6.txt","diter":2,"Foil_fn":"opt_spline_fx08s176_nsopt-Re45000000-N4.dat","Top_Xtr":0.319751980977984},
             {"CDp":-0.00119701304850542,"CD":0.00577717045241162,"CL":2.04852259199356,"n":5,"Cpmin":-4.51775368559108,"CDf":0.00233,"r":6,"id":710,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","xver":6.991,"good":74.4927209570155,"Cm":-0.126891377711209,"Top_Xtr":0.351104366957102,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","diter":6,"src":"retest_71.txt","Re":45000000,"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"Bot_Xtr":0.933876216575609,"sym":10.5670651208425,"alpha":10.7,"clcd":354.589259373233,"CDpres":0.00344},
             {"diter":5,"Top_Xtr":0.353191011657081,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","Re":45000000,"src":"retest_72.txt","sym":10.5670651208425,"Bot_Xtr":0.97961952057932,"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"CDpres":0.0035,"clcd":362.461398225213,"alpha":11,"CL":2.07303542578584,"CD":0.0057193274537273,"n":6,"CDp":-0.00131595915834134,"CDf":0.00222,"Cpmin":-4.54010951835074,"id":711,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","xver":6.991,"good":86.4303857198401,"r":6,"Cm":-0.125993028307566},
             {"Cpmin":-4.53736678644586,"CDf":0.00221,"CDp":-0.00131093948388206,"CD":0.00572770049140004,"CL":2.07289434927565,"n":7,"Cm":-0.125940464646249,"r":6,"id":712,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt85.5691819333112>20.3392430267098) l1 Foil spline 17pts Re13000000 N3","good":101.291730465319,"iver":1.2020052,"src":"retest_73.txt","Re":45000000,"Top_Xtr":0.353579165889412,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re13000000-N3.dat","diter":3,"alpha":11,"clcd":361.906903544981,"CDpres":0.00352,"Bot_Xtr":0.98493989797066,"xy":[1,0,0.965270809535891,0.0142581394351915,0.874747959490912,0.0403039042617896,0.732361948126876,0.0882256571188818,0.552216966314442,0.157959365772264,0.344108992825163,0.226795283626066,0.156386775777539,0.178680841371437,0.0405273197421349,0.0852135545570161,0,0,0.0363065817475381,-0.0256590839121453,0.157736576820271,-0.0295426119147067,0.290169024435699,-0.0301135411201526,0.500690663051727,-0.0264910198831922,0.675719681347116,-0.0204049436106071,0.866206159537903,-0.0120477551562754,0.973258770491703,-0.00439850981044219,1,0],"sym":10.5670651208425},
             {"CDp":-9.53256908175163e-05,"n":8,"CL":1.7404186973909,"CD":0.00361745501723532,"Cpmin":-3.274020072128,"CDf":0.00202,"r":6,"good":112.341312344642,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"iver":1.2020052,"id":713,"Cm":-0.175779906161381,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.450178398885494,"diter":3,"src":"retest_153.txt","Re":45000000,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.838330101086648,"sym":6.4243025225839,"alpha":6.4,"clcd":481.116887175845,"CDpres":0.0016},
             {"clcd":490.502733907173,"CDpres":0.00165,"alpha":6.8,"sym":6.4243025225839,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.843402890173355,"Re":45000000,"src":"retest_154.txt","diter":2,"Top_Xtr":0.450337659033284,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Cm":-0.177785398175502,"id":714,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","good":123.258360243015,"iver":1.2020052,"r":6,"CDf":0.002,"Cpmin":-3.31184994475189,"CL":1.79012957837362,"CD":0.00364958124517283,"n":9,"CDp":-0.000104561758797029},
             {"Cpmin":-3.34945751366386,"CDf":0.00199,"CDp":-0.000112068372165463,"CD":0.00369049054418692,"CL":1.83883254918912,"n":10,"Cm":-0.179608515123528,"r":6,"id":715,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"good":137.26879127735,"iver":1.2020052,"src":"retest_155.txt","Re":45000000,"Top_Xtr":0.450194958359973,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","diter":3,"alpha":7.2,"clcd":498.262365713294,"CDpres":0.00171,"Bot_Xtr":0.845415529306566,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"sym":6.4243025225839},
             {"Re":45000000,"src":"retest_155.txt","diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.449776094282844,"clcd":505.018452027822,"CDpres":0.00176,"alpha":7.6,"sym":6.4243025225839,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.846429575311218,"CDf":0.00198,"Cpmin":-3.38730040011298,"n":11,"CD":0.00373686426551622,"CL":1.88718540680908,"CDp":-0.00012298878740667,"Cm":-0.181393421669946,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"good":139.651804884217,"iver":1.2020052,"id":716,"r":6},
             {"src":"retestc_22.txt","Re":45000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re55000000-N12.dat","Top_Xtr":0.363638866295913,"diter":3,"alpha":10.3,"clcd":398.07710196892,"CDpres":0.00276,"Bot_Xtr":0.988473932009257,"xy":[1,0,0.965270809535891,0.0129136969082838,0.874747959490912,0.0365035288245693,0.732361948126876,0.079906596561637,0.552216966314442,0.143064905675778,0.344108992825163,0.205410079364675,0.156386775777539,0.161832491488529,0.0405273197421349,0.0771785141412482,0,0,0.0363065817475381,-0.0227134082383014,0.157736576820271,-0.0261511052827115,0.290169024435699,-0.0266564915296587,0.500690663051727,-0.0234498375435414,0.675719681347116,-0.0180624458727408,0.866206159537903,-0.0106646668352044,0.973258770491703,-0.00389355868303071,1,0],"sym":8.74341218336741,"Cpmin":-3.98592263319466,"CDf":0.00216,"CDp":-0.00038007529425924,"n":12,"CD":0.00491704150556397,"CL":1.9573616327958,"Cm":-0.120268784165174,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt127.698094817124>32.8816386236874) l1 Foil spline 17pts Re55000000 N12","xver":6.991,"good":120.729065830276,"id":717},
             {"id":718,"good":118.924439127421,"cmt":"OPT s(0) ../foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt131.142110230518>104.437270140922) l1 Foil spline 17pts Re20000000 N9","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.102997655955343,"CD":0.00415729231571138,"CL":1.66472127300993,"n":13,"CDp":4.59936655781407e-05,"CDf":0.00219,"Cpmin":-3.24374881218702,"sym":6.83054689235892,"Bot_Xtr":0.986139737497472,"xy":[1,0,0.965270809535891,0.0114268522470196,0.874747959490912,0.0323006210642595,0.732361948126876,0.0707063886474147,0.552216966314442,0.12659283786057,0.344108992825163,0.181759773643367,0.156386775777539,0.143199579650986,0.0405273197421349,0.0682924095245596,0,0,0.0363065817475381,-0.0202197639933375,0.157736576820271,-0.023280045488272,0.290169024435699,-0.0237299467330143,0.500690663051727,-0.0208753426979293,0.675719681347116,-0.0160794183267216,0.866206159537903,-0.00949382163227187,0.973258770491703,-0.00346609530542998,1,0],"CDpres":0.00197,"clcd":400.434019690788,"alpha":8.5,"diter":3,"Top_Xtr":0.363547732504101,"Foil_fn":"optbs-spline_foil_fx049915.dat-s17_n17s0-Re20000000-N9-sq1.dat","Re":45000000,"src":"retest_65.txt"},
             {"Cm":-0.179601390968585,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_gu255118.dat-s17_n17s0.dat (opt99.4239414520599>75.3241040645208) l1 Foil spline 17pts Re16000000 N7","good":110.387066070655,"iver":1.2020052,"id":719,"Cpmin":-2.56284989477505,"CDf":0.002,"CDp":-0.00286121684347047,"n":14,"CL":1.59632192451286,"CD":0.00447080173103236,"alpha":6.8,"CDpres":0.00247,"clcd":357.054958047592,"Bot_Xtr":0.862429583200017,"xy":[1,0,0.850203906919876,0.0668466584869872,0.786878980256792,0.0961255295029902,0.603993922289437,0.177057729043944,0.464110894666417,0.210286176090126,0.300719048572926,0.194386038235343,0.151647407370497,0.14125515370489,0.0445917027294438,0.0675737604449179,0,0,0.0255348494188518,-0.0278575977262241,0.113212321059693,-0.0392268886899491,0.241812094300539,-0.0426858661233344,0.388474534135911,-0.0404362783894523,0.529590978122237,-0.0331133140124614,0.742367239267483,-0.0187178528791128,0.920936730844689,-0.00762258034832574,1,0],"sym":8.9697943364288,"src":"retest_152.txt","Re":45000000,"Foil_fn":"optbs_spline_gu255118.dat-s17_n17s0_nsopt-Re16000000-N7.dat","Top_Xtr":0.506328541051493,"diter":4},
             {"r":6,"id":720,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":54.955712075193,"iver":1.2020052,"Cm":-0.155915395071286,"CDp":0.000796913504206058,"CD":0.00646744936824117,"CL":1.69973702978356,"n":3,"Cpmin":-3.28330616195741,"CDf":0.00287,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.769223217725111,"sym":8.38983867838026,"alpha":7.3,"clcd":262.814122384974,"CDpres":0.0036,"Top_Xtr":0.314670705983582,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","diter":4,"src":"retestc_23.txt","Re":55000000},
             {"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"iver":1.2020052,"good":50.6308818195509,"id":721,"r":6,"Cm":-0.159460311144707,"n":4,"CL":1.82020926521162,"CD":0.00669270669490307,"CDp":0.000673275199666494,"CDf":0.00285,"Cpmin":-3.43157420411767,"sym":8.38983867838026,"Bot_Xtr":0.769734446290621,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"CDpres":0.00385,"clcd":271.969077413451,"alpha":8.4,"diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.315915690958488,"Re":55000000,"src":"retest_99.txt"},
             {"id":722,"good":52.0191657789955,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.161533938483888,"CL":1.90451198713994,"CD":0.00687531130583326,"n":5,"CDp":0.000551114966410312,"CDf":0.00282,"Cpmin":-3.53583693687304,"sym":8.38983867838026,"Bot_Xtr":0.77009996040462,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"CDpres":0.00405,"clcd":277.007382272871,"alpha":9.2,"diter":3,"Top_Xtr":0.316560418732289,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Re":55000000,"src":"retestc_5.txt"},
             {"CDf":0.00237,"Cpmin":-4.61092079879953,"CL":1.54976397590066,"CD":0.00398157520310146,"n":6,"CDp":0.00025591912012029,"Cm":-0.0333465891280315,"id":723,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"iver":1.2020052,"good":62.8144266117526,"r":6,"Re":55000000,"src":"retest_72.txt","diter":3,"Top_Xtr":0.279800540360462,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","clcd":389.233882784248,"CDpres":0.00161,"alpha":9.5,"sym":3.10397035932037,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"Bot_Xtr":0.813112835554313},
             {"clcd":373.421339576526,"CDpres":0.00247,"alpha":9,"sym":8.99060062933398,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"Bot_Xtr":0.854458756243724,"Re":55000000,"src":"retest_104.txt","diter":9,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.352042382165591,"Cm":-0.120761428754715,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"good":72.0004196203828,"id":724,"r":6,"CDf":0.00244,"Cpmin":-3.92272989946926,"n":7,"CL":1.8351439460797,"CD":0.00491440566348142,"CDp":-0.000285575385572554},
             {"Cm":-0.156891342538746,"id":725,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt79.5348021207839>39.9385429608016) l1 Foil spline 17pts Re55000000 N11","xver":6.991,"iver":1.2020052,"good":64.8368104062224,"r":6,"CDf":0.00273,"Cpmin":-2.92591847433668,"CL":1.63680265269999,"CD":0.00585408901046425,"n":8,"CDp":0.000206187561444399,"CDpres":0.00312,"clcd":279.59989159273,"alpha":6.9,"sym":8.12515003534643,"xy":[1,0,0.973965755697248,0.0115648324656055,0.890072391735232,0.0402184843552304,0.67825918414735,0.118728253343988,0.470142329353297,0.201302367709491,0.28991275136068,0.206239638802844,0.141660118822593,0.152276014668748,0.0403733026176668,0.070991386087319,0,0,0.0403098296561238,-0.0228047597125723,0.134772684857098,-0.0345343480841162,0.282435958408202,-0.0429200858464484,0.512264841811112,-0.0472728680898814,0.746315658275679,-0.0317085837825182,0.884813584248645,-0.00439416653915844,0.958527103144847,0.00424765930424487,1,0],"Bot_Xtr":0.788309474051,"Re":55000000,"src":"retest_88.txt","diter":3,"Top_Xtr":0.346512371870943,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re55000000-N11.dat"},
             {"Cm":-0.122581390815291,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","iver":1.2020052,"good":97.461727753987,"id":726,"Cpmin":-4.06032817402747,"CDf":0.00218,"CDp":-0.000383593463474457,"n":9,"CD":0.00495837918142663,"CL":1.96129554241097,"alpha":10.2,"CDpres":0.00278,"clcd":395.551745973302,"Bot_Xtr":0.978332801052151,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"sym":8.99060062933398,"src":"retest_106.txt","Re":55000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.352558696963244,"diter":2},
             {"Cm":-0.174318731065961,"r":6,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","xver":6.991,"good":103.079828337662,"id":727,"Cpmin":-3.23280642589314,"CDf":0.00196,"CDp":-9.89908527491193e-05,"n":10,"CL":1.68301484326394,"CD":0.00342357514921688,"alpha":5.9,"CDpres":0.00146,"clcd":491.595706216327,"Bot_Xtr":0.835462998086988,"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"sym":6.4243025225839,"src":"retest_74.txt","Re":55000000,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.450057010099628,"diter":3},
             {"xy":[1,0,0.962261278806624,0.0174635491058907,0.800397266184757,0.0532415799513357,0.614949646796207,0.107417196187608,0.444365127950544,0.194718817107683,0.286068227472377,0.197757800015595,0.141326761325519,0.144686372998947,0.0395263172601574,0.0663333466691459,0,0,0.0316801834776731,-0.0269709927532056,0.135023768028494,-0.0381972572592076,0.285008003478072,-0.042797171240065,0.548002601838327,-0.0432338913164777,0.792413414672203,-0.0288854861102191,0.880536919299262,-0.00258745396008723,0.952889441946068,0.0156154434258539,1,0],"Bot_Xtr":0.836583010141629,"sym":6.4243025225839,"alpha":6.2,"clcd":499.8096854328,"CDpres":0.00149,"Foil_fn":"opt_spline_fx08s176_nsopt-Re16000000-N4.dat","Top_Xtr":0.450576698578739,"diter":7,"src":"retest_75.txt","Re":55000000,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re16000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re16000000-N4.dat (opt129.099708940728>61.7174872940506) l1 Foil spline 17pts Re16000000 N4","iver":1.2020052,"good":118.974075861276,"id":728,"Cm":-0.175695692391393,"CDp":-0.00010341366496175,"n":11,"CL":1.71990257196393,"CD":0.00344111493252599,"Cpmin":-3.26001795399357,"CDf":0.00195},
             {"src":"retestc_10.txt","Re":55000000,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re55000000-N12.dat","Top_Xtr":0.362643382216855,"diter":2,"alpha":9,"clcd":407.365320705492,"CDpres":0.00234,"Bot_Xtr":0.979008654311866,"xy":[1,0,0.965270809535891,0.0129136969082838,0.874747959490912,0.0365035288245693,0.732361948126876,0.079906596561637,0.552216966314442,0.143064905675778,0.344108992825163,0.205410079364675,0.156386775777539,0.161832491488529,0.0405273197421349,0.0771785141412482,0,0,0.0363065817475381,-0.0227134082383014,0.157736576820271,-0.0261511052827115,0.290169024435699,-0.0266564915296587,0.500690663051727,-0.0234498375435414,0.675719681347116,-0.0180624458727408,0.866206159537903,-0.0106646668352044,0.973258770491703,-0.00389355868303071,1,0],"sym":8.74341218336741,"Cpmin":-3.84343822981461,"CDf":0.00214,"CDp":-0.000264096976661815,"n":12,"CL":1.82171963675062,"CD":0.00447195562350691,"Cm":-0.118507488250374,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt127.698094817124>32.8816386236874) l1 Foil spline 17pts Re55000000 N12","good":127.698092644754,"xver":6.991,"iver":1.2020052,"id":729},
             {"diter":7,"Top_Xtr":0.363995789036758,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N12.dat","Re":55000000,"src":"retest_84.txt","sym":6.89234452544228,"Bot_Xtr":0.975544013932925,"xy":[1,0,0.965270809535891,0.0114851359302346,0.874747959490912,0.0324653732746722,0.732361948126876,0.0710670329148046,0.552216966314442,0.127238535967069,0.344108992825163,0.182686855646288,0.156386775777539,0.1439299819312,0.0405273197421349,0.0686407410752501,0,0,0.0363065817475381,-0.0203862615856012,0.157736576820271,-0.0234717426575794,0.290169024435699,-0.0239253485684112,0.500690663051727,-0.0210472385864288,0.675719681347116,-0.0162118226632549,0.866206159537903,-0.00957199754192516,0.973258770491703,-0.0034946365150653,1,0],"clcd":415.214032866667,"CDpres":0.00177,"alpha":8,"CD":0.00389722795333165,"CL":1.61818373550354,"n":13,"CDp":1.92984100209596e-05,"CDf":0.00213,"Cpmin":-3.22407705400674,"id":730,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt116.129000518306>45.6558477863397) l1 Foil spline 17pts Re45000000 N12","iver":1.2020052,"xver":6.991,"good":104.675884466971,"r":6,"Cm":-0.103692501999992},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt105.516895233202>67.2128918187047) l1 Foil spline 17pts Re30000000 N11","iver":1.2020052,"xver":6.991,"good":124.680240295093,"id":731,"Cm":-0.105820071857393,"CDp":1.2631312323057e-05,"n":14,"CD":0.00394637460028733,"CL":1.6332586808703,"Cpmin":-3.28034227540077,"CDf":0.00213,"xy":[1,0,0.965270809535891,0.0116636846315765,0.874747959490912,0.0329700821672778,0.732361948126876,0.0721718458236148,0.552216966314442,0.129216594868206,0.344108992825163,0.185526917882036,0.156386775777539,0.146167527182217,0.0405273197421349,0.0697078346867302,0,0,0.0363065817475381,-0.0198710956526855,0.157736576820271,-0.022878605845684,0.290169024435699,-0.0233207490216123,0.500690663051727,-0.0205153695992607,0.675719681347116,-0.0158021458467621,0.866206159537903,-0.00933011076818555,0.973258770491703,-0.00340632617562786,1,0],"Bot_Xtr":0.979373587961182,"sym":7.21620816271298,"alpha":8,"clcd":413.863063266063,"CDpres":0.00182,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re30000000-N11.dat","Top_Xtr":0.364263677460961,"diter":4,"src":"retest_104.txt","Re":55000000},
             {"Cm":-0.158331810111037,"id":732,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":41.1243992470508,"iver":1.2020052,"r":6,"CDf":0.00286,"Cpmin":-3.42700768235856,"CL":1.81432555345616,"CD":0.00681239989248466,"n":3,"CDp":0.000733164307287022,"CDpres":0.00396,"clcd":266.326930610416,"alpha":8.4,"sym":8.38983867838026,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.769175640054169,"Re":65536000,"src":"retestc_1.txt","diter":3,"Top_Xtr":0.302517607049387,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat"},
             {"CDp":0.000802437797496167,"n":4,"CL":1.64251441293743,"CD":0.00607668988884386,"Cpmin":-3.21123072837007,"CDf":0.00279,"r":6,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","good":59.150918178522,"iver":1.2020052,"id":733,"Cm":-0.155754748757401,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.316087639514168,"diter":3,"src":"retestc_4.txt","Re":65536000,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.769486306956272,"sym":8.38983867838026,"alpha":6.7,"CDpres":0.00328,"clcd":270.297553928645},
             {"src":"retestc_5.txt","Re":65536000,"Top_Xtr":0.316069566734572,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","diter":3,"alpha":7.8,"CDpres":0.00355,"clcd":278.820538859926,"Bot_Xtr":0.770022135482842,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"sym":8.38983867838026,"Cpmin":-3.36142756339608,"CDf":0.00278,"CDp":0.00072752718983552,"CD":0.00632868469443777,"CL":1.76456727677771,"n":5,"Cm":-0.159484645641627,"r":6,"id":734,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"iver":1.2020052,"good":56.6460037740384},
             {"alpha":8.5,"CDpres":0.00371,"clcd":284.145861900238,"Bot_Xtr":0.770294474524976,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"sym":8.38983867838026,"src":"retest_108.txt","Re":65536000,"Top_Xtr":0.316510436289087,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","diter":3,"Cm":-0.161752749535909,"r":6,"id":735,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","good":53.8189816114317,"xver":6.991,"iver":1.2020052,"Cpmin":-3.45570478109134,"CDf":0.00277,"CDp":0.00065301108735307,"CL":1.84106012327852,"CD":0.00647927832193772,"n":6},
             {"Re":65536000,"src":"retest_80.txt","diter":3,"Top_Xtr":0.280297079630524,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","CDpres":0.0015,"clcd":401.11165701455,"alpha":9.3,"sym":3.10397035932037,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"Bot_Xtr":0.808933998927737,"CDf":0.00231,"Cpmin":-4.58005610323738,"CL":1.52856854301303,"CD":0.00381083051634568,"n":7,"CDp":0.000237594799029818,"Cm":-0.0334518292362049,"id":736,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"good":59.1269369497476,"r":6},
             {"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"iver":1.2020052,"good":62.2330157784204,"id":737,"r":6,"Cm":-0.0338935437405193,"n":8,"CL":1.563561911479,"CD":0.00384376804124453,"CDp":0.000234344576017169,"CDf":0.0023,"Cpmin":-4.63489968150189,"sym":3.10397035932037,"Bot_Xtr":0.815402574375153,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"CDpres":0.00154,"clcd":406.778425415274,"alpha":9.6,"diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","Top_Xtr":0.27971655847065,"Re":65536000,"src":"retest_81.txt"},
             {"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt66.1608778902064>20.9959000145765) l1 Foil spline 17pts Re65536000 N9","good":66.160877507439,"iver":1.2020052,"id":738,"Cm":-0.158633068737803,"CDp":8.95100920527707e-05,"n":9,"CL":1.64906445009238,"CD":0.00582858715952299,"Cpmin":-2.97945378627021,"CDf":0.00268,"xy":[1,0,0.973965755697248,0.0117867209137598,0.890072391735232,0.0409901355751891,0.67825918414735,0.121006230821391,0.470142329353297,0.205164651933124,0.28991275136068,0.210196651888679,0.141660118822593,0.155197655659784,0.0403733026176668,0.0723534610277119,0,0,0.0403098296561238,-0.0229090992004195,0.134772684857098,-0.0346923544055005,0.282435958408202,-0.043116459754002,0.512264841811112,-0.0474891574482319,0.746315658275679,-0.0318536612765997,0.884813584248645,-0.0044142713371037,0.958527103144847,0.00426709378204427,1,0],"Bot_Xtr":0.784341594462593,"sym":8.51646555642602,"alpha":6.9,"CDpres":0.00315,"clcd":282.926960678295,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N9.dat","Top_Xtr":0.344717188351499,"diter":4,"src":"retest_152.txt","Re":65536000},
             {"src":"retest_100.txt","Re":65536000,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re55000000-N11.dat","Top_Xtr":0.346448213067543,"diter":3,"alpha":7.2,"clcd":292.92785713148,"CDpres":0.00307,"Bot_Xtr":0.790150958946101,"xy":[1,0,0.973965755697248,0.0115648324656055,0.890072391735232,0.0402184843552304,0.67825918414735,0.118728253343988,0.470142329353297,0.201302367709491,0.28991275136068,0.206239638802844,0.141660118822593,0.152276014668748,0.0403733026176668,0.070991386087319,0,0,0.0403098296561238,-0.0228047597125723,0.134772684857098,-0.0345343480841162,0.282435958408202,-0.0429200858464484,0.512264841811112,-0.0472728680898814,0.746315658275679,-0.0317085837825182,0.884813584248645,-0.00439416653915844,0.958527103144847,0.00424765930424487,1,0],"sym":8.12515003534643,"Cpmin":-2.97223432175599,"CDf":0.00266,"CDp":0.000176618345236498,"n":10,"CD":0.00572992463514928,"CL":1.67845454489916,"Cm":-0.159548165528032,"r":6,"good":69.7127975743175,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt79.5348021207839>39.9385429608016) l1 Foil spline 17pts Re55000000 N11","xver":6.991,"iver":1.2020052,"id":739},
             {"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.352538099561688,"diter":2,"src":"retest_156.txt","Re":65536000,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"Bot_Xtr":0.978739691248325,"sym":8.99060062933398,"alpha":10.1,"CDpres":0.00264,"clcd":410.415712727033,"CDp":-0.000370094359881287,"n":11,"CL":1.95580510929571,"CD":0.00476542454064501,"Cpmin":-4.05606788485222,"CDf":0.00212,"r":6,"good":100.343443631998,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"iver":1.2020052,"id":740,"Cm":-0.123388326454428},
             {"diter":15,"Top_Xtr":0.361404082300312,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Re":65536000,"src":"retest_157.txt","sym":8.99060062933398,"Bot_Xtr":0.965587653407531,"xy":[1,0,0.965270809535891,0.0130975003025012,0.874747959490912,0.0370230913128729,0.732361948126876,0.0810439241427858,0.552216966314442,0.145101178901281,0.344108992825163,0.20833372470511,0.156386775777539,0.164135887753867,0.0405273197421349,0.0782770123451757,0,0,0.0363065817475381,-0.0230606252991743,0.157736576820271,-0.0265508739928749,0.290169024435699,-0.0270639860168358,0.500690663051727,-0.0238083123080677,0.675719681347116,-0.0183385642475047,0.866206159537903,-0.0108276962773233,0.973258770491703,-0.00395307903277631,1,0],"CDpres":0.00229,"clcd":418.911021215769,"alpha":9,"CD":0.00439754267256488,"CL":1.84217909180407,"n":12,"CDp":-0.00030253751267246,"CDf":0.00211,"Cpmin":-3.92938085696082,"id":741,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt115.327345846045>26.1264404062658) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"iver":1.2020052,"good":122.151481476024,"r":6,"Cm":-0.122040266787779},
             {"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"Bot_Xtr":0.985489957110968,"sym":8.70050600401918,"alpha":10.4,"clcd":418.721034244187,"CDpres":0.00262,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat","Top_Xtr":0.353771423835023,"diter":3,"src":"retest_158.txt","Re":65536000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","good":101.796297512107,"xver":6.991,"iver":1.2020052,"id":742,"Cm":-0.122084205932344,"CDp":-0.000347274310417818,"n":13,"CL":1.97482212848344,"CD":0.00471631937967506,"Cpmin":-3.99961862211858,"CDf":0.0021},
             {"Cm":-0.118761213960637,"id":743,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx049915.dat-s17_n17s0.dat (opt125.090047497101>38.4859253219142) l1 Foil spline 17pts Re45000000 N11","xver":6.991,"iver":1.2020052,"good":110.652002258023,"r":6,"CDf":0.00211,"Cpmin":-3.83064717185702,"CD":0.00440263952705597,"CL":1.82208503948142,"n":14,"CDp":-0.000233221891135843,"clcd":413.861963552542,"CDpres":0.0023,"alpha":9,"sym":8.70050600401918,"xy":[1,0,0.965270809535891,0.0128754005122629,0.874747959490912,0.0363952752697619,0.732361948126876,0.0796696284270786,0.552216966314442,0.142640637526745,0.344108992825163,0.204800922606397,0.156386775777539,0.161352566860662,0.0405273197421349,0.0769496363099926,0,0,0.0363065817475381,-0.0225839237411206,0.157736576820271,-0.0260020231774314,0.290169024435699,-0.0265045283206983,0.500690663051727,-0.023316154813436,0.675719681347116,-0.0179594755612336,0.866206159537903,-0.0106038697497002,0.973258770491703,-0.00387136230091903,1,0],"Bot_Xtr":0.978710347937524,"Re":65536000,"src":"retest_159.txt","diter":17,"Top_Xtr":0.358829750448914,"Foil_fn":"optbs_spline_fx049915.dat-s17_n17s0_nsopt-Re45000000-N11.dat"},
             {"clcd":261.783595744423,"CDpres":0.00328,"alpha":6.3,"sym":8.38983867838026,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.760739634634848,"Re":81920000,"src":"retestc_1.txt","diter":4,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.301655746398415,"Cm":-0.153680468753638,"good":29.6672430039137,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"iver":1.2020052,"id":744,"r":6,"CDf":0.00281,"Cpmin":-3.15408699332205,"n":3,"CD":0.00608899682603377,"CL":1.5939994835955,"CDp":0.000882462880267816},
             {"Cpmin":-3.2514291288293,"CDf":0.00278,"CDp":0.00084729766119547,"CL":1.67409371715114,"CD":0.00619243734577678,"n":4,"Cm":-0.156444499171668,"r":6,"id":745,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":42.4400561583589,"src":"retest_158.txt","Re":81920000,"Top_Xtr":0.30268608218393,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","diter":2,"alpha":7,"CDpres":0.00341,"clcd":270.344877739114,"Bot_Xtr":0.769138651206288,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"sym":8.38983867838026},
             {"clcd":275.268925787976,"CDpres":0.00359,"alpha":7.7,"sym":8.38983867838026,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.76982476951218,"Re":81920000,"src":"retestc_6.txt","diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.30266331538219,"Cm":-0.158694998432864,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","iver":1.2020052,"xver":6.991,"good":44.8148999743957,"id":746,"r":6,"CDf":0.00277,"Cpmin":-3.34645720385546,"n":5,"CL":1.75107180485598,"CD":0.00636131303176855,"CDp":0.000798183001886525},
             {"Cm":-0.159958887244216,"r":6,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":48.8134062468323,"iver":1.2020052,"id":747,"Cpmin":-3.4001677333977,"CDf":0.00277,"CDp":0.000760293267280008,"n":6,"CL":1.79472812405021,"CD":0.00645221359115983,"alpha":8.1,"CDpres":0.00368,"clcd":278.156960970599,"Bot_Xtr":0.77016004158916,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"sym":8.38983867838026,"src":"retest_153.txt","Re":81920000,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.302888888588576,"diter":3},
             {"CDp":0.000756165456945052,"CL":1.6857935154719,"CD":0.00587873839618016,"n":7,"Cpmin":-3.26273356377106,"CDf":0.00269,"r":6,"id":748,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":53.9158641642295,"Cm":-0.158722612662328,"Top_Xtr":0.316850090963181,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","diter":3,"src":"retest_154.txt","Re":81920000,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.770228580755885,"sym":8.38983867838026,"alpha":7,"CDpres":0.00318,"clcd":286.761104485833},
             {"Re":81920000,"src":"retest_155.txt","diter":4,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.317383211500393,"clcd":287.600210121353,"CDpres":0.00318,"alpha":7,"sym":8.38983867838026,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.770432075035965,"CDf":0.00269,"Cpmin":-3.26308758632963,"n":8,"CL":1.68639914576685,"CD":0.00586369232851142,"CDp":0.000756003088941594,"Cm":-0.158836904003435,"good":56.7052262458958,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"iver":1.2020052,"id":749,"r":6},
             {"src":"retest_156.txt","Re":81920000,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.316963709222812,"diter":8,"alpha":8,"CDpres":0.00342,"clcd":294.652434013797,"Bot_Xtr":0.770659456842955,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"sym":8.38983867838026,"Cpmin":-3.40012817737051,"CDf":0.00268,"CDp":0.000696857012969751,"n":9,"CD":0.00610023143299789,"CL":1.7974480397803,"Cm":-0.162298469364322,"r":6,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","iver":1.2020052,"xver":6.991,"good":54.8094515152982,"id":750},
             {"Cm":-0.155511176545676,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt66.1608778902064>20.9959000145765) l1 Foil spline 17pts Re65536000 N9","xver":6.991,"good":58.7430942793964,"iver":1.2020052,"id":751,"r":6,"CDf":0.00266,"Cpmin":-3.03461682768534,"n":10,"CD":0.0060149682153365,"CL":1.69144926236763,"CDp":-0.00010165405851742,"clcd":281.206683362832,"CDpres":0.00335,"alpha":7.5,"sym":8.51646555642602,"xy":[1,0,0.973965755697248,0.0117867209137598,0.890072391735232,0.0409901355751891,0.67825918414735,0.121006230821391,0.470142329353297,0.205164651933124,0.28991275136068,0.210196651888679,0.141660118822593,0.155197655659784,0.0403733026176668,0.0723534610277119,0,0,0.0403098296561238,-0.0229090992004195,0.134772684857098,-0.0346923544055005,0.282435958408202,-0.043116459754002,0.512264841811112,-0.0474891574482319,0.746315658275679,-0.0318536612765997,0.884813584248645,-0.0044142713371037,0.958527103144847,0.00426709378204427,1,0],"Bot_Xtr":0.784761445839479,"Re":81920000,"src":"retestc_19.txt","diter":3,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N9.dat","Top_Xtr":0.33068434799582},
             {"src":"retest_156.txt","Re":81920000,"Top_Xtr":0.33345712183176,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N7.dat","diter":4,"alpha":7.6,"CDpres":0.00325,"clcd":290.601524494727,"Bot_Xtr":0.789544348987439,"xy":[1,0,0.973965755697248,0.0116721313807286,0.890072391735232,0.0405916328424263,0.67825918414735,0.119829818179983,0.470142329353297,0.203170058031093,0.28991275136068,0.208153137296208,0.141660118822593,0.153688836793222,0.0403733026176668,0.0716500466198355,0,0,0.0403098296561238,-0.022546652182207,0.134772684857098,-0.0341434833958182,0.282435958408202,-0.0424343101794159,0.512264841811112,-0.0467378270111879,0.746315658275679,-0.0313497014985285,0.884813584248645,-0.00434443273412254,0.958527103144847,0.00419958368903691,1,0],"sym":8.383568591328,"Cpmin":-3.03259910339972,"CDf":0.00263,"CDp":-8.60169847526006e-06,"CD":0.00588550601731364,"CL":1.71033702105423,"n":11,"Cm":-0.157694964172185,"r":6,"id":752,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt69.8491412515621>36.5511973880261) l1 Foil spline 17pts Re36000000 N7","good":65.3046622079394,"iver":1.2020052},
             {"clcd":287.246472751021,"CDpres":0.00338,"alpha":7.3,"sym":9.37761025579476,"xy":[1,0,0.973965755697248,0.0124894317640398,0.890072391735232,0.0434339206816565,0.67825918414735,0.128220484214835,0.470142329353297,0.21739633435457,0.28991275136068,0.222728336405131,0.141660118822593,0.164450362784022,0.0403733026176668,0.0766670918069162,0,0,0.0403098296561238,-0.0250354566703219,0.134772684857098,-0.0379124001302702,0.282435958408202,-0.0471184069921539,0.512264841811112,-0.0518969660572045,0.746315658275679,-0.0348102275739771,0.884813584248645,-0.00482399145528514,0.958527103144847,0.00466315329790937,1,0],"Bot_Xtr":0.788612311640849,"Re":81920000,"src":"retest_66.txt","diter":3,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N6.dat","Top_Xtr":0.350103998278804,"Cm":-0.159980889659138,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt44.6906360680186>0) l1 Foil spline 17pts Re65536000 N6","xver":6.991,"good":69.8201018298681,"id":753,"r":6,"CDf":0.00254,"Cpmin":-3.18736900236323,"n":12,"CD":0.00592187130657851,"CL":1.70103664490016,"CDp":-0.000576518054185183},
             {"CDp":7.72068011529786e-05,"n":13,"CD":0.00558200625592442,"CL":1.72848242941422,"Cpmin":-3.04742789299935,"CDf":0.00256,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt69.8491412515621>36.5511973880261) l1 Foil spline 17pts Re36000000 N7","xver":6.991,"good":75.6583133997568,"id":754,"Cm":-0.163456040104584,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N7.dat","Top_Xtr":0.347745474986889,"diter":4,"src":"retest_158.txt","Re":81920000,"xy":[1,0,0.973965755697248,0.0116721313807286,0.890072391735232,0.0405916328424263,0.67825918414735,0.119829818179983,0.470142329353297,0.203170058031093,0.28991275136068,0.208153137296208,0.141660118822593,0.153688836793222,0.0403733026176668,0.0716500466198355,0,0,0.0403098296561238,-0.022546652182207,0.134772684857098,-0.0341434833958182,0.282435958408202,-0.0424343101794159,0.512264841811112,-0.0467378270111879,0.746315658275679,-0.0313497014985285,0.884813584248645,-0.00434443273412254,0.958527103144847,0.00419958368903691,1,0],"Bot_Xtr":0.79010474060587,"sym":8.383568591328,"alpha":7.5,"clcd":309.652542502924,"CDpres":0.00302},
             {"r":6,"id":755,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt79.5348021207839>39.9385429608016) l1 Foil spline 17pts Re55000000 N11","xver":6.991,"iver":1.2020052,"good":73.9114881848677,"Cm":-0.164001452090788,"CDp":7.11774887416413e-05,"CD":0.00565679710049415,"CL":1.77608977232123,"n":14,"Cpmin":-3.08329189881491,"CDf":0.00256,"xy":[1,0,0.973965755697248,0.0115648324656055,0.890072391735232,0.0402184843552304,0.67825918414735,0.118728253343988,0.470142329353297,0.201302367709491,0.28991275136068,0.206239638802844,0.141660118822593,0.152276014668748,0.0403733026176668,0.070991386087319,0,0,0.0403098296561238,-0.0228047597125723,0.134772684857098,-0.0345343480841162,0.282435958408202,-0.0429200858464484,0.512264841811112,-0.0472728680898814,0.746315658275679,-0.0317085837825182,0.884813584248645,-0.00439416653915844,0.958527103144847,0.00424765930424487,1,0],"Bot_Xtr":0.793287043500275,"sym":8.12515003534643,"alpha":8,"CDpres":0.0031,"clcd":313.974452462876,"Top_Xtr":0.346499914516691,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re55000000-N11.dat","diter":3,"src":"retest_157.txt","Re":81920000},
             {"diter":3,"Top_Xtr":0.197428546237009,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re30000000-N5.dat","Re":100000000,"src":"retest_108.txt","sym":7.10853085558794,"Bot_Xtr":0.228481953950637,"xy":[1,0,0.973965755697248,0.0108352747403851,0.890072391735232,0.0376813351102867,0.67825918414735,0.111238381382018,0.470142329353297,0.188603377222221,0.28991275136068,0.193229184722964,0.141660118822593,0.142669810411336,0.0403733026176668,0.0665129542295176,0,0,0.0403098296561238,-0.0214793001221896,0.134772684857098,-0.0325271406659004,0.282435958408202,-0.0404254820829254,0.512264841811112,-0.044525271659822,0.746315658275679,-0.02986561560387,0.884813584248645,-0.00413876853214261,0.958527103144847,0.00400077659938631,1,0],"clcd":167.346067345517,"CDpres":0.00408,"alpha":5.9,"CD":0.00816215537356833,"CL":1.36590460282974,"n":3,"CDp":0.000800966780828443,"CDf":0.00408,"Cpmin":-2.51174406894688,"id":756,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt62.0754730788549>29.5877606501349) l1 Foil spline 17pts Re30000000 N5","xver":6.991,"good":7.6712362260114,"r":6,"Cm":-0.123171516173957},
             {"CDf":0.00345,"Cpmin":-9.45899122829618,"n":4,"CL":2.09009319152986,"CD":0.00762010309852179,"CDp":0.00192133069773318,"Cm":-0.175160459219974,"cmt":"OPT s(0) optbs_spline_Re100000000_N4_goe553.dat-s17_n17s0_nsopt-Re100000000-N4.dat (opt24.1030173487522>4.01228331863518) l1 Foil spline 17pts Re100000000 N4","good":24.1030203387318,"xver":6.991,"iver":1.2020052,"id":757,"r":6,"Re":100000000,"src":"retestc_4.txt","diter":2,"Foil_fn":"opt_spline_goe553_nsopt-Re100000000-N4.dat","Top_Xtr":0.141865476861026,"clcd":274.286733985963,"CDpres":0.00417,"alpha":9.8,"sym":4.10456757732528,"xy":[1,0,0.94732247307886,0.0195333428927663,0.809202514559497,0.0645077224274987,0.635604681432229,0.0995251659033644,0.492322873992533,0.123538765813297,0.211661362941753,0.146986620809563,0.121925012725191,0.151974602681578,0.033082529156211,0.0739994902757112,0,0,0.0191168639132827,-0.0388077371442295,0.0868267556420695,-0.0458424543005653,0.216479123249296,-0.0534609958317593,0.452029972609417,-0.0571036397186934,0.631122640827001,-0.0369627931436915,0.776643380175708,0.0343005831662454,0.933314814569274,0.016883340965861,1,0],"Bot_Xtr":0.642434342510451},
             {"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"Bot_Xtr":0.431199128698057,"sym":3.10397035932037,"alpha":7.5,"CDpres":0.00132,"clcd":317.012235190535,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","Top_Xtr":0.271264671756405,"diter":4,"src":"retest_158.txt","Re":100000000,"r":6,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","good":21.0065045329214,"xver":6.991,"iver":1.2020052,"id":758,"Cm":-0.0312087833266587,"CDp":0.000320818349693292,"n":5,"CD":0.00416102371356106,"CL":1.31909542811681,"Cpmin":-4.26348217900465,"CDf":0.00284},
             {"n":6,"CD":0.0041155000338995,"CL":1.36636341460899,"CDp":0.000335003653189332,"CDf":0.00274,"Cpmin":-4.33665408048716,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"good":25.0440660033029,"iver":1.2020052,"id":759,"r":6,"Cm":-0.0318230610355986,"diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","Top_Xtr":0.271075011199044,"Re":100000000,"src":"retest_93.txt","sym":3.10397035932037,"Bot_Xtr":0.498734310790692,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"clcd":332.004228733862,"CDpres":0.00137,"alpha":7.9},
             {"diter":3,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","Top_Xtr":0.271147465905969,"Re":100000000,"src":"retest_94.txt","sym":3.10397035932037,"Bot_Xtr":0.568790026257047,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"clcd":347.339586454419,"CDpres":0.0014,"alpha":8.2,"n":7,"CL":1.40197117472475,"CD":0.00403631267324242,"CDp":0.000334236364504982,"CDf":0.00263,"Cpmin":-4.39166235541199,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","iver":1.2020052,"good":29.4269835216546,"id":760,"r":6,"Cm":-0.0323450401398087},
             {"diter":4,"Top_Xtr":0.271109831963446,"Foil_fn":"opt_spline_fx08s176_nsopt-Re36000000-N4.dat","Re":100000000,"src":"retest_95.txt","sym":3.10397035932037,"Bot_Xtr":0.63258368849839,"xy":[1,0,0.934890022398798,0.0156930739146641,0.832165049334697,0.0176248819104568,0.741838615179871,0.0256085179207112,0.434409381819687,0.0864974640393966,0.266824317413372,0.154887703951598,0.13276520523585,0.12931525584177,0.0333242932450548,0.060960906126527,0,0,0.0403098296561238,-0.017461511939864,0.143694662982475,-0.0267381236448946,0.313525689978455,-0.03275444569051,0.523061614463401,-0.0337577771153388,0.775153535770869,-0.0221028967646955,0.877058840027642,0.00634393154447391,0.933045913946373,0.00382947996710076,1,0],"clcd":363.343367267988,"CDpres":0.00142,"alpha":8.5,"CD":0.00395640486831646,"CL":1.43753346712956,"n":8,"CDp":0.00031927618992853,"CDf":0.00253,"Cpmin":-4.44680083599968,"id":761,"xver":6.991,"cmt":"OPT s(0) optbs_spline_Re36000000_N4_fx08s176.dat-s17_n17s0_nsopt-Re36000000-N4.dat (opt66.7979407874316>28.4032567487225) l1 Foil spline 17pts Re36000000 N4","iver":1.2020052,"good":32.3183163192573,"r":6,"Cm":-0.0328632382598517},
             {"Cm":-0.147219965200704,"r":6,"good":37.9121568003194,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt66.1608778902064>20.9959000145765) l1 Foil spline 17pts Re65536000 N9","xver":6.991,"iver":1.2020052,"id":762,"Cpmin":-2.98507169321712,"CDf":0.00299,"CDp":-0.000136170702215832,"n":9,"CD":0.00672702198256352,"CL":1.64172225503904,"alpha":7.4,"clcd":244.048891068647,"CDpres":0.00374,"Bot_Xtr":0.640432453405526,"xy":[1,0,0.973965755697248,0.0117867209137598,0.890072391735232,0.0409901355751891,0.67825918414735,0.121006230821391,0.470142329353297,0.205164651933124,0.28991275136068,0.210196651888679,0.141660118822593,0.155197655659784,0.0403733026176668,0.0723534610277119,0,0,0.0403098296561238,-0.0229090992004195,0.134772684857098,-0.0346923544055005,0.282435958408202,-0.043116459754002,0.512264841811112,-0.0474891574482319,0.746315658275679,-0.0318536612765997,0.884813584248645,-0.0044142713371037,0.958527103144847,0.00426709378204427,1,0],"sym":8.51646555642602,"src":"retest_90.txt","Re":100000000,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N9.dat","Top_Xtr":0.3009084701496,"diter":4},
             {"Re":100000000,"src":"retest_75.txt","diter":2,"Foil_fn":"opt_spline_fx08s176_nsopt-Re65536000-N4.dat","Top_Xtr":0.31683970150298,"clcd":296.139347905586,"CDpres":0.00302,"alpha":6.8,"sym":8.38983867838026,"xy":[1,0,0.973965755697248,0.0116886236997755,0.897157773345941,0.0363681044980983,0.637242142203905,0.13075452784622,0.473107768362088,0.195828746738813,0.290133502929281,0.207069726666782,0.14209777643468,0.153616795646295,0.0362229935925326,0.0713079442782324,0,0,0.0614752002802975,-0.0179852803550288,0.234266825490798,-0.0321726238544862,0.398935750968792,-0.0433919051405195,0.597944554026252,-0.053945121313732,0.752139153297588,-0.0456696614305514,0.865247395133627,0.00771185205119474,0.952205265410605,0.00745232092985392,1,0],"Bot_Xtr":0.770459618478464,"CDf":0.00262,"Cpmin":-3.24255145074272,"n":10,"CD":0.00563970480386861,"CL":1.67013850299765,"CDp":0.000745906822693831,"Cm":-0.15935687999016,"iver":1.2020052,"cmt":"OPT s(0) optbs_spline_Re65536000_N4_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N4.dat (opt59.1506714807378>25.4235761260232) l1 Foil spline 17pts Re65536000 N4","xver":6.991,"good":53.621061435452,"id":763,"r":6},
             {"Cpmin":-3.06576263875654,"CDf":0.00268,"CDp":-0.000182758039054508,"CD":0.00612260532359376,"CL":1.7008362283328,"n":11,"Cm":-0.155451005629495,"r":6,"id":764,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt55.3008648579805>14.9673000537906) l1 Foil spline 17pts Re100000000 N11","xver":6.991,"good":55.2397290051143,"iver":1.2020052,"src":"retestc_15.txt","Re":100000000,"Top_Xtr":0.324812809583461,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re100000000-N11.dat","diter":5,"alpha":7.6,"CDpres":0.00344,"clcd":277.796156773089,"Bot_Xtr":0.754139403640691,"xy":[1,0,0.973965755697248,0.0119118654099073,0.890072391735232,0.0414253448162584,0.67825918414735,0.122291004075771,0.470142329353297,0.20734296998963,0.28991275136068,0.212428396772176,0.141660118822593,0.156845453428385,0.0403733026176668,0.0731216676808674,0,0,0.0403098296561238,-0.0236874285680113,0.134772684857098,-0.0358710161253907,0.282435958408202,-0.0445813277769452,0.512264841811112,-0.0491025864862218,0.746315658275679,-0.032935879299229,0.884813584248645,-0.00456424480345996,0.958527103144847,0.00441206693772262,1,0],"sym":8.57422584795934},
             {"Cpmin":-4.52997384696545,"CDf":0.00288,"CDp":0.000536320129352711,"CL":2.38876351169868,"CD":0.00647227779316223,"n":12,"Cm":-0.284883762891394,"r":6,"id":765,"good":59.8157523567424,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx74cl6140.dat-s17_n17s0.dat (opt72.6402436061875>18.6250320661283) l1 Foil spline 17pts Re55000000 N11","xver":6.991,"iver":1.2020052,"src":"retest_66.txt","Re":100000000,"Top_Xtr":0.335859067187282,"Foil_fn":"optbs_spline_fx74cl6140.dat-s17_n17s0_nsopt-Re55000000-N11.dat","diter":4,"alpha":7.7,"CDpres":0.00359,"clcd":369.076171950212,"Bot_Xtr":0.602258505641643,"xy":[1,0,0.958752500766796,0.0214619824190688,0.819064601702063,0.0792181935255563,0.706718808907257,0.124133672074134,0.473693452947499,0.214795830227508,0.314458706835602,0.246319785577811,0.153163714587615,0.197072495749812,0.0373014080844622,0.0907456666835687,0,0,0.0380877732969944,-0.0219959770568387,0.142717206268942,-0.0134993646620344,0.315502791149633,0.00126471679628068,0.573156924337356,0.0169590120647513,0.739030484403919,0.0352156974797257,0.853549439255321,0.0334834739188133,0.939952004843586,0.0182680507203415,1,0],"sym":20.1419465747224},
             {"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re45000000-N9.dat","Top_Xtr":0.340365371203508,"diter":3,"src":"retest_69.txt","Re":100000000,"xy":[1,0,0.973965755697248,0.0120366329407795,0.890072391735232,0.0418592431025803,0.67825918414735,0.123571907284577,0.470142329353297,0.209514726429037,0.28991275136068,0.214653419104141,0.141660118822593,0.158488287634396,0.0403733026176668,0.0738875603111026,0,0,0.0403098296561238,-0.0239990149330023,0.134772684857098,-0.0363428663936017,0.282435958408202,-0.0451677541941736,0.512264841811112,-0.0497484859088193,0.746315658275679,-0.0333691205385288,0.884813584248645,-0.00462428325141374,0.958527103144847,0.00447010362563389,1,0],"Bot_Xtr":0.786570287786295,"sym":8.73997595091193,"alpha":7.7,"clcd":301.627519726774,"CDpres":0.00324,"CDp":-0.000257354989187204,"n":13,"CL":1.73943952277026,"CD":0.00576684622260565,"Cpmin":-3.13296857438995,"CDf":0.00253,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt74.382707673265>37.0118645947228) l1 Foil spline 17pts Re45000000 N9","iver":1.2020052,"good":64.891140293243,"id":766,"Cm":-0.161146785620295},
             {"Cpmin":-3.06745341164985,"CDf":0.00251,"CDp":6.67903123381299e-05,"CD":0.00548134717148137,"CL":1.72877130044166,"n":14,"Cm":-0.165252462100757,"r":6,"id":767,"cmt":"OPT s(0) foildb2020_spline/spline_foil_fx08s176.dat-s17_n17s0.dat (opt66.1608778902064>20.9959000145765) l1 Foil spline 17pts Re65536000 N9","xver":6.991,"iver":1.2020052,"good":68.5848989249328,"src":"retest_95.txt","Re":100000000,"Top_Xtr":0.345532285272402,"Foil_fn":"optbs_spline_fx08s176.dat-s17_n17s0_nsopt-Re65536000-N9.dat","diter":3,"alpha":7.4,"CDpres":0.00297,"clcd":315.39168134363,"Bot_Xtr":0.787796554878656,"xy":[1,0,0.973965755697248,0.0117867209137598,0.890072391735232,0.0409901355751891,0.67825918414735,0.121006230821391,0.470142329353297,0.205164651933124,0.28991275136068,0.210196651888679,0.141660118822593,0.155197655659784,0.0403733026176668,0.0723534610277119,0,0,0.0403098296561238,-0.0229090992004195,0.134772684857098,-0.0346923544055005,0.282435958408202,-0.043116459754002,0.512264841811112,-0.0474891574482319,0.746315658275679,-0.0318536612765997,0.884813584248645,-0.0044142713371037,0.958527103144847,0.00426709378204427,1,0],"sym":8.51646555642602},
             {"n":3,"CL":0.0591362742293408,"CD":0.567886183165356,"CDp":0.0301334876202304,"CDf":0.52177,"Cpmin":-0.309121615063441,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","good":1.75738943891573,"xver":6.991,"iver":1.2020052,"id":768,"r":6,"Cm":-0.00117804766725667,"diter":4,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","Top_Xtr":1,"Re":50,"src":"retestc_17.txt","sym":4.1252318558898e-05,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"clcd":1.76091623576061,"CDpres":0.04611,"alpha":0.9},
             {"src":"retestc_18.txt","Re":50,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","Top_Xtr":1,"diter":4,"alpha":0.9,"clcd":1.76091623576061,"CDpres":0.04611,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"sym":4.1252318558898e-05,"Cpmin":-0.309121615063441,"CDf":0.52177,"CDp":0.0301334876202304,"n":4,"CD":0.567886183165356,"CL":0.0591362742293408,"Cm":-0.00117804766725667,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","iver":1.2020052,"good":1.75738943891573,"id":769},
             {"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"Bot_Xtr":1,"sym":4.1252318558898e-05,"alpha":0.9,"clcd":1.76091623576061,"CDpres":0.04611,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","diter":4,"src":"retest_77.txt","Re":50,"r":6,"id":770,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","good":1.75738943891573,"xver":6.991,"iver":1.2020052,"Cm":-0.00117804766725667,"CDp":0.0301334876202304,"CL":0.0591362742293408,"CD":0.567886183165356,"n":5,"Cpmin":-0.309121615063441,"CDf":0.52177},
             {"Cm":0.000436209362365703,"id":771,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"good":1.76079036344344,"iver":1.2020052,"r":6,"CDf":0.49237,"Cpmin":-0.281510863512221,"CL":-0.0316218706572405,"CD":0.566182859631673,"n":6,"CDp":0.0231126111139463,"CDpres":0.07381,"clcd":1.76621383531558,"alpha":-0.5,"sym":0.000437330999893252,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"Bot_Xtr":1,"Re":50,"src":"retestc_20.txt","diter":5,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat"},
             {"alpha":0.9,"clcd":1.76091623576061,"CDpres":0.04611,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"sym":4.1252318558898e-05,"src":"retest_79.txt","Re":50,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","Top_Xtr":1,"diter":4,"Cm":-0.00117804766725667,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","xver":6.991,"iver":1.2020052,"good":1.75738943891573,"id":772,"Cpmin":-0.309121615063441,"CDf":0.52177,"CDp":0.0301334876202304,"n":7,"CD":0.567886183165356,"CL":0.0591362742293408},
             {"diter":4,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N8.dat","Top_Xtr":1,"Re":50,"src":"retestc_22.txt","sym":3.7604090930473e-05,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145249030682064,0.707548243935809,0.0260685927174291,0.503056452239259,0.0300279605699047,0.293727127633715,0.0269078566418147,0.144498782157076,0.020299299718761,0.0772542272248852,0.0152346149695393,0.0248124276986501,0.00906550292223594,0,0,0.0246606363984082,-0.00909179777517882,0.0798904739512234,-0.0156629620354501,0.150528301231026,-0.0208483583581744,0.295205165909812,-0.0272075095006708,0.504800317369777,-0.0303365445272418,0.71280527778783,-0.0261157484626,0.884488680537926,-0.0142268152357446,1,0],"CDpres":0.04606,"clcd":1.76106549154633,"alpha":0.9,"n":8,"CD":0.567838053042498,"CL":0.0591580695095548,"CDp":0.0300999371174738,"CDf":0.52178,"Cpmin":-0.309072016327014,"good":1.75754455884553,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75754453237299>1.74752479096356) l1 Foil spline 17pts Re50 N8","xver":6.991,"iver":1.2020052,"id":773,"r":6,"Cm":-0.00118714600826939},
             {"Cm":-0.00117804766725667,"r":6,"id":774,"good":1.75738943891573,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","xver":6.991,"iver":1.2020052,"Cpmin":-0.309121615063441,"CDf":0.52177,"CDp":0.0301334876202304,"CL":0.0591362742293408,"CD":0.567886183165356,"n":9,"alpha":0.9,"CDpres":0.04611,"clcd":1.76091623576061,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"sym":4.1252318558898e-05,"src":"retest_81.txt","Re":50,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","diter":4},
             {"CL":-0.0316218706572405,"CD":0.566182859631673,"n":10,"CDp":0.0231126111139463,"CDf":0.49237,"Cpmin":-0.281510863512221,"id":775,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","good":1.76079036344344,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000436209362365703,"diter":5,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Re":50,"src":"retestc_0.txt","sym":0.000437330999893252,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"CDpres":0.07381,"clcd":1.76621383531558,"alpha":-0.5},
             {"Cm":-0.0425570126219846,"id":776,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_n64008a.dat-s17_n17s0.dat (opt1.76397716287398>1.70082406415432) l1 Foil spline 17pts Re50 N6","xver":6.991,"iver":1.2020052,"good":1.17997143905552,"r":6,"CDf":0.27177,"Cpmin":-2.1277772776489,"CL":0.840547885651071,"CD":0.702717685546139,"n":11,"CDp":0.298440981677696,"CDpres":0.43095,"clcd":1.19613879505226,"alpha":20.3,"sym":0.00261045712892392,"xy":[1,0,0.834572029108263,0.0102626896410939,0.731144982970981,0.0165509786097673,0.549006839790294,0.0257810679700829,0.360723469766044,0.0290362875732188,0.172973899438296,0.0231331216898734,0.0677940348296797,0.0147505052159482,0.0218187281153614,0.00835365739017255,0,0,0.0165315788718247,-0.00953358978156561,0.0836843816845759,-0.0187745869082403,0.212871024526011,-0.0271413495374882,0.380503202758195,-0.0307373254249833,0.533373456390264,-0.0275832267385246,0.682886622411824,-0.0202309792804661,0.836391213494486,-0.0106095457277572,1,0],"Bot_Xtr":1,"Re":50,"src":"retestc_1.txt","diter":5,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_n64008a.dat-s17_n17s0_nsopt-Re50-N6.dat"},
             {"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"Bot_Xtr":1,"sym":4.1252318558898e-05,"alpha":0.9,"CDpres":0.04611,"clcd":1.76091623576061,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","Top_Xtr":1,"diter":4,"src":"retestc_2.txt","Re":50,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","good":1.75738943891573,"iver":1.2020052,"id":777,"Cm":-0.00117804766725667,"CDp":0.0301334876202304,"n":12,"CL":0.0591362742293408,"CD":0.567886183165356,"Cpmin":-0.309121615063441,"CDf":0.52177},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_n64008a.dat-s17_n17s0.dat (opt1.72899745917287>0) l1 Foil spline 17pts Re50 N12","xver":6.991,"good":1.13864771486648,"id":778,"r":6,"Cm":-0.0418462447850959,"n":13,"CD":0.736176953868783,"CL":0.843101719455596,"CDp":0.325168717741669,"CDf":0.26931,"Cpmin":-2.26363787849288,"sym":0.00398167736814169,"Bot_Xtr":1,"xy":[1,0,0.834572029108263,0.0130546298406132,0.731144982970981,0.0210536328006299,0.549006839790294,0.0327947459209384,0.360723469766044,0.0369355402404592,0.172973899438296,0.0294264321810835,0.0677940348296797,0.0187633449213136,0.0218187281153614,0.0106262499264648,0,0,0.0165315788718247,-0.0120885689902943,0.0836843816845759,-0.0238061311955535,0.212871024526011,-0.0344151661536813,0.380503202758195,-0.0389748549592007,0.533373456390264,-0.0349754653853826,0.682886622411824,-0.0256528332324539,0.836391213494486,-0.013452878550918,1,0],"clcd":1.14524329378269,"CDpres":0.46687,"alpha":22,"diter":6,"Foil_fn":"optbs_spline_sym_n64008a.dat-s17_n17s0_nsopt-Re50-N12.dat","Top_Xtr":1,"Re":50,"src":"retest_98.txt"},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":1.78470117393896,"id":779,"r":6,"Cm":0.000747281888863278,"n":14,"CD":0.557488321165958,"CL":-0.00310852745017957,"CDp":0.0205213344214465,"CDf":0.51457,"Cpmin":-0.28850590534237,"sym":0.00058980099013711,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"clcd":1.79375954981183,"CDpres":0.04292,"alpha":0,"diter":21,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"Re":50,"src":"retest_149.txt"},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","diter":4,"src":"retestc_1.txt","Re":100,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"Bot_Xtr":1,"sym":4.1252318558898e-05,"alpha":0,"clcd":2.63316006349365,"CDpres":0.03709,"CDp":0.0202181635736208,"CD":0.379771823925208,"CL":-0.00025848723452917,"n":3,"Cpmin":-0.236280073081133,"CDf":0.34268,"r":6,"id":780,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","good":2.61371869192021,"xver":6.991,"iver":1.2020052,"Cm":0.00015061552847681},
             {"CD":0.370154272716916,"CL":-0.00109129230548737,"n":4,"CDp":0.0157814315465262,"CDf":0.34012,"Cpmin":-0.216187661037876,"id":781,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":2.67578534837367,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000188853169827589,"diter":16,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Re":100,"src":"retest_152.txt","sym":0.00058980099013711,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"CDpres":0.03003,"clcd":2.70157627159088,"alpha":0},
             {"CDf":0.34012,"Cpmin":-0.216187661037876,"CD":0.370154272716916,"CL":-0.00109129230548737,"n":5,"CDp":0.0157814315465262,"Cm":0.000188853169827589,"id":782,"good":2.67578534837367,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"iver":1.2020052,"r":6,"Re":100,"src":"retest_153.txt","diter":16,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","CDpres":0.03003,"clcd":2.70157627159088,"alpha":0,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":16,"src":"retest_154.txt","Re":100,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":0,"CDpres":0.03003,"clcd":2.70157627159088,"CDp":0.0157814315465262,"CL":-0.00109129230548737,"CD":0.370154272716916,"n":6,"Cpmin":-0.216187661037876,"CDf":0.34012,"r":6,"id":783,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":2.67578534837367,"Cm":0.000188853169827589},
             {"Cm":0.000188853169827589,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":2.67578534837367,"id":784,"r":6,"CDf":0.34012,"Cpmin":-0.216187661037876,"n":7,"CL":-0.00109129230548737,"CD":0.370154272716916,"CDp":0.0157814315465262,"clcd":2.70157627159088,"CDpres":0.03003,"alpha":0,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"Re":100,"src":"retest_155.txt","diter":16,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1},
             {"diter":16,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"Re":100,"src":"retest_156.txt","sym":0.00058980099013711,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"CDpres":0.03003,"clcd":2.70157627159088,"alpha":0,"n":8,"CD":0.370154272716916,"CL":-0.00109129230548737,"CDp":0.0157814315465262,"CDf":0.34012,"Cpmin":-0.216187661037876,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"good":2.67578534837367,"id":785,"r":6,"Cm":0.000188853169827589},
             {"CDf":0.34012,"Cpmin":-0.216187661037876,"CL":-0.00109129230548737,"CD":0.370154272716916,"n":9,"CDp":0.0157814315465262,"Cm":0.000188853169827589,"id":786,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":2.67578534837367,"r":6,"Re":100,"src":"retest_157.txt","diter":16,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","clcd":2.70157627159088,"CDpres":0.03003,"alpha":0,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1},
             {"alpha":0,"clcd":2.70157627159213,"CDpres":0.03003,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"sym":0.00058980099013711,"src":"retest_96.txt","Re":100,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":16,"Cm":0.000188853169762865,"r":6,"id":787,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":2.67752679809824,"iver":1.2020052,"Cpmin":-0.216187661039378,"CDf":0.34012,"CDp":0.0157814315465564,"CD":0.370154272716745,"CL":-0.00109129230529298,"n":10},
             {"Cm":0.000188853169762865,"id":788,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":2.67752679809824,"r":6,"CDf":0.34012,"Cpmin":-0.216187661039378,"CD":0.370154272716745,"CL":-0.00109129230529298,"n":11,"CDp":0.0157814315465564,"CDpres":0.03003,"clcd":2.70157627159213,"alpha":0,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"Re":100,"src":"retest_105.txt","diter":16,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat"},
             {"Re":100,"src":"retest_65.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","CDpres":0.06003,"clcd":2.66547920899628,"alpha":-0.3,"sym":0.000437330999893252,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"Bot_Xtr":1,"CDf":0.31514,"Cpmin":-0.243031079745791,"CL":-0.0202257482683849,"CD":0.375167060626431,"n":12,"CDp":0.0140539219654851,"Cm":-0.000254633616640898,"id":789,"good":2.61980272563439,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"iver":1.2020052,"r":6},
             {"alpha":0,"CDpres":0.01274,"clcd":2.66682447284726,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"sym":0.000538535349419939,"src":"retest_84.txt","Re":100,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat","Top_Xtr":1,"diter":8,"Cm":0.000181270986188045,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","iver":1.2020052,"good":2.64285607839322,"id":790,"Cpmin":-0.346784491378297,"CDf":0.36224,"CDp":0.0176384167112764,"n":13,"CD":0.37497780981901,"CL":-0.00111868650360987},
             {"diter":16,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Re":100,"src":"retest_74.txt","sym":0.00058980099013711,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"clcd":2.70157627159616,"CDpres":0.03003,"alpha":0,"CL":-0.00109129230476134,"CD":0.370154272716193,"n":14,"CDp":0.0157814315466975,"CDf":0.34012,"Cpmin":-0.216187661043339,"id":791,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"good":2.6775267699964,"r":6,"Cm":0.000188853169587724},
             {"CDp":0.0100986208945697,"CL":-0.00821515730246157,"CD":0.249576094469332,"n":3,"Cpmin":-0.185055167903565,"CDf":0.22426,"r":6,"id":792,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":3.97413629932045,"Cm":0.000198355754741908,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retest_156.txt","Re":200,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":-0.1,"clcd":4.0067940085619,"CDpres":0.02531},
             {"Cm":0.000198355754741908,"r":6,"id":793,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":3.97413629932045,"xver":6.991,"iver":1.2020052,"Cpmin":-0.185055167903565,"CDf":0.22426,"CDp":0.0100986208945697,"CD":0.249576094469332,"CL":-0.00821515730246157,"n":4,"alpha":-0.1,"clcd":4.0067940085619,"CDpres":0.02531,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"sym":0.00058980099013711,"src":"retest_157.txt","Re":200,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4},
             {"src":"retest_158.txt","Re":200,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"alpha":-0.1,"CDpres":0.02531,"clcd":4.0067940085619,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"sym":0.00058980099013711,"Cpmin":-0.185055167903565,"CDf":0.22426,"CDp":0.0100986208945697,"n":5,"CL":-0.00821515730246157,"CD":0.249576094469332,"Cm":0.000198355754741908,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":3.97413629932045,"xver":6.991,"iver":1.2020052,"id":794},
             {"Re":200,"src":"retestc_16.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat","CDpres":0.02526,"clcd":4.00741550564275,"alpha":-0.1,"sym":0.000538535349419939,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"Bot_Xtr":1,"CDf":0.22427,"Cpmin":-0.184734969695052,"CL":-0.00812182315638566,"CD":0.249537388521835,"n":6,"CDp":0.010075948608262,"Cm":0.000164220573404676,"id":795,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","good":3.97472810780745,"iver":1.2020052,"r":6},
             {"sym":0.00058980099013711,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"clcd":4.00679400856162,"CDpres":0.02531,"alpha":-0.1,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Re":200,"src":"retestc_17.txt","id":796,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":3.97413629931939,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.00019835575474306,"CL":-0.00821515730247384,"CD":0.24957609446935,"n":7,"CDp":0.0100986208945781,"CDf":0.22426,"Cpmin":-0.185055167903489},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retestc_18.txt","Re":200,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":-0.1,"clcd":4.00679400856162,"CDpres":0.02531,"CDp":0.0100986208945781,"CD":0.24957609446935,"CL":-0.00821515730247384,"n":8,"Cpmin":-0.185055167903489,"CDf":0.22426,"r":6,"id":797,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":3.97413629931939,"Cm":0.00019835575474306},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":3.97413629931939,"iver":1.2020052,"id":798,"Cm":0.00019835575474306,"CDp":0.0100986208945781,"n":9,"CL":-0.00821515730247384,"CD":0.24957609446935,"Cpmin":-0.185055167903489,"CDf":0.22426,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":-0.1,"clcd":4.00679400856162,"CDpres":0.02531,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"src":"retestc_19.txt","Re":200},
             {"sym":0.000538535349419939,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"clcd":4.00741550564275,"CDpres":0.02526,"alpha":-0.1,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat","Re":200,"src":"retestc_20.txt","id":799,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","good":3.97472810780745,"iver":1.2020052,"r":6,"Cm":0.000164220573404676,"CL":-0.00812182315638566,"CD":0.249537388521835,"n":10,"CDp":0.010075948608262,"CDf":0.22427,"Cpmin":-0.184734969695052},
             {"CDf":0.22426,"Cpmin":-0.185055167903565,"n":11,"CL":-0.00821515730246157,"CD":0.249576094469332,"CDp":0.0100986208945697,"Cm":0.000198355754741908,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":3.97413629932045,"iver":1.2020052,"id":800,"r":6,"Re":200,"src":"retest_152.txt","diter":4,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"CDpres":0.02531,"clcd":4.0067940085619,"alpha":-0.1,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1},
             {"Cm":0.000198355754741908,"id":801,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"iver":1.2020052,"good":3.97413629932045,"r":6,"CDf":0.22426,"Cpmin":-0.185055167903565,"CD":0.249576094469332,"CL":-0.00821515730246157,"n":12,"CDp":0.0100986208945697,"clcd":4.0067940085619,"CDpres":0.02531,"alpha":-0.1,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"Re":200,"src":"retest_153.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat"},
             {"Cm":0.000164220573404676,"id":802,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","xver":6.991,"good":3.97472810780745,"iver":1.2020052,"r":6,"CDf":0.22427,"Cpmin":-0.184734969695052,"CL":-0.00812182315638566,"CD":0.249537388521835,"n":13,"CDp":0.010075948608262,"clcd":4.00741550564275,"CDpres":0.02526,"alpha":-0.1,"sym":0.000538535349419939,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"Bot_Xtr":1,"Re":200,"src":"retest_86.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat"},
             {"alpha":-0.1,"clcd":4.00741550564275,"CDpres":0.02526,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"sym":0.000538535349419939,"src":"retest_87.txt","Re":200,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat","diter":4,"Cm":0.000164220573404676,"r":6,"id":803,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","good":3.97472810780745,"xver":6.991,"iver":1.2020052,"Cpmin":-0.184734969695052,"CDf":0.22427,"CDp":0.010075948608262,"CL":-0.00812182315638566,"CD":0.249537388521835,"n":14},
             {"Cm":0.000209957679591761,"r":6,"id":804,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":4.98046128970096,"iver":1.2020052,"Cpmin":-0.166441908108751,"CDf":0.17669,"CDp":0.00769418121637855,"CL":-0.000790722902894619,"CD":0.198880248360255,"n":3,"alpha":0,"clcd":5.02815140389699,"CDpres":0.02219,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"sym":0.00058980099013711,"src":"retestc_1.txt","Re":300,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4},
             {"r":6,"id":805,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":4.98046128970096,"xver":6.991,"iver":1.2020052,"Cm":0.000209957679591761,"CDp":0.00769418121637855,"CD":0.198880248360255,"CL":-0.000790722902894619,"n":4,"Cpmin":-0.166441908108751,"CDf":0.17669,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":0,"CDpres":0.02219,"clcd":5.02815140389699,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retestc_0.txt","Re":300},
             {"CDpres":0.02219,"clcd":5.02815140389699,"alpha":0,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"Re":300,"src":"retestc_3.txt","diter":4,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"Cm":0.000209957679591761,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":4.98046128970096,"iver":1.2020052,"id":806,"r":6,"CDf":0.17669,"Cpmin":-0.166441908108751,"n":5,"CD":0.198880248360255,"CL":-0.000790722902894619,"CDp":0.00769418121637855},
             {"sym":0.00058980099013711,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"clcd":5.02815140389699,"CDpres":0.02219,"alpha":0,"diter":4,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"Re":300,"src":"retestc_4.txt","iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":4.98046128970096,"id":807,"r":6,"Cm":0.000209957679591761,"n":6,"CL":-0.000790722902894619,"CD":0.198880248360255,"CDp":0.00769418121637855,"CDf":0.17669,"Cpmin":-0.166441908108751},
             {"r":6,"id":808,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":4.98046128970096,"iver":1.2020052,"Cm":0.000209957679591761,"CDp":0.00769418121637855,"CL":-0.000790722902894619,"CD":0.198880248360255,"n":7,"Cpmin":-0.166441908108751,"CDf":0.17669,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":0,"CDpres":0.02219,"clcd":5.02815140389699,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retestc_9.txt","Re":300},
             {"Cm":0.000209957679591761,"r":6,"id":809,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","iver":1.2020052,"xver":6.991,"good":4.98046128970096,"Cpmin":-0.166441908108751,"CDf":0.17669,"CDp":0.00769418121637855,"CL":-0.000790722902894619,"CD":0.198880248360255,"n":8,"alpha":0,"CDpres":0.02219,"clcd":5.02815140389699,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"sym":0.00058980099013711,"src":"retestc_8.txt","Re":300,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4},
             {"CDp":0.00769418121637855,"CL":-0.000790722902894619,"CD":0.198880248360255,"n":9,"Cpmin":-0.166441908108751,"CDf":0.17669,"r":6,"id":810,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":4.98046128970096,"iver":1.2020052,"Cm":0.000209957679591761,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retestc_10.txt","Re":300,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":0,"CDpres":0.02219,"clcd":5.02815140389699},
             {"Re":300,"src":"retest_98.txt","diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","clcd":5.02815140389774,"CDpres":0.02219,"alpha":0,"sym":0.00058980099013711,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"CDf":0.17669,"Cpmin":-0.166441908108653,"CL":-0.00079072290289049,"CD":0.198880248360226,"n":10,"CDp":0.00769418121638435,"Cm":0.000209957679590851,"id":811,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","xver":6.991,"good":4.98046128970173,"r":6},
             {"r":6,"id":812,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":4.98046128970173,"xver":6.991,"iver":1.2020052,"Cm":0.000209957679590851,"CDp":0.00769418121638435,"CL":-0.00079072290289049,"CD":0.198880248360226,"n":11,"Cpmin":-0.166441908108653,"CDf":0.17669,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"Bot_Xtr":1,"sym":0.00058980099013711,"alpha":0,"CDpres":0.02219,"clcd":5.02815140389774,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","diter":4,"src":"retest_107.txt","Re":300},
             {"alpha":0,"clcd":5.02815140389699,"CDpres":0.02219,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491667149648015,0.677396722306524,0.0150066762780501,0.47941394978603,0.0204965516661759,0.299311787696268,0.0213184989933821,0.156929652384745,0.0163647491225264,0.0764132539783211,0.0117720070203443,0.0250324225664481,0.00690777605874281,0,0,0.0160177258245528,-0.00639415668312031,0.0429242559416574,-0.00983535796801612,0.113672727318502,-0.0152871221469264,0.279918327264509,-0.0219915620700708,0.429777416806303,-0.022004412497344,0.60206127090537,-0.0182588229201987,0.852124131282681,-0.00804234049644394,1,0],"sym":0.00058980099013711,"src":"retestc_15.txt","Re":300,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N7.dat","Top_Xtr":1,"diter":4,"Cm":0.000209957679591761,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97413629931937>3.9412029670143) l1 Foil spline 17pts Re200 N7","good":4.98046128970096,"iver":1.2020052,"id":813,"Cpmin":-0.166441908108751,"CDf":0.17669,"CDp":0.00769418121637855,"n":12,"CD":0.198880248360255,"CL":-0.000790722902894619},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","xver":6.991,"iver":1.2020052,"good":4.98326710287371,"id":814,"r":6,"Cm":0.000173886473708131,"n":13,"CL":-0.000689202037292212,"CD":0.198848440575478,"CDp":0.00767549004244884,"CDf":0.1767,"Cpmin":-0.166100800138167,"sym":0.000538535349419939,"Bot_Xtr":1,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"clcd":5.02895570669776,"CDpres":0.02215,"alpha":0,"diter":4,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat","Top_Xtr":1,"Re":300,"src":"retest_88.txt"},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt3.97472810780714>3.94120296701505) l1 Foil spline 17pts Re200 N10","iver":1.2020052,"xver":6.991,"good":4.98326710287371,"id":815,"Cm":0.000173886473708131,"CDp":0.00767549004244884,"n":14,"CL":-0.000689202037292212,"CD":0.198848440575478,"Cpmin":-0.166100800138167,"CDf":0.1767,"xy":[1,0,0.911596282594944,0.00491214280644043,0.677396722306524,0.0149928537996848,0.47941394978603,0.0204776725262037,0.299311787696268,0.0212988627671014,0.156929652384745,0.0163496757387531,0.0764132539783211,0.0117611639589401,0.0250324225664481,0.00690141338499976,0,0,0.0160177258245528,-0.00637002436829071,0.0429242559416574,-0.00979823814648084,0.113672727318502,-0.0152294267129903,0.279918327264509,-0.0219085632751131,0.429777416806303,-0.0219213652033313,0.60206127090537,-0.0181899119308432,0.852124131282681,-0.008011987738067,1,0],"Bot_Xtr":1,"sym":0.000538535349419939,"alpha":0,"clcd":5.02895570669776,"CDpres":0.02215,"Foil_fn":"optbs_spline_sym_goe443.dat-s17_n17s0_nsopt-Re200-N10.dat","Top_Xtr":1,"diter":4,"src":"retest_89.txt","Re":300},
             {"Cm":-4.37943912188407e-05,"r":6,"id":816,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","good":5.84490727698995,"xver":6.991,"iver":1.2020052,"Cpmin":-0.155556375433926,"CDf":0.15079,"CDp":0.00599021493556184,"CD":0.169543820494928,"CL":0.000189951628803852,"n":3,"alpha":0,"CDpres":0.01875,"clcd":5.89818017006355,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"sym":1.52094499678478e-05,"src":"retest_72.txt","Re":400,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","diter":3},
             {"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"Bot_Xtr":1,"sym":1.52094499678478e-05,"alpha":0,"clcd":5.89818017006355,"CDpres":0.01875,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","diter":3,"src":"retest_73.txt","Re":400,"r":6,"id":817,"good":5.84490727698995,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","xver":6.991,"iver":1.2020052,"Cm":-4.37943912188407e-05,"CDp":0.00599021493556184,"CD":0.169543820494928,"CL":0.000189951628803852,"n":4,"Cpmin":-0.155556375433926,"CDf":0.15079},
             {"Re":400,"src":"retest_74.txt","diter":3,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","Top_Xtr":1,"CDpres":0.01875,"clcd":5.89818017006355,"alpha":0,"sym":1.52094499678478e-05,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"Bot_Xtr":1,"CDf":0.15079,"Cpmin":-0.155556375433926,"n":5,"CL":0.000189951628803852,"CD":0.169543820494928,"CDp":0.00599021493556184,"Cm":-4.37943912188407e-05,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","xver":6.991,"good":5.84490727698995,"iver":1.2020052,"id":818,"r":6},
             {"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"Bot_Xtr":1,"sym":1.52094499678478e-05,"alpha":0,"CDpres":0.01875,"clcd":5.89818017006355,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","diter":3,"src":"retest_75.txt","Re":400,"r":6,"id":819,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","iver":1.2020052,"good":5.84490727698995,"Cm":-4.37943912188407e-05,"CDp":0.00599021493556184,"CD":0.169543820494928,"CL":0.000189951628803852,"n":6,"Cpmin":-0.155556375433926,"CDf":0.15079},
             {"Re":400,"src":"retest_76.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","clcd":5.89818017006355,"CDpres":0.01875,"alpha":0,"sym":1.52094499678478e-05,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"Bot_Xtr":1,"CDf":0.15079,"Cpmin":-0.155556375433926,"CL":0.000189951628803852,"CD":0.169543820494928,"n":7,"CDp":0.00599021493556184,"Cm":-4.37943912188407e-05,"id":820,"good":5.84490727698995,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","xver":6.991,"iver":1.2020052,"r":6},
             {"CDp":0.00599021493556184,"n":8,"CL":0.000189951628803852,"CD":0.169543820494928,"Cpmin":-0.155556375433926,"CDf":0.15079,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","iver":1.2020052,"good":5.84490727698995,"id":821,"Cm":-4.37943912188407e-05,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","Top_Xtr":1,"diter":3,"src":"retest_77.txt","Re":400,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"Bot_Xtr":1,"sym":1.52094499678478e-05,"alpha":0,"clcd":5.89818017006355,"CDpres":0.01875},
             {"r":6,"id":822,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","iver":1.2020052,"xver":6.991,"good":5.84490727698995,"Cm":-4.37943912188407e-05,"CDp":0.00599021493556184,"CD":0.169543820494928,"CL":0.000189951628803852,"n":9,"Cpmin":-0.155556375433926,"CDf":0.15079,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"Bot_Xtr":1,"sym":1.52094499678478e-05,"alpha":0,"CDpres":0.01875,"clcd":5.89818017006355,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","diter":3,"src":"retest_78.txt","Re":400},
             {"src":"retest_79.txt","Re":400,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","diter":3,"alpha":0,"clcd":5.89818017006355,"CDpres":0.01875,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"sym":1.52094499678478e-05,"Cpmin":-0.155556375433926,"CDf":0.15079,"CDp":0.00599021493556184,"CD":0.169543820494928,"CL":0.000189951628803852,"n":10,"Cm":-4.37943912188407e-05,"r":6,"id":823,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","iver":1.2020052,"good":5.84490727698995},
             {"alpha":0,"CDpres":0.01875,"clcd":5.89818017006355,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"sym":1.52094499678478e-05,"src":"retest_80.txt","Re":400,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","Top_Xtr":1,"diter":3,"Cm":-4.37943912188407e-05,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","xver":6.991,"good":5.84490727698995,"iver":1.2020052,"id":824,"Cpmin":-0.155556375433926,"CDf":0.15079,"CDp":0.00599021493556184,"n":11,"CL":0.000189951628803852,"CD":0.169543820494928},
             {"sym":1.52094499678478e-05,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00552615423699697,0.694333673847856,0.0147367861399562,0.509231179755794,0.0199699986462546,0.297443068278191,0.0208319578537581,0.152023524084313,0.0172841030054581,0.0753937499526754,0.0119554464363579,0.0282005505081749,0.00710815442517118,0,0,0.0305092906552454,-0.00751997804057668,0.070587140399756,-0.0113810651549899,0.144007724163616,-0.0168180056478163,0.294381870174478,-0.02070197820277,0.518667901491446,-0.0197197216753103,0.712644267487666,-0.0139520588940302,0.913821594597361,-0.00524650516331093,1,0],"clcd":5.89818017006355,"CDpres":0.01875,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re100-N11.dat","Re":400,"src":"retest_81.txt","id":825,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt2.69106685799534>2.62852184971199) l1 Foil spline 17pts Re100 N11","xver":6.991,"good":5.84490727698995,"iver":1.2020052,"r":6,"Cm":-4.37943912188407e-05,"CL":0.000189951628803852,"CD":0.169543820494928,"n":12,"CDp":0.00599021493556184,"CDf":0.15079,"Cpmin":-0.155556375433926},
             {"Re":400,"src":"retest_103.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N8.dat","CDpres":0.02342,"clcd":5.70611477998379,"alpha":0,"sym":3.7604090930473e-05,"xy":[1,0,0.880109807575427,0.0145249030682064,0.707548243935809,0.0260685927174291,0.503056452239259,0.0300279605699047,0.293727127633715,0.0269078566418147,0.144498782157076,0.020299299718761,0.0772542272248852,0.0152346149695393,0.0248124276986501,0.00906550292223594,0,0,0.0246606363984082,-0.00909179777517882,0.0798904739512234,-0.0156629620354501,0.150528301231026,-0.0208483583581744,0.295205165909812,-0.0272075095006708,0.504800317369777,-0.0303365445272418,0.71280527778783,-0.0261157484626,0.884488680537926,-0.0142268152357446,1,0],"Bot_Xtr":1,"CDf":0.15184,"Cpmin":-0.166047032957518,"CL":-0.000272419308256502,"CD":0.175250593189582,"n":13,"CDp":0.00862253810432428,"Cm":0.00016056138812249,"id":826,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75754453237299>1.74752479096356) l1 Foil spline 17pts Re50 N8","good":5.6737111456232,"xver":6.991,"iver":1.2020052,"r":6},
             {"alpha":0,"clcd":5.70611477998379,"CDpres":0.02342,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145249030682064,0.707548243935809,0.0260685927174291,0.503056452239259,0.0300279605699047,0.293727127633715,0.0269078566418147,0.144498782157076,0.020299299718761,0.0772542272248852,0.0152346149695393,0.0248124276986501,0.00906550292223594,0,0,0.0246606363984082,-0.00909179777517882,0.0798904739512234,-0.0156629620354501,0.150528301231026,-0.0208483583581744,0.295205165909812,-0.0272075095006708,0.504800317369777,-0.0303365445272418,0.71280527778783,-0.0261157484626,0.884488680537926,-0.0142268152357446,1,0],"sym":3.7604090930473e-05,"src":"retest_104.txt","Re":400,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N8.dat","Top_Xtr":1,"diter":3,"Cm":0.00016056138812249,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75754453237299>1.74752479096356) l1 Foil spline 17pts Re50 N8","iver":1.2020052,"xver":6.991,"good":5.6737111456232,"id":827,"Cpmin":-0.166047032957518,"CDf":0.15184,"CDp":0.00862253810432428,"n":14,"CD":0.175250593189582,"CL":-0.000272419308256502},
             {"src":"retest_96.txt","Re":500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","diter":3,"alpha":-0.1,"CDpres":0.0261,"clcd":6.54006712575403,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"sym":0.000437330999893252,"Cpmin":-0.364772904331694,"CDf":0.12681,"CDp":0.00232430974812866,"CL":-0.00835641952080277,"CD":0.15290362939275,"n":3,"Cm":-0.000944958801213595,"r":6,"id":828,"good":6.47930829785073,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"iver":1.2020052},
             {"Re":500,"src":"retest_97.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","clcd":6.54006712575403,"CDpres":0.0261,"alpha":-0.1,"sym":0.000437330999893252,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"Bot_Xtr":1,"CDf":0.12681,"Cpmin":-0.364772904331694,"CD":0.15290362939275,"CL":-0.00835641952080277,"n":4,"CDp":0.00232430974812866,"Cm":-0.000944958801213595,"id":829,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"good":6.47930829785073,"r":6},
             {"CL":-0.00835641952080277,"CD":0.15290362939275,"n":5,"CDp":0.00232430974812866,"CDf":0.12681,"Cpmin":-0.364772904331694,"id":830,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","iver":1.2020052,"good":6.47930829785073,"r":6,"Cm":-0.000944958801213595,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Re":500,"src":"retest_98.txt","sym":0.000437330999893252,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"clcd":6.54006712575403,"CDpres":0.0261,"alpha":-0.1},
             {"n":6,"CD":0.15290362939275,"CL":-0.00835641952080277,"CDp":0.00232430974812866,"CDf":0.12681,"Cpmin":-0.364772904331694,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"good":6.47930829785073,"iver":1.2020052,"id":831,"r":6,"Cm":-0.000944958801213595,"diter":3,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Top_Xtr":1,"Re":500,"src":"retest_99.txt","sym":0.000437330999893252,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"CDpres":0.0261,"clcd":6.54006712575403,"alpha":-0.1},
             {"Cm":-0.000944958801213595,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"iver":1.2020052,"good":6.47930829785073,"id":832,"r":6,"CDf":0.12681,"Cpmin":-0.364772904331694,"n":7,"CD":0.15290362939275,"CL":-0.00835641952080277,"CDp":0.00232430974812866,"CDpres":0.0261,"clcd":6.54006712575403,"alpha":-0.1,"sym":0.000437330999893252,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"Bot_Xtr":1,"Re":500,"src":"retest_100.txt","diter":3,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Top_Xtr":1},
             {"Cm":-0.000944958801213595,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"good":6.47930829785073,"iver":1.2020052,"id":833,"r":6,"CDf":0.12681,"Cpmin":-0.364772904331694,"n":8,"CD":0.15290362939275,"CL":-0.00835641952080277,"CDp":0.00232430974812866,"clcd":6.54006712575403,"CDpres":0.0261,"alpha":-0.1,"sym":0.000437330999893252,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"Bot_Xtr":1,"Re":500,"src":"retest_101.txt","diter":3,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Top_Xtr":1},
             {"diter":3,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"Re":500,"src":"retest_64.txt","sym":4.5915759379823e-05,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"clcd":6.61651935769505,"CDpres":0.02095,"alpha":0,"n":9,"CL":-0.000645802527682848,"CD":0.151136866067957,"CDp":0.00663702349005037,"CDf":0.13019,"Cpmin":-0.166748264194216,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":6.57069280214038,"iver":1.2020052,"id":834,"r":6,"Cm":0.000189665009446273},
             {"Cm":0.000189665009446273,"r":6,"id":835,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"xver":6.991,"good":6.57069280214038,"Cpmin":-0.166748264194216,"CDf":0.13019,"CDp":0.00663702349005037,"CD":0.151136866067957,"CL":-0.000645802527682848,"n":10,"alpha":0,"CDpres":0.02095,"clcd":6.61651935769505,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"sym":4.5915759379823e-05,"src":"retest_65.txt","Re":500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","diter":3},
             {"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"Bot_Xtr":1,"sym":0.000437330999893252,"alpha":-0.1,"clcd":6.54006712575403,"CDpres":0.0261,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Top_Xtr":1,"diter":3,"src":"retest_104.txt","Re":500,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","good":6.47930829785073,"xver":6.991,"iver":1.2020052,"id":836,"Cm":-0.000944958801213595,"CDp":0.00232430974812866,"n":11,"CL":-0.00835641952080277,"CD":0.15290362939275,"Cpmin":-0.364772904331694,"CDf":0.12681},
             {"src":"retest_105.txt","Re":500,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Top_Xtr":1,"diter":3,"alpha":-0.1,"clcd":6.54006712575403,"CDpres":0.0261,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"sym":0.000437330999893252,"Cpmin":-0.364772904331694,"CDf":0.12681,"CDp":0.00232430974812866,"n":12,"CL":-0.00835641952080277,"CD":0.15290362939275,"Cm":-0.000944958801213595,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"good":6.47930829785073,"id":837},
             {"src":"retest_156.txt","Re":500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","diter":3,"alpha":-0.1,"clcd":6.54006712575221,"CDpres":0.0261,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"sym":0.000437330999893252,"Cpmin":-0.364772904337386,"CDf":0.12681,"CDp":0.00232430974798375,"CL":-0.00835641952093008,"CD":0.152903629392792,"n":13,"Cm":-0.000944958801218245,"r":6,"id":838,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"good":6.47930829784938},
             {"sym":0.000437330999893252,"Bot_Xtr":1,"xy":[1,0,0.976897960413403,0.00144319810921475,0.841802458831161,0.00832366519363324,0.685311999750461,0.0151005469088736,0.49973932537838,0.0209649935999116,0.312336520450744,0.0240249071220531,0.145590765507442,0.0221652641662187,0.0378559354704006,0.0130802961373594,0,0,0.0394434003278519,-0.0128435665855893,0.146561206567468,-0.02118042713652,0.30663469936699,-0.0230164789281046,0.500275056378041,-0.020057902162343,0.695358932880317,-0.0140802233067886,0.847906706265167,-0.00767117316910685,0.977829248599176,-0.00133765811912582,1,0],"clcd":6.54006712575221,"CDpres":0.0261,"alpha":-0.1,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx76100.dat-s17_n17s0_nsopt-Re50-N10.dat","Re":500,"src":"retest_157.txt","id":839,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76100.dat-s17_n17s0.dat (opt1.760790363444>1.61685554941177) l1 Foil spline 17pts Re50 N10","xver":6.991,"iver":1.2020052,"good":6.47930829784938,"r":6,"Cm":-0.000944958801218245,"CD":0.152903629392792,"CL":-0.00835641952093008,"n":14,"CDp":0.00232430974798375,"CDf":0.12681,"Cpmin":-0.364772904337386},
             {"clcd":8.30413245898353,"CDpres":0.01349,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"Re":750,"src":"retest_66.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Cm":0.000203528409969033,"id":840,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":8.22215427712417,"r":6,"CDf":0.10694,"Cpmin":-0.182607628439424,"CD":0.120421971222073,"CL":-0.000742593619858886,"n":3,"CDp":0.00579589961862761},
             {"CDf":0.10694,"Cpmin":-0.182607628439424,"CD":0.120421971222073,"CL":-0.000742593619858886,"n":4,"CDp":0.00579589961862761,"Cm":0.000203528409969033,"id":841,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":8.22215427712417,"iver":1.2020052,"r":6,"Re":750,"src":"retest_67.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","clcd":8.30413245898353,"CDpres":0.01349,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1},
             {"CDp":0.00579589961862761,"n":5,"CD":0.120421971222073,"CL":-0.000742593619858886,"Cpmin":-0.182607628439424,"CDf":0.10694,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":8.22215427712417,"iver":1.2020052,"id":842,"Cm":0.000203528409969033,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_68.txt","Re":750,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"clcd":8.30413245898353,"CDpres":0.01349},
             {"Cm":0.000203528409969033,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":8.22215427712417,"xver":6.991,"iver":1.2020052,"id":843,"r":6,"CDf":0.10694,"Cpmin":-0.182607628439424,"n":6,"CL":-0.000742593619858886,"CD":0.120421971222073,"CDp":0.00579589961862761,"clcd":8.30413245898353,"CDpres":0.01349,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"Re":750,"src":"retest_69.txt","diter":3,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1},
             {"sym":4.5915759379823e-05,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"clcd":8.30413245898353,"CDpres":0.01349,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"Re":750,"src":"retest_70.txt","good":8.22215427712417,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"iver":1.2020052,"id":844,"r":6,"Cm":0.000203528409969033,"n":7,"CD":0.120421971222073,"CL":-0.000742593619858886,"CDp":0.00579589961862761,"CDf":0.10694,"Cpmin":-0.182607628439424},
             {"r":6,"id":845,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":8.22215427712417,"iver":1.2020052,"Cm":0.000203528409969033,"CDp":0.00579589961862761,"CD":0.120421971222073,"CL":-0.000742593619858886,"n":8,"Cpmin":-0.182607628439424,"CDf":0.10694,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"CDpres":0.01349,"clcd":8.30413245898353,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","diter":3,"src":"retest_71.txt","Re":750},
             {"Cpmin":-0.182607628439424,"CDf":0.10694,"CDp":0.00579589961862761,"CL":-0.000742593619858886,"CD":0.120421971222073,"n":9,"Cm":0.000203528409969033,"r":6,"id":846,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"xver":6.991,"good":8.22215427712417,"src":"retest_72.txt","Re":750,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","diter":3,"alpha":0,"clcd":8.30413245898353,"CDpres":0.01349,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"sym":4.5915759379823e-05},
             {"clcd":8.30413245898353,"CDpres":0.01349,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"Re":750,"src":"retest_73.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Cm":0.000203528409969033,"id":847,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"iver":1.2020052,"good":8.22215427712417,"r":6,"CDf":0.10694,"Cpmin":-0.182607628439424,"CL":-0.000742593619858886,"CD":0.120421971222073,"n":10,"CDp":0.00579589961862761},
             {"Cm":-1.47457335684605e-05,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt2.60398401640815>2.55732883086936) l1 Foil spline 17pts Re100 N9","iver":1.2020052,"xver":6.991,"good":8.00165399708787,"id":848,"r":6,"CDf":0.10511,"Cpmin":-0.23804357158765,"n":11,"CD":0.123599405284574,"CL":0.000179643465887015,"CDp":0.00930221575918003,"clcd":8.09065381583034,"CDpres":0.01849,"alpha":0,"sym":2.18935026061114e-05,"xy":[1,0,0.957161379295047,0.00191212699835839,0.840936018693537,0.00870169766498076,0.693142957839131,0.0192234053829514,0.510945017907535,0.0300004109110515,0.310831802004258,0.0332278316869427,0.141208349666857,0.0276767082041124,0.039312956593761,0.0158180658463432,0,0,0.0414480062413493,-0.0163138730394172,0.14748763733964,-0.0280078519543454,0.314606487742102,-0.0331848753566064,0.500000736363886,-0.0303030457915639,0.65939238192171,-0.0215184011283741,0.842205184753321,-0.00861253014129323,0.960017460050938,-0.00176990225831257,1,0],"Bot_Xtr":1,"Re":750,"src":"retest_151.txt","diter":3,"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re100-N9.dat","Top_Xtr":1},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re100-N9.dat","Re":750,"src":"retest_76.txt","sym":2.18935026061114e-05,"Bot_Xtr":1,"xy":[1,0,0.957161379295047,0.00191212699835839,0.840936018693537,0.00870169766498076,0.693142957839131,0.0192234053829514,0.510945017907535,0.0300004109110515,0.310831802004258,0.0332278316869427,0.141208349666857,0.0276767082041124,0.039312956593761,0.0158180658463432,0,0,0.0414480062413493,-0.0163138730394172,0.14748763733964,-0.0280078519543454,0.314606487742102,-0.0331848753566064,0.500000736363886,-0.0303030457915639,0.65939238192171,-0.0215184011283741,0.842205184753321,-0.00861253014129323,0.960017460050938,-0.00176990225831257,1,0],"clcd":8.09065381583016,"CDpres":0.01849,"alpha":0,"CL":0.00017964346586805,"CD":0.123599405284577,"n":12,"CDp":0.00930221575917236,"CDf":0.10511,"Cpmin":-0.23804357158765,"id":849,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt2.60398401640815>2.55732883086936) l1 Foil spline 17pts Re100 N9","good":8.00165399708759,"iver":1.2020052,"r":6,"Cm":-1.4745733572199e-05},
             {"CDf":0.11038,"Cpmin":-0.17982300920088,"CD":0.124064060883776,"CL":-0.000334497702234216,"n":13,"CDp":0.00709249277130352,"Cm":0.000180586983379078,"id":850,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","good":7.97485451424502,"iver":1.2020052,"r":6,"Re":750,"src":"retest_152.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","clcd":8.06035198974187,"CDpres":0.01369,"alpha":0,"sym":4.1252318558898e-05,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"Bot_Xtr":1},
             {"Cm":0.000180586983379078,"r":6,"id":851,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16006.dat-s17_n17s0.dat (opt1.75922592941846>1.74752479096354) l1 Foil spline 17pts Re50 N12","xver":6.991,"iver":1.2020052,"good":7.97485451424502,"Cpmin":-0.17982300920088,"CDf":0.11038,"CDp":0.00709249277130352,"CD":0.124064060883776,"CL":-0.000334497702234216,"n":14,"alpha":0,"clcd":8.06035198974187,"CDpres":0.01369,"Bot_Xtr":1,"xy":[1,0,0.880109807575427,0.0145382941251127,0.707548243935809,0.026092626337957,0.503056452239259,0.0300556444812453,0.293727127633715,0.0269326640114629,0.144498782157076,0.0203180144101029,0.0772542272248852,0.0152486603366612,0.0248124276986501,0.00907386075188518,0,0,0.0246606363984082,-0.00910465892148343,0.0798904739512234,-0.0156851186706154,0.150528301231026,-0.0208778501917683,0.295205165909812,-0.0272459969119535,0.504800317369777,-0.0303794582333304,0.71280527778783,-0.0261526914820267,0.884488680537926,-0.0142469403151535,1,0],"sym":4.1252318558898e-05,"src":"retest_153.txt","Re":750,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca16006.dat-s17_n17s0_nsopt-Re50-N12.dat","diter":3},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":9.60751083591016,"iver":1.2020052,"id":852,"Cm":0.000204882500309125,"CDp":0.00487447832424565,"n":3,"CD":0.102974549440445,"CL":-0.00077458402709157,"Cpmin":-0.180965219041521,"CDf":0.091,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"clcd":9.71113741632193,"CDpres":0.01198,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_74.txt","Re":1000},
             {"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_75.txt","Re":1000,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"CDpres":0.01198,"clcd":9.71113741632193,"CDp":0.00487447832424565,"n":4,"CD":0.102974549440445,"CL":-0.00077458402709157,"Cpmin":-0.180965219041521,"CDf":0.091,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"xver":6.991,"good":9.60751083591016,"id":853,"Cm":0.000204882500309125},
             {"Cm":7.64602609229914e-05,"id":854,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","iver":1.2020052,"good":9.67249836201959,"r":6,"CDf":0.08809,"Cpmin":-0.154089522617992,"CL":-0.00034756057349066,"CD":0.102369885511458,"n":5,"CDp":0.0036745558924224,"clcd":9.76849778627595,"CDpres":0.01428,"alpha":0,"sym":1.12286706951842e-05,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1,"Re":1000,"src":"retest_152.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat"},
             {"Re":1000,"src":"retest_153.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","Top_Xtr":1,"clcd":9.76849778627595,"CDpres":0.01428,"alpha":0,"sym":1.12286706951842e-05,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1,"CDf":0.08809,"Cpmin":-0.154089522617992,"n":6,"CL":-0.00034756057349066,"CD":0.102369885511458,"CDp":0.0036745558924224,"Cm":7.64602609229914e-05,"good":9.67249836201959,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","xver":6.991,"iver":1.2020052,"id":855,"r":6},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","diter":3,"src":"retest_154.txt","Re":1000,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1,"sym":1.12286706951842e-05,"alpha":0,"CDpres":0.01428,"clcd":9.76849778627595,"CDp":0.0036745558924224,"CD":0.102369885511458,"CL":-0.00034756057349066,"n":7,"Cpmin":-0.154089522617992,"CDf":0.08809,"r":6,"id":856,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","xver":6.991,"iver":1.2020052,"good":9.67249836201959,"Cm":7.64602609229914e-05},
             {"CDf":0.08809,"Cpmin":-0.154089522617992,"CD":0.102369885511458,"CL":-0.00034756057349066,"n":8,"CDp":0.0036745558924224,"Cm":7.64602609229914e-05,"id":857,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","iver":1.2020052,"good":9.67249836201959,"r":6,"Re":1000,"src":"retest_155.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","clcd":9.76849778627595,"CDpres":0.01428,"alpha":0,"sym":1.12286706951842e-05,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1},
             {"CDp":0.0036745558924224,"n":9,"CD":0.102369885511458,"CL":-0.00034756057349066,"Cpmin":-0.154089522617992,"CDf":0.08809,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","iver":1.2020052,"xver":6.991,"good":9.67249836201959,"id":858,"Cm":7.64602609229914e-05,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_156.txt","Re":1000,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1,"sym":1.12286706951842e-05,"alpha":0,"clcd":9.76849778627595,"CDpres":0.01428},
             {"CDp":0.0036745558924224,"CD":0.102369885511458,"CL":-0.00034756057349066,"n":10,"Cpmin":-0.154089522617992,"CDf":0.08809,"r":6,"id":859,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","good":9.67249836201959,"iver":1.2020052,"Cm":7.64602609229914e-05,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","diter":3,"src":"retest_157.txt","Re":1000,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1,"sym":1.12286706951842e-05,"alpha":0,"CDpres":0.01428,"clcd":9.76849778627595},
             {"Cpmin":-0.154089522617992,"CDf":0.08809,"CDp":0.0036745558924224,"n":11,"CL":-0.00034756057349066,"CD":0.102369885511458,"Cm":7.64602609229914e-05,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","iver":1.2020052,"good":9.67249836201959,"id":860,"src":"retest_158.txt","Re":1000,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":9.76849778627595,"CDpres":0.01428,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"sym":1.12286706951842e-05},
             {"CDpres":0.01428,"clcd":9.76849778627595,"alpha":0,"sym":1.12286706951842e-05,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"Bot_Xtr":1,"Re":1000,"src":"retest_159.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","Cm":7.64602609229914e-05,"id":861,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","xver":6.991,"good":9.67249836201959,"r":6,"CDf":0.08809,"Cpmin":-0.154089522617992,"CD":0.102369885511458,"CL":-0.00034756057349066,"n":12,"CDp":0.0036745558924224},
             {"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re100-N8.dat","Top_Xtr":1,"Re":1000,"src":"retest_151.txt","sym":1.12286706951842e-05,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00547406357000542,0.672127682508641,0.0130186403779867,0.448051878989487,0.0185410251022464,0.261607586958807,0.0197981083545296,0.14960260982261,0.0176064727318713,0.0876932172572549,0.014706668366206,0.0269668136105797,0.00906127943444113,0,0,0.0260784653873372,-0.00893738594767688,0.0852103572234493,-0.0146612700315711,0.159346520639483,-0.0180836671791744,0.277295492850028,-0.0200049195709503,0.461088095254591,-0.0184469528616278,0.679515403216876,-0.0128843142464138,0.887295989576364,-0.0053634287362285,1,0],"CDpres":0.01428,"clcd":9.76849778627595,"alpha":0,"n":13,"CL":-0.00034756057349066,"CD":0.102369885511458,"CDp":0.0036745558924224,"CDf":0.08809,"Cpmin":-0.154089522617992,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt2.67883146988465>0) l1 Foil spline 17pts Re100 N8","xver":6.991,"good":9.67249836201959,"iver":1.2020052,"id":862,"r":6,"Cm":7.64602609229914e-05},
             {"sym":0.0014787503569594,"Bot_Xtr":1,"xy":[1,0,0.834572029108263,0.00808139161742746,0.731144982970981,0.0130331272283255,0.549006839790294,0.020301394066083,0.360723469766044,0.022864728370604,0.172973899438296,0.018216259308953,0.0677940348296797,0.0116153380228575,0.0218187281153614,0.00657811735214918,0,0,0.0165315788718247,-0.00747080073624883,0.0836843816845759,-0.0147123172813731,0.212871024526011,-0.021268758018048,0.380503202758195,-0.0240866702550291,0.533373456390264,-0.0216150259606038,0.682886622411824,-0.0158535890851726,0.836391213494486,-0.00831395139189404,1,0],"CDpres":0.06286,"clcd":3.87248779121384,"alpha":6.7,"diter":4,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_n64008a.dat-s17_n17s0_nsopt-Re50-N7.dat","Re":1000,"src":"retest_95.txt","id":863,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_n64008a.dat-s17_n17s0.dat (opt1.78975224437386>0) l1 Foil spline 17pts Re50 N7","xver":6.991,"good":3.57026062537863,"r":6,"Cm":0.00501150723109633,"CD":0.120619016847728,"CL":0.467095670131042,"n":14,"CDp":0.0442769386571964,"CDf":0.05775,"Cpmin":-2.53220031183617},
             {"Cm":0.000195727532056518,"r":6,"good":10.7685989202138,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"iver":1.2020052,"id":864,"Cpmin":-0.162136197893013,"CDf":0.07801,"CDp":0.00365730387612322,"n":3,"CL":-0.000747290506699928,"CD":0.0917097137987357,"alpha":0,"CDpres":0.0137,"clcd":10.9039703492542,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"sym":4.5915759379823e-05,"src":"retest_82.txt","Re":1250,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3},
             {"Cm":0.000195727532056518,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"good":10.7685989202138,"id":865,"Cpmin":-0.162136197893013,"CDf":0.07801,"CDp":0.00365730387612322,"n":4,"CD":0.0917097137987357,"CL":-0.000747290506699928,"alpha":0,"CDpres":0.0137,"clcd":10.9039703492542,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"sym":4.5915759379823e-05,"src":"retest_83.txt","Re":1250,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3},
             {"Cpmin":-0.162136197893013,"CDf":0.07801,"CDp":0.00365730387612322,"n":5,"CD":0.0917097137987357,"CL":-0.000747290506699928,"Cm":0.000195727532056518,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"good":10.7685989202138,"id":866,"src":"retest_84.txt","Re":1250,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"alpha":0,"CDpres":0.0137,"clcd":10.9039703492542,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"sym":4.5915759379823e-05},
             {"id":867,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":10.7685989202138,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000195727532056518,"CL":-0.000747290506699928,"CD":0.0917097137987357,"n":6,"CDp":0.00365730387612322,"CDf":0.07801,"Cpmin":-0.162136197893013,"sym":4.5915759379823e-05,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"CDpres":0.0137,"clcd":10.9039703492542,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Re":1250,"src":"retest_85.txt"},
             {"CDp":0.00365730387612322,"n":7,"CD":0.0917097137987357,"CL":-0.000747290506699928,"Cpmin":-0.162136197893013,"CDf":0.07801,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"good":10.7685989202138,"id":868,"Cm":0.000195727532056518,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_86.txt","Re":1250,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"clcd":10.9039703492542,"CDpres":0.0137},
             {"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"CDpres":0.0137,"clcd":10.9039703492542,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_87.txt","Re":1250,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":10.7685989202138,"id":869,"Cm":0.000195727532056518,"CDp":0.00365730387612322,"n":8,"CD":0.0917097137987357,"CL":-0.000747290506699928,"Cpmin":-0.162136197893013,"CDf":0.07801},
             {"Re":1250,"src":"retest_88.txt","diter":3,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"CDpres":0.0137,"clcd":10.9039703492551,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"CDf":0.07801,"Cpmin":-0.162136197893033,"n":9,"CD":0.0917097137987282,"CL":-0.000747290506704431,"CDp":0.00365730387612477,"Cm":0.000195727532054392,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":10.7685989201529,"iver":1.2020052,"id":870,"r":6},
             {"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_89.txt","Re":1250,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"clcd":10.9039703492551,"CDpres":0.0137,"CDp":0.00365730387612477,"n":10,"CL":-0.000747290506704431,"CD":0.0917097137987282,"Cpmin":-0.162136197893033,"CDf":0.07801,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":10.7685989201529,"iver":1.2020052,"id":871,"Cm":0.000195727532054392},
             {"alpha":0,"CDpres":0.01504,"clcd":10.670092722775,"Bot_Xtr":1,"xy":[1,0,0.957161379295047,0.00191212699835839,0.840936018693537,0.00870169766498076,0.693142957839131,0.0192234053829514,0.510945017907535,0.0300004109110515,0.310831802004258,0.0332278316869427,0.141208349666857,0.0276767082041124,0.039312956593761,0.0158180658463432,0,0,0.0414480062413493,-0.0163138730394172,0.14748763733964,-0.0280078519543454,0.314606487742102,-0.0331848753566064,0.500000736363886,-0.0303030457915639,0.65939238192171,-0.0215184011283741,0.842205184753321,-0.00861253014129323,0.960017460050938,-0.00176990225831257,1,0],"sym":2.18935026061114e-05,"src":"retest_154.txt","Re":1250,"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re100-N9.dat","Top_Xtr":1,"diter":3,"Cm":-1.60263328074962e-05,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt2.60398401640815>2.55732883086936) l1 Foil spline 17pts Re100 N9","iver":1.2020052,"good":10.5644875064785,"id":872,"Cpmin":-0.230260853134498,"CDf":0.07868,"CDp":0.00723361822793096,"n":11,"CL":0.000190670195802709,"CD":0.0937198978473285},
             {"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re100-N9.dat","Top_Xtr":1,"diter":3,"src":"retest_155.txt","Re":1250,"xy":[1,0,0.957161379295047,0.00191212699835839,0.840936018693537,0.00870169766498076,0.693142957839131,0.0192234053829514,0.510945017907535,0.0300004109110515,0.310831802004258,0.0332278316869427,0.141208349666857,0.0276767082041124,0.039312956593761,0.0158180658463432,0,0,0.0414480062413493,-0.0163138730394172,0.14748763733964,-0.0280078519543454,0.314606487742102,-0.0331848753566064,0.500000736363886,-0.0303030457915639,0.65939238192171,-0.0215184011283741,0.842205184753321,-0.00861253014129323,0.960017460050938,-0.00176990225831257,1,0],"Bot_Xtr":1,"sym":2.18935026061114e-05,"alpha":0,"CDpres":0.01504,"clcd":10.670092722775,"CDp":0.00723361822793096,"n":12,"CD":0.0937198978473285,"CL":0.000190670195802709,"Cpmin":-0.230260853134498,"CDf":0.07868,"r":6,"good":10.5644875064785,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt2.60398401640815>2.55732883086936) l1 Foil spline 17pts Re100 N9","xver":6.991,"iver":1.2020052,"id":873,"Cm":-1.60263328074962e-05},
             {"CDf":0.07868,"Cpmin":-0.230260853134498,"CL":0.000190670195802709,"CD":0.0937198978473285,"n":13,"CDp":0.00723361822793096,"Cm":-1.60263328074962e-05,"id":874,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt2.60398401640815>2.55732883086936) l1 Foil spline 17pts Re100 N9","xver":6.991,"iver":1.2020052,"good":10.5644875064785,"r":6,"Re":1250,"src":"retest_156.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re100-N9.dat","clcd":10.670092722775,"CDpres":0.01504,"alpha":0,"sym":2.18935026061114e-05,"xy":[1,0,0.957161379295047,0.00191212699835839,0.840936018693537,0.00870169766498076,0.693142957839131,0.0192234053829514,0.510945017907535,0.0300004109110515,0.310831802004258,0.0332278316869427,0.141208349666857,0.0276767082041124,0.039312956593761,0.0158180658463432,0,0,0.0414480062413493,-0.0163138730394172,0.14748763733964,-0.0280078519543454,0.314606487742102,-0.0331848753566064,0.500000736363886,-0.0303030457915639,0.65939238192171,-0.0215184011283741,0.842205184753321,-0.00861253014129323,0.960017460050938,-0.00176990225831257,1,0],"Bot_Xtr":1},
             {"CDpres":0.01504,"clcd":10.670092722775,"alpha":0,"sym":2.18935026061114e-05,"xy":[1,0,0.957161379295047,0.00191212699835839,0.840936018693537,0.00870169766498076,0.693142957839131,0.0192234053829514,0.510945017907535,0.0300004109110515,0.310831802004258,0.0332278316869427,0.141208349666857,0.0276767082041124,0.039312956593761,0.0158180658463432,0,0,0.0414480062413493,-0.0163138730394172,0.14748763733964,-0.0280078519543454,0.314606487742102,-0.0331848753566064,0.500000736363886,-0.0303030457915639,0.65939238192171,-0.0215184011283741,0.842205184753321,-0.00861253014129323,0.960017460050938,-0.00176990225831257,1,0],"Bot_Xtr":1,"Re":1250,"src":"retest_157.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re100-N9.dat","Cm":-1.60263328074962e-05,"id":875,"good":10.5644875064785,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt2.60398401640815>2.55732883086936) l1 Foil spline 17pts Re100 N9","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.07868,"Cpmin":-0.230260853134498,"CL":0.000190670195802709,"CD":0.0937198978473285,"n":14,"CDp":0.00723361822793096},
             {"r":6,"id":876,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"xver":6.991,"good":11.9417095819111,"Cm":0.0002056759231336,"CDp":0.00382337666781473,"CD":0.0827328104598222,"CL":-0.000817987884311662,"n":3,"Cpmin":-0.180851923119652,"CDf":0.07272,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"clcd":12.0871029817805,"CDpres":0.01001,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","diter":3,"src":"retest_90.txt","Re":1500},
             {"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_91.txt","Re":1500,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"CDpres":0.01001,"clcd":12.0871029817805,"CDp":0.00382337666781473,"n":4,"CL":-0.000817987884311662,"CD":0.0827328104598222,"Cpmin":-0.180851923119652,"CDf":0.07272,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":11.9417095819111,"iver":1.2020052,"id":877,"Cm":0.0002056759231336},
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":11.9417095819111,"iver":1.2020052,"id":878,"r":6,"Cm":0.0002056759231336,"n":5,"CL":-0.000817987884311662,"CD":0.0827328104598222,"CDp":0.00382337666781473,"CDf":0.07272,"Cpmin":-0.180851923119652,"sym":4.5915759379823e-05,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"CDpres":0.01001,"clcd":12.0871029817805,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"Re":1500,"src":"retest_92.txt"},
             {"id":879,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":11.9417095819111,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.0002056759231336,"CL":-0.000817987884311662,"CD":0.0827328104598222,"n":6,"CDp":0.00382337666781473,"CDf":0.07272,"Cpmin":-0.180851923119652,"sym":4.5915759379823e-05,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"CDpres":0.01001,"clcd":12.0871029817805,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Re":1500,"src":"retest_93.txt"},
             {"Cm":0.0002056759231336,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":11.9417095819111,"xver":6.991,"iver":1.2020052,"id":880,"Cpmin":-0.180851923119652,"CDf":0.07272,"CDp":0.00382337666781473,"n":7,"CD":0.0827328104598222,"CL":-0.000817987884311662,"alpha":0,"clcd":12.0871029817805,"CDpres":0.01001,"Bot_Xtr":1,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"sym":4.5915759379823e-05,"src":"retest_94.txt","Re":1500,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"diter":3},
             {"CDf":0.07272,"Cpmin":-0.180851923119652,"CD":0.0827328104598222,"CL":-0.000817987884311662,"n":8,"CDp":0.00382337666781473,"Cm":0.0002056759231336,"id":881,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","iver":1.2020052,"xver":6.991,"good":11.9417095819111,"r":6,"Re":1500,"src":"retest_95.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","CDpres":0.01001,"clcd":12.0871029817805,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1},
             {"r":6,"id":882,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","xver":6.991,"good":11.9417095819111,"iver":1.2020052,"Cm":0.0002056759231336,"CDp":0.00382337666781473,"CD":0.0827328104598222,"CL":-0.000817987884311662,"n":9,"Cpmin":-0.180851923119652,"CDf":0.07272,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"sym":4.5915759379823e-05,"alpha":0,"clcd":12.0871029817805,"CDpres":0.01001,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","diter":3,"src":"retest_96.txt","Re":1500},
             {"clcd":12.0871029817805,"CDpres":0.01001,"alpha":0,"sym":4.5915759379823e-05,"xy":[1,0,0.910123796760017,0.00572371277022645,0.701641995826699,0.0145562406358204,0.483148569314118,0.0205113586223941,0.294626038433414,0.0217086892281736,0.159957634200504,0.0191716630655439,0.0834793088892451,0.0152761661911912,0.0241333008880493,0.00935861173004774,0,0,0.0228276948657296,-0.00926208607888521,0.0728640340173156,-0.0146809661521951,0.147214986967934,-0.0190168105898017,0.291933587242318,-0.0220547858611714,0.4876660423869,-0.0207386771068442,0.701692376777326,-0.014773693788197,0.907978351583207,-0.00593115697283933,1,0],"Bot_Xtr":1,"Re":1500,"src":"retest_97.txt","diter":3,"Foil_fn":"optbs_spline_sym_nacam2.dat-s17_n17s0_nsopt-Re200-N5.dat","Top_Xtr":1,"Cm":0.0002056759231336,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_nacam2.dat-s17_n17s0.dat (opt3.94260677364503>3.74128927230575) l1 Foil spline 17pts Re200 N5","good":11.9417095819111,"iver":1.2020052,"id":883,"r":6,"CDf":0.07272,"Cpmin":-0.180851923119652,"n":10,"CL":-0.000817987884311662,"CD":0.0827328104598222,"CDp":0.00382337666781473},
             {"sym":5.65319272874192e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00556873677835104,0.672127682508641,0.0132437960483804,0.448051878989487,0.0188616896889831,0.261607586958807,0.0201405140305192,0.14960260982261,0.0179109743584708,0.0876932172572549,0.0149610182582922,0.0269668136105797,0.00921799306861872,0,0,0.0260784653873372,-0.00898643335407243,0.0852103572234493,-0.0147417294940721,0.159346520639483,-0.0181829083866653,0.277295492850028,-0.0201147044035458,0.461088095254591,-0.0185481877416096,0.679515403216876,-0.0129550219679637,0.887295989576364,-0.00539286265241377,1,0],"CDpres":0.00928,"clcd":12.2044577842452,"alpha":0,"diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N4.dat","Top_Xtr":1,"Re":1500,"src":"retesth_5.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.3209737713595>30.3516362019243) l1 Foil spline 17pts Re10000 N4","good":12.0495105186755,"iver":1.2020052,"id":884,"r":6,"Cm":-5.67043120788964e-05,"n":11,"CD":0.0819372738779845,"CL":0.000220725447865848,"CDp":0.00332402301333609,"CDf":0.07265,"Cpmin":-0.172445077966924},
             {"xy":[1,0,0.883609074234346,0.00556873677835104,0.672127682508641,0.0132437960483804,0.448051878989487,0.0188616896889831,0.261607586958807,0.0201405140305192,0.14960260982261,0.0179109743584708,0.0876932172572549,0.0149610182582922,0.0269668136105797,0.00921799306861872,0,0,0.0260784653873372,-0.00898643335407243,0.0852103572234493,-0.0147417294940721,0.159346520639483,-0.0181829083866653,0.277295492850028,-0.0201147044035458,0.461088095254591,-0.0185481877416096,0.679515403216876,-0.0129550219679637,0.887295989576364,-0.00539286265241377,1,0],"Bot_Xtr":1,"sym":5.65319272874192e-06,"alpha":0,"clcd":12.2044577842452,"CDpres":0.00928,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N4.dat","Top_Xtr":1,"diter":3,"src":"retesth_6.txt","Re":1500,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.3209737713595>30.3516362019243) l1 Foil spline 17pts Re10000 N4","xver":6.991,"good":12.0495105186755,"iver":1.2020052,"id":885,"Cm":-5.67043120788964e-05,"CDp":0.00332402301333609,"n":12,"CL":0.000220725447865848,"CD":0.0819372738779845,"Cpmin":-0.172445077966924,"CDf":0.07265},
             {"Re":1500,"src":"retesth_7.txt","diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N4.dat","Top_Xtr":1,"CDpres":0.00928,"clcd":12.2044577842452,"alpha":0,"sym":5.65319272874192e-06,"xy":[1,0,0.883609074234346,0.00556873677835104,0.672127682508641,0.0132437960483804,0.448051878989487,0.0188616896889831,0.261607586958807,0.0201405140305192,0.14960260982261,0.0179109743584708,0.0876932172572549,0.0149610182582922,0.0269668136105797,0.00921799306861872,0,0,0.0260784653873372,-0.00898643335407243,0.0852103572234493,-0.0147417294940721,0.159346520639483,-0.0181829083866653,0.277295492850028,-0.0201147044035458,0.461088095254591,-0.0185481877416096,0.679515403216876,-0.0129550219679637,0.887295989576364,-0.00539286265241377,1,0],"Bot_Xtr":1,"CDf":0.07265,"Cpmin":-0.172445077966924,"n":13,"CD":0.0819372738779845,"CL":0.000220725447865848,"CDp":0.00332402301333609,"Cm":-5.67043120788964e-05,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.3209737713595>30.3516362019243) l1 Foil spline 17pts Re10000 N4","xver":6.991,"good":12.0495105186755,"id":886,"r":6},
             {"Re":1500,"src":"retesth_8.txt","diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N4.dat","Top_Xtr":1,"CDpres":0.00928,"clcd":12.2044577842452,"alpha":0,"sym":5.65319272874192e-06,"xy":[1,0,0.883609074234346,0.00556873677835104,0.672127682508641,0.0132437960483804,0.448051878989487,0.0188616896889831,0.261607586958807,0.0201405140305192,0.14960260982261,0.0179109743584708,0.0876932172572549,0.0149610182582922,0.0269668136105797,0.00921799306861872,0,0,0.0260784653873372,-0.00898643335407243,0.0852103572234493,-0.0147417294940721,0.159346520639483,-0.0181829083866653,0.277295492850028,-0.0201147044035458,0.461088095254591,-0.0185481877416096,0.679515403216876,-0.0129550219679637,0.887295989576364,-0.00539286265241377,1,0],"Bot_Xtr":1,"CDf":0.07265,"Cpmin":-0.172445077966924,"n":14,"CD":0.0819372738779845,"CL":0.000220725447865848,"CDp":0.00332402301333609,"Cm":-5.67043120788964e-05,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.3209737713595>30.3516362019243) l1 Foil spline 17pts Re10000 N4","xver":6.991,"good":12.0495105186755,"id":887,"r":6},
             {"Cm":0.000810271171002711,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","xver":6.991,"good":14.0443403042027,"iver":1.2020052,"id":888,"r":6,"CDf":0.06209,"Cpmin":-0.172703954500935,"n":3,"CL":-0.00377039490309069,"CD":0.0702121999068931,"CDp":0.00277698933833667,"CDpres":0.00812,"clcd":14.2425390648075,"alpha":0,"sym":0.000742403322588993,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1,"Re":2000,"src":"retestg_49.txt","diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1},
             {"Re":2000,"src":"retestg_50.txt","diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"clcd":14.2425390648075,"CDpres":0.00812,"alpha":0,"sym":0.000742403322588993,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1,"CDf":0.06209,"Cpmin":-0.172703954500935,"n":4,"CL":-0.00377039490309069,"CD":0.0702121999068931,"CDp":0.00277698933833667,"Cm":0.000810271171002711,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","iver":1.2020052,"good":14.0443403042028,"id":889,"r":6},
             {"Cm":0.000810271171002711,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","good":14.0443403042028,"xver":6.991,"iver":1.2020052,"id":890,"r":6,"CDf":0.06209,"Cpmin":-0.172703954500935,"n":5,"CD":0.0702121999068931,"CL":-0.00377039490309069,"CDp":0.00277698933833667,"clcd":14.2425390648075,"CDpres":0.00812,"alpha":0,"sym":0.000742403322588993,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1,"Re":2000,"src":"retestg_51.txt","diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1},
             {"n":6,"CL":-0.00377039490309069,"CD":0.0702121999068931,"CDp":0.00277698933833667,"CDf":0.06209,"Cpmin":-0.172703954500935,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","iver":1.2020052,"xver":6.991,"good":14.0443403042028,"id":891,"r":6,"Cm":0.000810271171002711,"diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"Re":2000,"src":"retestg_52.txt","sym":0.000742403322588993,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"clcd":14.2425390648075,"CDpres":0.00812,"alpha":0},
             {"alpha":0,"clcd":14.2425390648075,"CDpres":0.00812,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"sym":0.000742403322588993,"src":"retestg_53.txt","Re":2000,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"diter":3,"Cm":0.000810271171002711,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","good":14.0443403042028,"iver":1.2020052,"id":892,"Cpmin":-0.172703954500935,"CDf":0.06209,"CDp":0.00277698933833667,"n":7,"CD":0.0702121999068931,"CL":-0.00377039490309069},
             {"CDp":0.00277698933833667,"CL":-0.00377039490309069,"CD":0.0702121999068931,"n":8,"Cpmin":-0.172703954500935,"CDf":0.06209,"r":6,"id":893,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","good":14.0443403042028,"iver":1.2020052,"Cm":0.000810271171002711,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","diter":3,"src":"retestg_54.txt","Re":2000,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1,"sym":0.000742403322588993,"alpha":0,"clcd":14.2425390648075,"CDpres":0.00812},
             {"CDp":0.00277698933833667,"n":9,"CL":-0.00377039490309069,"CD":0.0702121999068931,"Cpmin":-0.172703954500935,"CDf":0.06209,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","good":14.0443403042028,"iver":1.2020052,"id":894,"Cm":0.000810271171002711,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"diter":3,"src":"retestg_55.txt","Re":2000,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1,"sym":0.000742403322588993,"alpha":0,"CDpres":0.00812,"clcd":14.2425390648075},
             {"diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"Re":2000,"src":"retestg_56.txt","sym":0.000742403322588993,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"CDpres":0.00812,"clcd":14.2425390648075,"alpha":0,"n":10,"CL":-0.00377039490309069,"CD":0.0702121999068931,"CDp":0.00277698933833667,"CDf":0.06209,"Cpmin":-0.172703954500935,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","iver":1.2020052,"good":14.0443403042028,"id":895,"r":6,"Cm":0.000810271171002711},
             {"CDp":0.00277698933833667,"CL":-0.00377039490309069,"CD":0.0702121999068931,"n":11,"Cpmin":-0.172703954500935,"CDf":0.06209,"r":6,"id":896,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","xver":6.991,"iver":1.2020052,"good":14.0443403042028,"Cm":0.000810271171002711,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","diter":3,"src":"retestg_57.txt","Re":2000,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1,"sym":0.000742403322588993,"alpha":0,"clcd":14.2425390648075,"CDpres":0.00812},
             {"diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"Re":2000,"src":"retestg_58.txt","sym":0.000742403322588993,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"CDpres":0.00812,"clcd":14.2425390648075,"alpha":0,"n":12,"CD":0.0702121999068931,"CL":-0.00377039490309069,"CDp":0.00277698933833667,"CDf":0.06209,"Cpmin":-0.172703954500935,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","good":14.0443403042028,"iver":1.2020052,"id":897,"r":6,"Cm":0.000810271171002711},
             {"sym":0.000742403322588993,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"clcd":14.2425390648075,"CDpres":0.00812,"alpha":0,"diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"Re":2000,"src":"retestg_59.txt","good":14.0443403042028,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","xver":6.991,"iver":1.2020052,"id":898,"r":6,"Cm":0.000810271171002711,"n":13,"CL":-0.00377039490309069,"CD":0.0702121999068931,"CDp":0.00277698933833667,"CDf":0.06209,"Cpmin":-0.172703954500935},
             {"CDf":0.06209,"Cpmin":-0.172703954500935,"n":14,"CL":-0.00377039490309069,"CD":0.0702121999068931,"CDp":0.00277698933833667,"Cm":0.000810271171002711,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.0823454922379>33.887143528159) l1 Foil spline 17pts Re12500 N6","good":14.0443403042028,"xver":6.991,"iver":1.2020052,"id":899,"r":6,"Re":2000,"src":"retestg_60.txt","diter":3,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N6.dat","Top_Xtr":1,"clcd":14.2425390648075,"CDpres":0.00812,"alpha":0,"sym":0.000742403322588993,"xy":[1,0,0.883609074234346,0.0053797205870238,0.672127682508641,0.0127942700629699,0.448051878989487,0.0182214790112459,0.261607586958807,0.0194568970083929,0.14960260982261,0.017303033223713,0.0876932172572549,0.0144532056605495,0.0269668136105797,0.00890511242604916,0,0,0.0260784653873372,-0.00934069100752392,0.0852103572234493,-0.0153228688952807,0.159346520639483,-0.0188997038275466,0.277295492850028,-0.0209076539199011,0.461088095254591,-0.0192793830007546,0.679515403216876,-0.0134657268830236,0.887295989576364,-0.00560545676994145,1,0],"Bot_Xtr":1},
             {"id":900,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.3209737713595>30.3516362019243) l1 Foil spline 17pts Re10000 N4","xver":6.991,"iver":1.2020052,"good":15.809217146574,"r":6,"Cm":-5.6221884344319e-05,"CD":0.0623023056370266,"CL":0.000234040725275326,"n":3,"CDp":0.00238899439916074,"CDf":0.05503,"Cpmin":-0.170867444282901,"sym":5.65319272874192e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00556873677835104,0.672127682508641,0.0132437960483804,0.448051878989487,0.0188616896889831,0.261607586958807,0.0201405140305192,0.14960260982261,0.0179109743584708,0.0876932172572549,0.0149610182582922,0.0269668136105797,0.00921799306861872,0,0,0.0260784653873372,-0.00898643335407243,0.0852103572234493,-0.0147417294940721,0.159346520639483,-0.0181829083866653,0.277295492850028,-0.0201147044035458,0.461088095254591,-0.0185481877416096,0.679515403216876,-0.0129550219679637,0.887295989576364,-0.00539286265241377,1,0],"CDpres":0.00727,"clcd":16.0507703491104,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N4.dat","Re":2500,"src":"retesti_5.txt"},
             {"CDp":0.00238899439916074,"CL":0.000234040725275326,"CD":0.0623023056370266,"n":4,"Cpmin":-0.170867444282901,"CDf":0.05503,"r":6,"id":901,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.3209737713595>30.3516362019243) l1 Foil spline 17pts Re10000 N4","xver":6.991,"good":15.8092171971544,"Cm":-5.6221884344319e-05,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N4.dat","diter":3,"src":"retesti_6.txt","Re":2500,"xy":[1,0,0.883609074234346,0.00556873677835104,0.672127682508641,0.0132437960483804,0.448051878989487,0.0188616896889831,0.261607586958807,0.0201405140305192,0.14960260982261,0.0179109743584708,0.0876932172572549,0.0149610182582922,0.0269668136105797,0.00921799306861872,0,0,0.0260784653873372,-0.00898643335407243,0.0852103572234493,-0.0147417294940721,0.159346520639483,-0.0181829083866653,0.277295492850028,-0.0201147044035458,0.461088095254591,-0.0185481877416096,0.679515403216876,-0.0129550219679637,0.887295989576364,-0.00539286265241377,1,0],"Bot_Xtr":1,"sym":5.65319272874192e-06,"alpha":0,"CDpres":0.00727,"clcd":16.0507703491104},
             {"alpha":5,"clcd":5.44303720370297,"CDpres":0.03682,"Bot_Xtr":1,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"sym":0.00893113932109085,"src":"retest_101.txt","Re":2500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","diter":4,"Cm":0.0054488542435619,"r":6,"id":902,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","good":4.41606361283351,"iver":1.2020052,"Cpmin":-2.45755132744091,"CDf":0.03513,"CDp":0.0230875420972356,"CL":0.39163761248138,"CD":0.0719520366708028,"n":5},
             {"alpha":5,"CDpres":0.03682,"clcd":5.44303720370297,"Bot_Xtr":1,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"sym":0.00893113932109085,"src":"retest_102.txt","Re":2500,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","Top_Xtr":1,"diter":4,"Cm":0.0054488542435619,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","xver":6.991,"iver":1.2020052,"good":4.41646379260641,"id":903,"Cpmin":-2.45755132744091,"CDf":0.03513,"CDp":0.0230875420972356,"n":6,"CL":0.39163761248138,"CD":0.0719520366708028},
             {"src":"retest_103.txt","Re":2500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","diter":4,"alpha":5,"CDpres":0.03682,"clcd":5.44303720370297,"Bot_Xtr":1,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"sym":0.00893113932109085,"Cpmin":-2.45755132744091,"CDf":0.03513,"CDp":0.0230875420972356,"CD":0.0719520366708028,"CL":0.39163761248138,"n":7,"Cm":0.0054488542435619,"r":6,"id":904,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","good":4.41646379260641,"xver":6.991,"iver":1.2020052},
             {"sym":0.00893113932109085,"Bot_Xtr":1,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"CDpres":0.03682,"clcd":5.44303720370297,"alpha":5,"diter":4,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","Top_Xtr":1,"Re":2500,"src":"retest_104.txt","good":4.41646379260641,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","xver":6.991,"iver":1.2020052,"id":905,"r":6,"Cm":0.0054488542435619,"n":8,"CD":0.0719520366708028,"CL":0.39163761248138,"CDp":0.0230875420972356,"CDf":0.03513,"Cpmin":-2.45755132744091},
             {"Cpmin":-2.45755132744091,"CDf":0.03513,"CDp":0.0230875420972356,"n":9,"CD":0.0719520366708028,"CL":0.39163761248138,"Cm":0.0054488542435619,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","iver":1.2020052,"xver":6.991,"good":4.41646379260641,"id":906,"src":"retest_105.txt","Re":2500,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","Top_Xtr":1,"diter":4,"alpha":5,"clcd":5.44303720370297,"CDpres":0.03682,"Bot_Xtr":1,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"sym":0.00893113932109085},
             {"clcd":5.44303720370297,"CDpres":0.03682,"alpha":5,"sym":0.00893113932109085,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"Bot_Xtr":1,"Re":2500,"src":"retest_106.txt","diter":4,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","Top_Xtr":1,"Cm":0.0054488542435619,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","iver":1.2020052,"xver":6.991,"good":4.41646379260641,"id":907,"r":6,"CDf":0.03513,"Cpmin":-2.45755132744091,"n":10,"CL":0.39163761248138,"CD":0.0719520366708028,"CDp":0.0230875420972356},
             {"Cm":0.0054488542435619,"r":6,"id":908,"good":4.41646379260641,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","xver":6.991,"iver":1.2020052,"Cpmin":-2.45755132744091,"CDf":0.03513,"CDp":0.0230875420972356,"CD":0.0719520366708028,"CL":0.39163761248138,"n":11,"alpha":5,"CDpres":0.03682,"clcd":5.44303720370297,"Bot_Xtr":1,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"sym":0.00893113932109085,"src":"retest_107.txt","Re":2500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","diter":4},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hd801.cor-s17_n17s0.dat (opt26.7130305490594>25.4860169293593) l1 Foil spline 17pts Re7000 N5","xver":6.991,"good":4.41646379260641,"iver":1.2020052,"id":909,"Cm":0.0054488542435619,"CDp":0.0230875420972356,"n":12,"CD":0.0719520366708028,"CL":0.39163761248138,"Cpmin":-2.45755132744091,"CDf":0.03513,"xy":[1,0,0.878735368587195,0.0043013451298243,0.841651308655572,0.00551563977129361,0.629527282437399,0.0131452716904111,0.492862645776605,0.0172162125300865,0.352699714772407,0.0201689093080654,0.202675181608158,0.0192571168831872,0.0647726512835792,0.012419391706336,0,-6.47725305495802e-09,0.0407988994502468,-0.0138887791153172,0.190790008314314,-0.0233210140991056,0.372695731399878,-0.0234620585943342,0.509243951797101,-0.0195679602253904,0.572777811063447,-0.0175153383005667,0.743460814742662,-0.0106566484338661,0.879825479431461,-0.00495317709934902,1,0],"Bot_Xtr":1,"sym":0.00893113932109085,"alpha":5,"clcd":5.44303720370297,"CDpres":0.03682,"Foil_fn":"optbs_spline_sym_hd801.cor-s17_n17s0_nsopt-Re7000-N5.dat","Top_Xtr":1,"diter":4,"src":"retest_108.txt","Re":2500},
             {"r":6,"id":910,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt23.7436899781828>23.1799783945306) l1 Foil spline 17pts Re5500 N7","xver":6.991,"good":15.8140924373047,"iver":1.2020052,"Cm":-0.00149234511839462,"CDp":0.00203850033559089,"CL":0.00551201227767269,"CD":0.0622791234491558,"n":13,"Cpmin":-0.145442178033876,"CDf":0.05592,"xy":[1,0,0.911596282594944,0.0049237360054892,0.677396722306524,0.0150282385890238,0.47941394978603,0.0205260020929542,0.299311787696268,0.0213491304334338,0.156929652384745,0.0163882627775855,0.0764132539783211,0.0117889216036573,0.0250324225664481,0.00691770148211804,0,0,0.0160177258245528,-0.00565346775466487,0.0429242559416574,-0.00869604576230542,0.113672727318502,-0.0135162862598319,0.279918327264509,-0.0194440945380752,0.429777416806303,-0.0194554563923153,0.60206127090537,-0.0161437499475077,0.852124131282681,-0.0071107285795339,1,0],"Bot_Xtr":1,"sym":0.000957687572466379,"alpha":0,"clcd":16.0567449350245,"CDpres":0.00636,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_goe443.dat-s17_n17s0_nsopt-Re5500-N7.dat","diter":3,"src":"retesti_7.txt","Re":2500},
             {"Foil_fn":"optbs-spline_foil_sym_goe443.dat-s17_n17s0_nsopt-Re5500-N7.dat","Top_Xtr":1,"diter":3,"src":"retesti_8.txt","Re":2500,"xy":[1,0,0.911596282594944,0.0049237360054892,0.677396722306524,0.0150282385890238,0.47941394978603,0.0205260020929542,0.299311787696268,0.0213491304334338,0.156929652384745,0.0163882627775855,0.0764132539783211,0.0117889216036573,0.0250324225664481,0.00691770148211804,0,0,0.0160177258245528,-0.00565346775466487,0.0429242559416574,-0.00869604576230542,0.113672727318502,-0.0135162862598319,0.279918327264509,-0.0194440945380752,0.429777416806303,-0.0194554563923153,0.60206127090537,-0.0161437499475077,0.852124131282681,-0.0071107285795339,1,0],"Bot_Xtr":1,"sym":0.000957687572466379,"alpha":0,"CDpres":0.00636,"clcd":16.0567449350245,"CDp":0.00203850033559089,"n":14,"CD":0.0622791234491558,"CL":0.00551201227767269,"Cpmin":-0.145442178033876,"CDf":0.05592,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe443.dat-s17_n17s0.dat (opt23.7436899781828>23.1799783945306) l1 Foil spline 17pts Re5500 N7","xver":6.991,"good":15.8140924373047,"iver":1.2020052,"id":911,"Cm":-0.00149234511839462},
             {"Cm":-0.000129072719930494,"r":6,"id":912,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","iver":1.2020052,"xver":6.991,"good":17.2863785232135,"Cpmin":-0.145983169120965,"CDf":0.05105,"CDp":0.00182924250336482,"CD":0.0568323211700782,"CL":0.000584807610666244,"n":3,"alpha":0,"CDpres":0.00578,"clcd":17.5956212840114,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_90.txt","Re":3000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3},
             {"diter":3,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Top_Xtr":1,"Re":3000,"src":"retest_91.txt","sym":2.97642223542851e-05,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"CDpres":0.00578,"clcd":17.5956212840114,"alpha":0,"n":4,"CL":0.000584807610666244,"CD":0.0568323211700782,"CDp":0.00182924250336482,"CDf":0.05105,"Cpmin":-0.145983169120965,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","good":17.3039703568106,"iver":1.2020052,"id":913,"r":6,"Cm":-0.000129072719930494},
             {"alpha":0,"clcd":17.5956212840114,"CDpres":0.00578,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_92.txt","Re":3000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3,"Cm":-0.000129072719930494,"r":6,"id":914,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","good":17.3039703596077,"iver":1.2020052,"Cpmin":-0.145983169120965,"CDf":0.05105,"CDp":0.00182924250336482,"CL":0.000584807610666244,"CD":0.0568323211700782,"n":5},
             {"Cm":-0.000129072719930494,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"good":17.3039703596077,"iver":1.2020052,"id":915,"Cpmin":-0.145983169120965,"CDf":0.05105,"CDp":0.00182924250336482,"n":6,"CL":0.000584807610666244,"CD":0.0568323211700782,"alpha":0,"clcd":17.5956212840114,"CDpres":0.00578,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_93.txt","Re":3000,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Top_Xtr":1,"diter":3},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Re":3000,"src":"retest_94.txt","sym":2.97642223542851e-05,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"CDpres":0.00578,"clcd":17.5956212840114,"alpha":0,"CL":0.000584807610666244,"CD":0.0568323211700782,"n":7,"CDp":0.00182924250336482,"CDf":0.05105,"Cpmin":-0.145983169120965,"id":916,"good":17.3039703596077,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.000129072719930494},
             {"id":917,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","iver":1.2020052,"xver":6.991,"good":17.3039703596077,"r":6,"Cm":-0.000129072719930494,"CD":0.0568323211700782,"CL":0.000584807610666244,"n":8,"CDp":0.00182924250336482,"CDf":0.05105,"Cpmin":-0.145983169120965,"sym":2.97642223542851e-05,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"clcd":17.5956212840114,"CDpres":0.00578,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Re":3000,"src":"retest_95.txt"},
             {"sym":2.97642223542851e-05,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"CDpres":0.00578,"clcd":17.5956212840114,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Top_Xtr":1,"Re":3000,"src":"retest_96.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","good":17.3039703596077,"iver":1.2020052,"id":918,"r":6,"Cm":-0.000129072719930494,"n":9,"CL":0.000584807610666244,"CD":0.0568323211700782,"CDp":0.00182924250336482,"CDf":0.05105,"Cpmin":-0.145983169120965},
             {"Cm":-0.000129072719930494,"r":6,"id":919,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","iver":1.2020052,"xver":6.991,"good":17.3039703596077,"Cpmin":-0.145983169120965,"CDf":0.05105,"CDp":0.00182924250336482,"CD":0.0568323211700782,"CL":0.000584807610666244,"n":10,"alpha":0,"CDpres":0.00578,"clcd":17.5956212840114,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_97.txt","Re":3000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3},
             {"clcd":17.5956212840114,"CDpres":0.00578,"alpha":0,"sym":2.97642223542851e-05,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"Re":3000,"src":"retest_98.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Cm":-0.000129072719930494,"id":920,"good":17.3039703596077,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.05105,"Cpmin":-0.145983169120965,"CD":0.0568323211700782,"CL":0.000584807610666244,"n":11,"CDp":0.00182924250336482},
             {"Cm":-0.000129072719930494,"id":921,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"good":17.3039703596077,"r":6,"CDf":0.05105,"Cpmin":-0.145983169120965,"CL":0.000584807610666244,"CD":0.0568323211700782,"n":12,"CDp":0.00182924250336482,"clcd":17.5956212840114,"CDpres":0.00578,"alpha":0,"sym":2.97642223542851e-05,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"Re":3000,"src":"retest_99.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat"},
             {"src":"retest_100.txt","Re":3000,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":17.5956212840114,"CDpres":0.00578,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"Cpmin":-0.145983169120965,"CDf":0.05105,"CDp":0.00182924250336482,"n":13,"CL":0.000584807610666244,"CD":0.0568323211700782,"Cm":-0.000129072719930494,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","good":17.3039703596077,"iver":1.2020052,"id":922},
             {"src":"retest_101.txt","Re":3000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3,"alpha":0,"CDpres":0.00578,"clcd":17.5956212840114,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"Cpmin":-0.145983169120965,"CDf":0.05105,"CDp":0.00182924250336482,"CD":0.0568323211700782,"CL":0.000584807610666244,"n":14,"Cm":-0.000129072719930494,"r":6,"id":923,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"good":17.3039703596077},
             {"Cm":1.55748035952077e-05,"id":924,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.320218818733>30.5511915050191) l1 Foil spline 17pts Re10000 N9","iver":1.2020052,"xver":6.991,"good":18.4039267800263,"r":6,"CDf":0.04534,"Cpmin":-0.205704928491884,"CL":-0.000118243276801999,"CD":0.0533440981290753,"n":3,"CDp":0.00311228275488365,"CDpres":0.008,"clcd":18.7462162652057,"alpha":0,"sym":5.602591368312e-06,"xy":[1,0,0.883609074234346,0.00722047452282592,0.672127682508641,0.0171720258577474,0.448051878989487,0.0244562376132057,0.261607586958807,0.026114372832153,0.14960260982261,0.0232235315084548,0.0876932172572549,0.019398591721823,0.0269668136105797,0.0119521332669733,0,0,0.0260784653873372,-0.011720472489085,0.0852103572234493,-0.0192267641865396,0.159346520639483,-0.0237148898924273,0.277295492850028,-0.0262344169593155,0.461088095254591,-0.0241913021086838,0.679515403216876,-0.0168964674402443,0.887295989576364,-0.00703359117734801,1,0],"Bot_Xtr":1,"Re":3500,"src":"retest_110.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N9.dat"},
             {"CDpres":0.00539,"clcd":19.0742655849332,"alpha":0,"sym":2.97642223542851e-05,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"Re":3500,"src":"retest_103.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Cm":-0.000129347453359851,"id":925,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"good":18.7179830154641,"r":6,"CDf":0.04703,"Cpmin":-0.14485250874954,"CL":0.000592372112247876,"CD":0.0524266580827049,"n":4,"CDp":0.00165178520550262},
             {"alpha":0,"clcd":19.0742655849332,"CDpres":0.00539,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_104.txt","Re":3500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3,"Cm":-0.000129347453359851,"r":6,"id":926,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"good":18.7345715182057,"Cpmin":-0.14485250874954,"CDf":0.04703,"CDp":0.00165178520550262,"CL":0.000592372112247876,"CD":0.0524266580827049,"n":5},
             {"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"sym":2.97642223542851e-05,"alpha":0,"CDpres":0.00539,"clcd":19.0742655849332,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3,"src":"retest_105.txt","Re":3500,"r":6,"id":927,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"good":18.7345714740731,"Cm":-0.000129347453359851,"CDp":0.00165178520550262,"CL":0.000592372112247876,"CD":0.0524266580827049,"n":6,"Cpmin":-0.14485250874954,"CDf":0.04703},
             {"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_106.txt","Re":3500,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"sym":2.97642223542851e-05,"alpha":0,"clcd":19.0742655849332,"CDpres":0.00539,"CDp":0.00165178520550262,"n":7,"CD":0.0524266580827049,"CL":0.000592372112247876,"Cpmin":-0.14485250874954,"CDf":0.04703,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","iver":1.2020052,"xver":6.991,"good":18.7345714740118,"id":928,"Cm":-0.000129347453359851},
             {"Cm":-0.000129347453359851,"r":6,"id":929,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","good":18.7345714740118,"xver":6.991,"iver":1.2020052,"Cpmin":-0.14485250874954,"CDf":0.04703,"CDp":0.00165178520550262,"CD":0.0524266580827049,"CL":0.000592372112247876,"n":8,"alpha":0,"clcd":19.0742655849332,"CDpres":0.00539,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_107.txt","Re":3500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3},
             {"Cpmin":-0.14485250874954,"CDf":0.04703,"CDp":0.00165178520550262,"CL":0.000592372112247876,"CD":0.0524266580827049,"n":9,"Cm":-0.000129347453359851,"r":6,"id":930,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"good":18.7345714740118,"iver":1.2020052,"src":"retest_108.txt","Re":3500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3,"alpha":0,"clcd":19.0742655849332,"CDpres":0.00539,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05},
             {"Cm":-0.000129347453359851,"r":6,"id":931,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"good":18.7345714740118,"Cpmin":-0.14485250874954,"CDf":0.04703,"CDp":0.00165178520550262,"CL":0.000592372112247876,"CD":0.0524266580827049,"n":10,"alpha":0,"clcd":19.0742655849332,"CDpres":0.00539,"Bot_Xtr":1,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"sym":2.97642223542851e-05,"src":"retest_109.txt","Re":3500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat","diter":3,"src":"retest_110.txt","Re":3500,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"sym":2.97642223542851e-05,"alpha":0,"clcd":19.0742655849332,"CDpres":0.00539,"CDp":0.00165178520550262,"CL":0.000592372112247876,"CD":0.0524266580827049,"n":11,"Cpmin":-0.14485250874954,"CDf":0.04703,"r":6,"id":932,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"iver":1.2020052,"good":18.7345714740118,"Cm":-0.000129347453359851},
             {"Cm":-0.000129347453359851,"id":933,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe444.dat-s17_n17s0.dat (opt31.1401300969066>30.0725051677768) l1 Foil spline 17pts Re10000 N8","xver":6.991,"good":18.7345714740118,"r":6,"CDf":0.04703,"Cpmin":-0.14485250874954,"CD":0.0524266580827049,"CL":0.000592372112247876,"n":12,"CDp":0.00165178520550262,"CDpres":0.00539,"clcd":19.0742655849332,"alpha":0,"sym":2.97642223542851e-05,"xy":[1,0,0.908904010644487,0.00565546141833488,0.694333673847856,0.0150816140611495,0.509231179755794,0.0204372791682098,0.297443068278191,0.0213194074681364,0.152023524084313,0.0176885359158946,0.0753937499526754,0.0122351934383456,0.0282005505081749,0.00727447902883134,0,0,0.0305092906552454,-0.00765713066543288,0.070587140399756,-0.011588637963214,0.144007724163616,-0.0171247397375967,0.294381870174478,-0.0210795498705203,0.518667901491446,-0.0200793785219937,0.712644267487666,-0.0142065226024532,0.913821594597361,-0.00534219320263591,1,0],"Bot_Xtr":1,"Re":3500,"src":"retest_111.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe444.dat-s17_n17s0_nsopt-Re10000-N8.dat"},
             {"Cm":-0.000258116693037683,"r":6,"id":934,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"iver":1.2020052,"good":18.5306086240044,"Cpmin":-0.309002434252696,"CDf":0.04317,"CDp":0.0042544806209707,"CL":0.00136396662047734,"CD":0.0529365050489446,"n":13,"alpha":0,"clcd":18.8905557530746,"CDpres":0.00976,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"sym":0.000118953289988034,"src":"retest_70.txt","Re":3500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","diter":3},
             {"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Top_Xtr":1,"diter":3,"src":"retest_71.txt","Re":3500,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"Bot_Xtr":1,"sym":0.000118953289988034,"alpha":0,"CDpres":0.00976,"clcd":18.8905557530746,"CDp":0.0042544806209707,"n":14,"CD":0.0529365050489446,"CL":0.00136396662047734,"Cpmin":-0.309002434252696,"CDf":0.04317,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":18.5306086240044,"iver":1.2020052,"id":935,"Cm":-0.000258116693037683},
             {"Cm":-0.000589253074810569,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt35.1540521112329>31.6019589820895) l1 Foil spline 17pts Re12500 N7","good":21.1949354432443,"iver":1.2020052,"id":936,"Cpmin":-0.2040193778053,"CDf":0.0397,"CDp":0.00209571303558809,"n":3,"CL":0.00340115431245364,"CD":0.0458393698715526,"alpha":0,"clcd":21.8153086048547,"CDpres":0.00614,"Bot_Xtr":1,"xy":[1,0,0.969087652468728,0.00176514861384408,0.801860568053254,0.00901605150262981,0.696504319290661,0.0128504122828961,0.549776607886737,0.0172469093888087,0.338361913064034,0.0210736024147001,0.144153484994011,0.0199609192689678,0.0380479581477159,0.0125672324663714,0,0,0.039910401665453,-0.0122616262553296,0.148421317779882,-0.0189985047612047,0.328374676921391,-0.0200082753150125,0.517844762768298,-0.0170640723341493,0.689480272273693,-0.0124374907256732,0.832528496272264,-0.00733475049348438,0.973498898866872,-0.00145287762346223,1,0],"sym":0.000512697600456184,"src":"retest_108.txt","Re":4500,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re12500-N7.dat","Top_Xtr":1,"diter":3},
             {"CL":0.000612365091127387,"CD":0.0463349571343001,"n":4,"CDp":0.00338122352259823,"CDf":0.03844,"Cpmin":-0.255592171785813,"id":937,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mg05.dat-s17_n17s0.dat (opt35.4073832624108>31.9794647214962) l1 Foil spline 17pts Re12500 N10","good":21.0981137589346,"xver":6.991,"iver":1.2020052,"r":6,"Cm":5.17249969255786e-05,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_mg05.dat-s17_n17s0_nsopt-Re12500-N10.dat","Re":4500,"src":"retest_88.txt","sym":3.95491081523972e-05,"Bot_Xtr":1,"xy":[1,0,0.801235107180673,0.00775331836188269,0.632392839686874,0.014796135354975,0.41012406326402,0.0268590010988351,0.251193047118843,0.0308614199026755,0.128621890131565,0.0269900407543237,0.0597303880338732,0.0192687781384809,0.0238258795790934,0.0118290548639802,0,0,0.0235934150860801,-0.0117767680103831,0.0511837449510818,-0.0176486833914061,0.104435976234778,-0.0248125662632416,0.210350577998097,-0.0302548864056997,0.366049363276158,-0.0285324296563584,0.564864782236522,-0.0184475730570271,0.760314714100426,-0.00955204420354881,1,0],"CDpres":0.00789,"clcd":21.581977449586,"alpha":0},
             {"Re":4500,"src":"retest_110.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re12500-N7.dat","CDpres":0.00614,"clcd":21.8153086048547,"alpha":0,"sym":0.000512697600456184,"xy":[1,0,0.969087652468728,0.00176514861384408,0.801860568053254,0.00901605150262981,0.696504319290661,0.0128504122828961,0.549776607886737,0.0172469093888087,0.338361913064034,0.0210736024147001,0.144153484994011,0.0199609192689678,0.0380479581477159,0.0125672324663714,0,0,0.039910401665453,-0.0122616262553296,0.148421317779882,-0.0189985047612047,0.328374676921391,-0.0200082753150125,0.517844762768298,-0.0170640723341493,0.689480272273693,-0.0124374907256732,0.832528496272264,-0.00733475049348438,0.973498898866872,-0.00145287762346223,1,0],"Bot_Xtr":1,"CDf":0.0397,"Cpmin":-0.2040193778053,"CL":0.00340115431245364,"CD":0.0458393698715526,"n":5,"CDp":0.00209571303558809,"Cm":-0.000589253074810569,"id":938,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt35.1540521112329>31.6019589820895) l1 Foil spline 17pts Re12500 N7","iver":1.2020052,"good":21.3767743625751,"r":6},
             {"Cpmin":-0.2040193778053,"CDf":0.0397,"CDp":0.00209571303558809,"CL":0.00340115431245364,"CD":0.0458393698715526,"n":6,"Cm":-0.000589253074810569,"r":6,"id":939,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt35.1540521112329>31.6019589820895) l1 Foil spline 17pts Re12500 N7","xver":6.991,"good":21.3930250459569,"iver":1.2020052,"src":"retest_111.txt","Re":4500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re12500-N7.dat","diter":3,"alpha":0,"CDpres":0.00614,"clcd":21.8153086048547,"Bot_Xtr":1,"xy":[1,0,0.969087652468728,0.00176514861384408,0.801860568053254,0.00901605150262981,0.696504319290661,0.0128504122828961,0.549776607886737,0.0172469093888087,0.338361913064034,0.0210736024147001,0.144153484994011,0.0199609192689678,0.0380479581477159,0.0125672324663714,0,0,0.039910401665453,-0.0122616262553296,0.148421317779882,-0.0189985047612047,0.328374676921391,-0.0200082753150125,0.517844762768298,-0.0170640723341493,0.689480272273693,-0.0124374907256732,0.832528496272264,-0.00733475049348438,0.973498898866872,-0.00145287762346223,1,0],"sym":0.000512697600456184},
             {"id":940,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":21.1085626990244,"iver":1.2020052,"r":6,"Cm":-0.000254251904562795,"CD":0.0463475375198699,"CL":0.00139806713834562,"n":7,"CDp":0.00374724518643853,"CDf":0.03769,"Cpmin":-0.311453886153924,"sym":0.000118953289988034,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"CDpres":0.00866,"clcd":21.5761193261084,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Re":4500,"src":"retest_75.txt"},
             {"CL":0.00139806713834562,"CD":0.0463475375198699,"n":8,"CDp":0.00374724518643853,"CDf":0.03769,"Cpmin":-0.311453886153924,"id":941,"good":21.1085626990244,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.000254251904562795,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Re":4500,"src":"retest_76.txt","sym":0.000118953289988034,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"CDpres":0.00866,"clcd":21.5761193261084,"alpha":0},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Re":4500,"src":"retest_77.txt","sym":0.000118953289988034,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"CDpres":0.00866,"clcd":21.5761193261084,"alpha":0,"CD":0.0463475375198699,"CL":0.00139806713834562,"n":9,"CDp":0.00374724518643853,"CDf":0.03769,"Cpmin":-0.311453886153924,"id":942,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","iver":1.2020052,"good":21.1085626990244,"r":6,"Cm":-0.000254251904562795},
             {"clcd":21.5761193261084,"CDpres":0.00866,"alpha":0,"sym":0.000118953289988034,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"Bot_Xtr":1,"Re":4500,"src":"retest_78.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Cm":-0.000254251904562795,"id":943,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","iver":1.2020052,"good":21.1085626990244,"r":6,"CDf":0.03769,"Cpmin":-0.311453886153924,"CD":0.0463475375198699,"CL":0.00139806713834562,"n":10,"CDp":0.00374724518643853},
             {"Cm":-8.12850809877361e-05,"id":944,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","good":21.3793029046817,"iver":1.2020052,"r":6,"CDf":0.04102,"Cpmin":-0.14737946014781,"CD":0.0458532370055647,"CL":0.000445020941566683,"n":11,"CDp":0.00139154764167212,"clcd":21.8087111249886,"CDpres":0.00484,"alpha":0,"sym":2.29214578003216e-05,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"Bot_Xtr":1,"Re":4500,"src":"retest_64.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat"},
             {"sym":2.29214578003216e-05,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"clcd":21.8087111249886,"CDpres":0.00484,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","Re":4500,"src":"retest_65.txt","id":945,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","xver":6.991,"iver":1.2020052,"good":21.3793029046817,"r":6,"Cm":-8.12850809877361e-05,"CD":0.0458532370055647,"CL":0.000445020941566683,"n":12,"CDp":0.00139154764167212,"CDf":0.04102,"Cpmin":-0.14737946014781},
             {"sym":2.29214578003216e-05,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"clcd":21.8087111249886,"CDpres":0.00484,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","Top_Xtr":1,"Re":4500,"src":"retest_66.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","iver":1.2020052,"xver":6.991,"good":21.3793029046817,"id":946,"r":6,"Cm":-8.12850809877361e-05,"n":13,"CD":0.0458532370055647,"CL":0.000445020941566683,"CDp":0.00139154764167212,"CDf":0.04102,"Cpmin":-0.14737946014781},
             {"sym":2.29214578003216e-05,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"CDpres":0.00484,"clcd":21.8087111249886,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","Top_Xtr":1,"Re":4500,"src":"retest_67.txt","good":21.3793029046817,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","xver":6.991,"iver":1.2020052,"id":947,"r":6,"Cm":-8.12850809877361e-05,"n":14,"CD":0.0458532370055647,"CL":0.000445020941566683,"CDp":0.00139154764167212,"CDf":0.04102,"Cpmin":-0.14737946014781},
             {"CDf":0.03477,"Cpmin":-0.234094281777478,"CL":0.00142232440363714,"CD":0.0422138481123654,"n":3,"CDp":0.00320570637975417,"Cm":-0.000240167724698891,"id":948,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt31.2804197569266>28.8485316000824) l1 Foil spline 17pts Re10000 N9","iver":1.2020052,"xver":6.991,"good":23.1093581286832,"r":6,"Re":5500,"src":"retest_73.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re10000-N9.dat","CDpres":0.00744,"clcd":23.6889088466464,"alpha":0,"sym":9.4360716053725e-05,"xy":[1,0,0.794574379082928,0.00953757402486681,0.546030639687268,0.0234877562533178,0.363514019175692,0.0310899673066628,0.221984972352103,0.0313529822383881,0.122670417262654,0.0263765242667698,0.0658532742824706,0.0200343435577631,0.0236940673606567,0.0120543171400276,0,0,0.0239783675371822,-0.0120011584277482,0.0623361812874123,-0.0191440539136796,0.114829236142557,-0.0253151327391953,0.214306107242777,-0.0306627075096426,0.357389074847702,-0.0307336279935147,0.542695962832085,-0.0233038285634435,0.784157786565453,-0.00991572219880187,1,0],"Bot_Xtr":1},
             {"src":"retest_99.txt","Re":5500,"Foil_fn":"optbs_spline_sym_mg05.dat-s17_n17s0_nsopt-Re12500-N10.dat","Top_Xtr":1,"diter":3,"alpha":0,"CDpres":0.0072,"clcd":23.9716006807128,"Bot_Xtr":1,"xy":[1,0,0.801235107180673,0.00775331836188269,0.632392839686874,0.014796135354975,0.41012406326402,0.0268590010988351,0.251193047118843,0.0308614199026755,0.128621890131565,0.0269900407543237,0.0597303880338732,0.0192687781384809,0.0238258795790934,0.0118290548639802,0,0,0.0235934150860801,-0.0117767680103831,0.0511837449510818,-0.0176486833914061,0.104435976234778,-0.0248125662632416,0.210350577998097,-0.0302548864056997,0.366049363276158,-0.0285324296563584,0.564864782236522,-0.0184475730570271,0.760314714100426,-0.00955204420354881,1,0],"sym":3.95491081523972e-05,"Cpmin":-0.255527717108116,"CDf":0.03451,"CDp":0.00306142540641744,"n":4,"CD":0.041716029451658,"CL":0.000597675377020092,"Cm":6.02813863531556e-05,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mg05.dat-s17_n17s0.dat (opt35.4073832624108>31.9794647214962) l1 Foil spline 17pts Re12500 N10","good":23.361816618583,"xver":6.991,"iver":1.2020052,"id":949},
             {"sym":0.000118953289988034,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"clcd":23.9659680739057,"CDpres":0.00788,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Re":5500,"src":"retest_84.txt","id":950,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":23.3842418292563,"r":6,"Cm":-0.00025133957175305,"CL":0.001424550632639,"CD":0.0417258337704624,"n":5,"CDp":0.00339092538970331,"CDf":0.03384,"Cpmin":-0.313394548591132},
             {"CDf":0.03384,"Cpmin":-0.313394548591132,"CD":0.0417258337704624,"CL":0.001424550632639,"n":6,"CDp":0.00339092538970331,"Cm":-0.00025133957175305,"id":951,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":23.3990557906894,"iver":1.2020052,"r":6,"Re":5500,"src":"retest_85.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","CDpres":0.00788,"clcd":23.9659680739057,"alpha":0,"sym":0.000118953289988034,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"Bot_Xtr":1},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":23.399055877046,"id":952,"r":6,"Cm":-0.00025133957175305,"n":7,"CL":0.001424550632639,"CD":0.0417258337704624,"CDp":0.00339092538970331,"CDf":0.03384,"Cpmin":-0.313394548591132,"sym":0.000118953289988034,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"clcd":23.9659680739057,"CDpres":0.00788,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Top_Xtr":1,"Re":5500,"src":"retest_86.txt"},
             {"Cpmin":-0.14643263681611,"CDf":0.03692,"CDp":0.00121743231384337,"CD":0.041334255034355,"CL":0.000451305497223318,"n":8,"Cm":-8.18003118149311e-05,"r":6,"id":953,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","good":23.6836143854714,"xver":6.991,"iver":1.2020052,"src":"retest_69.txt","Re":5500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","diter":3,"alpha":0,"CDpres":0.00442,"clcd":24.1930089019107,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"sym":2.29214578003216e-05},
             {"n":9,"CL":0.000451305497223318,"CD":0.041334255034355,"CDp":0.00121743231384337,"CDf":0.03692,"Cpmin":-0.14643263681611,"good":23.6836144394159,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","xver":6.991,"iver":1.2020052,"id":954,"r":6,"Cm":-8.18003118149311e-05,"diter":3,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","Top_Xtr":1,"Re":5500,"src":"retest_70.txt","sym":2.29214578003216e-05,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"clcd":24.1930089019107,"CDpres":0.00442,"alpha":0},
             {"sym":2.29214578003216e-05,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"clcd":24.1930089019107,"CDpres":0.00442,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","Re":5500,"src":"retest_71.txt","id":955,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","iver":1.2020052,"good":23.6836144400857,"r":6,"Cm":-8.18003118149311e-05,"CL":0.000451305497223318,"CD":0.041334255034355,"n":10,"CDp":0.00121743231384337,"CDf":0.03692,"Cpmin":-0.14643263681611},
             {"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"Bot_Xtr":1,"sym":2.29214578003216e-05,"alpha":0,"clcd":24.1930089019107,"CDpres":0.00442,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","diter":3,"src":"retest_72.txt","Re":5500,"r":6,"id":956,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","iver":1.2020052,"good":23.6836144400857,"Cm":-8.18003118149311e-05,"CDp":0.00121743231384337,"CL":0.000451305497223318,"CD":0.041334255034355,"n":11,"Cpmin":-0.14643263681611,"CDf":0.03692},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_64.txt","Re":5500,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":24.3179819059869,"CDpres":0.00495,"CDp":0.00139953354514681,"CL":-0.000354525817646848,"CD":0.041121833376881,"n":12,"Cpmin":-0.170575037381256,"CDf":0.03618,"r":6,"id":957,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":23.8083744281112,"iver":1.2020052,"Cm":6.25878945264861e-05},
             {"Cm":6.25878945264861e-05,"r":6,"id":958,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":23.8083744281112,"iver":1.2020052,"Cpmin":-0.170575037381256,"CDf":0.03618,"CDp":0.00139953354514681,"CD":0.041121833376881,"CL":-0.000354525817646848,"n":13,"alpha":0,"CDpres":0.00495,"clcd":24.3179819059869,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"sym":8.12617280627953e-06,"src":"retest_65.txt","Re":5500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3},
             {"CDp":0.00139953354514681,"n":14,"CL":-0.000354525817646848,"CD":0.041121833376881,"Cpmin":-0.170575037381256,"CDf":0.03618,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"good":23.8083744281112,"id":959,"Cm":6.25878945264861e-05,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"diter":3,"src":"retest_66.txt","Re":5500,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"CDpres":0.00495,"clcd":24.3179819059869},
             {"Cm":-0.0002379880416195,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt31.2804197569266>28.8485316000824) l1 Foil spline 17pts Re10000 N9","xver":6.991,"good":25.9085458137398,"iver":1.2020052,"id":960,"r":6,"CDf":0.03056,"Cpmin":-0.233358580600529,"n":3,"CL":0.00144945237394668,"CD":0.0372554677551089,"CDp":0.002862914094056,"CDpres":0.00669,"clcd":26.8416976153217,"alpha":0,"sym":9.4360716053725e-05,"xy":[1,0,0.794574379082928,0.00953757402486681,0.546030639687268,0.0234877562533178,0.363514019175692,0.0310899673066628,0.221984972352103,0.0313529822383881,0.122670417262654,0.0263765242667698,0.0658532742824706,0.0200343435577631,0.0236940673606567,0.0120543171400276,0,0,0.0239783675371822,-0.0120011584277482,0.0623361812874123,-0.0191440539136796,0.114829236142557,-0.0253151327391953,0.214306107242777,-0.0306627075096426,0.357389074847702,-0.0307336279935147,0.542695962832085,-0.0233038285634435,0.784157786565453,-0.00991572219880187,1,0],"Bot_Xtr":1,"Re":7000,"src":"retest_74.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re10000-N9.dat","Top_Xtr":1},
             {"src":"retest_110.txt","Re":7000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_mg05.dat-s17_n17s0_nsopt-Re12500-N10.dat","diter":3,"alpha":0,"clcd":27.177421315008,"CDpres":0.00645,"Bot_Xtr":1,"xy":[1,0,0.801235107180673,0.00775331836188269,0.632392839686874,0.014796135354975,0.41012406326402,0.0268590010988351,0.251193047118843,0.0308614199026755,0.128621890131565,0.0269900407543237,0.0597303880338732,0.0192687781384809,0.0238258795790934,0.0118290548639802,0,0,0.0235934150860801,-0.0117767680103831,0.0511837449510818,-0.0176486833914061,0.104435976234778,-0.0248125662632416,0.210350577998097,-0.0302548864056997,0.366049363276158,-0.0285324296563584,0.564864782236522,-0.0184475730570271,0.760314714100426,-0.00955204420354881,1,0],"sym":3.95491081523972e-05,"Cpmin":-0.25553482203251,"CDf":0.03034,"CDp":0.00271663349847829,"CL":0.000576676008274085,"CD":0.0367952495716647,"n":4,"Cm":7.09496454511337e-05,"r":6,"id":961,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mg05.dat-s17_n17s0.dat (opt35.4073832624108>31.9794647214962) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":26.2310007057348},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_mg05.dat-s17_n17s0_nsopt-Re12500-N10.dat","Re":7000,"src":"retest_111.txt","sym":3.95491081523972e-05,"Bot_Xtr":1,"xy":[1,0,0.801235107180673,0.00775331836188269,0.632392839686874,0.014796135354975,0.41012406326402,0.0268590010988351,0.251193047118843,0.0308614199026755,0.128621890131565,0.0269900407543237,0.0597303880338732,0.0192687781384809,0.0238258795790934,0.0118290548639802,0,0,0.0235934150860801,-0.0117767680103831,0.0511837449510818,-0.0176486833914061,0.104435976234778,-0.0248125662632416,0.210350577998097,-0.0302548864056997,0.366049363276158,-0.0285324296563584,0.564864782236522,-0.0184475730570271,0.760314714100426,-0.00955204420354881,1,0],"CDpres":0.00645,"clcd":27.177421315008,"alpha":0,"CL":0.000576676008274085,"CD":0.0367952495716647,"n":5,"CDp":0.00271663349847829,"CDf":0.03034,"Cpmin":-0.25553482203251,"id":962,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mg05.dat-s17_n17s0.dat (opt35.4073832624108>31.9794647214962) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":26.4130435968232,"r":6,"Cm":7.09496454511337e-05},
             {"CDp":0.00119221511545886,"CD":0.0363039270189326,"CL":-0.000361071285244711,"n":6,"Cpmin":-0.170588927831005,"CDf":0.03188,"r":6,"id":963,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":26.6785975121529,"iver":1.2020052,"Cm":6.24882410561053e-05,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_67.txt","Re":7000,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"CDpres":0.00442,"clcd":27.5452294590196},
             {"Cm":6.24882410561053e-05,"r":6,"id":964,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":26.7148533381924,"Cpmin":-0.170588927831005,"CDf":0.03188,"CDp":0.00119221511545886,"CD":0.0363039270189326,"CL":-0.000361071285244711,"n":7,"alpha":0,"clcd":27.5452294590196,"CDpres":0.00442,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"sym":8.12617280627953e-06,"src":"retest_68.txt","Re":7000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3},
             {"Cpmin":-0.145455970431292,"CDf":0.03255,"CDp":0.00103261353764996,"n":8,"CD":0.0365057516098656,"CL":0.000457462915136766,"Cm":-8.22425950721455e-05,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_goe445.dat-s17_n17s0.dat (opt31.9779686074701>30.274758132725) l1 Foil spline 17pts Re10000 N12","good":26.5667407384303,"iver":1.2020052,"id":965,"src":"retest_77.txt","Re":7000,"Foil_fn":"optbs_spline_sym_goe445.dat-s17_n17s0_nsopt-Re10000-N12.dat","Top_Xtr":1,"diter":3,"alpha":0,"CDpres":0.00396,"clcd":27.3929437390285,"Bot_Xtr":1,"xy":[1,0,0.9112412035098,0.00499330442702786,0.710114611336472,0.0136881816174421,0.462254587738653,0.020622172587305,0.311741633180908,0.0212552828846429,0.161980271392086,0.0183060370080327,0.0718140661270555,0.0124502015614127,0.0267208209700742,0.0072240423237067,0,0,0.0307226858057254,-0.00794090920765124,0.0771031469865192,-0.0127318265980021,0.167845873632751,-0.0184118032659024,0.339875167224296,-0.0213362445860228,0.483105143271364,-0.0200087482187415,0.704443165301574,-0.013787122241408,0.903011829924982,-0.00537822254755252,1,0],"sym":2.29214578003216e-05},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":26.9214859826695,"iver":1.2020052,"id":966,"Cm":6.24882410561053e-05,"CDp":0.00119221511545886,"n":9,"CD":0.0363039270189326,"CL":-0.000361071285244711,"Cpmin":-0.170588927831005,"CDf":0.03188,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":27.5452294590196,"CDpres":0.00442,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"diter":3,"src":"retest_70.txt","Re":7000},
             {"Cpmin":-0.170588927831005,"CDf":0.03188,"CDp":0.00119221511545886,"CD":0.0363039270189326,"CL":-0.000361071285244711,"n":10,"Cm":6.24882410561053e-05,"r":6,"id":967,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"xver":6.991,"good":26.9214859656513,"src":"retest_71.txt","Re":7000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"alpha":0,"CDpres":0.00442,"clcd":27.5452294590196,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"sym":8.12617280627953e-06},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":26.9214859656513,"id":968,"r":6,"Cm":6.24882410561053e-05,"n":11,"CL":-0.000361071285244711,"CD":0.0363039270189326,"CDp":0.00119221511545886,"CDf":0.03188,"Cpmin":-0.170588927831005,"sym":8.12617280627953e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"CDpres":0.00442,"clcd":27.5452294590196,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"Re":7000,"src":"retest_72.txt"},
             {"CD":0.0363039270189326,"CL":-0.000361071285244711,"n":12,"CDp":0.00119221511545886,"CDf":0.03188,"Cpmin":-0.170588927831005,"id":969,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"xver":6.991,"good":26.9214859656513,"r":6,"Cm":6.24882410561053e-05,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Re":7000,"src":"retest_73.txt","sym":8.12617280627953e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"clcd":27.5452294590196,"CDpres":0.00442,"alpha":0},
             {"CDp":0.00119221511545886,"CL":-0.000361071285244711,"CD":0.0363039270189326,"n":13,"Cpmin":-0.170588927831005,"CDf":0.03188,"r":6,"id":970,"good":26.9214859656513,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"iver":1.2020052,"Cm":6.24882410561053e-05,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_74.txt","Re":7000,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":27.5452294590196,"CDpres":0.00442},
             {"r":6,"id":971,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"good":26.9214859656513,"Cm":6.24882410561053e-05,"CDp":0.00119221511545886,"CL":-0.000361071285244711,"CD":0.0363039270189326,"n":14,"Cpmin":-0.170588927831005,"CDf":0.03188,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":27.5452294590196,"CDpres":0.00442,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_75.txt","Re":7000},
             {"xy":[1,0,0.961992840051787,0.00148863835423775,0.838375902301386,0.00697819352317008,0.669468112967632,0.0164157194233952,0.498697719332731,0.0239323075656099,0.301319859646249,0.0260799430397695,0.134615624611079,0.0213963343457895,0.0376550591335466,0.0121515868931804,0,0,0.0409493023355519,-0.0124949100648738,0.14830924318344,-0.0216348846337542,0.317279938768802,-0.0255814308605469,0.498956936169248,-0.0233589085142558,0.653261727003669,-0.0169066512789993,0.844873051243488,-0.00649782170343262,0.969355895385625,-0.0011463740676587,1,0],"Bot_Xtr":1,"sym":0.00013422701702231,"alpha":0,"clcd":29.493004790964,"CDpres":0.00506,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N3.dat","Top_Xtr":1,"diter":3,"src":"retest_98.txt","Re":8192,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt51.9108360270713>47.0700430042467) l1 Foil spline 17pts Re30000 N3","iver":1.2020052,"good":28.3820398013461,"id":972,"Cm":-0.00030989850872389,"CDp":0.00186807271163155,"n":3,"CL":0.00165058300304608,"CD":0.0339063451515926,"Cpmin":-0.177020035922037,"CDf":0.02885},
             {"Re":8192,"src":"retest_99.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N3.dat","clcd":29.493004790964,"CDpres":0.00506,"alpha":0,"sym":0.00013422701702231,"xy":[1,0,0.961992840051787,0.00148863835423775,0.838375902301386,0.00697819352317008,0.669468112967632,0.0164157194233952,0.498697719332731,0.0239323075656099,0.301319859646249,0.0260799430397695,0.134615624611079,0.0213963343457895,0.0376550591335466,0.0121515868931804,0,0,0.0409493023355519,-0.0124949100648738,0.14830924318344,-0.0216348846337542,0.317279938768802,-0.0255814308605469,0.498956936169248,-0.0233589085142558,0.653261727003669,-0.0169066512789993,0.844873051243488,-0.00649782170343262,0.969355895385625,-0.0011463740676587,1,0],"Bot_Xtr":1,"CDf":0.02885,"Cpmin":-0.177020035922037,"CL":0.00165058300304608,"CD":0.0339063451515926,"n":4,"CDp":0.00186807271163155,"Cm":-0.00030989850872389,"id":973,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt51.9108360270713>47.0700430042467) l1 Foil spline 17pts Re30000 N3","xver":6.991,"good":28.403078519411,"iver":1.2020052,"r":6},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt49.0203534259805>46.0216907085324) l1 Foil spline 17pts Re25000 N7","good":28.5597277860581,"xver":6.991,"iver":1.2020052,"id":974,"r":6,"Cm":0.000475237190193953,"n":5,"CL":-0.00238225156812723,"CD":0.0337379694046221,"CDp":0.00167918905094555,"CDf":0.02894,"Cpmin":-0.169368512990176,"sym":0.000224622387951024,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00150974904919386,0.838375902301386,0.00649368204213336,0.669468112967632,0.0152759395500363,0.498697719332731,0.0222706342765648,0.301319859646249,0.0242691546479607,0.134615624611079,0.0199107393120298,0.0376550591335466,0.011307875215794,0,0,0.0409493023355519,-0.0122652209361624,0.14830924318344,-0.0212371788659257,0.317279938768802,-0.0251111772504734,0.498956936169248,-0.0229295106781423,0.653261727003669,-0.0165958628074106,0.844873051243488,-0.0063783747448043,0.969355895385625,-0.00110396419394091,1,0],"clcd":29.6401952354311,"CDpres":0.0048,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re25000-N7.dat","Top_Xtr":1,"Re":8192,"src":"retest_91.txt"},
             {"sym":1.34455595343594e-05,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00146314161549705,0.838375902301386,0.00655362853626627,0.669468112967632,0.0154169595468069,0.498697719332731,0.0224762258713386,0.301319859646249,0.0244931956045821,0.134615624611079,0.0200945455115952,0.0376550591335466,0.01141226398489,0,0,0.0409493023355519,-0.0120149523963516,0.14830924318344,-0.0208038399336602,0.317279938768802,-0.0245987904213966,0.498956936169248,-0.0224616401696645,0.653261727003669,-0.0162572286830578,0.844873051243488,-0.00624822572082367,0.969355895385625,-0.00125337829148436,1,0],"CDpres":0.00476,"clcd":29.6553389907845,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re25000-N11.dat","Top_Xtr":1,"Re":8192,"src":"retest_156.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt49.3885017874538>45.8219566954329) l1 Foil spline 17pts Re25000 N11","good":28.6436674574534,"xver":6.991,"iver":1.2020052,"id":975,"r":6,"Cm":3.36647972742307e-05,"n":6,"CL":-2.30643980946351e-05,"CD":0.033720740818736,"CDp":0.00165531786742446,"CDf":0.02896,"Cpmin":-0.167641401225598},
             {"CDp":0.00165531786742446,"CL":-2.30643980946351e-05,"CD":0.033720740818736,"n":7,"Cpmin":-0.167641401225598,"CDf":0.02896,"r":6,"id":976,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt49.3885017874538>45.8219566954329) l1 Foil spline 17pts Re25000 N11","good":28.6773221175864,"iver":1.2020052,"Cm":3.36647972742307e-05,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re25000-N11.dat","diter":3,"src":"retest_157.txt","Re":8192,"xy":[1,0,0.961992840051787,0.00146314161549705,0.838375902301386,0.00655362853626627,0.669468112967632,0.0154169595468069,0.498697719332731,0.0224762258713386,0.301319859646249,0.0244931956045821,0.134615624611079,0.0200945455115952,0.0376550591335466,0.01141226398489,0,0,0.0409493023355519,-0.0120149523963516,0.14830924318344,-0.0208038399336602,0.317279938768802,-0.0245987904213966,0.498956936169248,-0.0224616401696645,0.653261727003669,-0.0162572286830578,0.844873051243488,-0.00624822572082367,0.969355895385625,-0.00125337829148436,1,0],"Bot_Xtr":1,"sym":1.34455595343594e-05,"alpha":0,"clcd":29.6553389907845,"CDpres":0.00476},
             {"CDpres":0.00411,"clcd":29.8688720008111,"alpha":0,"sym":8.12617280627953e-06,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"Re":8192,"src":"retest_78.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"Cm":6.23746684240767e-05,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"good":28.9366749276253,"id":977,"r":6,"CDf":0.02937,"Cpmin":-0.170527930105763,"n":8,"CL":-0.000364872645805127,"CD":0.0334796707412602,"CDp":0.00107103020333099},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_79.txt","Re":8192,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"CDpres":0.00411,"clcd":29.8688720008111,"CDp":0.00107103020333099,"CD":0.0334796707412602,"CL":-0.000364872645805127,"n":9,"Cpmin":-0.170527930105763,"CDf":0.02937,"r":6,"id":978,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":28.7649224132618,"xver":6.991,"iver":1.2020052,"Cm":6.23746684240767e-05},
             {"CDp":0.00107103020333099,"n":10,"CL":-0.000364872645805127,"CD":0.0334796707412602,"Cpmin":-0.170527930105763,"CDf":0.02937,"r":6,"good":29.1554046502641,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"iver":1.2020052,"id":979,"Cm":6.23746684240767e-05,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"diter":3,"src":"retest_80.txt","Re":8192,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"CDpres":0.00411,"clcd":29.8688720008111},
             {"Re":8192,"src":"retest_81.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","clcd":29.8688720008111,"CDpres":0.00411,"alpha":0,"sym":8.12617280627953e-06,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"CDf":0.02937,"Cpmin":-0.170527930105763,"CD":0.0334796707412602,"CL":-0.000364872645805127,"n":11,"CDp":0.00107103020333099,"Cm":6.23746684240767e-05,"id":980,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":29.1554046903704,"xver":6.991,"iver":1.2020052,"r":6},
             {"Re":8192,"src":"retest_82.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","clcd":29.8688720008111,"CDpres":0.00411,"alpha":0,"sym":8.12617280627953e-06,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"CDf":0.02937,"Cpmin":-0.170527930105763,"CD":0.0334796707412602,"CL":-0.000364872645805127,"n":12,"CDp":0.00107103020333099,"Cm":6.23746684240767e-05,"id":981,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":29.1554046903704,"iver":1.2020052,"r":6},
             {"r":6,"id":982,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"iver":1.2020052,"good":29.1554046903704,"Cm":6.23746684240767e-05,"CDp":0.00107103020333099,"CD":0.0334796707412602,"CL":-0.000364872645805127,"n":13,"Cpmin":-0.170527930105763,"CDf":0.02937,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":29.8688720008111,"CDpres":0.00411,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_83.txt","Re":8192},
             {"CDp":0.00107103020333099,"CL":-0.000364872645805127,"CD":0.0334796707412602,"n":14,"Cpmin":-0.170527930105763,"CDf":0.02937,"r":6,"id":983,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"good":29.1554046903704,"Cm":6.23746684240767e-05,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_84.txt","Re":8192,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":29.8688720008111,"CDpres":0.00411},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_raf30md.dat-s17_n17s0_nsopt-Re25000-N7.dat","diter":3,"src":"retest_109.txt","Re":10000,"xy":[1,0,0.890051584584834,0.00589183942422797,0.688319663136467,0.0158985959222134,0.531077021072871,0.0225144307296684,0.356235003186791,0.0262203030419175,0.185354945883713,0.0239466407102943,0.0805049102365469,0.0171407138095478,0.0227160217511022,0.00936137608562102,0,0,0.0082927963827511,-0.00637793952920062,0.0300900072589043,-0.0124361035447949,0.119578560658688,-0.0219615428970742,0.27134218735548,-0.0269565271072318,0.435924274981712,-0.0257898161383497,0.588980424483976,-0.0208233626927139,0.79895599276978,-0.0107597373237915,1,0],"Bot_Xtr":1,"sym":0.00115093952164514,"alpha":0,"clcd":32.3578983237095,"CDpres":0.00482,"CDp":0.00187432300376395,"CL":0.000933277908699318,"CD":0.0309043557154413,"n":3,"Cpmin":-0.195439649649172,"CDf":0.02609,"r":6,"id":984,"good":31.1024309549648,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_raf30md.dat-s17_n17s0.dat (opt48.2130951605367>44.5564811453529) l1 Foil spline 17pts Re25000 N7","xver":6.991,"iver":1.2020052,"Cm":-0.000213452432860819},
             {"CDpres":0.00479,"clcd":32.5709967009414,"alpha":0,"sym":0.000135960499028547,"xy":[1,0,0.961992840051787,0.00152879565229698,0.838375902301386,0.00716643628638198,0.669468112967632,0.0168585475527829,0.498697719332731,0.0245779021154356,0.301319859646249,0.0267834719009159,0.134615624611079,0.0219735188400979,0.0376550591335466,0.012479386385497,0,0,0.0409493023355519,-0.0128385209950285,0.14830924318344,-0.0222298455253648,0.317279938768802,-0.026284922058726,0.498956936169248,-0.0240012801872256,0.653261727003669,-0.0173715854115073,0.844873051243488,-0.00667651227006359,0.969355895385625,-0.00117310725077275,1,0],"Bot_Xtr":1,"Re":10000,"src":"retest_149.txt","diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re35000-N4.dat","Top_Xtr":1,"Cm":-0.000304462666435373,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt55.8962467179484>51.1406290005629) l1 Foil spline 17pts Re35000 N4","good":31.2913861636059,"iver":1.2020052,"id":985,"r":6,"CDf":0.02591,"Cpmin":-0.180459964219933,"n":4,"CD":0.0307021614715001,"CL":0.00163836484611314,"CDp":0.00180436208412931},
             {"diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re35000-N4.dat","Top_Xtr":1,"Re":10000,"src":"retest_150.txt","sym":0.000135960499028547,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00152879565229698,0.838375902301386,0.00716643628638198,0.669468112967632,0.0168585475527829,0.498697719332731,0.0245779021154356,0.301319859646249,0.0267834719009159,0.134615624611079,0.0219735188400979,0.0376550591335466,0.012479386385497,0,0,0.0409493023355519,-0.0128385209950285,0.14830924318344,-0.0222298455253648,0.317279938768802,-0.026284922058726,0.498956936169248,-0.0240012801872256,0.653261727003669,-0.0173715854115073,0.844873051243488,-0.00667651227006359,0.969355895385625,-0.00117310725077275,1,0],"CDpres":0.00479,"clcd":32.5709967009414,"alpha":0,"n":5,"CD":0.0307021614715001,"CL":0.00163836484611314,"CDp":0.00180436208412931,"CDf":0.02591,"Cpmin":-0.180459964219933,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt55.8962467179484>51.1406290005629) l1 Foil spline 17pts Re35000 N4","xver":6.991,"good":31.3100850702929,"id":986,"r":6,"Cm":-0.000304462666435373},
             {"Re":10000,"src":"retest_85.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","CDpres":0.00375,"clcd":33.0898246329903,"alpha":0,"sym":8.12617280627953e-06,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"CDf":0.02647,"Cpmin":-0.170381652663069,"CL":-0.000369149792294227,"CD":0.0302207706172914,"n":6,"CDp":0.000931230333733778,"Cm":6.21702905187681e-05,"id":987,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":31.4526769180003,"iver":1.2020052,"r":6},
             {"Cm":0.000392405845793943,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt53.0482647362947>50.4609267036206) l1 Foil spline 17pts Re30000 N6","good":31.5198545166508,"xver":6.991,"iver":1.2020052,"id":988,"Cpmin":-0.180731381376119,"CDf":0.02637,"CDp":0.00118292804552139,"n":7,"CD":0.0304598415556233,"CL":-0.00218239427353388,"alpha":0,"clcd":32.8301116791393,"CDpres":0.00409,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00590508850626053,0.672127682508641,0.014043721392719,0.448051878989487,0.0200009358359451,0.261607586958807,0.0213570011737948,0.14960260982261,0.0189927972949462,0.0876932172572549,0.0158646638322803,0.0269668136105797,0.00977475989382423,0,0,0.0260784653873372,-0.00989225469190087,0.0852103572234493,-0.0162276775455506,0.159346520639483,-0.0200157230030399,0.277295492850028,-0.0221422416627618,0.461088095254591,-0.0204178220639721,0.679515403216876,-0.0142608721165434,0.887295989576364,-0.00593645651997645,1,0],"sym":0.000202097589951647,"src":"retest_100.txt","Re":10000,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re30000-N6.dat","Top_Xtr":1,"diter":3},
             {"n":8,"CD":0.0307232244173682,"CL":0.00457573778531006,"CDp":0.00271519420447537,"CDf":0.02448,"Cpmin":-0.332291225981216,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt28.5253842665019>26.8688690268967) l1 Foil spline 17pts Re8192 N8","xver":6.991,"iver":1.2020052,"good":31.5182220885765,"id":989,"r":6,"Cm":-0.000618048319116254,"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re8192-N8.dat","Top_Xtr":1,"Re":10000,"src":"retest_66.txt","sym":0.000809052053243109,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00566327393389478,0.751503599940214,0.0102560551559937,0.617882281805394,0.0164536530879406,0.516474874255053,0.0210086955117196,0.425516435642791,0.0248464641654521,0.22020135983351,0.0300339473508033,0.0597789339840893,0.0227170247186664,0,0,0.0545974187204916,-0.0207728717302745,0.191614124162238,-0.0284203281975338,0.354272483283979,-0.025921407824626,0.461006103363399,-0.022226407784769,0.600655324159936,-0.0163658527566607,0.736649107785801,-0.0103762136821458,0.846409340674087,-0.00582401142761232,1,0],"CDpres":0.00625,"clcd":32.5486669763311,"alpha":0},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_naca0006.dat-s17_n17s0-Re25000-N3.dat","Re":10000,"src":"retest_69.txt","sym":0.000612768912129542,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00601084082309971,0.672127682508641,0.014295225849045,0.448051878989487,0.0203591261156268,0.261607586958807,0.0217394767882537,0.14960260982261,0.0193329331481291,0.0876932172572549,0.0161487789567801,0.0269668136105797,0.0099498129017889,0,0,0.0260784653873372,-0.00917569984927864,0.0852103572234493,-0.0150522103450046,0.159346520639483,-0.0185658651401853,0.277295492850028,-0.0205383474056766,0.461088095254591,-0.0189388377746052,0.679515403216876,-0.0132278723310151,0.887295989576364,-0.00550644366649744,1,0],"CDpres":0.00398,"clcd":32.9212868643876,"alpha":0,"CL":0.00386322525186749,"CD":0.0303754833193275,"n":9,"CDp":0.00109557809368973,"CDf":0.0264,"Cpmin":-0.181299620751682,"id":990,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt48.5560238203315>45.5663061413053) l1 Foil spline 17pts Re25000 N3","good":31.8616698504789,"iver":1.2020052,"r":6,"Cm":-0.000711621511145167},
             {"CDp":0.00251990095532418,"CD":0.0306062107314066,"CL":0.00149503129421905,"n":10,"Cpmin":-0.318614454147942,"CDf":0.02464,"r":6,"id":991,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","xver":6.991,"good":31.6846519847882,"Cm":-0.00024312868778799,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","diter":3,"src":"retest_152.txt","Re":10000,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"Bot_Xtr":1,"sym":0.000118953289988034,"alpha":0,"clcd":32.6731070623469,"CDpres":0.00596},
             {"Cpmin":-0.174368212313455,"CDf":0.0262,"CDp":0.0011573438385645,"CD":0.0302196948870857,"CL":0.00241678985347122,"n":11,"Cm":-0.000468248825891903,"r":6,"id":992,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","good":32.2285437534175,"iver":1.2020052,"src":"retest_151.txt","Re":10000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","diter":3,"alpha":0,"CDpres":0.00402,"clcd":33.0910025311787,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"sym":0.000266217784733598},
             {"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"sym":8.12617280627953e-06,"alpha":0,"clcd":33.0898246329833,"CDpres":0.00375,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"src":"retest_91.txt","Re":10000,"r":6,"id":993,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":32.23284653025,"xver":6.991,"iver":1.2020052,"Cm":6.21702905146315e-05,"CDp":0.000931230333743348,"CD":0.0302207706172978,"CL":-0.000369149792285279,"n":12,"Cpmin":-0.170381652662884,"CDf":0.02647},
             {"alpha":0,"CDpres":0.00375,"clcd":33.0898246329833,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"sym":8.12617280627953e-06,"src":"retest_92.txt","Re":10000,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"diter":3,"Cm":6.21702905146315e-05,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"xver":6.991,"good":32.2328465302501,"id":994,"Cpmin":-0.170381652662884,"CDf":0.02647,"CDp":0.000931230333743348,"n":13,"CL":-0.000369149792285279,"CD":0.0302207706172978},
             {"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"Re":10000,"src":"retest_93.txt","sym":8.12617280627953e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"clcd":33.0898246329833,"CDpres":0.00375,"alpha":0,"n":14,"CD":0.0302207706172978,"CL":-0.000369149792285279,"CDp":0.000931230333743348,"CDf":0.02647,"Cpmin":-0.170381652662884,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":32.2328465302501,"id":995,"r":6,"Cm":6.21702905146315e-05},
             {"clcd":37.2551771745596,"CDpres":0.00327,"alpha":0,"sym":0.000369915580133456,"xy":[1,0,0.890051584584834,0.00471599208649437,0.688319663136467,0.0127256782062343,0.531077021072871,0.0180211763267724,0.356235003186791,0.0209874595601984,0.185354945883713,0.0191675570151286,0.0805049102365469,0.0137199038979723,0.0227160217511022,0.00749310569411373,0,0,0.0082927963827511,-0.00484778770089916,0.0300900072589043,-0.00945251825225781,0.119578560658688,-0.0166926790481109,0.27134218735548,-0.0204893006544031,0.435924274981712,-0.0196024990377437,0.588980424483976,-0.0158275632891981,0.79895599276978,-0.00817833440163073,1,0],"Bot_Xtr":1,"Re":12500,"src":"retest_66.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_raf30md.dat-s17_n17s0_nsopt-Re20000-N3.dat","Cm":-0.000851935785478115,"id":996,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_raf30md.dat-s17_n17s0.dat (opt43.8763267752051>39.3547008891982) l1 Foil spline 17pts Re20000 N3","iver":1.2020052,"good":34.6716099369313,"r":6,"CDf":0.02357,"Cpmin":-0.173937112919304,"CD":0.0268419069734788,"CL":0.00419078005530783,"n":3,"CDp":0.000836743035186695},
             {"CDf":0.02322,"Cpmin":-0.161784459109639,"CD":0.0270486657163912,"CL":7.24142037761241e-06,"n":4,"CDp":0.00121900302601348,"Cm":1.76536841545829e-05,"id":997,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt44.1795114315451>38.4456592319157) l1 Foil spline 17pts Re20000 N9","xver":6.991,"iver":1.2020052,"good":34.8531086835392,"r":6,"Re":12500,"src":"retest_67.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re20000-N9.dat","clcd":36.9704003326867,"CDpres":0.00383,"alpha":0,"sym":1.23224447369755e-05,"xy":[1,0,0.961992840051787,0.00145695237485134,0.838375902301386,0.0063756325685884,0.669468112967632,0.0149982362978466,0.498697719332731,0.0218657735773801,0.301319859646249,0.023827962592208,0.134615624611079,0.0195487794442036,0.0376550591335466,0.0111023079109159,0,0,0.0409493023355519,-0.0116747023279585,0.14830924318344,-0.0202146983601641,0.317279938768802,-0.0239021800772882,0.498956936169248,-0.0218255515401106,0.653261727003669,-0.0157968420757023,0.844873051243488,-0.00607128292831692,0.969355895385625,-0.00118456467382707,1,0],"Bot_Xtr":1},
             {"alpha":0,"CDpres":0.00394,"clcd":37.0328395800555,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"sym":0.00111550182733531,"src":"retest_67.txt","Re":12500,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","diter":3,"Cm":-0.000114775065225621,"r":6,"id":998,"good":35.0714847279437,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"iver":1.2020052,"Cpmin":-0.195414064447532,"CDf":0.02306,"CDp":0.00129181066922143,"CD":0.0270030602929666,"CL":0.00050439024542331,"n":5},
             {"Cm":-0.00011477506522292,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"iver":1.2020052,"good":35.1091553503851,"id":999,"r":6,"CDf":0.02306,"Cpmin":-0.195414064447478,"n":6,"CD":0.0270030602929668,"CL":0.000504390245403757,"CDp":0.00129181066921516,"CDpres":0.00394,"clcd":37.0328395800552,"alpha":0,"sym":0.00111550182733531,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"Re":12500,"src":"retest_148.txt","diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1},
             {"diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"Re":12500,"src":"retest_69.txt","sym":0.00111550182733531,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"clcd":37.0328395800555,"CDpres":0.00394,"alpha":0,"n":7,"CD":0.0270030602929666,"CL":0.00050439024542331,"CDp":0.00129181066922143,"CDf":0.02306,"Cpmin":-0.195414064447532,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","iver":1.2020052,"good":35.1451768679004,"id":1000,"r":6,"Cm":-0.000114775065225621},
             {"n":8,"CL":-0.00133038115840827,"CD":0.0283828736476493,"CDp":0.00142205034209217,"CDf":0.02435,"Cpmin":-0.151764341284381,"good":37.428114747408,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca000834.dat-s17_n17s0.dat (opt37.4281091403732>30.3871178560239) l1 Foil spline 17pts Re12500 N8","xver":6.991,"iver":1.2020052,"id":1001,"r":6,"Cm":0.000387850774724184,"diter":3,"Foil_fn":"optbs_spline_sym_naca000834.dat-s17_n17s0_nsopt-Re12500-N8.dat","Top_Xtr":1,"Re":12500,"src":"retestc_20.txt","sym":0.000211816976829876,"Bot_Xtr":1,"xy":[1,0,0.882475028942614,0.00939141691445623,0.699239640304744,0.0197134441977319,0.497717544683343,0.0256400657867919,0.305167273261072,0.0255489220396352,0.159866510817707,0.0203023726597664,0.0760104824652203,0.0137290454359465,0.0261521745928966,0.00756174914414556,0,0,0.0246906691091517,-0.00745953744068126,0.0735651603193743,-0.0138924347258053,0.15942101402779,-0.0208452630611451,0.305078501105519,-0.0262715513145348,0.499727822478872,-0.0263414506883574,0.703403311961931,-0.0200859270688941,0.885223603433491,-0.00945701393683815,1,0],"clcd":35.2325142413063,"CDpres":0.00403,"alpha":0},
             {"r":6,"id":1002,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt44.1795114315451>38.4456592319157) l1 Foil spline 17pts Re20000 N9","xver":6.991,"good":35.1163094495593,"iver":1.2020052,"Cm":1.76536841545829e-05,"CDp":0.00121900302601348,"CD":0.0270486657163912,"CL":7.24142037761241e-06,"n":9,"Cpmin":-0.161784459109639,"CDf":0.02322,"xy":[1,0,0.961992840051787,0.00145695237485134,0.838375902301386,0.0063756325685884,0.669468112967632,0.0149982362978466,0.498697719332731,0.0218657735773801,0.301319859646249,0.023827962592208,0.134615624611079,0.0195487794442036,0.0376550591335466,0.0111023079109159,0,0,0.0409493023355519,-0.0116747023279585,0.14830924318344,-0.0202146983601641,0.317279938768802,-0.0239021800772882,0.498956936169248,-0.0218255515401106,0.653261727003669,-0.0157968420757023,0.844873051243488,-0.00607128292831692,0.969355895385625,-0.00118456467382707,1,0],"Bot_Xtr":1,"sym":1.23224447369755e-05,"alpha":0,"CDpres":0.00383,"clcd":36.9704003326867,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re20000-N9.dat","diter":3,"src":"retest_72.txt","Re":12500},
             {"Re":12500,"src":"retestc_22.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re12500-N10.dat","Top_Xtr":1,"CDpres":0.00537,"clcd":36.6528891749646,"alpha":0,"sym":0.000118953289988034,"xy":[1,0,0.857899050218291,0.00550701746287259,0.751503599940214,0.00971863870528317,0.617882281805394,0.0155914830128727,0.516474874255053,0.0199078415864783,0.425516435642791,0.0235445114768787,0.22020135983351,0.0284601709679157,0.0597789339840893,0.0215266544828087,0,0,0.0545974187204916,-0.020362356853898,0.191614124162238,-0.0278586837764793,0.354272483283979,-0.0254091472346219,0.461006103363399,-0.0217871680319543,0.600655324159936,-0.0160424296831237,0.736649107785801,-0.0101711582554195,0.846409340674087,-0.00581836646671863,1,0],"Bot_Xtr":1,"CDf":0.02191,"Cpmin":-0.320327673898243,"n":10,"CL":0.00151657084019673,"CD":0.0272829788458542,"CDp":0.00225164073365272,"Cm":-0.000240024776185945,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt35.4451143223024>32.9059813520509) l1 Foil spline 17pts Re12500 N10","good":35.4450390048503,"iver":1.2020052,"id":1003,"r":6},
             {"xy":[1,0,0.857899050218291,0.0058258728073934,0.751503599940214,0.00947742009447672,0.617882281805394,0.0152044991989017,0.516474874255053,0.0194137248652718,0.425516435642791,0.0229601318612971,0.22020135983351,0.0277537836731126,0.0597789339840893,0.0209923584926892,0,0,0.0545974187204916,-0.0208011909394731,0.191614124162238,-0.028459073019635,0.354272483283979,-0.0259567459223354,0.461006103363399,-0.0222567085684047,0.600655324159936,-0.0163881639716891,0.736649107785801,-0.0103903593510629,0.846409340674087,-0.0058319511771152,1,0],"Bot_Xtr":1,"sym":0.000268053028847243,"alpha":0,"CDpres":0.00536,"clcd":36.6381746550551,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re35000-N12.dat","diter":3,"src":"retest_154.txt","Re":12500,"r":6,"id":1004,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt56.7849713067586>47.2294203694912) l1 Foil spline 17pts Re35000 N12","xver":6.991,"iver":1.2020052,"good":35.4175186468941,"Cm":0.00016766375581791,"CDp":0.00224185965094738,"CD":0.027293936158526,"CL":-0.00291047873785821,"n":11,"Cpmin":-0.314724862600419,"CDf":0.02193},
             {"diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"Re":12500,"src":"retest_74.txt","sym":0.00111550182733531,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"clcd":37.0328395800555,"CDpres":0.00394,"alpha":0,"n":12,"CL":0.00050439024542331,"CD":0.0270030602929666,"CDp":0.00129181066922143,"CDf":0.02306,"Cpmin":-0.195414064447532,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"good":35.9679794449129,"id":1005,"r":6,"Cm":-0.000114775065225621},
             {"Re":12500,"src":"retest_101.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","CDpres":0.00338,"clcd":37.0921632771163,"alpha":0,"sym":8.12617280627953e-06,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"CDf":0.02358,"Cpmin":-0.170140147667814,"CL":-0.00037319275333937,"CD":0.0269598726968006,"n":13,"CDp":0.000791039174942571,"Cm":6.18539042002863e-05,"id":1006,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","iver":1.2020052,"good":36.0238428963586,"r":6},
             {"sym":8.12617280627953e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"CDpres":0.00338,"clcd":37.0921632771163,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"Re":12500,"src":"retest_102.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":36.0238428963587,"iver":1.2020052,"id":1007,"r":6,"Cm":6.18539042002863e-05,"n":14,"CL":-0.00037319275333937,"CD":0.0269598726968006,"CDp":0.000791039174942571,"CDf":0.02358,"Cpmin":-0.170140147667814},
             {"Cm":-0.000848008726806772,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_raf30md.dat-s17_n17s0.dat (opt43.8763267752051>39.3547008891982) l1 Foil spline 17pts Re20000 N3","good":37.9910313622277,"xver":6.991,"iver":1.2020052,"id":1008,"Cpmin":-0.174913304240837,"CDf":0.02144,"CDp":0.000730130033010193,"n":3,"CL":0.00423554765078784,"CD":0.0244501135855144,"alpha":0,"clcd":40.8996054968208,"CDpres":0.00301,"Bot_Xtr":1,"xy":[1,0,0.890051584584834,0.00471599208649437,0.688319663136467,0.0127256782062343,0.531077021072871,0.0180211763267724,0.356235003186791,0.0209874595601984,0.185354945883713,0.0191675570151286,0.0805049102365469,0.0137199038979723,0.0227160217511022,0.00749310569411373,0,0,0.0082927963827511,-0.00484778770089916,0.0300900072589043,-0.00945251825225781,0.119578560658688,-0.0166926790481109,0.27134218735548,-0.0204893006544031,0.435924274981712,-0.0196024990377437,0.588980424483976,-0.0158275632891981,0.79895599276978,-0.00817833440163073,1,0],"sym":0.000369915580133456,"src":"retest_74.txt","Re":15000,"Foil_fn":"optbs_spline_sym_raf30md.dat-s17_n17s0_nsopt-Re20000-N3.dat","Top_Xtr":1,"diter":3},
             {"alpha":0,"CDpres":0.00301,"clcd":40.8996054968208,"Bot_Xtr":1,"xy":[1,0,0.890051584584834,0.00471599208649437,0.688319663136467,0.0127256782062343,0.531077021072871,0.0180211763267724,0.356235003186791,0.0209874595601984,0.185354945883713,0.0191675570151286,0.0805049102365469,0.0137199038979723,0.0227160217511022,0.00749310569411373,0,0,0.0082927963827511,-0.00484778770089916,0.0300900072589043,-0.00945251825225781,0.119578560658688,-0.0166926790481109,0.27134218735548,-0.0204893006544031,0.435924274981712,-0.0196024990377437,0.588980424483976,-0.0158275632891981,0.79895599276978,-0.00817833440163073,1,0],"sym":0.000369915580133456,"src":"retest_75.txt","Re":15000,"Foil_fn":"optbs_spline_sym_raf30md.dat-s17_n17s0_nsopt-Re20000-N3.dat","Top_Xtr":1,"diter":3,"Cm":-0.000848008726806714,"r":6,"good":38.0282403874351,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_raf30md.dat-s17_n17s0.dat (opt43.8763267752051>39.3547008891982) l1 Foil spline 17pts Re20000 N3","xver":6.991,"iver":1.2020052,"id":1009,"Cpmin":-0.174913304240837,"CDf":0.02144,"CDp":0.000730130033010192,"n":4,"CD":0.0244501135855144,"CL":0.00423554765078771},
             {"CDp":0.00115751701460923,"CL":0.000511584304782119,"CD":0.024592055006615,"n":5,"Cpmin":-0.194993384722182,"CDf":0.02097,"r":6,"id":1010,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"iver":1.2020052,"good":38.3680892749154,"Cm":-0.000113958852686038,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","diter":3,"src":"retest_77.txt","Re":15000,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"sym":0.00111550182733531,"alpha":0,"CDpres":0.00362,"clcd":40.6635394939956},
             {"Cm":-0.000113958852686038,"id":1011,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"iver":1.2020052,"good":38.4064733246715,"r":6,"CDf":0.02097,"Cpmin":-0.194993384722182,"CL":0.000511584304782119,"CD":0.024592055006615,"n":6,"CDp":0.00115751701460923,"clcd":40.6635394939956,"CDpres":0.00362,"alpha":0,"sym":0.00111550182733531,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"Re":15000,"src":"retest_78.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat"},
             {"n":7,"CL":0.000511584304782119,"CD":0.024592055006615,"CDp":0.00115751701460923,"CDf":0.02097,"Cpmin":-0.194993384722182,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"good":38.4443780186608,"id":1012,"r":6,"Cm":-0.000113958852686038,"diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"Re":15000,"src":"retest_79.txt","sym":0.00111550182733531,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"clcd":40.6635394939956,"CDpres":0.00362,"alpha":0},
             {"n":8,"CL":6.68490948690067e-05,"CD":0.024825560416112,"CDp":0.00122812992731461,"CDf":0.02101,"Cpmin":-0.190920509096365,"good":38.2597106204849,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt38.2597106199947>33.9757429139916) l1 Foil spline 17pts Re15000 N8","xver":6.991,"iver":1.2020052,"id":1013,"r":6,"Cm":-9.82952846014503e-06,"diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re15000-N8.dat","Top_Xtr":1,"Re":15000,"src":"retestc_6.txt","sym":9.67390468525686e-07,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00220504680167475,0.814149693519042,0.00856736176987912,0.682864593067749,0.014822867268822,0.52069384686288,0.0210349401824068,0.325213183352731,0.0246371742177404,0.152815219118241,0.0221945321248167,0.0429551112266143,0.01348693160124,0,0,0.0408398189079085,-0.0131457177001331,0.136824284769333,-0.0214111806736169,0.289192311415617,-0.024672280949769,0.490511679687803,-0.021903431100646,0.680813751073162,-0.0149137736066989,0.840165601920523,-0.00725815472068301,0.955145580885723,-0.00174346059882933,1,0],"CDpres":0.00381,"clcd":40.2810644850939,"alpha":0},
             {"src":"retest_106.txt","Re":15000,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":40.7057331802838,"CDpres":0.00312,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"sym":8.12617280627953e-06,"Cpmin":-0.169892596992057,"CDf":0.02145,"CDp":0.000687686353581026,"n":9,"CD":0.024566564016205,"CL":-0.000375892946350267,"Cm":6.15196397381937e-05,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"good":38.5330380911028,"id":1014},
             {"CDf":0.01959,"Cpmin":-0.363433809817792,"CL":4.50896819026786e-05,"CD":0.0277268204708233,"n":10,"CDp":0.00430114643688575,"Cm":8.99632339845999e-06,"id":1015,"iver":1.2020052,"cmt":"OPT s(na) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt41.2615981906242>41.2615981906242) l1 Foil spline 17pts Re15000 N10","xver":6.991,"good":41.2615981906237,"r":6,"Re":15000,"src":"retestc_8.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re15000-N10.dat","clcd":36.0661620416337,"CDpres":0.00813,"alpha":0,"sym":5.08351700932719e-05,"xy":[1,0,0.969087652468728,0.00332620414216212,0.801860568053254,0.0169896334046824,0.696504319290661,0.0242150118288202,0.549776607886737,0.0324996665995272,0.338361913064034,0.0397105960893583,0.144153484994011,0.0376138823853553,0.0380479581477159,0.0236813945054323,0,0,0.039910401665453,-0.0243947180434366,0.148421317779882,-0.0377978546438754,0.328374676921391,-0.0398068106694271,0.517844762768298,-0.0339492677884747,0.689480272273693,-0.0247446034565582,0.832528496272264,-0.0145926132864909,0.973498898866872,-0.00289052522381147,1,0],"Bot_Xtr":1},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re8192-N8.dat","diter":3,"src":"retest_93.txt","Re":15000,"xy":[1,0,0.857899050218291,0.00566327393389478,0.751503599940214,0.0102560551559937,0.617882281805394,0.0164536530879406,0.516474874255053,0.0210086955117196,0.425516435642791,0.0248464641654521,0.22020135983351,0.0300339473508033,0.0597789339840893,0.0227170247186664,0,0,0.0545974187204916,-0.0207728717302745,0.191614124162238,-0.0284203281975338,0.354272483283979,-0.025921407824626,0.461006103363399,-0.022226407784769,0.600655324159936,-0.0163658527566607,0.736649107785801,-0.0103762136821458,0.846409340674087,-0.00582401142761232,1,0],"Bot_Xtr":1,"sym":0.000809052053243109,"alpha":0,"clcd":40.0950214135379,"CDpres":0.00518,"CDp":0.00222174340395111,"CL":0.00467300349878057,"CD":0.024940752361398,"n":11,"Cpmin":-0.334601266784625,"CDf":0.01976,"r":6,"id":1016,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt28.5253842665019>26.8688690268967) l1 Foil spline 17pts Re8192 N8","good":38.5754116738571,"xver":6.991,"iver":1.2020052,"Cm":-0.000600205917178572},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","Re":15000,"src":"retestc_11.txt","sym":8.12617280627953e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"CDpres":0.00312,"clcd":40.705733180291,"alpha":0,"CD":0.0245665640162006,"CL":-0.000375892946359163,"n":12,"CDp":0.000687686353571587,"CDf":0.02145,"Cpmin":-0.169892596992308,"id":1017,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":38.7103985031712,"xver":6.991,"iver":1.2020052,"r":6,"Cm":6.15196397422484e-05},
             {"alpha":0,"CDpres":0.00312,"clcd":40.7057331802838,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"sym":8.12617280627953e-06,"src":"retest_110.txt","Re":15000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","diter":3,"Cm":6.15196397381937e-05,"r":6,"id":1018,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","good":45.0411034194792,"iver":1.2020052,"Cpmin":-0.169892596992057,"CDf":0.02145,"CDp":0.000687686353581026,"CL":-0.000375892946350267,"CD":0.024566564016205,"n":13},
             {"Re":15000,"src":"retest_111.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re12500-N12.dat","clcd":40.7057331802838,"CDpres":0.00312,"alpha":0,"sym":8.12617280627953e-06,"xy":[1,0,0.883609074234346,0.00550824539610304,0.672127682508641,0.0130999329855235,0.448051878989487,0.0186568012688202,0.261607586958807,0.0199217341561269,0.14960260982261,0.0177164132507229,0.0876932172572549,0.0147985015672896,0.0269668136105797,0.00911786099837237,0,0,0.0260784653873372,-0.0089789662671088,0.0852103572234493,-0.0147294801653574,0.159346520639483,-0.0181677996830422,0.277295492850028,-0.0200979905148303,0.461088095254591,-0.0185327755168228,0.679515403216876,-0.0129442572661249,0.887295989576364,-0.00538838156711309,1,0],"Bot_Xtr":1,"CDf":0.02145,"Cpmin":-0.169892596992057,"CL":-0.000375892946350267,"CD":0.024566564016205,"n":14,"CDp":0.000687686353581026,"Cm":6.15196397381937e-05,"id":1019,"good":39.424069576947,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt35.8664029734897>34.2639465517054) l1 Foil spline 17pts Re12500 N12","xver":6.991,"iver":1.2020052,"r":6},
             {"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re20000-N9.dat","Top_Xtr":1,"diter":3,"src":"retest_86.txt","Re":20000,"xy":[1,0,0.927533762368065,0.00374862981030181,0.828124577508512,0.00793194300675154,0.673910782200253,0.0134746809050704,0.485356610471494,0.0185512861343503,0.298817780508802,0.0206902578865809,0.140740099512849,0.0181032724624612,0.0345490619416974,0.0104898971963697,0,0,0.033827731492854,-0.0105010944350928,0.142528433402255,-0.0185074743398574,0.31046792119717,-0.0210246088088307,0.499715124890922,-0.0185373301002131,0.684159552318164,-0.0133605175939923,0.829477323686799,-0.00800304978421095,0.922486667396241,-0.00405806263743012,1,0],"Bot_Xtr":1,"sym":7.8770502367573e-05,"alpha":0,"clcd":46.9195087304687,"CDpres":0.00297,"CDp":0.000804849048574658,"n":3,"CD":0.0213130961311753,"CL":-0.00108864452654659,"Cpmin":-0.160989515652642,"CDf":0.01835,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt44.2578503997375>38.0824779800794) l1 Foil spline 17pts Re20000 N9","iver":1.2020052,"xver":6.991,"good":43.5582442597742,"id":1020,"Cm":0.000176263802199741},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_raf30md.dat-s17_n17s0.dat (opt43.8763267752051>39.3547008891982) l1 Foil spline 17pts Re20000 N3","xver":6.991,"good":43.8989535511068,"iver":1.2020052,"id":1021,"Cm":-0.00084077954509243,"CDp":0.000578722631446538,"n":4,"CD":0.0211135168389908,"CL":0.0042946701578554,"Cpmin":-0.17600416701543,"CDf":0.01847,"xy":[1,0,0.890051584584834,0.00471599208649437,0.688319663136467,0.0127256782062343,0.531077021072871,0.0180211763267724,0.356235003186791,0.0209874595601984,0.185354945883713,0.0191675570151286,0.0805049102365469,0.0137199038979723,0.0227160217511022,0.00749310569411373,0,0,0.0082927963827511,-0.00484778770089916,0.0300900072589043,-0.00945251825225781,0.119578560658688,-0.0166926790481109,0.27134218735548,-0.0204893006544031,0.435924274981712,-0.0196024990377437,0.588980424483976,-0.0158275632891981,0.79895599276978,-0.00817833440163073,1,0],"Bot_Xtr":1,"sym":0.000369915580133456,"alpha":0,"CDpres":0.00265,"clcd":47.3630237741008,"Foil_fn":"optbs_spline_sym_raf30md.dat-s17_n17s0_nsopt-Re20000-N3.dat","Top_Xtr":1,"diter":3,"src":"retest_83.txt","Re":20000},
             {"n":5,"CD":0.0211135168389908,"CL":0.0042946701578554,"CDp":0.00057872263144654,"CDf":0.01847,"Cpmin":-0.17600416701543,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_raf30md.dat-s17_n17s0.dat (opt43.8763267752051>39.3547008891982) l1 Foil spline 17pts Re20000 N3","xver":6.991,"good":43.9275536572622,"iver":1.2020052,"id":1022,"r":6,"Cm":-0.000840779545092434,"diter":3,"Foil_fn":"optbs_spline_sym_raf30md.dat-s17_n17s0_nsopt-Re20000-N3.dat","Top_Xtr":1,"Re":20000,"src":"retest_84.txt","sym":0.000369915580133456,"Bot_Xtr":1,"xy":[1,0,0.890051584584834,0.00471599208649437,0.688319663136467,0.0127256782062343,0.531077021072871,0.0180211763267724,0.356235003186791,0.0209874595601984,0.185354945883713,0.0191675570151286,0.0805049102365469,0.0137199038979723,0.0227160217511022,0.00749310569411373,0,0,0.0082927963827511,-0.00484778770089916,0.0300900072589043,-0.00945251825225781,0.119578560658688,-0.0166926790481109,0.27134218735548,-0.0204893006544031,0.435924274981712,-0.0196024990377437,0.588980424483976,-0.0158275632891981,0.79895599276978,-0.00817833440163073,1,0],"CDpres":0.00265,"clcd":47.3630237741008,"alpha":0},
             {"r":6,"id":1023,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt75.0154098323998>53.3490918126008) l1 Foil spline 17pts Re65536 N6","good":43.9001942201368,"xver":6.991,"iver":1.2020052,"Cm":3.82001056657635e-05,"CDp":0.00111232399327486,"CD":0.0212764735297553,"CL":-8.98130135115903e-05,"n":6,"Cpmin":-0.226326568025374,"CDf":0.01779,"xy":[1,0,0.888395795100267,0.00434109202539287,0.724782775337367,0.0107065110148271,0.573493663117091,0.0175929070970927,0.434846152115145,0.022576912779263,0.296738332433587,0.0253824330373243,0.156304320466368,0.0239955807309266,0.0490216324689624,0.0158949596872312,0,0,0.0501864526744944,-0.0160468205742262,0.168411092824914,-0.0244406411146426,0.326746855954174,-0.0250529701100815,0.462695012305671,-0.0216846592082053,0.564195027615659,-0.0179768061419363,0.67400816885005,-0.0130581753059419,0.86979319971664,-0.00501391567962391,1,0],"Bot_Xtr":1,"sym":7.80424623422109e-06,"alpha":0,"CDpres":0.00348,"clcd":47.0002699743212,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N6.dat","diter":3,"src":"retest_85.txt","Re":20000},
             {"n":7,"CD":0.0212288140049394,"CL":0.000521350812332668,"CDp":0.000966627447777939,"CDf":0.01805,"Cpmin":-0.194391361770154,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","iver":1.2020052,"xver":6.991,"good":43.8352934705457,"id":1024,"r":6,"Cm":-0.000112623945124788,"diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"Re":20000,"src":"retest_89.txt","sym":0.00111550182733531,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"clcd":47.1057874343487,"CDpres":0.00318,"alpha":0},
             {"CDf":0.01783,"Cpmin":-0.227894036781853,"CL":0.00376396792421646,"CD":0.0212404048211559,"n":8,"CDp":0.00105588905793184,"Cm":-0.000479658421614193,"id":1025,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","iver":1.2020052,"xver":6.991,"good":44.423908938635,"r":6,"Re":20000,"src":"retest_64.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","clcd":47.0800819673633,"CDpres":0.00341,"alpha":0,"sym":0.000474112710432711,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"Bot_Xtr":1},
             {"Cm":-0.000112623945124788,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"good":44.380555791855,"iver":1.2020052,"id":1026,"r":6,"CDf":0.01805,"Cpmin":-0.194391361770154,"n":9,"CL":0.000521350812332668,"CD":0.0212288140049394,"CDp":0.000966627447777939,"clcd":47.1057874343487,"CDpres":0.00318,"alpha":0,"sym":0.00111550182733531,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"Re":20000,"src":"retest_91.txt","diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1},
             {"alpha":0,"CDpres":0.00314,"clcd":46.9664314553384,"Bot_Xtr":1,"xy":[1,0,0.957161379295047,0.00179105982875314,0.840936018693537,0.00630373381271411,0.693142957839131,0.0139259297637629,0.510945017907535,0.021733070021082,0.310831802004258,0.024071096720713,0.141208349666857,0.0200497199567174,0.039312956593761,0.0114590141333706,0,0,0.0414480062413493,-0.0118185250515131,0.14748763733964,-0.0202901848728208,0.314606487742102,-0.0240406603499841,0.500000736363886,-0.0219529295685594,0.65939238192171,-0.0155889261973367,0.842205184753321,-0.00623931564171484,0.960017460050938,-0.00145799228937842,1,0],"sym":1.3721422258111e-05,"src":"retestc_18.txt","Re":20000,"Foil_fn":"optbs_spline_sym_hq09.dat-s17_n17s0_nsopt-Re20000-N10.dat","Top_Xtr":1,"diter":3,"Cm":-1.15427904398088e-05,"r":6,"good":44.3060773719664,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq09.dat-s17_n17s0.dat (opt44.3307797580838>37.2447751371708) l1 Foil spline 17pts Re20000 N10","xver":6.991,"iver":1.2020052,"id":1027,"Cpmin":-0.160288218927741,"CDf":0.01815,"CDp":0.000937778782347615,"n":10,"CL":1.24456732778955e-05,"CD":0.021291802868841},
             {"CDpres":0.00318,"clcd":47.1057874343487,"alpha":0,"sym":0.00111550182733531,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"Re":20000,"src":"retest_93.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Cm":-0.000112623945124788,"id":1028,"good":44.6037603069768,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.01805,"Cpmin":-0.194391361770154,"CL":0.000521350812332668,"CD":0.0212288140049394,"n":11,"CDp":0.000966627447777939},
             {"src":"retest_97.txt","Re":20000,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re20000-N9.dat","Top_Xtr":1,"diter":3,"alpha":0,"CDpres":0.00312,"clcd":47.0122078061196,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00145695237485134,0.838375902301386,0.0063756325685884,0.669468112967632,0.0149982362978466,0.498697719332731,0.0218657735773801,0.301319859646249,0.023827962592208,0.134615624611079,0.0195487794442036,0.0376550591335466,0.0111023079109159,0,0,0.0409493023355519,-0.0116747023279585,0.14830924318344,-0.0202146983601641,0.317279938768802,-0.0239021800772882,0.498956936169248,-0.0218255515401106,0.653261727003669,-0.0157968420757023,0.844873051243488,-0.00607128292831692,0.969355895385625,-0.00118456467382707,1,0],"sym":1.23224447369755e-05,"Cpmin":-0.160042513959134,"CDf":0.01815,"CDp":0.000922312893704672,"n":12,"CL":5.74104883807995e-06,"CD":0.0212710707849341,"Cm":1.62405571871011e-05,"r":6,"good":44.4783926463061,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt44.1795114315451>38.4456592319157) l1 Foil spline 17pts Re20000 N9","xver":6.991,"iver":1.2020052,"id":1029},
             {"Re":20000,"src":"retestc_22.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re20000-N12.dat","CDpres":0.00416,"clcd":46.7451767198592,"alpha":0,"sym":6.44776707251984e-05,"xy":[1,0,0.857899050218291,0.00586574649043476,0.751503599940214,0.00934192392399973,0.617882281805394,0.0149871244919735,0.516474874255053,0.0191361719713708,0.425516435642791,0.0226318769237888,0.22020135983351,0.0273569951624771,0.0597789339840893,0.0206922362910051,0,0,0.0545974187204916,-0.0199415327171994,0.191614124162238,-0.0272829347787618,0.354272483283979,-0.0248840222441319,0.461006103363399,-0.0213368976509792,0.600655324159936,-0.0157108844857583,0.736649107785801,-0.00996095327164609,0.846409340674087,-0.0055909320548979,1,0],"Bot_Xtr":1,"CDf":0.01723,"Cpmin":-0.310583712073021,"CL":-0.000487006927697491,"CD":0.0213925814419942,"n":13,"CDp":0.00164902252776002,"Cm":-0.00016520662844096,"id":1030,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt44.6963667387654>40.8736556608881) l1 Foil spline 17pts Re20000 N12","xver":6.991,"good":44.8521496629829,"r":6},
             {"Cpmin":-0.227894036781853,"CDf":0.01783,"CDp":0.00105588905793184,"CD":0.0212404048211559,"CL":0.00376396792421646,"n":14,"Cm":-0.000479658421614193,"r":6,"id":1031,"good":45.4132704045221,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"iver":1.2020052,"src":"retest_70.txt","Re":20000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","diter":3,"alpha":0,"CDpres":0.00341,"clcd":47.0800819673633,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"sym":0.000474112710432711},
             {"Cm":-0.000539555061903254,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt52.8763045819518>48.5303195011039) l1 Foil spline 17pts Re30000 N4","iver":1.2020052,"good":48.0127494322775,"id":1032,"Cpmin":-0.168094866954572,"CDf":0.01609,"CDp":0.000916224304834595,"n":3,"CD":0.0190769242050786,"CL":0.0030899292036108,"alpha":0,"CDpres":0.00298,"clcd":52.4193517387767,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00146126236079956,0.838375902301386,0.00675664336084454,0.669468112967632,0.0158945379326744,0.498697719332731,0.0231724824606769,0.301319859646249,0.0252519328112316,0.134615624611079,0.0207170236715095,0.0376550591335466,0.0117657870382813,0,0,0.0409493023355519,-0.0118892775652844,0.14830924318344,-0.0205862344881318,0.317279938768802,-0.02434149028997,0.498956936169248,-0.0222266943504308,0.653261727003669,-0.0160871801967247,0.844873051243488,-0.00618287009676205,0.969355895385625,-0.0011463740676587,1,0],"sym":0.000362474211347171,"src":"retest_67.txt","Re":25000,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N4.dat","Top_Xtr":1,"diter":3},
             {"sym":0.000266217784733598,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"CDpres":0.00266,"clcd":52.84808272691,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","Top_Xtr":1,"Re":25000,"src":"retest_64.txt","iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","xver":6.991,"good":48.9131793160411,"id":1033,"r":6,"Cm":-0.000458473495754668,"n":4,"CL":0.00253103698343452,"CD":0.0189221623264453,"CDp":0.000606330125469009,"CDf":0.01626,"Cpmin":-0.171435050429022},
             {"n":5,"CL":0.00378437487185674,"CD":0.0189564451160552,"CDp":0.000910887205711716,"CDf":0.01588,"Cpmin":-0.228118761922672,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"iver":1.2020052,"good":48.970560920338,"id":1034,"r":6,"Cm":-0.000469944307276259,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"Re":25000,"src":"retest_73.txt","sym":0.000474112710432711,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"CDpres":0.00308,"clcd":52.7525068058805,"alpha":0},
             {"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"Bot_Xtr":1,"sym":0.000474112710432711,"alpha":0,"clcd":52.7525068058805,"CDpres":0.00308,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_74.txt","Re":25000,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"good":49.0103591083733,"id":1035,"Cm":-0.000469944307276259,"CDp":0.000910887205711716,"n":6,"CL":0.00378437487185674,"CD":0.0189564451160552,"Cpmin":-0.228118761922672,"CDf":0.01588},
             {"alpha":0,"CDpres":0.00308,"clcd":52.7525068058805,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"sym":0.000474112710432711,"src":"retest_75.txt","Re":25000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","diter":3,"Cm":-0.000469944307276259,"r":6,"id":1036,"good":49.0456741451996,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"iver":1.2020052,"Cpmin":-0.228118761922672,"CDf":0.01588,"CDp":0.000910887205711716,"CL":0.00378437487185674,"CD":0.0189564451160552,"n":7},
             {"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"diter":3,"src":"retest_100.txt","Re":25000,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"sym":0.00111550182733531,"alpha":0,"clcd":52.7754595159953,"CDpres":0.00288,"CDp":0.000834137346613022,"n":8,"CL":0.000527596141674775,"CD":0.018948200720013,"Cpmin":-0.193973899145126,"CDf":0.01607,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","xver":6.991,"good":49.4860744124217,"iver":1.2020052,"id":1037,"Cm":-0.000111537274544328},
             {"CDp":0.000834137346613022,"n":9,"CD":0.018948200720013,"CL":0.000527596141674775,"Cpmin":-0.193973899145126,"CDf":0.01607,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","iver":1.2020052,"good":49.6802348962066,"id":1038,"Cm":-0.000111537274544328,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"diter":3,"src":"retest_101.txt","Re":25000,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1,"sym":0.00111550182733531,"alpha":0,"CDpres":0.00288,"clcd":52.7754595159953},
             {"src":"retest_102.txt","Re":25000,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":52.7754595159953,"CDpres":0.00288,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"sym":0.00111550182733531,"Cpmin":-0.193973899145126,"CDf":0.01607,"CDp":0.000834137346613022,"n":10,"CD":0.018948200720013,"CL":0.000527596141674775,"Cm":-0.000111537274544328,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","good":49.6996636664497,"xver":6.991,"iver":1.2020052,"id":1039},
             {"xy":[1,0,0.950207049544918,0.00199610811686703,0.834910988468956,0.00761211190603595,0.659043244109732,0.0159072478226106,0.465214000878362,0.0227883568299649,0.274034131185736,0.0251979081201411,0.127715926423755,0.0210849181875223,0.0388000725455763,0.0122654325402306,0,0,0.0389767678832851,-0.0120549933245242,0.129212631455479,-0.0207659138739738,0.280832340153077,-0.0247572961681352,0.484957925061925,-0.021846182197998,0.688315412782588,-0.0143398891213705,0.842457876227992,-0.00708172787172079,0.958862150999706,-0.00157944927910909,1,0],"Bot_Xtr":1,"sym":8.17113620313596e-05,"alpha":0,"CDpres":0.00293,"clcd":52.2857189124464,"Foil_fn":"optbs_spline_sym_eh0009.dat-s17_n17s0_nsopt-Re15000-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_107.txt","Re":25000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_eh0009.dat-s17_n17s0.dat (opt38.2620738804191>33.4278586753513) l1 Foil spline 17pts Re15000 N8","good":49.2941614951416,"iver":1.2020052,"id":1040,"Cm":-0.000242879800341479,"CDp":0.000821829187041241,"n":11,"CD":0.019125681367689,"CL":0.00144687323419162,"Cpmin":-0.18399042816083,"CDf":0.0162},
             {"sym":7.80424623422109e-06,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.00434109202539287,0.724782775337367,0.0107065110148271,0.573493663117091,0.0175929070970927,0.434846152115145,0.022576912779263,0.296738332433587,0.0253824330373243,0.156304320466368,0.0239955807309266,0.0490216324689624,0.0158949596872312,0,0,0.0501864526744944,-0.0160468205742262,0.168411092824914,-0.0244406411146426,0.326746855954174,-0.0250529701100815,0.462695012305671,-0.0216846592082053,0.564195027615659,-0.0179768061419363,0.67400816885005,-0.0130581753059419,0.86979319971664,-0.00501391567962391,1,0],"CDpres":0.00315,"clcd":52.6620504305037,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N6.dat","Top_Xtr":1,"Re":25000,"src":"retest_101.txt","cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt75.0154098323998>53.3490918126008) l1 Foil spline 17pts Re65536 N6","xver":6.991,"good":49.8825039554104,"iver":1.2020052,"id":1041,"r":6,"Cm":4.01216312331405e-05,"n":12,"CD":0.018989006159562,"CL":-9.69828406736979e-05,"CDp":0.000963296651682776,"CDf":0.01584,"Cpmin":-0.226488988610489},
             {"Re":25000,"src":"retest_95.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re80000-N12.dat","Top_Xtr":1,"clcd":50.9011157543048,"CDpres":0.00347,"alpha":0,"sym":6.82108888167849e-06,"xy":[1,0,0.883609074234346,0.00725163682436915,0.672127682508641,0.0172461373093141,0.448051878989487,0.024561786445032,0.261607586958807,0.0262270778847413,0.14960260982261,0.0233237601969541,0.0876932172572549,0.0194823126411114,0.0269668136105797,0.0120037165777063,0,0,0.0260784653873372,-0.0117830874369398,0.0852103572234493,-0.0193294804241381,0.159346520639483,-0.0238415832996579,0.277295492850028,-0.0263745705795246,0.461088095254591,-0.024320540680037,0.679515403216876,-0.0169867344007858,0.887295989576364,-0.00707116713217503,1,0],"Bot_Xtr":1,"CDf":0.01617,"Cpmin":-0.21379474746339,"n":13,"CD":0.0196459347733537,"CL":-0.000192377540281177,"CDp":0.00117321663257224,"Cm":2.58891784810843e-05,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt83.1453911519864>78.3157980125232) l1 Foil spline 17pts Re80000 N12","good":48.3697427562657,"iver":1.2020052,"id":1042,"r":6},
             {"sym":9.67390468525686e-07,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00220504680167475,0.814149693519042,0.00856736176987912,0.682864593067749,0.014822867268822,0.52069384686288,0.0210349401824068,0.325213183352731,0.0246371742177404,0.152815219118241,0.0221945321248167,0.0429551112266143,0.01348693160124,0,0,0.0408398189079085,-0.0131457177001331,0.136824284769333,-0.0214111806736169,0.289192311415617,-0.024672280949769,0.490511679687803,-0.021903431100646,0.680813751073162,-0.0149137736066989,0.840165601920523,-0.00725815472068301,0.955145580885723,-0.00174346059882933,1,0],"clcd":52.2051273837959,"CDpres":0.00306,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re15000-N8.dat","Top_Xtr":1,"Re":25000,"src":"retest_151.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt38.2597106199947>33.9757429139916) l1 Foil spline 17pts Re15000 N8","good":49.3132983765578,"iver":1.2020052,"id":1043,"r":6,"Cm":-9.55054140888849e-06,"n":14,"CD":0.0191552065882018,"CL":6.8192606134661e-05,"CDp":0.000905205897306449,"CDf":0.0161,"Cpmin":-0.189844529783404},
             {"n":3,"CD":0.0174942484291064,"CL":0.00172155216551149,"CDp":0.000944958877481979,"CDf":0.01457,"Cpmin":-0.172653965787037,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt51.9108360270713>47.0700430042467) l1 Foil spline 17pts Re30000 N3","iver":1.2020052,"xver":6.991,"good":51.9108360270796,"id":1044,"r":6,"Cm":-0.000294034041144787,"diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N3.dat","Top_Xtr":1,"Re":30000,"src":"retest_152.txt","sym":0.00013422701702231,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00148863835423775,0.838375902301386,0.00697819352317008,0.669468112967632,0.0164157194233952,0.498697719332731,0.0239323075656099,0.301319859646249,0.0260799430397695,0.134615624611079,0.0213963343457895,0.0376550591335466,0.0121515868931804,0,0,0.0409493023355519,-0.0124949100648738,0.14830924318344,-0.0216348846337542,0.317279938768802,-0.0255814308605469,0.498956936169248,-0.0233589085142558,0.653261727003669,-0.0169066512789993,0.844873051243488,-0.00649782170343262,0.969355895385625,-0.0011463740676587,1,0],"CDpres":0.00292,"clcd":57.1616439570065,"alpha":0},
             {"sym":7.8770502367573e-05,"Bot_Xtr":1,"xy":[1,0,0.927533762368065,0.00374862981030181,0.828124577508512,0.00793194300675154,0.673910782200253,0.0134746809050704,0.485356610471494,0.0185512861343503,0.298817780508802,0.0206902578865809,0.140740099512849,0.0181032724624612,0.0345490619416974,0.0104898971963697,0,0,0.033827731492854,-0.0105010944350928,0.142528433402255,-0.0185074743398574,0.31046792119717,-0.0210246088088307,0.499715124890922,-0.0185373301002131,0.684159552318164,-0.0133605175939923,0.829477323686799,-0.00800304978421095,0.922486667396241,-0.00405806263743012,1,0],"CDpres":0.0025,"clcd":57.5579341172959,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re20000-N9.dat","Top_Xtr":1,"Re":30000,"src":"retest_111.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt44.2578503997375>38.0824779800794) l1 Foil spline 17pts Re20000 N9","good":53.2366848729095,"iver":1.2020052,"id":1045,"r":6,"Cm":0.000171951341331067,"n":4,"CL":-0.00109187362883152,"CD":0.01737379937859,"CDp":0.000611125540176186,"CDf":0.01488,"Cpmin":-0.160600859480126},
             {"Re":30000,"src":"retest_75.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","clcd":57.9613036052063,"CDpres":0.00246,"alpha":0,"sym":0.000266217784733598,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"Bot_Xtr":1,"CDf":0.01479,"Cpmin":-0.1709677795965,"CL":0.00254215601937727,"CD":0.0172528900801012,"n":5,"CDp":0.000521208447095416,"Cm":-0.000455220408282975,"id":1046,"good":53.5689266610168,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","xver":6.991,"iver":1.2020052,"r":6},
             {"CDf":0.01479,"Cpmin":-0.1709677795965,"CL":0.00254215601937727,"CD":0.0172528900801012,"n":6,"CDp":0.000521208447095416,"Cm":-0.000455220408282975,"id":1047,"good":53.5932238346391,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","xver":6.991,"iver":1.2020052,"r":6,"Re":30000,"src":"retest_76.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","CDpres":0.00246,"clcd":57.9613036052063,"alpha":0,"sym":0.000266217784733598,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"Bot_Xtr":1},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","Re":30000,"src":"retest_77.txt","sym":0.000266217784733598,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"clcd":57.9613036052063,"CDpres":0.00246,"alpha":0,"CL":0.00254215601937727,"CD":0.0172528900801012,"n":7,"CDp":0.000521208447095416,"CDf":0.01479,"Cpmin":-0.1709677795965,"id":1048,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","xver":6.991,"good":53.6307972913368,"r":6,"Cm":-0.000455220408282975},
             {"CDf":0.01462,"Cpmin":-0.193664772293852,"n":8,"CL":0.000531876213146448,"CD":0.0172730961779958,"CDp":0.000735086278208586,"Cm":-0.000110613465460039,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt58.9107978316103>47.6421244614518) l1 Foil spline 17pts Re35000 N11","iver":1.2020052,"xver":6.991,"good":54.1320638240056,"id":1049,"r":6,"Re":30000,"src":"retest_110.txt","diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re35000-N11.dat","Top_Xtr":1,"CDpres":0.00265,"clcd":57.8935003716301,"alpha":0,"sym":0.00111550182733531,"xy":[1,0,0.972922049750542,0.00101555322813647,0.846603687659606,0.0059141883848298,0.652049868216663,0.0141212752862993,0.479143275669244,0.0205794951461525,0.293993827172706,0.0242162816818973,0.148391481755207,0.0216827979879078,0.0488930707148337,0.0133604575601675,0,0,0.0372961728230362,-0.0130531080004327,0.141024649091098,-0.0227559499585477,0.309704810294,-0.0251538829701609,0.516173420171465,-0.0200532648313073,0.694999251146369,-0.0127436785618701,0.795598835662968,-0.00834134065208056,0.902196709833545,-0.00383282322387036,1,0],"Bot_Xtr":1},
             {"r":6,"id":1050,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt75.0154098323998>53.3490918126008) l1 Foil spline 17pts Re65536 N6","xver":6.991,"iver":1.2020052,"good":54.1130147321384,"Cm":4.16057983000383e-05,"CDp":0.000851933162662384,"CL":-0.000102797615026973,"CD":0.0173089469886726,"n":9,"Cpmin":-0.226592933831686,"CDf":0.01441,"xy":[1,0,0.888395795100267,0.00434109202539287,0.724782775337367,0.0107065110148271,0.573493663117091,0.0175929070970927,0.434846152115145,0.022576912779263,0.296738332433587,0.0253824330373243,0.156304320466368,0.0239955807309266,0.0490216324689624,0.0158949596872312,0,0,0.0501864526744944,-0.0160468205742262,0.168411092824914,-0.0244406411146426,0.326746855954174,-0.0250529701100815,0.462695012305671,-0.0216846592082053,0.564195027615659,-0.0179768061419363,0.67400816885005,-0.0130581753059419,0.86979319971664,-0.00501391567962391,1,0],"Bot_Xtr":1,"sym":7.80424623422109e-06,"alpha":0,"CDpres":0.0029,"clcd":57.7735896154992,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N6.dat","diter":3,"src":"retest_108.txt","Re":30000},
             {"good":54.2604802726892,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"iver":1.2020052,"id":1051,"r":6,"Cm":-0.000461933723327684,"n":10,"CL":0.00379735931499063,"CD":0.0172789610566582,"CDp":0.00080258933835508,"CDf":0.01444,"Cpmin":-0.228266180365042,"sym":0.000474112710432711,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"CDpres":0.00283,"clcd":57.873849979809,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"Re":30000,"src":"retest_90.txt"},
             {"CDf":0.01465,"Cpmin":-0.162424262173918,"CD":0.0173782256100125,"CL":-0.000833741920094976,"n":11,"CDp":0.00079427573567914,"Cm":0.000159638077879089,"id":1052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt54.2215715209985>49.6771192289168) l1 Foil spline 17pts Re30000 N11","iver":1.2020052,"xver":6.991,"good":53.9692747123439,"r":6,"Re":30000,"src":"retestc_15.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N11.dat","CDpres":0.00273,"clcd":57.5432741202214,"alpha":0,"sym":3.63620785174967e-05,"xy":[1,0,0.961992840051787,0.0015190740326067,0.838375902301386,0.00653379034845319,0.669468112967632,0.0153702915769481,0.498697719332731,0.0224081891207511,0.301319859646249,0.0244190533775917,0.134615624611079,0.0200337182361902,0.0376550591335466,0.0113777184449571,0,0,0.0409493023355519,-0.012088171605106,0.14830924318344,-0.0209306186880612,0.317279938768802,-0.0247486956321336,0.498956936169248,-0.0225985215709632,0.653261727003669,-0.0163563003548752,0.844873051243488,-0.00628630245457225,0.969355895385625,-0.00120379044022226,1,0],"Bot_Xtr":1},
             {"xy":[1,0,0.961992840051787,0.00145401493787202,0.838375902301386,0.00665894057857383,0.669468112967632,0.0156646988696969,0.498697719332731,0.0228374024679031,0.301319859646249,0.0248867834372587,0.134615624611079,0.0204174502376348,0.0376550591335466,0.0115956507638249,0,0,0.0409493023355519,-0.0127169577741283,0.14830924318344,-0.022019359315682,0.317279938768802,-0.0260360398247205,0.498956936169248,-0.0237740209159733,0.653261727003669,-0.0172071002752845,0.844873051243488,-0.00661329483744476,0.969355895385625,-0.00118938781970418,1,0],"Bot_Xtr":1,"sym":0.000425939936242868,"alpha":0,"CDpres":0.00287,"clcd":57.2767060632002,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N9.dat","Top_Xtr":1,"diter":3,"src":"retest_68.txt","Re":30000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt53.6223595791024>49.6771952717087) l1 Foil spline 17pts Re30000 N9","xver":6.991,"iver":1.2020052,"good":53.7336953329694,"id":1053,"Cm":0.000603764533382078,"CDp":0.000900784195360308,"n":12,"CL":-0.00327778241805555,"CD":0.0174591045598289,"Cpmin":-0.16981639556866,"CDf":0.01459},
             {"r":6,"id":1054,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt53.2260682027001>49.9540683916289) l1 Foil spline 17pts Re30000 N8","iver":1.2020052,"good":53.5144313339778,"Cm":3.97985285572159e-06,"CDp":0.000943868041868136,"CL":4.91449579337655e-05,"CD":0.0174957753292687,"n":13,"Cpmin":-0.170912913216593,"CDf":0.01458,"xy":[1,0,0.961992840051787,0.00157219076508565,0.838375902301386,0.00690074688230933,0.669468112967632,0.0162335315373136,0.498697719332731,0.023666697730794,0.301319859646249,0.0257904979311517,0.134615624611079,0.0211588697045019,0.0376550591335466,0.0120167239687173,0,0,0.0409493023355519,-0.0126228076953519,0.14830924318344,-0.0218563388471865,0.317279938768802,-0.0258432818362094,0.498956936169248,-0.0235980097990203,0.653261727003669,-0.017079707397585,0.844873051243488,-0.00656433326652698,0.969355895385625,-0.00123180407810422,1,0],"Bot_Xtr":1,"sym":1.48126932224709e-05,"alpha":0,"CDpres":0.00292,"clcd":57.1566553170751,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N8.dat","diter":3,"src":"retest_67.txt","Re":30000},
             {"Cm":-0.000461933723327684,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"good":55.4500426376736,"id":1055,"Cpmin":-0.228266180365042,"CDf":0.01444,"CDp":0.00080258933835508,"n":14,"CL":0.00379735931499063,"CD":0.0172789610566582,"alpha":0,"clcd":57.873849979809,"CDpres":0.00283,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"sym":0.000474112710432711,"src":"retest_94.txt","Re":30000,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"diter":3},
             {"CDp":0.000717527521526811,"n":3,"CL":0.00380585406323802,"CD":0.0159803071014267,"Cpmin":-0.228367632042901,"CDf":0.01334,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","iver":1.2020052,"xver":6.991,"good":54.2714490310932,"id":1056,"Cm":-0.000455117143659778,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_95.txt","Re":35000,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"Bot_Xtr":1,"sym":0.000474112710432711,"alpha":0,"CDpres":0.00264,"clcd":62.5770201819663},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re35000-N4.dat","Re":35000,"src":"retestc_18.txt","sym":0.000135960499028547,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00152879565229698,0.838375902301386,0.00716643628638198,0.669468112967632,0.0168585475527829,0.498697719332731,0.0245779021154356,0.301319859646249,0.0267834719009159,0.134615624611079,0.0219735188400979,0.0376550591335466,0.012479386385497,0,0,0.0409493023355519,-0.0128385209950285,0.14830924318344,-0.0222298455253648,0.317279938768802,-0.026284922058726,0.498956936169248,-0.0240012801872256,0.653261727003669,-0.0173715854115073,0.844873051243488,-0.00667651227006359,0.969355895385625,-0.00117310725077275,1,0],"clcd":61.513332192919,"CDpres":0.00285,"alpha":0,"CD":0.016256638428622,"CL":0.0016655639561192,"n":4,"CDp":0.000948762926859024,"CDf":0.0134,"Cpmin":-0.176562608289745,"id":1057,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt55.8962467179484>51.1406290005629) l1 Foil spline 17pts Re35000 N4","good":55.8962467179544,"iver":1.2020052,"r":6,"Cm":-0.000283142923769769},
             {"Re":35000,"src":"retest_97.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"clcd":62.5770201819663,"CDpres":0.00264,"alpha":0,"sym":0.000474112710432711,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"Bot_Xtr":1,"CDf":0.01334,"Cpmin":-0.228367632042901,"n":5,"CD":0.0159803071014267,"CL":0.00380585406323802,"CDp":0.000717527521526811,"Cm":-0.000455117143659778,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"good":56.7697401212457,"iver":1.2020052,"id":1058,"r":6},
             {"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"Bot_Xtr":1,"sym":0.000474112710432711,"alpha":0,"clcd":62.5770201819663,"CDpres":0.00264,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_98.txt","Re":35000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","good":57.7694562110345,"iver":1.2020052,"id":1059,"Cm":-0.000455117143659778,"CDp":0.000717527521526811,"n":6,"CL":0.00380585406323802,"CD":0.0159803071014267,"Cpmin":-0.228367632042901,"CDf":0.01334},
             {"CDp":0.000454305343698587,"CL":0.00254804411483961,"CD":0.0159604523281703,"n":7,"Cpmin":-0.170638801525729,"CDf":0.01366,"r":6,"id":1060,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","xver":6.991,"good":57.852538966077,"iver":1.2020052,"Cm":-0.000451995370341901,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","diter":3,"src":"retest_87.txt","Re":35000,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"Bot_Xtr":1,"sym":0.000266217784733598,"alpha":0,"clcd":62.6548658796465,"CDpres":0.0023},
             {"id":1061,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","iver":1.2020052,"xver":6.991,"good":57.8278952853957,"r":6,"Cm":-0.000455117143659778,"CD":0.0159803071014267,"CL":0.00380585406323802,"n":8,"CDp":0.000717527521526811,"CDf":0.01334,"Cpmin":-0.228367632042901,"sym":0.000474112710432711,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"CDpres":0.00264,"clcd":62.5770201819663,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Re":35000,"src":"retest_100.txt"},
             {"id":1062,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","iver":1.2020052,"xver":6.991,"good":58.0742446203793,"r":6,"Cm":-0.000451995370341974,"CL":0.00254804411483753,"CD":0.0159604523281725,"n":9,"CDp":0.000454305343712408,"CDf":0.01366,"Cpmin":-0.17063880152556,"sym":0.000266217784733598,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"clcd":62.6548658796379,"CDpres":0.0023,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","Re":35000,"src":"retest_89.txt"},
             {"CDp":0.000454305343712408,"CL":0.00254804411483753,"CD":0.0159604523281725,"n":10,"Cpmin":-0.17063880152556,"CDf":0.01366,"r":6,"id":1063,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt35.2137951118123>31.8179665027938) l1 Foil spline 17pts Re12500 N7","xver":6.991,"iver":1.2020052,"good":58.9260599835014,"Cm":-0.000451995370341974,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re12500-N7.dat","diter":3,"src":"retest_90.txt","Re":35000,"xy":[1,0,0.944740406454351,0.00231969995976712,0.814149693519042,0.00781021710438972,0.682864593067749,0.0135128893338054,0.52069384686288,0.0191759673532224,0.325213183352731,0.0224598522447991,0.152815219118241,0.0202330798069726,0.0429551112266143,0.0122950176153499,0,0,0.0408398189079085,-0.011546881864077,0.136824284769333,-0.0188070654983073,0.289192311415617,-0.0216715374499039,0.490511679687803,-0.0192394464194638,0.680813751073162,-0.0130998995956224,0.840165601920523,-0.00637538832208989,0.955145580885723,-0.00158747507414313,1,0],"Bot_Xtr":1,"sym":0.000266217784733598,"alpha":0,"clcd":62.6548658796379,"CDpres":0.0023},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","xver":6.991,"good":58.98144313891,"iver":1.2020052,"id":1064,"r":6,"Cm":-0.000455117143659778,"n":11,"CL":0.00380585406323802,"CD":0.0159803071014267,"CDp":0.000717527521526811,"CDf":0.01334,"Cpmin":-0.228367632042901,"sym":0.000474112710432711,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"CDpres":0.00264,"clcd":62.5770201819663,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"Re":35000,"src":"retest_103.txt"},
             {"n":12,"CL":0.000798743325208261,"CD":0.0160525841250833,"CDp":0.000358142749867257,"CDf":0.01384,"Cpmin":-0.173018554185142,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt57.8863149665203>0) l1 Foil spline 17pts Re35000 N9","good":59.1769491776762,"iver":1.2020052,"id":1065,"r":6,"Cm":-0.000136689358521263,"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re35000-N9.dat","Top_Xtr":1,"Re":35000,"src":"retest_84.txt","sym":2.67876828706009e-05,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00568761276976703,0.672127682508641,0.0135265117607629,0.448051878989487,0.0192643307457978,0.261607586958807,0.020570454188997,0.14960260982261,0.0182933204665445,0.0876932172572549,0.0152803915648132,0.0269668136105797,0.00941476984376775,0,0,0.0260784653873372,-0.00910544007350214,0.0852103572234493,-0.0149369532048243,0.159346520639483,-0.0184237033930409,0.277295492850028,-0.0203810820518349,0.461088095254591,-0.0187938201173835,0.679515403216876,-0.0131265844337164,0.887295989576364,-0.00546427996196383,1,0],"clcd":62.2952661208877,"CDpres":0.00221,"alpha":0},
             {"Cm":-0.000164354993314077,"id":1066,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt49.5678964506754>41.2858366932847) l1 Foil spline 17pts Re25000 N9","xver":6.991,"good":58.115201176751,"r":6,"CDf":0.01343,"Cpmin":-0.191480459985638,"CD":0.0159482089231591,"CL":0.00120508374143107,"n":13,"CDp":0.000654491033438587,"clcd":62.7029658827616,"CDpres":0.00252,"alpha":0,"sym":4.74668080691712e-05,"xy":[1,0,0.794574379082928,0.00783633905808538,0.546030639687268,0.0192982011185212,0.363514019175692,0.0255443915281382,0.221984972352103,0.0257604919932004,0.122670417262654,0.0216716941634549,0.0658532742824706,0.0164607801224372,0.0236940673606567,0.00990416598357839,0,0,0.0239783675371822,-0.00988428078642735,0.0623361812874123,-0.0157672449216069,0.114829236142557,-0.0208498105950623,0.214306107242777,-0.0252541296344064,0.357389074847702,-0.0253125404936848,0.542695962832085,-0.0191932792410491,0.784157786565453,-0.00816669349073481,1,0],"Bot_Xtr":1,"Re":35000,"src":"retest_71.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re25000-N9.dat"},
             {"CDpres":0.00252,"clcd":62.7029658827616,"alpha":0,"sym":4.74668080691712e-05,"xy":[1,0,0.794574379082928,0.00783633905808538,0.546030639687268,0.0192982011185212,0.363514019175692,0.0255443915281382,0.221984972352103,0.0257604919932004,0.122670417262654,0.0216716941634549,0.0658532742824706,0.0164607801224372,0.0236940673606567,0.00990416598357839,0,0,0.0239783675371822,-0.00988428078642735,0.0623361812874123,-0.0157672449216069,0.114829236142557,-0.0208498105950623,0.214306107242777,-0.0252541296344064,0.357389074847702,-0.0253125404936848,0.542695962832085,-0.0191932792410491,0.784157786565453,-0.00816669349073481,1,0],"Bot_Xtr":1,"Re":35000,"src":"retest_72.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re25000-N9.dat","Top_Xtr":1,"Cm":-0.000164354993314077,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt49.5678964506754>41.2858366932847) l1 Foil spline 17pts Re25000 N9","iver":1.2020052,"xver":6.991,"good":58.0861382027112,"id":1067,"r":6,"CDf":0.01343,"Cpmin":-0.191480459985638,"n":14,"CD":0.0159482089231591,"CL":0.00120508374143107,"CDp":0.000654491033438587},
             {"CDp":0.000798161894730458,"CL":0.00172738470281652,"CD":0.0142565102219411,"n":3,"Cpmin":-0.212922228178508,"CDf":0.01172,"r":6,"id":1068,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt66.0705109402994>43.107043899686) l1 Foil spline 17pts Re65536 N3","iver":1.2020052,"good":58.9759189802113,"Cm":-0.000271427527668349,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re65536-N3.dat","diter":3,"src":"retest_93.txt","Re":45000,"xy":[1,0,0.972922049750542,0.00108853034818267,0.846603687659606,0.006586471716744,0.652049868216663,0.0157264825239825,0.479143275669244,0.0229188273868122,0.293993827172706,0.0269690182327718,0.148391481755207,0.0241475459343756,0.0488930707148337,0.0148791803907569,0,0,0.0372961728230362,-0.0143456367248267,0.141024649091098,-0.0250092615048339,0.309704810294,-0.02764463967484,0.516173420171465,-0.0220389544319362,0.694999251146369,-0.01400556734691,0.795598835662968,-0.0091673065747108,0.902196709833545,-0.00421235230707511,1,0],"Bot_Xtr":1,"sym":0.0010387559649789,"alpha":0,"clcd":70.1433930486703,"CDpres":0.00254},
             {"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re65536-N3.dat","Top_Xtr":1,"diter":3,"src":"retest_94.txt","Re":45000,"xy":[1,0,0.972922049750542,0.00108853034818267,0.846603687659606,0.006586471716744,0.652049868216663,0.0157264825239825,0.479143275669244,0.0229188273868122,0.293993827172706,0.0269690182327718,0.148391481755207,0.0241475459343756,0.0488930707148337,0.0148791803907569,0,0,0.0372961728230362,-0.0143456367248267,0.141024649091098,-0.0250092615048339,0.309704810294,-0.02764463967484,0.516173420171465,-0.0220389544319362,0.694999251146369,-0.01400556734691,0.795598835662968,-0.0091673065747108,0.902196709833545,-0.00421235230707511,1,0],"Bot_Xtr":1,"sym":0.0010387559649789,"alpha":0,"clcd":70.1433930486704,"CDpres":0.00254,"CDp":0.000798161894730459,"n":4,"CD":0.0142565102219411,"CL":0.00172738470281643,"Cpmin":-0.212922228178508,"CDf":0.01172,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt66.0705109402994>43.107043899686) l1 Foil spline 17pts Re65536 N3","xver":6.991,"good":61.7438127777422,"iver":1.2020052,"id":1069,"Cm":-0.000271427527668347},
             {"clcd":71.1136075095058,"CDpres":0.00232,"alpha":0,"sym":0.0002053893137046,"xy":[1,0,0.888395795100267,0.00419663949320081,0.724782775337367,0.0101953070286959,0.573493663117091,0.0167528982255551,0.434846152115145,0.0214989324931256,0.296738332433587,0.0241704975217844,0.156304320466368,0.0228498632789765,0.0490216324689624,0.0151360227431366,0,0,0.0501864526744944,-0.015730373989637,0.168411092824914,-0.0239586666717849,0.326746855954174,-0.0245589204141632,0.462695012305671,-0.0212570332923625,0.564195027615659,-0.0176222998471145,0.67400816885005,-0.0128006654174616,0.86979319971664,-0.00517239596946446,1,0],"Bot_Xtr":1,"Re":45000,"src":"retest_148.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re55000-N6.dat","Cm":0.000423933242211503,"id":1070,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt69.7091729812019>54.0159058282702) l1 Foil spline 17pts Re55000 N6","iver":1.2020052,"good":62.8413568465775,"r":6,"CDf":0.01174,"Cpmin":-0.22028649097991,"CL":-0.00241174790706525,"CD":0.0140620063447959,"n":5,"CDp":0.000555020881126137},
             {"Cm":-9.63194827811214e-07,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0008.dat-s17_n17s0.dat (opt53.8173075066675>46.4404972981783) l1 Foil spline 17pts Re30000 N10","iver":1.2020052,"xver":6.991,"good":64.0594814623277,"id":1071,"Cpmin":-0.193908710261762,"CDf":0.01207,"CDp":0.000521102067768171,"n":6,"CD":0.0143853107243996,"CL":-1.82194406484573e-05,"alpha":0,"CDpres":0.00232,"clcd":69.5153562657395,"Bot_Xtr":1,"xy":[1,0,0.886281041500426,0.00623113267541942,0.677990070708394,0.0149152940448864,0.455947731350181,0.0213808645797141,0.267138022449174,0.0230416356325085,0.149004648592092,0.0204555179959927,0.0849623087762251,0.0168578994341553,0.0265168531598548,0.0104599984180862,0,0,0.0253827822868623,-0.0101830852816701,0.0809740539828315,-0.0165640195281824,0.15501744810753,-0.0207190559842658,0.275331687113213,-0.0230679571967432,0.458957257407033,-0.0213176490625083,0.676682621449976,-0.014971272871209,0.887378822900304,-0.00618189456217564,1,0],"sym":3.76708053021016e-06,"src":"retest_100.txt","Re":45000,"Foil_fn":"optbs_spline_sym_naca0008.dat-s17_n17s0_nsopt-Re30000-N10.dat","Top_Xtr":1,"diter":3},
             {"CDf":0.01174,"Cpmin":-0.22028649097991,"CL":-0.00241174790706525,"CD":0.0140620063447959,"n":7,"CDp":0.000555020881126137,"Cm":0.000423933242211503,"id":1072,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt69.7091729812019>54.0159058282702) l1 Foil spline 17pts Re55000 N6","iver":1.2020052,"xver":6.991,"good":65.331145576933,"r":6,"Re":45000,"src":"retest_150.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re55000-N6.dat","CDpres":0.00232,"clcd":71.1136075095058,"alpha":0,"sym":0.0002053893137046,"xy":[1,0,0.888395795100267,0.00419663949320081,0.724782775337367,0.0101953070286959,0.573493663117091,0.0167528982255551,0.434846152115145,0.0214989324931256,0.296738332433587,0.0241704975217844,0.156304320466368,0.0228498632789765,0.0490216324689624,0.0151360227431366,0,0,0.0501864526744944,-0.015730373989637,0.168411092824914,-0.0239586666717849,0.326746855954174,-0.0245589204141632,0.462695012305671,-0.0212570332923625,0.564195027615659,-0.0176222998471145,0.67400816885005,-0.0128006654174616,0.86979319971664,-0.00517239596946446,1,0],"Bot_Xtr":1},
             {"Cm":-0.000443927263711877,"r":6,"id":1073,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","good":65.3589114276096,"xver":6.991,"iver":1.2020052,"Cpmin":-0.228491725198288,"CDf":0.01171,"CDp":0.000590450552851821,"CD":0.0140746652999103,"CL":0.00381501836479036,"n":8,"alpha":0,"clcd":71.0496469146144,"CDpres":0.00236,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"sym":0.000474112710432711,"src":"retest_153.txt","Re":45000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","diter":3},
             {"Cm":-0.000443927263711877,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","good":65.5419443564564,"iver":1.2020052,"id":1074,"r":6,"CDf":0.01171,"Cpmin":-0.228491725198288,"n":9,"CD":0.0140746652999103,"CL":0.00381501836479036,"CDp":0.000590450552851821,"clcd":71.0496469146144,"CDpres":0.00236,"alpha":0,"sym":0.000474112710432711,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"Bot_Xtr":1,"Re":45000,"src":"retest_154.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re65536-N8.dat","Re":45000,"src":"retest_155.txt","sym":0.000474112710432711,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.0043765173991041,0.724782775337367,0.0107548290885685,0.573493663117091,0.0176723032123413,0.434846152115145,0.0226788015210772,0.296738332433587,0.0254969829845046,0.156304320466368,0.0241038718668175,0.0490216324689624,0.0159666930309153,0,0,0.0501864526744944,-0.0153804470922312,0.168411092824914,-0.0234256989305245,0.326746855954174,-0.0240125998479881,0.462695012305671,-0.0207841641976449,0.564195027615659,-0.0172302864903616,0.67400816885005,-0.0125159107678129,0.86979319971664,-0.00488458795879891,1,0],"clcd":71.0496469146144,"CDpres":0.00236,"alpha":0,"CL":0.00381501836479036,"CD":0.0140746652999103,"n":10,"CDp":0.000590450552851821,"CDf":0.01171,"Cpmin":-0.228491725198288,"id":1075,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt76.684242148813>59.122805729418) l1 Foil spline 17pts Re65536 N8","iver":1.2020052,"xver":6.991,"good":65.5914297458302,"r":6,"Cm":-0.000443927263711877},
             {"Re":45000,"src":"retest_107.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re80000-N4.dat","CDpres":0.0025,"clcd":70.7323207774948,"alpha":0,"sym":0.00010337954565373,"xy":[1,0,0.888395795100267,0.00455982762032328,0.724782775337367,0.0108553159604154,0.573493663117091,0.0178374229416753,0.434846152115145,0.0228906990606218,0.296738332433587,0.0257352119735984,0.156304320466368,0.0243290844353621,0.0490216324689624,0.016115876530086,0,0,0.0501864526744944,-0.0165875395368357,0.168411092824914,-0.0252642010247127,0.326746855954174,-0.025897163260092,0.462695012305671,-0.0224153526422949,0.564195027615659,-0.0185825585352616,0.67400816885005,-0.0134981878911355,0.86979319971664,-0.00499983466651039,1,0],"Bot_Xtr":1,"CDf":0.01164,"Cpmin":-0.231495867053274,"CD":0.0141378084164061,"CL":-0.00199757856256296,"n":11,"CDp":0.000690640467641554,"Cm":0.00017846113756447,"id":1076,"good":66.0533961773971,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt74.5629185185408>48.7991713041488) l1 Foil spline 17pts Re80000 N4","xver":6.991,"iver":1.2020052,"r":6},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re12500-N7.dat","diter":3,"src":"retest_79.txt","Re":45000,"xy":[1,0,0.969087652468728,0.00176514861384408,0.801860568053254,0.00901605150262981,0.696504319290661,0.0128504122828961,0.549776607886737,0.0172469093888087,0.338361913064034,0.0210736024147001,0.144153484994011,0.0199609192689678,0.0380479581477159,0.0125672324663714,0,0,0.039910401665453,-0.0122616262553296,0.148421317779882,-0.0189985047612047,0.328374676921391,-0.0200082753150125,0.517844762768298,-0.0170640723341493,0.689480272273693,-0.0124374907256732,0.832528496272264,-0.00733475049348438,0.973498898866872,-0.00145287762346223,1,0],"Bot_Xtr":1,"sym":0.000512697600456184,"alpha":0,"CDpres":0.00218,"clcd":70.5360006711805,"CDp":0.00047607616930975,"CL":0.00372942980537636,"CD":0.0141771576285098,"n":12,"Cpmin":-0.201887726045925,"CDf":0.012,"r":6,"id":1077,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt35.1540521112329>31.6019589820895) l1 Foil spline 17pts Re12500 N7","good":66.0934094532176,"xver":6.991,"iver":1.2020052,"Cm":-0.000538263063660028},
             {"xy":[1,0,0.801235107180673,0.00775331836188269,0.632392839686874,0.014796135354975,0.41012406326402,0.0268590010988351,0.251193047118843,0.0308614199026755,0.128621890131565,0.0269900407543237,0.0597303880338732,0.0192687781384809,0.0238258795790934,0.0118290548639802,0,0,0.0235934150860801,-0.0117767680103831,0.0511837449510818,-0.0176486833914061,0.104435976234778,-0.0248125662632416,0.210350577998097,-0.0302548864056997,0.366049363276158,-0.0285324296563584,0.564864782236522,-0.0184475730570271,0.760314714100426,-0.00955204420354881,1,0],"Bot_Xtr":1,"sym":3.95491081523972e-05,"alpha":0,"clcd":70.4798664737974,"CDpres":0.00279,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_mg05.dat-s17_n17s0_nsopt-Re12500-N10.dat","diter":3,"src":"retest_70.txt","Re":45000,"r":6,"id":1078,"good":64.0996209423328,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mg05.dat-s17_n17s0.dat (opt35.4073832624108>31.9794647214962) l1 Foil spline 17pts Re12500 N10","xver":6.991,"iver":1.2020052,"Cm":0.000150697906430355,"CDp":0.000970813720195423,"CL":0.000353867531208283,"CD":0.0141884491278339,"n":13,"Cpmin":-0.256469253591397,"CDf":0.0114},
             {"n":14,"CL":-0.000116173119945338,"CD":0.0146956981911666,"CDp":0.000843850616905232,"CDf":0.01194,"Cpmin":-0.214394604986914,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt31.320218818733>30.5511915050191) l1 Foil spline 17pts Re10000 N9","xver":6.991,"iver":1.2020052,"good":65.0125888051987,"id":1079,"r":6,"Cm":1.24373434016347e-05,"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re10000-N9.dat","Top_Xtr":1,"Re":45000,"src":"retest_95.txt","sym":5.602591368312e-06,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00722047452282592,0.672127682508641,0.0171720258577474,0.448051878989487,0.0244562376132057,0.261607586958807,0.026114372832153,0.14960260982261,0.0232235315084548,0.0876932172572549,0.019398591721823,0.0269668136105797,0.0119521332669733,0,0,0.0260784653873372,-0.011720472489085,0.0852103572234493,-0.0192267641865396,0.159346520639483,-0.0237148898924273,0.277295492850028,-0.0262344169593155,0.461088095254591,-0.0241913021086838,0.679515403216876,-0.0168964674402443,0.887295989576364,-0.00703359117734801,1,0],"clcd":68.0471241986373,"CDpres":0.00276,"alpha":0},
             {"n":3,"CL":0.00172708302518272,"CD":0.0128938493829729,"CDp":0.000699347745190252,"CDf":0.01056,"Cpmin":-0.212574710228346,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt66.0705109402994>43.107043899686) l1 Foil spline 17pts Re65536 N3","xver":6.991,"good":62.943030480817,"iver":1.2020052,"id":1080,"r":6,"Cm":-0.000266659391987891,"diter":3,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re65536-N3.dat","Top_Xtr":1,"Re":55000,"src":"retest_101.txt","sym":0.0010387559649789,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00108853034818267,0.846603687659606,0.006586471716744,0.652049868216663,0.0157264825239825,0.479143275669244,0.0229188273868122,0.293993827172706,0.0269690182327718,0.148391481755207,0.0241475459343756,0.0488930707148337,0.0148791803907569,0,0,0.0372961728230362,-0.0143456367248267,0.141024649091098,-0.0250092615048339,0.309704810294,-0.02764463967484,0.516173420171465,-0.0220389544319362,0.694999251146369,-0.01400556734691,0.795598835662968,-0.0091673065747108,0.902196709833545,-0.00421235230707511,1,0],"CDpres":0.00234,"clcd":77.5563580974163,"alpha":0},
             {"alpha":0,"CDpres":0.00234,"clcd":77.5563580974163,"Bot_Xtr":1,"xy":[1,0,0.972922049750542,0.00108853034818267,0.846603687659606,0.006586471716744,0.652049868216663,0.0157264825239825,0.479143275669244,0.0229188273868122,0.293993827172706,0.0269690182327718,0.148391481755207,0.0241475459343756,0.0488930707148337,0.0148791803907569,0,0,0.0372961728230362,-0.0143456367248267,0.141024649091098,-0.0250092615048339,0.309704810294,-0.02764463967484,0.516173420171465,-0.0220389544319362,0.694999251146369,-0.01400556734691,0.795598835662968,-0.0091673065747108,0.902196709833545,-0.00421235230707511,1,0],"sym":0.0010387559649789,"src":"retest_102.txt","Re":55000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re65536-N3.dat","diter":3,"Cm":-0.000266659391987903,"r":6,"id":1081,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt66.0705109402994>43.107043899686) l1 Foil spline 17pts Re65536 N3","iver":1.2020052,"good":66.2068755007486,"Cpmin":-0.212574710228346,"CDf":0.01056,"CDp":0.000699347745190253,"CD":0.0128938493829729,"CL":0.00172708302518278,"n":4},
             {"Cm":0.000173399148539921,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt74.5629185185408>48.7991713041488) l1 Foil spline 17pts Re80000 N4","xver":6.991,"good":68.2538200434216,"iver":1.2020052,"id":1082,"r":6,"CDf":0.01049,"Cpmin":-0.231562679850003,"n":5,"CL":-0.00200776741866458,"CD":0.0127803727203724,"CDp":0.000592245484523184,"clcd":78.2449793820149,"CDpres":0.00229,"alpha":0,"sym":0.00010337954565373,"xy":[1,0,0.888395795100267,0.00455982762032328,0.724782775337367,0.0108553159604154,0.573493663117091,0.0178374229416753,0.434846152115145,0.0228906990606218,0.296738332433587,0.0257352119735984,0.156304320466368,0.0243290844353621,0.0490216324689624,0.016115876530086,0,0,0.0501864526744944,-0.0165875395368357,0.168411092824914,-0.0252642010247127,0.326746855954174,-0.025897163260092,0.462695012305671,-0.0224153526422949,0.564195027615659,-0.0185825585352616,0.67400816885005,-0.0134981878911355,0.86979319971664,-0.00499983466651039,1,0],"Bot_Xtr":1,"Re":55000,"src":"retest_110.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re80000-N4.dat","Top_Xtr":1},
             {"Foil_fn":"optbs_spline_sym_hn274s.dat-s17_n17s0_nsopt-Re65536-N3.dat","Top_Xtr":1,"diter":3,"src":"retest_104.txt","Re":55000,"xy":[1,0,0.972922049750542,0.00108853034818267,0.846603687659606,0.006586471716744,0.652049868216663,0.0157264825239825,0.479143275669244,0.0229188273868122,0.293993827172706,0.0269690182327718,0.148391481755207,0.0241475459343756,0.0488930707148337,0.0148791803907569,0,0,0.0372961728230362,-0.0143456367248267,0.141024649091098,-0.0250092615048339,0.309704810294,-0.02764463967484,0.516173420171465,-0.0220389544319362,0.694999251146369,-0.01400556734691,0.795598835662968,-0.0091673065747108,0.902196709833545,-0.00421235230707511,1,0],"Bot_Xtr":1,"sym":0.0010387559649789,"alpha":0,"clcd":77.5563580974164,"CDpres":0.00234,"CDp":0.000699347745190254,"n":6,"CD":0.0128938493829729,"CL":0.00172708302518291,"Cpmin":-0.212574710228346,"CDf":0.01056,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn274s.dat-s17_n17s0.dat (opt66.0705109402994>43.107043899686) l1 Foil spline 17pts Re65536 N3","xver":6.991,"iver":1.2020052,"good":69.0173916957381,"id":1083,"Cm":-0.000266659391987908},
             {"sym":0.000145869776170288,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00722394104464662,0.672127682508641,0.0171802700807764,0.448051878989487,0.0244679789580536,0.261607586958807,0.0261269102412901,0.14960260982261,0.0232346810358818,0.0876932172572549,0.0194079049104898,0.0269668136105797,0.0119578714398099,0,0,0.0260784653873372,-0.0114348888494632,0.0852103572234493,-0.0187582805738136,0.159346520639483,-0.02313704761047,0.277295492850028,-0.0255951833204348,0.461088095254591,-0.0236018514606982,0.679515403216876,-0.0164847643563601,0.887295989576364,-0.00686220913025822,1,0],"clcd":75.1986469224297,"CDpres":0.00252,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re80000-N5.dat","Top_Xtr":1,"Re":55000,"src":"retest_74.txt","good":68.6338680394725,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt77.0948754487545>72.1856069331944) l1 Foil spline 17pts Re80000 N5","xver":6.991,"iver":1.2020052,"id":1084,"r":6,"Cm":-0.000238135704746024,"n":7,"CD":0.0132981116140499,"CL":0.00153325476044336,"CDp":0.000722181674387724,"CDf":0.01078,"Cpmin":-0.213756900318338},
             {"sym":0.000362474211347171,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00146126236079956,0.838375902301386,0.00675664336084454,0.669468112967632,0.0158945379326744,0.498697719332731,0.0231724824606769,0.301319859646249,0.0252519328112316,0.134615624611079,0.0207170236715095,0.0376550591335466,0.0117657870382813,0,0,0.0409493023355519,-0.0118892775652844,0.14830924318344,-0.0205862344881318,0.317279938768802,-0.02434149028997,0.498956936169248,-0.0222266943504308,0.653261727003669,-0.0160871801967247,0.844873051243488,-0.00618287009676205,0.969355895385625,-0.0011463740676587,1,0],"clcd":77.9634463593682,"CDpres":0.00216,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re30000-N4.dat","Re":55000,"src":"retest_108.txt","id":1085,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt52.8763045819518>48.5303195011039) l1 Foil spline 17pts Re30000 N4","good":71.0308623095672,"iver":1.2020052,"r":6,"Cm":-0.000513710951212161,"CL":0.00309967932804684,"CD":0.0128265237966849,"n":8,"CDp":0.000543275326916765,"CDf":0.01067,"Cpmin":-0.16602764919024},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re12500-N7.dat","diter":3,"src":"retest_86.txt","Re":55000,"xy":[1,0,0.969087652468728,0.00176514861384408,0.801860568053254,0.00901605150262981,0.696504319290661,0.0128504122828961,0.549776607886737,0.0172469093888087,0.338361913064034,0.0210736024147001,0.144153484994011,0.0199609192689678,0.0380479581477159,0.0125672324663714,0,0,0.039910401665453,-0.0122616262553296,0.148421317779882,-0.0189985047612047,0.328374676921391,-0.0200082753150125,0.517844762768298,-0.0170640723341493,0.689480272273693,-0.0124374907256732,0.832528496272264,-0.00733475049348438,0.973498898866872,-0.00145287762346223,1,0],"Bot_Xtr":1,"sym":0.000512697600456184,"alpha":0,"CDpres":0.00201,"clcd":77.9524584310871,"CDp":0.000401654003438773,"CD":0.0128283317823008,"CL":0.00371775440313309,"n":9,"Cpmin":-0.201824570330644,"CDf":0.01082,"r":6,"id":1086,"good":71.9496725654806,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt35.1540521112329>31.6019589820895) l1 Foil spline 17pts Re12500 N7","xver":6.991,"iver":1.2020052,"Cm":-0.000528442466066403},
             {"id":1087,"good":71.388605954368,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt89.3658123602953>56.8811725034642) l1 Foil spline 17pts Re125000 N5","xver":6.991,"iver":1.2020052,"r":6,"Cm":6.50576055701761e-05,"CD":0.0128206839930758,"CL":1.50473795568186e-05,"n":10,"CDp":0.000667311329941354,"CDf":0.01043,"Cpmin":-0.238475020618282,"sym":9.42238048931044e-06,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.00436213006613235,0.724782775337367,0.011317752819412,0.573493663117091,0.0185972978147626,0.434846152115145,0.023865843682154,0.296738332433587,0.0268315329497986,0.156304320466368,0.0253655043267388,0.0490216324689624,0.016802413462749,0,0,0.0501864526744944,-0.0169629441883576,0.168411092824914,-0.0258359735025175,0.326746855954174,-0.0264832607658416,0.462695012305671,-0.0229226507637996,0.564195027615659,-0.0190031139103263,0.67400816885005,-0.0138036751823757,0.86979319971664,-0.0052226509533086,1,0],"clcd":77.998958600031,"CDpres":0.00239,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N5.dat","Re":55000,"src":"retest_96.txt"},
             {"CD":0.0128674055262756,"CL":-0.000722308415076813,"n":11,"CDp":0.000487242541410699,"CDf":0.01071,"Cpmin":-0.186410306787027,"id":1088,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt57.8594107712462>49.3558429087721) l1 Foil spline 17pts Re35000 N8","iver":1.2020052,"good":71.9051836962976,"r":6,"Cm":0.000114056370943212,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re35000-N8.dat","Re":55000,"src":"retest_90.txt","sym":2.08959922333369e-05,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00215789755329527,0.814149693519042,0.00838417079736187,0.682864593067749,0.014505918417658,0.52069384686288,0.0205851621466052,0.325213183352731,0.0241103716819945,0.152815219118241,0.0217199592010019,0.0429551112266143,0.0131985482946086,0,0,0.0408398189079085,-0.0130010702579258,0.136824284769333,-0.0211755851291419,0.289192311415617,-0.024400802251214,0.490511679687803,-0.0216624191333617,0.680813751073162,-0.0147496715580259,0.840165601920523,-0.00717829042270853,0.955145580885723,-0.00172427662409608,1,0],"CDpres":0.00216,"clcd":77.7157444799551,"alpha":0},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt89.3658123602953>56.8811725034642) l1 Foil spline 17pts Re125000 N5","xver":6.991,"good":71.9726627730968,"iver":1.2020052,"id":1089,"Cm":6.50576055701761e-05,"CDp":0.000667311329941354,"n":12,"CL":1.50473795568186e-05,"CD":0.0128206839930758,"Cpmin":-0.238475020618282,"CDf":0.01043,"xy":[1,0,0.888395795100267,0.00436213006613235,0.724782775337367,0.011317752819412,0.573493663117091,0.0185972978147626,0.434846152115145,0.023865843682154,0.296738332433587,0.0268315329497986,0.156304320466368,0.0253655043267388,0.0490216324689624,0.016802413462749,0,0,0.0501864526744944,-0.0169629441883576,0.168411092824914,-0.0258359735025175,0.326746855954174,-0.0264832607658416,0.462695012305671,-0.0229226507637996,0.564195027615659,-0.0190031139103263,0.67400816885005,-0.0138036751823757,0.86979319971664,-0.0052226509533086,1,0],"Bot_Xtr":1,"sym":9.42238048931044e-06,"alpha":0,"CDpres":0.00239,"clcd":77.998958600031,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_98.txt","Re":55000},
             {"Cm":0.000203950247429532,"id":1090,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt48.8204114511181>44.9329060065433) l1 Foil spline 17pts Re25000 N6","good":73.4107174119991,"iver":1.2020052,"r":6,"CDf":0.0109,"Cpmin":-0.158211265191224,"CL":-0.00133157056029035,"CD":0.0128164106787488,"n":13,"CDp":0.000350254699188944,"clcd":78.024965418604,"CDpres":0.00191,"alpha":0,"sym":9.97489712681148e-05,"xy":[1,0,0.927533762368065,0.00368426135712283,0.828124577508512,0.00779574206723884,0.673910782200253,0.0132433045326806,0.485356610471494,0.018232738384005,0.298817780508802,0.0203349814353364,0.140740099512849,0.0177924176422056,0.0345490619416974,0.0103097731268547,0,0,0.033827731492854,-0.010362007320024,0.142528433402255,-0.0182623426320101,0.31046792119717,-0.0207461376263511,0.499715124890922,-0.0182918029524808,0.684159552318164,-0.0131835573867054,0.829477323686799,-0.00789704929891698,0.922486667396241,-0.00400431355170412,1,0],"Bot_Xtr":1,"Re":55000,"src":"retest_78.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re25000-N6.dat"},
             {"Cpmin":-0.186410306787027,"CDf":0.01071,"CDp":0.000487242541410699,"CD":0.0128674055262756,"CL":-0.000722308415076813,"n":14,"Cm":0.000114056370943212,"r":6,"id":1091,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt57.8594107712462>49.3558429087721) l1 Foil spline 17pts Re35000 N8","iver":1.2020052,"xver":6.991,"good":72.3033443576362,"src":"retest_93.txt","Re":55000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re35000-N8.dat","diter":3,"alpha":0,"clcd":77.7157444799551,"CDpres":0.00216,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00215789755329527,0.814149693519042,0.00838417079736187,0.682864593067749,0.014505918417658,0.52069384686288,0.0205851621466052,0.325213183352731,0.0241103716819945,0.152815219118241,0.0217199592010019,0.0429551112266143,0.0131985482946086,0,0,0.0408398189079085,-0.0130010702579258,0.136824284769333,-0.0211755851291419,0.289192311415617,-0.024400802251214,0.490511679687803,-0.0216624191333617,0.680813751073162,-0.0147496715580259,0.840165601920523,-0.00717829042270853,0.955145580885723,-0.00172427662409608,1,0],"sym":2.08959922333369e-05},
             {"Re":65536,"src":"retest_64.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re45000-N3.dat","clcd":83.6803569734915,"CDpres":0.002,"alpha":0.1,"sym":0.000745132181348914,"xy":[1,0,0.883609074234346,0.00613637673841589,0.672127682508641,0.0145937804630209,0.448051878989487,0.0207843247870241,0.261607586958807,0.0221935039697123,0.14960260982261,0.0197366998639552,0.0876932172572549,0.0164860448746842,0.0269668136105797,0.0101576139244097,0,0,0.0260784653873372,-0.0105676890749233,0.0852103572234493,-0.0173356889860404,0.159346520639483,-0.0213823788300856,0.277295492850028,-0.0236540942991952,0.461088095254591,-0.0218119328585245,0.679515403216876,-0.0152345918254876,0.887295989576364,-0.00634179250977791,1,0],"Bot_Xtr":1,"CDf":0.00995,"Cpmin":-0.204658698404629,"CL":0.00472389470630335,"CD":0.0119502358279469,"n":3,"CDp":0.00037704615040843,"Cm":0.0010368229401642,"id":1092,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt58.8362349161742>55.5538215181957) l1 Foil spline 17pts Re45000 N3","good":67.130320242297,"iver":1.2020052,"r":6},
             {"src":"retestc_0.txt","Re":65536,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re65536-N4.dat","diter":3,"alpha":0,"CDpres":0.00212,"clcd":85.274248628758,"Bot_Xtr":1,"xy":[1,0,0.794574379082928,0.00840544745590799,0.546030639687268,0.0206997188729232,0.363514019175692,0.0273995342967417,0.221984972352103,0.0276313289001673,0.122670417262654,0.0232455851158557,0.0658532742824706,0.0176562322503954,0.0236940673606567,0.0106234488008357,0,0,0.0239783675371822,-0.0105990718499956,0.0623361812874123,-0.0169074680709262,0.114829236142557,-0.0223575842624095,0.214306107242777,-0.0270804057763848,0.357389074847702,-0.0271430406719011,0.542695962832085,-0.0205812592851724,0.784157786565453,-0.00875727561321903,1,0],"sym":5.66847746830774e-05,"Cpmin":-0.204262817761523,"CDf":0.00961,"CDp":0.000534854600489793,"CL":0.00130097871027893,"CD":0.0117268696714468,"n":4,"Cm":-0.000168084567870672,"r":6,"id":1093,"good":71.255103676135,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt71.2551036562789>50.6450903523389) l1 Foil spline 17pts Re65536 N4","xver":6.991,"iver":1.2020052},
             {"Re":65536,"src":"retest_101.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N5.dat","clcd":85.1626150428481,"CDpres":0.00221,"alpha":0,"sym":9.42238048931044e-06,"xy":[1,0,0.888395795100267,0.00436213006613235,0.724782775337367,0.011317752819412,0.573493663117091,0.0185972978147626,0.434846152115145,0.023865843682154,0.296738332433587,0.0268315329497986,0.156304320466368,0.0253655043267388,0.0490216324689624,0.016802413462749,0,0,0.0501864526744944,-0.0169629441883576,0.168411092824914,-0.0258359735025175,0.326746855954174,-0.0264832607658416,0.462695012305671,-0.0229226507637996,0.564195027615659,-0.0190031139103263,0.67400816885005,-0.0138036751823757,0.86979319971664,-0.0052226509533086,1,0],"Bot_Xtr":1,"CDf":0.00953,"Cpmin":-0.238599381297496,"CD":0.0117422415868379,"CL":1.36051486590834e-05,"n":5,"CDp":0.000583605159962879,"Cm":6.65678391354165e-05,"id":1094,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt89.3658123602953>56.8811725034642) l1 Foil spline 17pts Re125000 N5","iver":1.2020052,"good":72.5984726880822,"r":6},
             {"Cpmin":-0.322138776854751,"CDf":0.00926,"CDp":0.000908308238549487,"CD":0.0117731592940317,"CL":-0.00290918912086133,"n":6,"Cm":6.94909130475001e-05,"r":6,"id":1095,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt56.7849713067586>47.2294203694912) l1 Foil spline 17pts Re35000 N12","good":73.7615418617912,"xver":6.991,"iver":1.2020052,"src":"retest_72.txt","Re":65536,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re35000-N12.dat","diter":3,"alpha":0,"clcd":84.9389679545866,"CDpres":0.00251,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.0058258728073934,0.751503599940214,0.00947742009447672,0.617882281805394,0.0152044991989017,0.516474874255053,0.0194137248652718,0.425516435642791,0.0229601318612971,0.22020135983351,0.0277537836731126,0.0597789339840893,0.0209923584926892,0,0,0.0545974187204916,-0.0208011909394731,0.191614124162238,-0.028459073019635,0.354272483283979,-0.0259567459223354,0.461006103363399,-0.0222567085684047,0.600655324159936,-0.0163881639716891,0.736649107785801,-0.0103903593510629,0.846409340674087,-0.0058319511771152,1,0],"sym":0.000268053028847243},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N5.dat","Re":65536,"src":"retest_103.txt","sym":9.42238048931044e-06,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.00436213006613235,0.724782775337367,0.011317752819412,0.573493663117091,0.0185972978147626,0.434846152115145,0.023865843682154,0.296738332433587,0.0268315329497986,0.156304320466368,0.0253655043267388,0.0490216324689624,0.016802413462749,0,0,0.0501864526744944,-0.0169629441883576,0.168411092824914,-0.0258359735025175,0.326746855954174,-0.0264832607658416,0.462695012305671,-0.0229226507637996,0.564195027615659,-0.0190031139103263,0.67400816885005,-0.0138036751823757,0.86979319971664,-0.0052226509533086,1,0],"clcd":85.1626150428481,"CDpres":0.00221,"alpha":0,"CD":0.0117422415868379,"CL":1.36051486591236e-05,"n":7,"CDp":0.000583605159962878,"CDf":0.00953,"Cpmin":-0.238599381297496,"id":1096,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt89.3658123602953>56.8811725034642) l1 Foil spline 17pts Re125000 N5","iver":1.2020052,"good":75.3082876889627,"r":6,"Cm":6.65678391354263e-05},
             {"Cm":-7.62302001121148e-05,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt79.9041100798203>66.1158723004061) l1 Foil spline 17pts Re100000 N6","xver":6.991,"good":77.3211286434965,"id":1097,"r":6,"CDf":0.00972,"Cpmin":-0.202268121688191,"n":8,"CD":0.0124193909659596,"CL":0.000437969143571495,"CDp":0.00107843453489127,"CDpres":0.0027,"clcd":80.5192462932286,"alpha":0,"sym":7.78622856638931e-05,"xy":[1,0,0.927533762368065,0.00509371427026252,0.828124577508512,0.0107780851481695,0.673910782200253,0.018309669902525,0.485356610471494,0.0252078641253336,0.298817780508802,0.0281143423558817,0.140740099512849,0.0245990940548662,0.0345490619416974,0.0142538852185122,0,0,0.033827731492854,-0.0139396676646752,0.142528433402255,-0.0245677289357541,0.31046792119717,-0.027909096655249,0.499715124890922,-0.0246073609360001,0.684159552318164,-0.0177354061749901,0.829477323686799,-0.0106236407057666,0.922486667396241,-0.00538687132830373,1,0],"Bot_Xtr":1,"Re":65536,"src":"retest_100.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re100000-N6.dat","Top_Xtr":1},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re55000-N8.dat","Re":65536,"src":"retestc_10.txt","sym":5.8140938024644e-05,"Bot_Xtr":1,"xy":[1,0,0.927533762368065,0.00475175836727135,0.828124577508512,0.0100545208405139,0.673910782200253,0.0170804883323021,0.485356610471494,0.0235155866472306,0.298817780508802,0.0262269445127331,0.140740099512849,0.0229476850880528,0.0345490619416974,0.0132969803093607,0,0,0.033827731492854,-0.0131385668655504,0.142528433402255,-0.0231558425295245,0.31046792119717,-0.02630518469901,0.499715124890922,-0.0231931969125538,0.684159552318164,-0.0167161675244452,0.829477323686799,-0.010013109144776,0.922486667396241,-0.00507729243232886,1,0],"clcd":81.6837590555661,"CDpres":0.00246,"alpha":0,"CL":-0.000221418091581821,"CD":0.012242335704944,"n":9,"CDp":0.000889661651624116,"CDf":0.00978,"Cpmin":-0.192967739961411,"id":1098,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt69.1404640752122>62.6643825642499) l1 Foil spline 17pts Re55000 N8","xver":6.991,"iver":1.2020052,"good":74.7064160782711,"r":6,"Cm":2.1692927651741e-05},
             {"CDf":0.00993,"Cpmin":-0.16482782068475,"CD":0.011848014683614,"CL":-0.00015069789325528,"n":10,"CDp":0.000408868230039417,"Cm":1.25619961704421e-05,"id":1099,"good":77.6367907182109,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt49.0468067604603>44.4009272159618) l1 Foil spline 17pts Re25000 N4","xver":6.991,"iver":1.2020052,"r":6,"Re":65536,"src":"retest_93.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re25000-N4.dat","CDpres":0.00192,"clcd":84.4023261874425,"alpha":0,"sym":3.88497709231284e-05,"xy":[1,0,0.927533762368065,0.00394139205294452,0.828124577508512,0.00833981980437335,0.673910782200253,0.0141675766674149,0.485356610471494,0.0195052313623737,0.298817780508802,0.0217541934344744,0.140740099512849,0.0190341799074818,0.0345490619416974,0.0110293092511708,0,0,0.033827731492854,-0.0108853664710516,0.142528433402255,-0.0191847280193659,0.31046792119717,-0.0217939733052787,0.499715124890922,-0.0192156763071613,0.684159552318164,-0.0138494259957824,0.829477323686799,-0.00829590956691909,0.922486667396241,-0.00420656144404237,1,0],"Bot_Xtr":1},
             {"sym":5.67031841182928e-05,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00238697218538699,0.814149693519042,0.00927420417168352,0.682864593067749,0.0160458144704633,0.52069384686288,0.0227704088178761,0.325213183352731,0.0266698419006865,0.152815219118241,0.024025671840334,0.0429551112266143,0.0145996586439462,0,0,0.0408398189079085,-0.0140354296195036,0.136824284769333,-0.022860305254538,0.289192311415617,-0.026342119214959,0.490511679687803,-0.0233858715553926,0.680813751073162,-0.0159231488605535,0.840165601920523,-0.00774939201292774,0.955145580885723,-0.00186145930465242,1,0],"CDpres":0.00229,"clcd":83.5118847323007,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re55000-N5.dat","Top_Xtr":1,"Re":65536,"src":"retest_81.txt","iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt67.443268224336>56.7266443076749) l1 Foil spline 17pts Re55000 N5","xver":6.991,"good":76.3686448039231,"id":1100,"r":6,"Cm":-0.000160856165818686,"n":11,"CL":0.00107534796047252,"CD":0.0119743435704454,"CDp":0.000629492554305842,"CDf":0.00969,"Cpmin":-0.200028362346978},
             {"xy":[1,0,0.883609074234346,0.00724077271891507,0.672127682508641,0.0172202998523452,0.448051878989487,0.0245249889819843,0.261607586958807,0.0261877855502253,0.14960260982261,0.0232888174941544,0.0876932172572549,0.0194531250377953,0.0269668136105797,0.0119857331008859,0,0,0.0260784653873372,-0.0117636653172521,0.0852103572234493,-0.0192976195485988,0.159346520639483,-0.02380228510325,0.277295492850028,-0.0263310972480021,0.461088095254591,-0.0242804530158757,0.679515403216876,-0.0169587350847832,0.887295989576364,-0.00705951169338556,1,0],"Bot_Xtr":1,"sym":6.5942924318351e-06,"alpha":0,"clcd":81.5642493319695,"CDpres":0.00243,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re25000-N8.dat","diter":3,"src":"retest_86.txt","Re":65536,"r":6,"id":1101,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt48.5640202614114>46.7905001385444) l1 Foil spline 17pts Re25000 N8","xver":6.991,"iver":1.2020052,"good":75.2054904868368,"Cm":1.94879188679267e-05,"CDp":0.000689395155394244,"CD":0.0122602734432087,"CL":-0.000168203349929871,"n":12,"Cpmin":-0.215542874233192,"CDf":0.00983},
             {"Cm":-0.000218649666237326,"id":1102,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt44.6963667387654>40.8736556608881) l1 Foil spline 17pts Re20000 N12","xver":6.991,"good":74.6588126589638,"iver":1.2020052,"r":6,"CDf":0.00931,"Cpmin":-0.315313222953679,"CD":0.0117364547448774,"CL":-0.000401923707066644,"n":13,"CDp":0.000833359969617613,"CDpres":0.00242,"clcd":85.2046057977148,"alpha":0,"sym":6.44776707251984e-05,"xy":[1,0,0.857899050218291,0.00586574649043476,0.751503599940214,0.00934192392399973,0.617882281805394,0.0149871244919735,0.516474874255053,0.0191361719713708,0.425516435642791,0.0226318769237888,0.22020135983351,0.0273569951624771,0.0597789339840893,0.0206922362910051,0,0,0.0545974187204916,-0.0199415327171994,0.191614124162238,-0.0272829347787618,0.354272483283979,-0.0248840222441319,0.461006103363399,-0.0213368976509792,0.600655324159936,-0.0157108844857583,0.736649107785801,-0.00996095327164609,0.846409340674087,-0.0055909320548979,1,0],"Bot_Xtr":1,"Re":65536,"src":"retest_97.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re20000-N12.dat"},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re25000-N8.dat","diter":3,"src":"retest_88.txt","Re":65536,"xy":[1,0,0.883609074234346,0.00724077271891507,0.672127682508641,0.0172202998523452,0.448051878989487,0.0245249889819843,0.261607586958807,0.0261877855502253,0.14960260982261,0.0232888174941544,0.0876932172572549,0.0194531250377953,0.0269668136105797,0.0119857331008859,0,0,0.0260784653873372,-0.0117636653172521,0.0852103572234493,-0.0192976195485988,0.159346520639483,-0.02380228510325,0.277295492850028,-0.0263310972480021,0.461088095254591,-0.0242804530158757,0.679515403216876,-0.0169587350847832,0.887295989576364,-0.00705951169338556,1,0],"Bot_Xtr":1,"sym":6.5942924318351e-06,"alpha":0,"CDpres":0.00243,"clcd":81.5642493319818,"CDp":0.000689395155398778,"CL":-0.000168203349943044,"CD":0.0122602734432069,"n":14,"Cpmin":-0.215542874232839,"CDf":0.00983,"r":6,"id":1103,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt48.5640202614114>46.7905001385444) l1 Foil spline 17pts Re25000 N8","xver":6.991,"good":76.2990583327353,"iver":1.2020052,"Cm":1.94879188670385e-05},
             {"src":"retestc_9.txt","Re":80000,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re80000-N3.dat","Top_Xtr":1,"diter":3,"alpha":0.1,"CDpres":0.00177,"clcd":93.1577325099265,"Bot_Xtr":1,"xy":[1,0,0.927533762368065,0.00379884575662034,0.828124577508512,0.00803819783701888,0.673910782200253,0.0136551852192411,0.485356610471494,0.0187997957060616,0.298817780508802,0.0209674207252517,0.140740099512849,0.0183457805265188,0.0345490619416974,0.0106304179042433,0,0,0.033827731492854,-0.0110905904132103,0.142528433402255,-0.0195464214473132,0.31046792119717,-0.0222048593447065,0.499715124890922,-0.0195779532092287,0.684159552318164,-0.014110531931632,0.829477323686799,-0.00845231397182753,0.922486667396241,-0.00428586856932611,1,0],"sym":0.000624092386469489,"Cpmin":-0.181737022283892,"CDf":0.00897,"CDp":0.000332731346191367,"n":3,"CL":0.00516846716945962,"CD":0.0107344819700656,"Cm":0.000977585320377105,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt71.8498416676805>52.7850198520138) l1 Foil spline 17pts Re80000 N3","xver":6.991,"good":71.8498417087731,"iver":1.2020052,"id":1104},
             {"src":"retestc_10.txt","Re":80000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re80000-N4.dat","diter":3,"alpha":0,"clcd":93.788258833237,"CDpres":0.00204,"Bot_Xtr":1,"xy":[1,0,0.794574379082928,0.00861472502075508,0.546030639687268,0.0212150973559211,0.363514019175692,0.02808172377513,0.221984972352103,0.0283192895656821,0.122670417262654,0.0238243501931476,0.0658532742824706,0.0180958344618327,0.0236940673606567,0.0108879498291247,0,0,0.0239783675371822,-0.0109627017912082,0.0623361812874123,-0.0174875246747209,0.114829236142557,-0.0231246219017476,0.214306107242777,-0.0280094726324117,0.357389074847702,-0.0280742563881015,0.542695962832085,-0.0212873552726197,0.784157786565453,-0.00905771773319752,1,0],"sym":1.21470172848609e-05,"Cpmin":-0.20917870795947,"CDf":0.00863,"CDp":0.000519981794436477,"CD":0.0106623154373521,"CL":0.000481447425136097,"n":4,"Cm":-5.58574271351807e-05,"r":6,"id":1105,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt75.792349965309>51.4087592390826) l1 Foil spline 17pts Re80000 N4","xver":6.991,"iver":1.2020052,"good":75.7923499642317},
             {"n":5,"CL":1.30702786709042e-05,"CD":0.0106303961014449,"CDp":0.000496036782231209,"CDf":0.0086,"Cpmin":-0.238719242758893,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt89.3658123602953>56.8811725034642) l1 Foil spline 17pts Re125000 N5","iver":1.2020052,"xver":6.991,"good":77.7926280876894,"id":1106,"r":6,"Cm":6.79604377167782e-05,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N5.dat","Top_Xtr":1,"Re":80000,"src":"retest_111.txt","sym":9.42238048931044e-06,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.00436213006613235,0.724782775337367,0.011317752819412,0.573493663117091,0.0185972978147626,0.434846152115145,0.023865843682154,0.296738332433587,0.0268315329497986,0.156304320466368,0.0253655043267388,0.0490216324689624,0.016802413462749,0,0,0.0501864526744944,-0.0169629441883576,0.168411092824914,-0.0258359735025175,0.326746855954174,-0.0264832607658416,0.462695012305671,-0.0229226507637996,0.564195027615659,-0.0190031139103263,0.67400816885005,-0.0138036751823757,0.86979319971664,-0.0052226509533086,1,0],"clcd":94.0698719461712,"CDpres":0.00203,"alpha":0},
             {"Cm":-6.48265067077309e-05,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt99.6223772427113>69.7602800923986) l1 Foil spline 17pts Re150000 N5","xver":6.991,"good":78.1290934514317,"iver":1.2020052,"id":1107,"r":6,"CDf":0.00863,"Cpmin":-0.217443227835145,"n":6,"CD":0.0110819109195362,"CL":0.000461050782787014,"CDp":0.000786311884582382,"CDpres":0.00245,"clcd":90.2371447723068,"alpha":0,"sym":1.65743451766806e-05,"xy":[1,0,0.944740406454351,0.00259865098066909,0.814149693519042,0.0100966487641595,0.682864593067749,0.0174687714270719,0.52069384686288,0.0247897087226496,0.325213183352731,0.0290349469649444,0.152815219118241,0.0261562895752786,0.0429551112266143,0.0158943692284265,0,0,0.0408398189079085,-0.0153968043270399,0.136824284769333,-0.0250776539373913,0.289192311415617,-0.0288971884799794,0.490511679687803,-0.025654197849086,0.680813751073162,-0.0174676240003077,0.840165601920523,-0.00850104882509426,0.955145580885723,-0.00204201263897575,1,0],"Bot_Xtr":1,"Re":80000,"src":"retest_66.txt","diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re150000-N5.dat","Top_Xtr":1},
             {"Cm":0.000113179955478149,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt87.8388189569664>59.0689594271922) l1 Foil spline 17pts Re100000 N5","good":79.1543702900786,"xver":6.991,"iver":1.2020052,"id":1108,"Cpmin":-0.225240966009634,"CDf":0.00851,"CDp":0.00072008520352514,"n":7,"CD":0.0107997294229535,"CL":-0.000792111065204633,"alpha":0,"CDpres":0.00229,"clcd":92.5949124127709,"Bot_Xtr":1,"xy":[1,0,0.794574379082928,0.00921453199993958,0.546030639687268,0.0226922151313001,0.363514019175692,0.0300369357949303,0.221984972352103,0.0302910422897817,0.122670417262654,0.0254831392416613,0.0658532742824706,0.0193557711142766,0.0236940673606567,0.0116460318666576,0,0,0.0239783675371822,-0.0118890386786991,0.0623361812874123,-0.01896520230252,0.114829236142557,-0.0250786283761413,0.214306107242777,-0.0303762439076623,0.357389074847702,-0.030446501823258,0.542695962832085,-0.0230861146297305,0.784157786565453,-0.00982308545116921,1,0],"sym":3.20657150509678e-05,"src":"retest_155.txt","Re":80000,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N5.dat","Top_Xtr":1,"diter":3},
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt80.2831864934908>51.9448045577382) l1 Foil spline 17pts Re100000 N4","iver":1.2020052,"good":81.6241927052448,"id":1109,"r":6,"Cm":-0.000173113292817998,"n":8,"CD":0.0106888260730705,"CL":0.00136276271207828,"CDp":0.000559082655745204,"CDf":0.0086,"Cpmin":-0.213340584093815,"sym":6.49868625513952e-05,"Bot_Xtr":1,"xy":[1,0,0.794574379082928,0.00879061839652528,0.546030639687268,0.0216482620921415,0.363514019175692,0.0286550896318874,0.221984972352103,0.0288975059833995,0.122670417262654,0.0243107900238919,0.0658532742824706,0.0184653108413111,0.0236940673606567,0.011110257360247,0,0,0.0239783675371822,-0.0110806599057954,0.0623361812874123,-0.0176756895522041,0.114829236142557,-0.0233734416591417,0.214306107242777,-0.028310853135615,0.357389074847702,-0.0283763339612263,0.542695962832085,-0.0215164061343808,0.784157786565453,-0.00915517831605568,1,0],"clcd":93.5556433572629,"CDpres":0.00208,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N4.dat","Top_Xtr":1,"Re":80000,"src":"retest_67.txt"},
             {"n":9,"CL":-0.00190246450864106,"CD":0.0108760514501649,"CDp":0.000565550260576428,"CDf":0.00873,"Cpmin":-0.204436632248017,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt97.1009110684734>64.1268138357685) l1 Foil spline 17pts Re275000 N4","xver":6.991,"good":81.8431297458125,"iver":1.2020052,"id":1110,"r":6,"Cm":0.000283201122759602,"diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re275000-N4.dat","Top_Xtr":1,"Re":80000,"src":"retest_99.txt","sym":0.000188018531487083,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00235318972790567,0.814149693519042,0.00914294775821499,0.682864593067749,0.0158187204773199,0.52069384686288,0.0224481426547295,0.325213183352731,0.026292387648995,0.152815219118241,0.0236856401288733,0.0429551112266143,0.014393031876194,0,0,0.0408398189079085,-0.01442199983871,0.136824284769333,-0.0234899342329835,0.289192311415617,-0.0270676459052954,0.490511679687803,-0.0240299759211711,0.680813751073162,-0.016361711506112,0.840165601920523,-0.0079628293105642,0.955145580885723,-0.00191272846783096,1,0],"clcd":91.9451332666178,"CDpres":0.00215,"alpha":0},
             {"clcd":92.0687904932039,"CDpres":0.00213,"alpha":0,"sym":5.67031841182928e-05,"xy":[1,0,0.944740406454351,0.00238697218538699,0.814149693519042,0.00927420417168352,0.682864593067749,0.0160458144704633,0.52069384686288,0.0227704088178761,0.325213183352731,0.0266698419006865,0.152815219118241,0.024025671840334,0.0429551112266143,0.0145996586439462,0,0,0.0408398189079085,-0.0140354296195036,0.136824284769333,-0.022860305254538,0.289192311415617,-0.026342119214959,0.490511679687803,-0.0233858715553926,0.680813751073162,-0.0159231488605535,0.840165601920523,-0.00774939201292774,0.955145580885723,-0.00186145930465242,1,0],"Bot_Xtr":1,"Re":80000,"src":"retest_89.txt","diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re55000-N5.dat","Top_Xtr":1,"Cm":-0.000154239103310721,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt67.443268224336>56.7266443076749) l1 Foil spline 17pts Re55000 N5","good":83.0642864169088,"iver":1.2020052,"id":1111,"r":6,"CDf":0.00873,"Cpmin":-0.199782234462253,"n":10,"CD":0.0108614438686888,"CL":0.00105415137294065,"CDp":0.00054929744227565},
             {"id":1112,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt67.443268224336>56.7266443076749) l1 Foil spline 17pts Re55000 N5","xver":6.991,"good":83.4222230320698,"r":6,"Cm":-0.000154239103310721,"CL":0.00105415137294065,"CD":0.0108614438686888,"n":11,"CDp":0.00054929744227565,"CDf":0.00873,"Cpmin":-0.199782234462253,"sym":5.67031841182928e-05,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00238697218538699,0.814149693519042,0.00927420417168352,0.682864593067749,0.0160458144704633,0.52069384686288,0.0227704088178761,0.325213183352731,0.0266698419006865,0.152815219118241,0.024025671840334,0.0429551112266143,0.0145996586439462,0,0,0.0408398189079085,-0.0140354296195036,0.136824284769333,-0.022860305254538,0.289192311415617,-0.026342119214959,0.490511679687803,-0.0233858715553926,0.680813751073162,-0.0159231488605535,0.840165601920523,-0.00774939201292774,0.955145580885723,-0.00186145930465242,1,0],"clcd":92.0687904932039,"CDpres":0.00213,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re55000-N5.dat","Re":80000,"src":"retest_90.txt"},
             {"xy":[1,0,0.883609074234346,0.00595231981006015,0.672127682508641,0.0141560487982902,0.448051878989487,0.0201609114697976,0.261607586958807,0.0215278231707249,0.14960260982261,0.0191447094259991,0.0876932172572549,0.0159915558773948,0.0269668136105797,0.00985294240601249,0,0,0.0260784653873372,-0.00974521830505693,0.0852103572234493,-0.0159864727699477,0.159346520639483,-0.0197182135188932,0.277295492850028,-0.021813124053873,0.461088095254591,-0.0201143358642116,0.679515403216876,-0.0140489015219148,0.887295989576364,-0.00584821828263425,1,0],"Bot_Xtr":1,"sym":2.21079131946457e-05,"alpha":0,"CDpres":0.00172,"clcd":93.0530140095944,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re35000-N7.dat","diter":3,"src":"retest_97.txt","Re":80000,"r":6,"id":1113,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt57.2307252428472>0) l1 Foil spline 17pts Re35000 N7","xver":6.991,"iver":1.2020052,"good":86.4662590598561,"Cm":9.57709994120016e-05,"CDp":0.000202871702081885,"CL":-0.000657130946803169,"CD":0.0107465621682807,"n":12,"Cpmin":-0.179606469372166,"CDf":0.00903},
             {"clcd":93.0530140095944,"CDpres":0.00172,"alpha":0,"sym":2.21079131946457e-05,"xy":[1,0,0.883609074234346,0.00595231981006015,0.672127682508641,0.0141560487982902,0.448051878989487,0.0201609114697976,0.261607586958807,0.0215278231707249,0.14960260982261,0.0191447094259991,0.0876932172572549,0.0159915558773948,0.0269668136105797,0.00985294240601249,0,0,0.0260784653873372,-0.00974521830505693,0.0852103572234493,-0.0159864727699477,0.159346520639483,-0.0197182135188932,0.277295492850028,-0.021813124053873,0.461088095254591,-0.0201143358642116,0.679515403216876,-0.0140489015219148,0.887295989576364,-0.00584821828263425,1,0],"Bot_Xtr":1,"Re":80000,"src":"retest_98.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re35000-N7.dat","Top_Xtr":1,"Cm":9.57709994120016e-05,"good":86.8818236364698,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt57.2307252428472>0) l1 Foil spline 17pts Re35000 N7","xver":6.991,"iver":1.2020052,"id":1114,"r":6,"CDf":0.00903,"Cpmin":-0.179606469372166,"n":13,"CD":0.0107465621682807,"CL":-0.000657130946803169,"CDp":0.000202871702081885},
             {"CDf":0.00888,"Cpmin":-0.215775121903215,"CL":-0.00016541958758772,"CD":0.011151477327524,"n":14,"CDp":0.000613560804162357,"Cm":1.85603346013315e-05,"id":1115,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt48.5640202614114>46.7905001385444) l1 Foil spline 17pts Re25000 N8","xver":6.991,"iver":1.2020052,"good":82.057938167597,"r":6,"Re":80000,"src":"retest_100.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re25000-N8.dat","CDpres":0.00228,"clcd":89.6742172027566,"alpha":0,"sym":6.5942924318351e-06,"xy":[1,0,0.883609074234346,0.00724077271891507,0.672127682508641,0.0172202998523452,0.448051878989487,0.0245249889819843,0.261607586958807,0.0261877855502253,0.14960260982261,0.0232888174941544,0.0876932172572549,0.0194531250377953,0.0269668136105797,0.0119857331008859,0,0,0.0260784653873372,-0.0117636653172521,0.0852103572234493,-0.0192976195485988,0.159346520639483,-0.02380228510325,0.277295492850028,-0.0263310972480021,0.461088095254591,-0.0242804530158757,0.679515403216876,-0.0169587350847832,0.887295989576364,-0.00705951169338556,1,0],"Bot_Xtr":1},
             {"alpha":0.1,"CDpres":0.00171,"clcd":104.958784270122,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00150974904919386,0.838375902301386,0.00649368204213336,0.669468112967632,0.0152759395500363,0.498697719332731,0.0222706342765648,0.301319859646249,0.0242691546479607,0.134615624611079,0.0199107393120298,0.0376550591335466,0.011307875215794,0,0,0.0409493023355519,-0.0122652209361624,0.14830924318344,-0.0212371788659257,0.317279938768802,-0.0251111772504734,0.498956936169248,-0.0229295106781423,0.653261727003669,-0.0165958628074106,0.844873051243488,-0.0063783747448043,0.969355895385625,-0.00110396419394091,1,0],"sym":0.000224622387951024,"src":"retest_85.txt","Re":100000,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re25000-N7.dat","Top_Xtr":1,"diter":3,"Cm":0.000776459496668908,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt49.0203534259805>46.0216907085324) l1 Foil spline 17pts Re25000 N7","iver":1.2020052,"good":75.7849645968385,"id":1116,"Cpmin":-0.169165599606593,"CDf":0.00782,"CDp":0.000317020206837345,"n":3,"CD":0.00952754938001571,"CL":0.00621208987488602},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt80.2831864934908>51.9448045577382) l1 Foil spline 17pts Re100000 N4","xver":6.991,"iver":1.2020052,"good":80.2831864934541,"id":1117,"r":6,"Cm":-0.000169402577317266,"n":4,"CD":0.00956868510571873,"CL":0.00136148730143276,"CDp":0.000463968252273253,"CDf":0.00767,"Cpmin":-0.213463413351279,"sym":6.49868625513952e-05,"Bot_Xtr":1,"xy":[1,0,0.794574379082928,0.00879061839652528,0.546030639687268,0.0216482620921415,0.363514019175692,0.0286550896318874,0.221984972352103,0.0288975059833995,0.122670417262654,0.0243107900238919,0.0658532742824706,0.0184653108413111,0.0236940673606567,0.011110257360247,0,0,0.0239783675371822,-0.0110806599057954,0.0623361812874123,-0.0176756895522041,0.114829236142557,-0.0233734416591417,0.214306107242777,-0.028310853135615,0.357389074847702,-0.0283763339612263,0.542695962832085,-0.0215164061343808,0.784157786565453,-0.00915517831605568,1,0],"CDpres":0.0019,"clcd":104.507567022176,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N4.dat","Top_Xtr":1,"Re":100000,"src":"retestc_20.txt"},
             {"src":"retest_72.txt","Re":100000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N4.dat","diter":3,"alpha":0,"CDpres":0.0019,"clcd":104.507567022176,"Bot_Xtr":1,"xy":[1,0,0.794574379082928,0.00879061839652528,0.546030639687268,0.0216482620921415,0.363514019175692,0.0286550896318874,0.221984972352103,0.0288975059833995,0.122670417262654,0.0243107900238919,0.0658532742824706,0.0184653108413111,0.0236940673606567,0.011110257360247,0,0,0.0239783675371822,-0.0110806599057954,0.0623361812874123,-0.0176756895522041,0.114829236142557,-0.0233734416591417,0.214306107242777,-0.028310853135615,0.357389074847702,-0.0283763339612263,0.542695962832085,-0.0215164061343808,0.784157786565453,-0.00915517831605568,1,0],"sym":6.49868625513952e-05,"Cpmin":-0.213463413351279,"CDf":0.00767,"CDp":0.00046396825227325,"CD":0.00956868510571872,"CL":0.00136148730143284,"n":5,"Cm":-0.000169402577317276,"r":6,"id":1118,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt80.2831864934908>51.9448045577382) l1 Foil spline 17pts Re100000 N4","good":83.4287224411999,"iver":1.2020052},
             {"CL":0.000580848213867721,"CD":0.00974719666963526,"n":6,"CDp":0.000874791432399169,"CDf":0.00737,"Cpmin":-0.27869217732206,"id":1119,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt100.632987093625>67.4379029134313) l1 Foil spline 17pts Re125000 N8","xver":6.991,"good":83.0809266621832,"iver":1.2020052,"r":6,"Cm":-8.07365011026371e-05,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N8.dat","Re":100000,"src":"retest_85.txt","sym":2.22854674252731e-05,"Bot_Xtr":1,"xy":[1,0,0.888395795100267,0.00454197246629566,0.724782775337367,0.0134000319191731,0.573493663117091,0.0220188926463172,0.434846152115145,0.0282567637075744,0.296738332433587,0.0317680906894311,0.156304320466368,0.0300323370767769,0.0490216324689624,0.019893779296346,0,0,0.0501864526744944,-0.0199544959677816,0.168411092824914,-0.0303923554398969,0.326746855954174,-0.0311537970235378,0.462695012305671,-0.0269652447805048,0.564195027615659,-0.022354466046004,0.67400816885005,-0.0162380644367346,0.86979319971664,-0.00540294801376601,1,0],"CDpres":0.00238,"clcd":102.593600385147,"alpha":0},
             {"Cm":-0.00016940257731729,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt80.2831864934908>51.9448045577382) l1 Foil spline 17pts Re100000 N4","xver":6.991,"iver":1.2020052,"good":88.0337903118469,"id":1120,"r":6,"CDf":0.00767,"Cpmin":-0.213463413351279,"n":7,"CD":0.00956868510571872,"CL":0.00136148730143289,"CDp":0.000463968252273254,"clcd":104.507567022176,"CDpres":0.0019,"alpha":0,"sym":6.49868625513952e-05,"xy":[1,0,0.794574379082928,0.00879061839652528,0.546030639687268,0.0216482620921415,0.363514019175692,0.0286550896318874,0.221984972352103,0.0288975059833995,0.122670417262654,0.0243107900238919,0.0658532742824706,0.0184653108413111,0.0236940673606567,0.011110257360247,0,0,0.0239783675371822,-0.0110806599057954,0.0623361812874123,-0.0176756895522041,0.114829236142557,-0.0233734416591417,0.214306107242777,-0.028310853135615,0.357389074847702,-0.0283763339612263,0.542695962832085,-0.0215164061343808,0.784157786565453,-0.00915517831605568,1,0],"Bot_Xtr":1,"Re":100000,"src":"retest_74.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N4.dat","Top_Xtr":1},
             {"src":"retest_74.txt","Re":100000,"Foil_fn":"optbs_spline_sym_hn316s.dat-s17_n17s0_nsopt-Re225000-N6.dat","Top_Xtr":1,"diter":3,"alpha":-0.1,"CDpres":0.00222,"clcd":99.8879781087751,"Bot_Xtr":1,"xy":[1,0,0.976271670242825,0.00141656386797106,0.907128780537913,0.00568382452245925,0.716356552639601,0.0155097413281723,0.488560752625044,0.024641926095943,0.262975364201479,0.0278045335323298,0.117858211216423,0.0240264228052691,0.0354659772563052,0.0143570808079203,0,0,0.0253873180369074,-0.0129045541878481,0.0949762346544546,-0.0225505471908077,0.231887483830828,-0.0273494519407347,0.46801849465003,-0.0246341605692518,0.688428153090694,-0.0163559050400646,0.823054058758013,-0.00983695484501259,0.915514737075389,-0.00507244077819269,1,0],"sym":0.000515569927028201,"Cpmin":-0.252078022064048,"CDf":0.00779,"CDp":0.000734459220299641,"n":8,"CD":0.0100112147520999,"CL":-0.00391760536875952,"Cm":-0.00109334713327304,"r":6,"good":86.9120808764611,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn316s.dat-s17_n17s0.dat (opt104.472042371804>73.0935170189118) l1 Foil spline 17pts Re225000 N6","xver":6.991,"iver":1.2020052,"id":1121},
             {"Cpmin":-0.206278806825581,"CDf":0.00778,"CDp":0.000568873775283403,"n":9,"CD":0.00987586770342646,"CL":0.000910549651270129,"Cm":-0.0001306385780007,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_eh0009.dat-s17_n17s0.dat (opt66.0329766006828>47.7116553757678) l1 Foil spline 17pts Re65536 N3","iver":1.2020052,"xver":6.991,"good":92.1409186548127,"id":1122,"src":"retest_95.txt","Re":100000,"Foil_fn":"optbs_spline_sym_eh0009.dat-s17_n17s0_nsopt-Re65536-N3.dat","Top_Xtr":1,"diter":3,"alpha":0,"clcd":101.25692547026,"CDpres":0.0021,"Bot_Xtr":1,"xy":[1,0,0.950207049544918,0.00228593680058232,0.834910988468956,0.00871736685459185,0.659043244109732,0.0182169306794673,0.465214000878362,0.0260971552904558,0.274034131185736,0.0288565659258624,0.127715926423755,0.0241463826607622,0.0388000725455763,0.014046335156825,0,0,0.0389767678832851,-0.013878312775015,0.129212631455479,-0.0239067612933254,0.280832340153077,-0.0285018407257079,0.484957925061925,-0.0251504203546083,0.688315412782588,-0.0165087993852763,0.842457876227992,-0.00815284021695313,0.958862150999706,-0.00181834120663962,1,0],"sym":5.66116534195992e-05},
             {"CDf":0.00737,"Cpmin":-0.278692177322351,"CD":0.00974719666963579,"CL":0.000580848213863618,"n":10,"CDp":0.000874791432406064,"Cm":-8.07365011015388e-05,"id":1123,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt100.632987093625>67.4379029134313) l1 Foil spline 17pts Re125000 N8","xver":6.991,"iver":1.2020052,"good":88.5602783542423,"r":6,"Re":100000,"src":"retest_89.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re125000-N8.dat","clcd":102.593600385142,"CDpres":0.00238,"alpha":0,"sym":2.22854674252731e-05,"xy":[1,0,0.888395795100267,0.00454197246629566,0.724782775337367,0.0134000319191731,0.573493663117091,0.0220188926463172,0.434846152115145,0.0282567637075744,0.296738332433587,0.0317680906894311,0.156304320466368,0.0300323370767769,0.0490216324689624,0.019893779296346,0,0,0.0501864526744944,-0.0199544959677816,0.168411092824914,-0.0303923554398969,0.326746855954174,-0.0311537970235378,0.462695012305671,-0.0269652447805048,0.564195027615659,-0.022354466046004,0.67400816885005,-0.0162380644367346,0.86979319971664,-0.00540294801376601,1,0],"Bot_Xtr":1},
             {"Cpmin":-0.212985426691978,"CDf":0.00775,"CDp":0.000530707175565917,"n":11,"CL":-0.0037951513994866,"CD":0.00980617107590727,"Cm":-0.00112651199441485,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt88.1112205858889>58.715451607407) l1 Foil spline 17pts Re125000 N5","good":90.6712690007715,"xver":6.991,"iver":1.2020052,"id":1124,"src":"retest_149.txt","Re":100000,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re125000-N5.dat","Top_Xtr":1,"diter":3,"alpha":-0.1,"CDpres":0.00206,"clcd":101.976601495042,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00250862550631557,0.814149693519042,0.00974686897413158,0.682864593067749,0.0168635980329555,0.52069384686288,0.0239309149471701,0.325213183352731,0.0280290847338126,0.152815219118241,0.0252501531245359,0.0429551112266143,0.0153437380971267,0,0,0.0408398189079085,-0.0140890040296022,0.136824284769333,-0.0229475649538764,0.289192311415617,-0.0264426692897301,0.490511679687803,-0.0234751373853091,0.680813751073162,-0.0159839288530612,0.840165601920523,-0.00777897209112769,0.955145580885723,-0.00186856465068547,1,0],"sym":0.00100235616515238},
             {"alpha":-0.1,"CDpres":0.00222,"clcd":99.8879781087751,"Bot_Xtr":1,"xy":[1,0,0.976271670242825,0.00141656386797106,0.907128780537913,0.00568382452245925,0.716356552639601,0.0155097413281723,0.488560752625044,0.024641926095943,0.262975364201479,0.0278045335323298,0.117858211216423,0.0240264228052691,0.0354659772563052,0.0143570808079203,0,0,0.0253873180369074,-0.0129045541878481,0.0949762346544546,-0.0225505471908077,0.231887483830828,-0.0273494519407347,0.46801849465003,-0.0246341605692518,0.688428153090694,-0.0163559050400646,0.823054058758013,-0.00983695484501259,0.915514737075389,-0.00507244077819269,1,0],"sym":0.000515569927028201,"src":"retest_78.txt","Re":100000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn316s.dat-s17_n17s0_nsopt-Re225000-N6.dat","diter":3,"Cm":-0.00109334713327304,"r":6,"id":1125,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn316s.dat-s17_n17s0.dat (opt104.472042371804>73.0935170189118) l1 Foil spline 17pts Re225000 N6","xver":6.991,"good":98.1669130328841,"Cpmin":-0.252078022064048,"CDf":0.00779,"CDp":0.000734459220299641,"CL":-0.00391760536875952,"CD":0.0100112147520999,"n":12},
             {"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re35000-N12.dat","Top_Xtr":1,"Re":100000,"src":"retest_99.txt","sym":0.000268053028847243,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.0058258728073934,0.751503599940214,0.00947742009447672,0.617882281805394,0.0152044991989017,0.516474874255053,0.0194137248652718,0.425516435642791,0.0229601318612971,0.22020135983351,0.0277537836731126,0.0597789339840893,0.0209923584926892,0,0,0.0545974187204916,-0.0208011909394731,0.191614124162238,-0.028459073019635,0.354272483283979,-0.0259567459223354,0.461006103363399,-0.0222567085684047,0.600655324159936,-0.0163881639716891,0.736649107785801,-0.0103903593510629,0.846409340674087,-0.0058319511771152,1,0],"CDpres":0.00209,"clcd":104.841814600012,"alpha":0,"n":13,"CL":-0.00292884829613466,"CD":0.00953817905398865,"CDp":0.000698586266325564,"CDf":0.00745,"Cpmin":-0.323433145642845,"good":90.2735942599765,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt56.7849713067586>47.2294203694912) l1 Foil spline 17pts Re35000 N12","xver":6.991,"iver":1.2020052,"id":1126,"r":6,"Cm":5.32957535283839e-05},
             {"sym":0.000690925028441966,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00330455223661777,0.814149693519042,0.0128393168240534,0.682864593067749,0.0222140133937616,0.52069384686288,0.0315236205300038,0.325213183352731,0.0369220413386875,0.152815219118241,0.0332614213530722,0.0429551112266143,0.0202119383380609,0,0,0.0408398189079085,-0.0189882848892086,0.136824284769333,-0.0309273033027963,0.289192311415617,-0.0356377879266389,0.490511679687803,-0.0316383326705704,0.680813751073162,-0.0215421469163521,0.840165601920523,-0.0104840156125433,0.955145580885723,-0.00251833542289945,1,0],"CDpres":0.0035,"clcd":91.8231454229061,"alpha":-0.1,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re275000-N7.dat","Re":100000,"src":"retest_78.txt","id":1127,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt103.816110716529>92.0222846548029) l1 Foil spline 17pts Re275000 N7","iver":1.2020052,"good":75.3739174272833,"r":6,"Cm":-0.00105943213279271,"CL":-0.00411004331926416,"CD":0.0108905003786828,"n":14,"CDp":0.00164386734751122,"CDf":0.00739,"Cpmin":-0.276526018224299},
             {"Cpmin":-0.171657478290706,"CDf":0.00707,"CDp":8.77687588344591e-05,"CL":0.00111143707226715,"CD":0.00849829390716243,"n":3,"Cm":-0.0001721530697763,"r":6,"id":1128,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt87.2962703316507>48.0812957714737) l1 Foil spline 17pts Re225000 N3","xver":6.991,"good":78.797726464296,"iver":1.2020052,"src":"retest_68.txt","Re":125000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re225000-N3.dat","diter":3,"alpha":0,"clcd":117.670677305852,"CDpres":0.00142,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.0022302096783402,0.814149693519042,0.0079432082061376,0.682864593067749,0.0137429846072505,0.52069384686288,0.019502492594621,0.325213183352731,0.0228422949420004,0.152815219118241,0.0205776053866482,0.0429551112266143,0.0125043751680043,0,0,0.0408398189079085,-0.0120020144316839,0.136824284769333,-0.0195483658865989,0.289192311415617,-0.0225257440313578,0.490511679687803,-0.0199977895593091,0.680813751073162,-0.0136162460005249,0.840165601920523,-0.00662668099925424,0.955145580885723,-0.00173644496810787,1,0],"sym":5.1549597510215e-05},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt86.0648054766839>60.9022560436671) l1 Foil spline 17pts Re125000 N4","xver":6.991,"iver":1.2020052,"good":86.0648054806586,"id":1129,"r":6,"Cm":-6.79643149462148e-06,"n":4,"CD":0.00841168970008697,"CL":-0.00020009856370012,"CDp":-4.21260545275104e-05,"CDf":0.00714,"Cpmin":-0.161303533723892,"sym":2.26920656349515e-06,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00224542528850533,0.814149693519042,0.00729101796063364,0.682864593067749,0.0126145941292023,0.52069384686288,0.0179012081887311,0.325213183352731,0.0209667905413243,0.152815219118241,0.0188880470670474,0.0429551112266143,0.0114776827662625,0,0,0.0408398189079085,-0.01119716091444,0.136824284769333,-0.0182374550282796,0.289192311415617,-0.021015170584261,0.490511679687803,-0.018656740408308,0.680813751073162,-0.0127031423255076,0.840165601920523,-0.00618229663859031,0.955145580885723,-0.00168863387281746,1,0],"clcd":118.882178926508,"CDpres":0.00127,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re125000-N4.dat","Top_Xtr":1,"Re":125000,"src":"retestc_6.txt"},
             {"xy":[1,0,0.961992840051787,0.001441558258881,0.838375902301386,0.00675749921178583,0.669468112967632,0.0158965512630405,0.498697719332731,0.0231754176741945,0.301319859646249,0.0252551314247016,0.134615624611079,0.0207196478568132,0.0376550591335466,0.0117672773877602,0,0,0.0409493023355519,-0.0126707077480049,0.14830924318344,-0.0219392775884593,0.317279938768802,-0.0259413499198368,0.498956936169248,-0.02368755769828,0.653261727003669,-0.0171445201479165,0.844873051243488,-0.00658924308981565,0.969355895385625,-0.00117504592573535,1,0],"Bot_Xtr":1,"sym":0.000146806693445089,"alpha":0,"clcd":116.284862810696,"CDpres":0.00167,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re35000-N7.dat","Top_Xtr":1,"diter":3,"src":"retest_108.txt","Re":125000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt56.7971235948164>52.9296654327898) l1 Foil spline 17pts Re35000 N7","good":95.3599230713027,"xver":6.991,"iver":1.2020052,"id":1130,"Cm":0.00029552172967053,"CDp":0.000329394385200819,"n":5,"CL":-0.00172071683879376,"CD":0.00859957156786547,"Cpmin":-0.165984653435947,"CDf":0.00693},
             {"r":6,"id":1131,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt80.2831864934908>51.9448045577382) l1 Foil spline 17pts Re100000 N4","xver":6.991,"iver":1.2020052,"good":100.51164699065,"Cm":-0.000165430402820588,"CDp":0.000376612259431247,"CL":0.00135811445917831,"CD":0.00857017851050136,"n":6,"Cpmin":-0.213702494683065,"CDf":0.00683,"xy":[1,0,0.794574379082928,0.00879061839652528,0.546030639687268,0.0216482620921415,0.363514019175692,0.0286550896318874,0.221984972352103,0.0288975059833995,0.122670417262654,0.0243107900238919,0.0658532742824706,0.0184653108413111,0.0236940673606567,0.011110257360247,0,0,0.0239783675371822,-0.0110806599057954,0.0623361812874123,-0.0176756895522041,0.114829236142557,-0.0233734416591417,0.214306107242777,-0.028310853135615,0.357389074847702,-0.0283763339612263,0.542695962832085,-0.0215164061343808,0.784157786565453,-0.00915517831605568,1,0],"Bot_Xtr":1,"sym":6.49868625513952e-05,"alpha":0,"clcd":116.683683866639,"CDpres":0.00174,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N4.dat","diter":3,"src":"retest_81.txt","Re":125000},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re35000-N3.dat","diter":3,"src":"retest_94.txt","Re":125000,"xy":[1,0,0.961992840051787,0.0015658447990834,0.838375902301386,0.00734010917033528,0.669468112967632,0.0172671010451679,0.498697719332731,0.0251735280264649,0.301319859646249,0.0274325480416127,0.134615624611079,0.0225060295937083,0.0376550591335466,0.0127818143897277,0,0,0.0409493023355519,-0.0130310616169697,0.14830924318344,-0.0225632288087483,0.317279938768802,-0.0266791197426199,0.498956936169248,-0.0243612298587199,0.653261727003669,-0.0176321088674826,0.844873051243488,-0.00677664061236827,0.969355895385625,-0.00119070046106193,1,0],"Bot_Xtr":1,"sym":0.000266965436719717,"alpha":0,"clcd":114.748992598761,"CDpres":0.00184,"CDp":0.000467040277507188,"CL":0.00198092491527877,"CD":0.00871467345684391,"n":7,"Cpmin":-0.177689089687805,"CDf":0.00687,"r":6,"id":1132,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt53.9240853741953>49.6659875000968) l1 Foil spline 17pts Re35000 N3","xver":6.991,"good":96.7550622000912,"iver":1.2020052,"Cm":-0.000312508590415818},
             {"Cpmin":-0.324059124103232,"CDf":0.00664,"CDp":0.000602371457496365,"CL":-0.00295237022350387,"CD":0.00854034348527258,"n":8,"Cm":4.83746996609988e-05,"r":6,"id":1133,"good":93.5069801888882,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt56.7849713067586>47.2294203694912) l1 Foil spline 17pts Re35000 N12","xver":6.991,"iver":1.2020052,"src":"retest_104.txt","Re":125000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re35000-N12.dat","diter":3,"alpha":0,"clcd":117.091309234161,"CDpres":0.0019,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.0058258728073934,0.751503599940214,0.00947742009447672,0.617882281805394,0.0152044991989017,0.516474874255053,0.0194137248652718,0.425516435642791,0.0229601318612971,0.22020135983351,0.0277537836731126,0.0597789339840893,0.0209923584926892,0,0,0.0545974187204916,-0.0208011909394731,0.191614124162238,-0.028459073019635,0.354272483283979,-0.0259567459223354,0.461006103363399,-0.0222567085684047,0.600655324159936,-0.0163881639716891,0.736649107785801,-0.0103903593510629,0.846409340674087,-0.0058319511771152,1,0],"sym":0.000268053028847243},
             {"Re":125000,"src":"retest_91.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re45000-N3.dat","clcd":114.124445586912,"CDpres":0.00162,"alpha":0.1,"sym":0.000745132181348914,"xy":[1,0,0.883609074234346,0.00613637673841589,0.672127682508641,0.0145937804630209,0.448051878989487,0.0207843247870241,0.261607586958807,0.0221935039697123,0.14960260982261,0.0197366998639552,0.0876932172572549,0.0164860448746842,0.0269668136105797,0.0101576139244097,0,0,0.0260784653873372,-0.0105676890749233,0.0852103572234493,-0.0173356889860404,0.159346520639483,-0.0213823788300856,0.277295492850028,-0.0236540942991952,0.461088095254591,-0.0218119328585245,0.679515403216876,-0.0152345918254876,0.887295989576364,-0.00634179250977791,1,0],"Bot_Xtr":1,"CDf":0.00715,"Cpmin":-0.204570656341177,"CD":0.00876236458242807,"CL":0.00474154743750306,"n":9,"CDp":0.000189902829172078,"Cm":0.00102856799607971,"id":1134,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt58.8362349161742>55.5538215181957) l1 Foil spline 17pts Re45000 N3","xver":6.991,"good":96.3670415057496,"r":6},
             {"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re150000-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_88.txt","Re":125000,"xy":[1,0,0.944740406454351,0.00259865098066909,0.814149693519042,0.0100966487641595,0.682864593067749,0.0174687714270719,0.52069384686288,0.0247897087226496,0.325213183352731,0.0290349469649444,0.152815219118241,0.0261562895752786,0.0429551112266143,0.0158943692284265,0,0,0.0408398189079085,-0.0153968043270399,0.136824284769333,-0.0250776539373913,0.289192311415617,-0.0288971884799794,0.490511679687803,-0.025654197849086,0.680813751073162,-0.0174676240003077,0.840165601920523,-0.00850104882509426,0.955145580885723,-0.00204201263897575,1,0],"Bot_Xtr":1,"sym":1.65743451766806e-05,"alpha":0,"CDpres":0.00212,"clcd":111.476475130287,"CDp":0.000607812452038275,"n":10,"CL":0.000411953667794511,"CD":0.00897050251033919,"Cpmin":-0.217108278602089,"CDf":0.00685,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt99.6223772427113>69.7602800923986) l1 Foil spline 17pts Re150000 N5","xver":6.991,"good":101.098666334883,"iver":1.2020052,"id":1135,"Cm":-5.33981305343451e-05},
             {"Cm":-0.000944837720199216,"id":1136,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt95.1861492659334>68.1876993897687) l1 Foil spline 17pts Re225000 N4","xver":6.991,"iver":1.2020052,"good":83.782388308205,"r":6,"CDf":0.00703,"Cpmin":-0.195284264924086,"CD":0.00900300867845591,"CL":-0.00548259751932339,"n":11,"CDp":0.000625062906466253,"clcd":111.073979345703,"CDpres":0.00198,"alpha":-0.1,"sym":0.000515002668716418,"xy":[1,0,0.927533762368065,0.00479371905998961,0.828124577508512,0.0101433079013888,0.673910782200253,0.0172313186285827,0.485356610471494,0.0237232424725331,0.298817780508802,0.0264585431494015,0.140740099512849,0.0231503260239235,0.0345490619416974,0.013414400106774,0,0,0.033827731492854,-0.0126613036172526,0.142528433402255,-0.022314698077789,0.31046792119717,-0.0253496392407423,0.499715124890922,-0.0223506955491882,0.684159552318164,-0.0161089466233038,0.829477323686799,-0.0096493792916726,0.922486667396241,-0.00489285792713448,1,0],"Bot_Xtr":1,"Re":125000,"src":"retest_79.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re225000-N4.dat"},
             {"Cm":-9.13118635345592e-05,"r":6,"id":1137,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt114.674935443792>82.9957443780523) l1 Foil spline 17pts Re225000 N9","xver":6.991,"good":93.0368406896449,"iver":1.2020052,"Cpmin":-0.390560750975432,"CDf":0.00633,"CDp":0.0010491733411933,"CD":0.00878266321307426,"CL":0.000434547472951375,"n":12,"alpha":0,"clcd":113.860679356503,"CDpres":0.00245,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00636301680679851,0.751503599940214,0.0115232729496734,0.617882281805394,0.0184866337658855,0.516474874255053,0.0236044881795167,0.425516435642791,0.0279164439014802,0.22020135983351,0.0337448822003626,0.0597789339840893,0.0255238951483884,0,0,0.0545974187204916,-0.0244665525182533,0.191614124162238,-0.0334738240075662,0.354272483283979,-0.0305305638104903,0.461006103363399,-0.026178545769655,0.600655324159936,-0.0192759095216128,0.736649107785801,-0.0122212364419911,0.846409340674087,-0.00685959473060787,1,0],"sym":5.65395053373896e-05,"src":"retest_92.txt","Re":125000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re225000-N9.dat","diter":3},
             {"alpha":0,"CDpres":0.00245,"clcd":113.860679356503,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00636301680679851,0.751503599940214,0.0115232729496734,0.617882281805394,0.0184866337658855,0.516474874255053,0.0236044881795167,0.425516435642791,0.0279164439014802,0.22020135983351,0.0337448822003626,0.0597789339840893,0.0255238951483884,0,0,0.0545974187204916,-0.0244665525182533,0.191614124162238,-0.0334738240075662,0.354272483283979,-0.0305305638104903,0.461006103363399,-0.026178545769655,0.600655324159936,-0.0192759095216128,0.736649107785801,-0.0122212364419911,0.846409340674087,-0.00685959473060787,1,0],"sym":5.65395053373896e-05,"src":"retest_93.txt","Re":125000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re225000-N9.dat","diter":3,"Cm":-9.13118635345592e-05,"r":6,"id":1138,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt114.674935443792>82.9957443780523) l1 Foil spline 17pts Re225000 N9","iver":1.2020052,"xver":6.991,"good":93.3909420355305,"Cpmin":-0.390560750975432,"CDf":0.00633,"CDp":0.0010491733411933,"CD":0.00878266321307426,"CL":0.000434547472951375,"n":13},
             {"CDp":0.00120060901568452,"CL":-0.00058303354488978,"CD":0.00888143765360917,"n":14,"Cpmin":-0.403306704292209,"CDf":0.00623,"r":6,"id":1139,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt97.8212719174194>81.3592721277507) l1 Foil spline 17pts Re125000 N12","good":90.679112550435,"iver":1.2020052,"Cm":-8.37089298274564e-06,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re125000-N12.dat","diter":3,"src":"retest_104.txt","Re":125000,"xy":[1,0,0.857899050218291,0.00665239269457153,0.751503599940214,0.0120473258385955,0.617882281805394,0.0193273648562422,0.516474874255053,0.0246779679344463,0.425516435642791,0.0291860218364033,0.22020135983351,0.0352795245785019,0.0597789339840893,0.0266846652739833,0,0,0.0545974187204916,-0.0258411885081321,0.191614124162238,-0.0353545271906297,0.354272483283979,-0.0322459019961166,0.461006103363399,-0.0276493688923982,0.600655324159936,-0.0203589128971921,0.736649107785801,-0.0129078779883,0.846409340674087,-0.00724499622048438,1,0],"Bot_Xtr":1,"sym":6.88726835055074e-05,"alpha":0,"CDpres":0.00265,"clcd":112.59438381506},
             {"sym":1.90738035701545e-05,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00154606945883586,0.838375902301386,0.00637357446843835,0.669468112967632,0.0149933947590592,0.498697719332731,0.0218587151480562,0.301319859646249,0.0238202707541262,0.134615624611079,0.0195424689572873,0.0376550591335466,0.0110987240058944,0,0,0.0409493023355519,-0.011604671563851,0.14830924318344,-0.0200934403843633,0.317279938768802,-0.0237588027227634,0.498956936169248,-0.0216946308529287,0.653261727003669,-0.0157020846343586,0.844873051243488,-0.00603486430532861,0.969355895385625,-0.0012057445813033,1,0],"clcd":128.991472863832,"CDpres":0.00137,"alpha":0.1,"diter":4,"Top_Xtr":0.991980470804801,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re150000-N3.dat","Re":150000,"src":"retest_68.txt","id":1140,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt83.8762955150437>60.1043499133465) l1 Foil spline 17pts Re150000 N3","good":83.8762955197153,"iver":1.2020052,"r":6,"Cm":-0.000695968739465005,"CL":0.0139264523946052,"CD":0.00775245043566279,"n":3,"CDp":0.000118929994789542,"CDf":0.00638,"Cpmin":-0.168873287947838},
             {"Cpmin":-0.166878158518528,"CDf":0.00647,"CDp":-2.16834100468304e-05,"n":4,"CL":-0.000112705566833136,"CD":0.00772596878831026,"Cm":1.12170362593207e-05,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt83.5371002500467>53.1216876813138) l1 Foil spline 17pts Re200000 N3","good":90.3856450287389,"xver":6.991,"iver":1.2020052,"id":1141,"src":"retestc_18.txt","Re":150000,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re200000-N3.dat","Top_Xtr":1,"diter":3,"alpha":0,"CDpres":0.00126,"clcd":129.433605985187,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00212701187096991,0.814149693519042,0.00757565457280877,0.682864593067749,0.0131070597020876,0.52069384686288,0.0186000597455636,0.325213183352731,0.0217853204448427,0.152815219118241,0.0196254241736183,0.0429551112266143,0.0119257640569478,0,0,0.0408398189079085,-0.0116489636687204,0.136824284769333,-0.0189733319595663,0.289192311415617,-0.0218631276712577,0.490511679687803,-0.0194095354040017,0.680813751073162,-0.0132157110681144,0.840165601920523,-0.00643175082348922,0.955145580885723,-0.00171988247812161,1,0],"sym":9.50528341213849e-07},
             {"clcd":118.870251775595,"CDpres":0.00205,"alpha":0,"sym":0.000139602407913757,"xy":[1,0,0.927533762368065,0.00500270267299431,0.828124577508512,0.0105855084364064,0.673910782200253,0.0179825231065198,0.485356610471494,0.0247574643078251,0.298817780508802,0.0276120112339945,0.140740099512849,0.0241595713956635,0.0345490619416974,0.0139992048826739,0,0,0.033827731492854,-0.0135592499868916,0.142528433402255,-0.0238972683039099,0.31046792119717,-0.0271474491042437,0.499715124890922,-0.0239358187350782,0.684159552318164,-0.0172514016639833,0.829477323686799,-0.0103337183902486,0.922486667396241,-0.00523986200709692,1,0],"Bot_Xtr":1,"Re":150000,"src":"retest_102.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re55000-N4.dat","Cm":-0.000145500928948348,"id":1142,"good":99.8623278678501,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt62.8272830249089>59.3945506949793) l1 Foil spline 17pts Re55000 N4","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00637,"Cpmin":-0.200069957999111,"CL":0.00100141851706148,"CD":0.00841253370849936,"n":5,"CDp":0.000706577379194628},
             {"CD":0.00824007351874717,"CL":0.000390645468561386,"n":6,"CDp":0.00054261631681503,"CDf":0.00623,"Cpmin":-0.216982510923077,"id":1143,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt99.6223772427113>69.7602800923986) l1 Foil spline 17pts Re150000 N5","good":95.9618514033713,"iver":1.2020052,"r":6,"Cm":-4.8802810738935e-05,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re150000-N5.dat","Re":150000,"src":"retest_93.txt","sym":1.65743451766806e-05,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00259865098066909,0.814149693519042,0.0100966487641595,0.682864593067749,0.0174687714270719,0.52069384686288,0.0247897087226496,0.325213183352731,0.0290349469649444,0.152815219118241,0.0261562895752786,0.0429551112266143,0.0158943692284265,0,0,0.0408398189079085,-0.0153968043270399,0.136824284769333,-0.0250776539373913,0.289192311415617,-0.0288971884799794,0.490511679687803,-0.025654197849086,0.680813751073162,-0.0174676240003077,0.840165601920523,-0.00850104882509426,0.955145580885723,-0.00204201263897575,1,0],"clcd":121.358140522033,"CDpres":0.00201,"alpha":0},
             {"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re200000-N3.dat","diter":3,"src":"retest_91.txt","Re":150000,"xy":[1,0,0.927533762368065,0.00488595630217566,0.828124577508512,0.010338478026246,0.673910782200253,0.0175628710807894,0.485356610471494,0.024179707783494,0.298817780508802,0.0269676391189026,0.140740099512849,0.0235957676948752,0.0345490619416974,0.0136725101995736,0,0,0.033827731492854,-0.0136412850336339,0.142528433402255,-0.0240418495694092,0.31046792119717,-0.0273116943433502,0.499715124890922,-0.0240806332351904,0.684159552318164,-0.0173557746597791,0.829477323686799,-0.0103962385939461,0.922486667396241,-0.00527156378448808,1,0],"Bot_Xtr":1,"sym":0.000105957567981595,"alpha":0,"clcd":119.193983845142,"CDpres":0.00202,"CDp":0.000684209927734756,"CD":0.00838968518158774,"CL":-0.00078041443564052,"n":7,"Cpmin":-0.197523803057579,"CDf":0.00637,"r":6,"id":1144,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt69.8913446371489>59.4143156005724) l1 Foil spline 17pts Re200000 N3","iver":1.2020052,"good":107.239617371636,"Cm":9.47618349895773e-05},
             {"CL":0.00474842277796872,"CD":0.00804233111301593,"n":8,"CDp":0.000145124404716334,"CDf":0.00651,"Cpmin":-0.205117235092166,"id":1145,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt58.8362349161742>55.5538215181957) l1 Foil spline 17pts Re45000 N3","iver":1.2020052,"xver":6.991,"good":99.8050998210515,"r":6,"Cm":0.00102601068523472,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re45000-N3.dat","Re":150000,"src":"retest_97.txt","sym":0.000745132181348914,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00613637673841589,0.672127682508641,0.0145937804630209,0.448051878989487,0.0207843247870241,0.261607586958807,0.0221935039697123,0.14960260982261,0.0197366998639552,0.0876932172572549,0.0164860448746842,0.0269668136105797,0.0101576139244097,0,0,0.0260784653873372,-0.0105676890749233,0.0852103572234493,-0.0173356889860404,0.159346520639483,-0.0213823788300856,0.277295492850028,-0.0236540942991952,0.461088095254591,-0.0218119328585245,0.679515403216876,-0.0152345918254876,0.887295989576364,-0.00634179250977791,1,0],"CDpres":0.00153,"clcd":124.342057787396,"alpha":0.1},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn316s.dat-s17_n17s0_nsopt-Re225000-N6.dat","Re":150000,"src":"retest_97.txt","sym":0.000515569927028201,"Bot_Xtr":1,"xy":[1,0,0.976271670242825,0.00141656386797106,0.907128780537913,0.00568382452245925,0.716356552639601,0.0155097413281723,0.488560752625044,0.024641926095943,0.262975364201479,0.0278045335323298,0.117858211216423,0.0240264228052691,0.0354659772563052,0.0143570808079203,0,0,0.0253873180369074,-0.0129045541878481,0.0949762346544546,-0.0225505471908077,0.231887483830828,-0.0273494519407347,0.46801849465003,-0.0246341605692518,0.688428153090694,-0.0163559050400646,0.823054058758013,-0.00983695484501259,0.915514737075389,-0.00507244077819269,1,0],"CDpres":0.00197,"clcd":120.64389349642,"alpha":-0.1,"CD":0.00828885715653461,"CL":-0.00394045091485375,"n":9,"CDp":0.000590216452893131,"CDf":0.00632,"Cpmin":-0.252105947459547,"id":1146,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn316s.dat-s17_n17s0.dat (opt104.472042371804>73.0935170189118) l1 Foil spline 17pts Re225000 N6","iver":1.2020052,"xver":6.991,"good":114.621551878038,"r":6,"Cm":-0.00108504764029552},
             {"clcd":124.709377263791,"CDpres":0.00154,"alpha":0,"sym":0.000355551746738009,"xy":[1,0,0.927533762368065,0.00420660093713124,0.828124577508512,0.00890099064831003,0.673910782200253,0.0151208863481374,0.485356610471494,0.0208177018235536,0.298817780508802,0.0232179923384248,0.140740099512849,0.0203149541991185,0.0345490619416974,0.0117714507992739,0,0,0.033827731492854,-0.0111394231716855,0.142528433402255,-0.0196324859075474,0.31046792119717,-0.0223026291200707,0.499715124890922,-0.0196641565063378,0.684159552318164,-0.0141726617346543,0.829477323686799,-0.00848953018767942,0.922486667396241,-0.00430473959213957,1,0],"Bot_Xtr":1,"Re":150000,"src":"retest_93.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re45000-N9.dat","Cm":-0.000354994220229369,"id":1147,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt64.4930306978025>57.9745184667305) l1 Foil spline 17pts Re45000 N9","xver":6.991,"iver":1.2020052,"good":110.722405160694,"r":6,"CDf":0.00648,"Cpmin":-0.173408212186373,"CL":0.00241994408289553,"CD":0.00801864320022027,"n":10,"CDp":0.000277934316945349},
             {"Cm":2.28927004453861e-05,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt106.471576822485>84.6839838246428) l1 Foil spline 17pts Re200000 N11","xver":6.991,"iver":1.2020052,"good":105.960776485645,"id":1148,"Cpmin":-0.397496401596738,"CDf":0.00573,"CDp":0.00100779117000202,"n":11,"CD":0.00807074992140858,"CL":-0.000954775649990956,"alpha":0,"CDpres":0.00234,"clcd":123.904223242922,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.0064440596659049,0.751503599940214,0.0116700396508249,0.617882281805394,0.0187220896355037,0.516474874255053,0.023905127839586,0.425516435642791,0.0282720029858821,0.22020135983351,0.0341746754598749,0.0597789339840893,0.0258489814244685,0,0,0.0545974187204916,-0.0251289564463619,0.191614124162238,-0.0343800895100265,0.354272483283979,-0.0313571439091924,0.461006103363399,-0.0268872999571138,0.600655324159936,-0.0197977827268981,0.736649107785801,-0.0125521124417659,0.846409340674087,-0.00704531041292142,1,0],"sym":8.89553250597183e-05,"src":"retestc_0.txt","Re":150000,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re200000-N11.dat","Top_Xtr":1,"diter":3},
             {"CDf":0.00567,"Cpmin":-0.40433326502892,"CD":0.00813002975279198,"CL":-0.000576994176568658,"n":12,"CDp":0.00109595714628741,"Cm":-1.02410664192188e-05,"id":1149,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt97.8212719174194>81.3592721277507) l1 Foil spline 17pts Re125000 N12","iver":1.2020052,"xver":6.991,"good":96.3303837911368,"r":6,"Re":150000,"src":"retestc_16.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re125000-N12.dat","clcd":123.000779874955,"CDpres":0.00246,"alpha":0,"sym":6.88726835055074e-05,"xy":[1,0,0.857899050218291,0.00665239269457153,0.751503599940214,0.0120473258385955,0.617882281805394,0.0193273648562422,0.516474874255053,0.0246779679344463,0.425516435642791,0.0291860218364033,0.22020135983351,0.0352795245785019,0.0597789339840893,0.0266846652739833,0,0,0.0545974187204916,-0.0258411885081321,0.191614124162238,-0.0353545271906297,0.354272483283979,-0.0322459019961166,0.461006103363399,-0.0276493688923982,0.600655324159936,-0.0203589128971921,0.736649107785801,-0.0129078779883,0.846409340674087,-0.00724499622048438,1,0],"Bot_Xtr":1},
             {"r":6,"id":1150,"good":86.1410681380915,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt114.674935443792>82.9957443780523) l1 Foil spline 17pts Re225000 N9","xver":6.991,"iver":1.2020052,"Cm":-8.9274000059762e-05,"CDp":0.000952577023967027,"CL":0.000430932697664518,"CD":0.00803476259789077,"n":13,"Cpmin":-0.391414504386713,"CDf":0.00576,"xy":[1,0,0.857899050218291,0.00636301680679851,0.751503599940214,0.0115232729496734,0.617882281805394,0.0184866337658855,0.516474874255053,0.0236044881795167,0.425516435642791,0.0279164439014802,0.22020135983351,0.0337448822003626,0.0597789339840893,0.0255238951483884,0,0,0.0545974187204916,-0.0244665525182533,0.191614124162238,-0.0334738240075662,0.354272483283979,-0.0305305638104903,0.461006103363399,-0.026178545769655,0.600655324159936,-0.0192759095216128,0.736649107785801,-0.0122212364419911,0.846409340674087,-0.00685959473060787,1,0],"Bot_Xtr":1,"sym":5.65395053373896e-05,"alpha":0,"CDpres":0.00227,"clcd":124.459184427243,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re225000-N9.dat","diter":3,"src":"retest_105.txt","Re":150000},
             {"n":14,"CL":0.000430932697664518,"CD":0.00803476259789077,"CDp":0.000952577023967027,"CDf":0.00576,"Cpmin":-0.391414504386713,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt114.674935443792>82.9957443780523) l1 Foil spline 17pts Re225000 N9","xver":6.991,"good":110.429174168514,"iver":1.2020052,"id":1151,"r":6,"Cm":-8.9274000059762e-05,"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re225000-N9.dat","Top_Xtr":1,"Re":150000,"src":"retest_106.txt","sym":5.65395053373896e-05,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00636301680679851,0.751503599940214,0.0115232729496734,0.617882281805394,0.0184866337658855,0.516474874255053,0.0236044881795167,0.425516435642791,0.0279164439014802,0.22020135983351,0.0337448822003626,0.0597789339840893,0.0255238951483884,0,0,0.0545974187204916,-0.0244665525182533,0.191614124162238,-0.0334738240075662,0.354272483283979,-0.0305305638104903,0.461006103363399,-0.026178545769655,0.600655324159936,-0.0192759095216128,0.736649107785801,-0.0122212364419911,0.846409340674087,-0.00685959473060787,1,0],"CDpres":0.00227,"clcd":124.459184427243,"alpha":0},
             {"alpha":0,"clcd":149.02385832261,"CDpres":0.00112,"Bot_Xtr":0.993591039817209,"xy":[1,0,0.944740406454351,0.00212701187096991,0.814149693519042,0.00757565457280877,0.682864593067749,0.0131070597020876,0.52069384686288,0.0186000597455636,0.325213183352731,0.0217853204448427,0.152815219118241,0.0196254241736183,0.0429551112266143,0.0119257640569478,0,0,0.0408398189079085,-0.0116489636687204,0.136824284769333,-0.0189733319595663,0.289192311415617,-0.0218631276712577,0.490511679687803,-0.0194095354040017,0.680813751073162,-0.0132157110681144,0.840165601920523,-0.00643175082348922,0.955145580885723,-0.00171988247812161,1,0],"sym":9.50528341213849e-07,"src":"retestc_1.txt","Re":200000,"Top_Xtr":0.996676648923356,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re200000-N3.dat","diter":4,"Cm":0.000405037033318723,"r":6,"id":1152,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt83.5371002500467>53.1216876813138) l1 Foil spline 17pts Re200000 N3","xver":6.991,"iver":1.2020052,"good":83.5371002500272,"Cpmin":-0.167910681620043,"CDf":0.00559,"CDp":-8.71279737569306e-05,"CL":-0.00191572522103005,"CD":0.0067103349172129,"n":3},
             {"Cm":-0.000156676000652964,"id":1153,"good":95.4028503383799,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt87.2962703316507>48.0812957714737) l1 Foil spline 17pts Re225000 N3","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00556,"Cpmin":-0.17121922705412,"CD":0.00676006699993299,"CL":0.00105756159123878,"n":4,"CDp":-2.43171070108153e-05,"clcd":147.92752793869,"CDpres":0.0012,"alpha":0,"sym":5.1549597510215e-05,"xy":[1,0,0.944740406454351,0.0022302096783402,0.814149693519042,0.0079432082061376,0.682864593067749,0.0137429846072505,0.52069384686288,0.019502492594621,0.325213183352731,0.0228422949420004,0.152815219118241,0.0205776053866482,0.0429551112266143,0.0125043751680043,0,0,0.0408398189079085,-0.0120020144316839,0.136824284769333,-0.0195483658865989,0.289192311415617,-0.0225257440313578,0.490511679687803,-0.0199977895593091,0.680813751073162,-0.0136162460005249,0.840165601920523,-0.00662668099925424,0.955145580885723,-0.00173644496810787,1,0],"Bot_Xtr":1,"Re":200000,"src":"retestc_17.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re225000-N3.dat"},
             {"CDpres":0.00142,"clcd":143.612447410069,"alpha":0,"sym":5.22605707649367e-05,"xy":[1,0,0.969087652468728,0.00186742433791754,0.801860568053254,0.00953845691851539,0.696504319290661,0.0135949871082495,0.549776607886737,0.0182462247619933,0.338361913064034,0.0222946429145739,0.144153484994011,0.021117489007852,0.0380479581477159,0.0132953993697226,0,0,0.039910401665453,-0.0138791522636918,0.148421317779882,-0.0215047445479445,0.328374676921391,-0.0226477217498144,0.517844762768298,-0.019315126169448,0.689480272273693,-0.0140782163772804,0.832528496272264,-0.00830233419249831,0.973498898866872,-0.00164453795415418,1,0],"Bot_Xtr":1,"Re":200000,"src":"retest_101.txt","diter":3,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re55000-N11.dat","Top_Xtr":1,"Cm":0.000119318782066928,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt71.7801269492676>58.659444003239) l1 Foil spline 17pts Re55000 N11","iver":1.2020052,"xver":6.991,"good":94.8698801178568,"id":1154,"r":6,"CDf":0.00555,"Cpmin":-0.224885660740904,"n":5,"CD":0.006963184724125,"CL":-0.000831358549772263,"CDp":0.00020356101992681},
             {"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re150000-N5.dat","Top_Xtr":1,"diter":3,"src":"retest_102.txt","Re":200000,"xy":[1,0,0.944740406454351,0.00259865098066909,0.814149693519042,0.0100966487641595,0.682864593067749,0.0174687714270719,0.52069384686288,0.0247897087226496,0.325213183352731,0.0290349469649444,0.152815219118241,0.0261562895752786,0.0429551112266143,0.0158943692284265,0,0,0.0408398189079085,-0.0153968043270399,0.136824284769333,-0.0250776539373913,0.289192311415617,-0.0288971884799794,0.490511679687803,-0.025654197849086,0.680813751073162,-0.0174676240003077,0.840165601920523,-0.00850104882509426,0.955145580885723,-0.00204201263897575,1,0],"Bot_Xtr":1,"sym":1.65743451766806e-05,"alpha":0,"clcd":138.518050262959,"CDpres":0.00185,"CDp":0.000447556327951121,"n":6,"CD":0.00721927574133209,"CL":0.00035437669762834,"Cpmin":-0.216797790033625,"CDf":0.00537,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt99.6223772427113>69.7602800923986) l1 Foil spline 17pts Re150000 N5","good":113.394601136929,"xver":6.991,"iver":1.2020052,"id":1155,"Cm":-4.15136044161217e-05},
             {"alpha":0,"clcd":139.370088579642,"CDpres":0.0017,"Bot_Xtr":1,"xy":[1,0,0.969087652468728,0.00213099996241242,0.801860568053254,0.0108847522880074,0.696504319290661,0.0155138371223028,0.549776607886737,0.0208215687738846,0.338361913064034,0.0254413966061595,0.144153484994011,0.0240980945617109,0.0380479581477159,0.0151719643906601,0,0,0.039910401665453,-0.0154512099874082,0.148421317779882,-0.0239405345098129,0.328374676921391,-0.0252129739514576,0.517844762768298,-0.0215029033983694,0.689480272273693,-0.0156728216075977,0.832528496272264,-0.00924271933592924,0.973498898866872,-0.00183081075696333,1,0],"sym":5.41832220034805e-05,"src":"retest_72.txt","Re":200000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re80000-N7.dat","diter":3,"Cm":-7.6127451036515e-05,"r":6,"id":1156,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt78.0180577931905>65.7244648136795) l1 Foil spline 17pts Re80000 N7","xver":6.991,"good":99.3141832745415,"Cpmin":-0.24827132363001,"CDf":0.00547,"CDp":0.000465193965717706,"CD":0.00717514073637515,"CL":0.000778906434011356,"n":7},
             {"clcd":143.063352026324,"CDpres":0.00202,"alpha":0,"sym":5.65395053373896e-05,"xy":[1,0,0.857899050218291,0.00636301680679851,0.751503599940214,0.0115232729496734,0.617882281805394,0.0184866337658855,0.516474874255053,0.0236044881795167,0.425516435642791,0.0279164439014802,0.22020135983351,0.0337448822003626,0.0597789339840893,0.0255238951483884,0,0,0.0545974187204916,-0.0244665525182533,0.191614124162238,-0.0334738240075662,0.354272483283979,-0.0305305638104903,0.461006103363399,-0.026178545769655,0.600655324159936,-0.0192759095216128,0.736649107785801,-0.0122212364419911,0.846409340674087,-0.00685959473060787,1,0],"Bot_Xtr":1,"Re":200000,"src":"retestc_9.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re225000-N9.dat","Cm":-8.59010273590686e-05,"id":1157,"good":97.098342178808,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt114.674935443792>82.9957443780523) l1 Foil spline 17pts Re225000 N9","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00497,"Cpmin":-0.39267514099754,"CL":0.000423776646552768,"CD":0.00698991031480934,"n":8,"CDp":0.000814456646940946},
             {"Cm":-0.000965990052816773,"good":112.892354378282,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt60.9689523624923>52.0325517888816) l1 Foil spline 17pts Re45000 N5","xver":6.991,"iver":1.2020052,"id":1158,"r":6,"CDf":0.00551,"Cpmin":-0.245302219003522,"n":9,"CD":0.00706097911834281,"CL":-0.00474808132473475,"CDp":0.00033078220655851,"CDpres":0.00155,"clcd":141.623418401313,"alpha":-0.1,"sym":0.000746881251080164,"xy":[1,0,0.969087652468728,0.00205098404047502,0.801860568053254,0.0104760458099467,0.696504319290661,0.0149313153006119,0.549776607886737,0.0200397494163004,0.338361913064034,0.0244861094917889,0.144153484994011,0.0231932464681862,0.0380479581477159,0.014602279388439,0,0,0.039910401665453,-0.0142155499157498,0.148421317779882,-0.0220259684265066,0.328374676921391,-0.0231966486782285,0.517844762768298,-0.0197832789045112,0.689480272273693,-0.0144194388701606,0.832528496272264,-0.00850356303384932,0.973498898866872,-0.00168439764414006,1,0],"Bot_Xtr":1,"Re":200000,"src":"retest_66.txt","diter":3,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re45000-N5.dat","Top_Xtr":1},
             {"id":1159,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt73.804721568701>71.3822161492161) l1 Foil spline 17pts Re65536 N8","xver":6.991,"iver":1.2020052,"good":108.252177621408,"r":6,"Cm":2.96792165155132e-05,"CL":-0.00027292191593846,"CD":0.00738260940359962,"n":10,"CDp":0.000378493276511075,"CDf":0.00553,"Cpmin":-0.221488683490363,"sym":1.1043636127906e-05,"Bot_Xtr":1,"xy":[1,0,0.883609074234346,0.00741653894014664,0.672127682508641,0.0176383142205651,0.448051878989487,0.0251203211110882,0.261607586958807,0.0268234812538843,0.14960260982261,0.023854142164159,0.0876932172572549,0.0199253401468411,0.0269668136105797,0.0122766809178681,0,0,0.0260784653873372,-0.0120743745054073,0.0852103572234493,-0.019807320185396,0.159346520639483,-0.0244309657466735,0.277295492850028,-0.0270265704384169,0.461088095254591,-0.0249217633253027,0.679515403216876,-0.0174066596617094,0.887295989576364,-0.00724597187291881,1,0],"clcd":135.453461686923,"CDpres":0.00185,"alpha":0,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re65536-N8.dat","Re":200000,"src":"retest_148.txt"},
             {"n":11,"CD":0.00692408661524592,"CL":-0.00191726343263258,"CDp":0.000714413700044694,"CDf":0.00503,"Cpmin":-0.372218819375287,"good":110.424654519976,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.6522676347788>76.0189035568534) l1 Foil spline 17pts Re150000 N10","xver":6.991,"iver":1.2020052,"id":1160,"r":6,"Cm":0.000103718668934754,"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re150000-N10.dat","Top_Xtr":1,"Re":200000,"src":"retest_82.txt","sym":0.000186621040472494,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00603237044939248,0.751503599940214,0.0109244802163061,0.617882281805394,0.0175259985356188,0.516474874255053,0.0223779099270984,0.425516435642791,0.0264658001631371,0.22020135983351,0.0319913708205523,0.0597789339840893,0.0241975772690122,0,0,0.0545974187204916,-0.0237660629022777,0.191614124162238,-0.0325154517110687,0.354272483283979,-0.0296564585231526,0.461006103363399,-0.0254290409320076,0.600655324159936,-0.0187240306065797,0.736649107785801,-0.01187133633998,0.846409340674087,-0.00666320110813053,1,0],"CDpres":0.00189,"clcd":144.423381099557,"alpha":0},
             {"alpha":0,"CDpres":0.00234,"clcd":139.692871429289,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00690861127145202,0.751503599940214,0.0125113316216725,0.617882281805394,0.0200717631721079,0.516474874255053,0.02562844607288,0.425516435642791,0.0303101288040856,0.22020135983351,0.0366383243360539,0.0597789339840893,0.027712431864884,0,0,0.0545974187204916,-0.0267830502629754,0.191614124162238,-0.0366431318928068,0.354272483283979,-0.0334212032726431,0.461006103363399,-0.0286571353539567,0.600655324159936,-0.021100956221632,0.736649107785801,-0.0133783453822257,0.846409340674087,-0.00750906243601124,1,0],"sym":6.53059873199423e-05,"src":"retest_154.txt","Re":200000,"Foil_fn":"optbs-spline_foil_sym_tp29-8.dat-s17_n17s0-Re200000-N10.dat","Top_Xtr":1,"diter":3,"Cm":-2.91550779081627e-05,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.9963777162855>86.4422066326818) l1 Foil spline 17pts Re200000 N10","xver":6.991,"good":113.58371975041,"id":1161,"Cpmin":-0.425851819807807,"CDf":0.00482,"CDp":0.00105370915234359,"n":12,"CL":-0.000376556827026472,"CD":0.00715856141955093},
             {"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re400000-N12.dat","Top_Xtr":1,"diter":3,"src":"retest_71.txt","Re":200000,"xy":[1,0,0.857899050218291,0.00711786402201851,0.751503599940214,0.0128902834040521,0.617882281805394,0.0206797104841587,0.516474874255053,0.0264046980029395,0.425516435642791,0.0312281827476456,0.22020135983351,0.03774805100068,0.0597789339840893,0.0285518049841353,0,0,0.0545974187204916,-0.0276171736484734,0.191614124162238,-0.0377843347404871,0.354272483283979,-0.0344620633295623,0.461006103363399,-0.0295496246905114,0.600655324159936,-0.021758118153078,0.736649107785801,-0.0137949966087668,0.846409340674087,-0.00774292245268378,1,0],"Bot_Xtr":1,"sym":7.28145479600258e-05,"alpha":0,"CDpres":0.00247,"clcd":138.310254873577,"CDp":0.001149932119892,"n":13,"CL":-0.00045260077048259,"CD":0.00723012188007357,"Cpmin":-0.436278000211471,"CDf":0.00476,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt115.005518948493>101.680092053478) l1 Foil spline 17pts Re400000 N12","xver":6.991,"good":111.961302487619,"id":1162,"Cm":-2.6852661854746e-05},
             {"clcd":139.69287142929,"CDpres":0.00234,"alpha":0,"sym":6.53059873199423e-05,"xy":[1,0,0.857899050218291,0.00690861127145202,0.751503599940214,0.0125113316216725,0.617882281805394,0.0200717631721079,0.516474874255053,0.02562844607288,0.425516435642791,0.0303101288040856,0.22020135983351,0.0366383243360539,0.0597789339840893,0.027712431864884,0,0,0.0545974187204916,-0.0267830502629754,0.191614124162238,-0.0366431318928068,0.354272483283979,-0.0334212032726431,0.461006103363399,-0.0286571353539567,0.600655324159936,-0.021100956221632,0.736649107785801,-0.0133783453822257,0.846409340674087,-0.00750906243601124,1,0],"Bot_Xtr":1,"Re":200000,"src":"retest_156.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs-spline_foil_sym_tp29-8.dat-s17_n17s0-Re200000-N10.dat","Cm":-2.91550779081445e-05,"id":1163,"good":105.051543673344,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.9963777162855>86.4422066326818) l1 Foil spline 17pts Re200000 N10","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00482,"Cpmin":-0.425851819807807,"CL":-0.000376556827026503,"CD":0.00715856141955093,"n":14,"CDp":0.00105370915234359},
             {"src":"retest_89.txt","Re":225000,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re225000-N3.dat","Top_Xtr":0.955194598524026,"diter":3,"alpha":0.1,"CDpres":0.00115,"clcd":155.761406302556,"Bot_Xtr":0.967176035093641,"xy":[1,0,0.944740406454351,0.0022302096783402,0.814149693519042,0.0079432082061376,0.682864593067749,0.0137429846072505,0.52069384686288,0.019502492594621,0.325213183352731,0.0228422949420004,0.152815219118241,0.0205776053866482,0.0429551112266143,0.0125043751680043,0,0,0.0408398189079085,-0.0120020144316839,0.136824284769333,-0.0195483658865989,0.289192311415617,-0.0225257440313578,0.490511679687803,-0.0199977895593091,0.680813751073162,-0.0136162460005249,0.840165601920523,-0.00662668099925424,0.955145580885723,-0.00173644496810787,1,0],"sym":5.1549597510215e-05,"Cpmin":-0.189495957416103,"CDf":0.00527,"CDp":-4.25680564796659e-05,"n":3,"CL":0.0170853622430689,"CD":0.00642007557416095,"Cm":-0.00124048532757588,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt87.2962703316507>48.0812957714737) l1 Foil spline 17pts Re225000 N3","good":87.2962703316065,"iver":1.2020052,"id":1164},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt95.1861492659334>68.1876993897687) l1 Foil spline 17pts Re225000 N4","good":95.1861492660168,"xver":6.991,"iver":1.2020052,"id":1165,"r":6,"Cm":-0.0135080942979725,"n":4,"CL":0.174725861898706,"CD":0.00679571379920846,"CDp":0.000370936625467174,"CDf":0.00514,"Cpmin":-0.604182338200721,"sym":0.000515002668716418,"Bot_Xtr":1,"xy":[1,0,0.927533762368065,0.00479371905998961,0.828124577508512,0.0101433079013888,0.673910782200253,0.0172313186285827,0.485356610471494,0.0237232424725331,0.298817780508802,0.0264585431494015,0.140740099512849,0.0231503260239235,0.0345490619416974,0.013414400106774,0,0,0.033827731492854,-0.0126613036172526,0.142528433402255,-0.022314698077789,0.31046792119717,-0.0253496392407423,0.499715124890922,-0.0223506955491882,0.684159552318164,-0.0161089466233038,0.829477323686799,-0.0096493792916726,0.922486667396241,-0.00489285792713448,1,0],"clcd":147.151576647692,"CDpres":0.00166,"alpha":1,"diter":4,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re225000-N4.dat","Top_Xtr":0.888529693956048,"Re":225000,"src":"retestc_12.txt"},
             {"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re100000-N4.dat","Top_Xtr":0.985835929029151,"diter":3,"src":"retest_154.txt","Re":225000,"xy":[1,0,0.794574379082928,0.00879061839652528,0.546030639687268,0.0216482620921415,0.363514019175692,0.0286550896318874,0.221984972352103,0.0288975059833995,0.122670417262654,0.0243107900238919,0.0658532742824706,0.0184653108413111,0.0236940673606567,0.011110257360247,0,0,0.0239783675371822,-0.0110806599057954,0.0623361812874123,-0.0176756895522041,0.114829236142557,-0.0233734416591417,0.214306107242777,-0.028310853135615,0.357389074847702,-0.0283763339612263,0.542695962832085,-0.0215164061343808,0.784157786565453,-0.00915517831605568,1,0],"Bot_Xtr":0.991573868031868,"sym":6.49868625513952e-05,"alpha":0,"CDpres":0.00137,"clcd":155.687275330109,"CDp":0.000174161513690569,"n":5,"CD":0.00642313251278672,"CL":0.00418708995001883,"Cpmin":-0.216048702973402,"CDf":0.00505,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt80.2831864934908>51.9448045577382) l1 Foil spline 17pts Re100000 N4","xver":6.991,"good":92.2398547593148,"iver":1.2020052,"id":1166,"Cm":-0.000757866950401759},
             {"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re55000-N6.dat","Top_Xtr":1,"diter":3,"src":"retest_81.txt","Re":225000,"xy":[1,0,0.888395795100267,0.00419663949320081,0.724782775337367,0.0101953070286959,0.573493663117091,0.0167528982255551,0.434846152115145,0.0214989324931256,0.296738332433587,0.0241704975217844,0.156304320466368,0.0228498632789765,0.0490216324689624,0.0151360227431366,0,0,0.0501864526744944,-0.015730373989637,0.168411092824914,-0.0239586666717849,0.326746855954174,-0.0245589204141632,0.462695012305671,-0.0212570332923625,0.564195027615659,-0.0176222998471145,0.67400816885005,-0.0128006654174616,0.86979319971664,-0.00517239596946446,1,0],"Bot_Xtr":1,"sym":0.0002053893137046,"alpha":0,"clcd":158.112413291922,"CDpres":0.00118,"CDp":1.29321623720106e-05,"n":6,"CD":0.00632461410954311,"CL":-0.00237189355764307,"Cpmin":-0.219585664639755,"CDf":0.00515,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt69.7091729812019>54.0159058282702) l1 Foil spline 17pts Re55000 N6","xver":6.991,"iver":1.2020052,"good":109.525354422263,"id":1167,"Cm":0.000390018575669653},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt73.804721568701>71.3822161492161) l1 Foil spline 17pts Re65536 N8","xver":6.991,"iver":1.2020052,"good":104.5871542668,"id":1168,"Cm":2.80162467256966e-05,"CDp":0.000345946855656341,"n":7,"CL":-0.000266294032884152,"CD":0.00700874528195198,"Cpmin":-0.221544648231007,"CDf":0.00521,"xy":[1,0,0.883609074234346,0.00741653894014664,0.672127682508641,0.0176383142205651,0.448051878989487,0.0251203211110882,0.261607586958807,0.0268234812538843,0.14960260982261,0.023854142164159,0.0876932172572549,0.0199253401468411,0.0269668136105797,0.0122766809178681,0,0,0.0260784653873372,-0.0120743745054073,0.0852103572234493,-0.019807320185396,0.159346520639483,-0.0244309657466735,0.277295492850028,-0.0270265704384169,0.461088095254591,-0.0249217633253027,0.679515403216876,-0.0174066596617094,0.887295989576364,-0.00724597187291881,1,0],"Bot_Xtr":1,"sym":1.1043636127906e-05,"alpha":0,"clcd":142.67889041068,"CDpres":0.0018,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re65536-N8.dat","Top_Xtr":1,"diter":3,"src":"retest_85.txt","Re":225000},
             {"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re150000-N10.dat","Top_Xtr":1,"Re":225000,"src":"retest_90.txt","sym":0.000186621040472494,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00603237044939248,0.751503599940214,0.0109244802163061,0.617882281805394,0.0175259985356188,0.516474874255053,0.0223779099270984,0.425516435642791,0.0264658001631371,0.22020135983351,0.0319913708205523,0.0597789339840893,0.0241975772690122,0,0,0.0545974187204916,-0.0237660629022777,0.191614124162238,-0.0325154517110687,0.354272483283979,-0.0296564585231526,0.461006103363399,-0.0254290409320076,0.600655324159936,-0.0187240306065797,0.736649107785801,-0.01187133633998,0.846409340674087,-0.00666320110813053,1,0],"CDpres":0.00181,"clcd":152.887232046576,"alpha":0,"n":8,"CD":0.00654076855610387,"CL":-0.00190618947178327,"CDp":0.000665871913250383,"CDf":0.00474,"Cpmin":-0.372722522947802,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.6522676347788>76.0189035568534) l1 Foil spline 17pts Re150000 N10","xver":6.991,"good":101.825021612285,"id":1169,"r":6,"Cm":9.97569286285487e-05},
             {"Cm":-8.44675468376268e-05,"good":95.7167955264602,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt114.674935443792>82.9957443780523) l1 Foil spline 17pts Re225000 N9","xver":6.991,"iver":1.2020052,"id":1170,"r":6,"CDf":0.00468,"Cpmin":-0.39316187150169,"n":9,"CL":0.00042035575041735,"CD":0.00660521090052502,"CDp":0.000762491890892653,"CDpres":0.00193,"clcd":151.395620073314,"alpha":0,"sym":5.65395053373896e-05,"xy":[1,0,0.857899050218291,0.00636301680679851,0.751503599940214,0.0115232729496734,0.617882281805394,0.0184866337658855,0.516474874255053,0.0236044881795167,0.425516435642791,0.0279164439014802,0.22020135983351,0.0337448822003626,0.0597789339840893,0.0255238951483884,0,0,0.0545974187204916,-0.0244665525182533,0.191614124162238,-0.0334738240075662,0.354272483283979,-0.0305305638104903,0.461006103363399,-0.026178545769655,0.600655324159936,-0.0192759095216128,0.736649107785801,-0.0122212364419911,0.846409340674087,-0.00685959473060787,1,0],"Bot_Xtr":1,"Re":225000,"src":"retestc_4.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re225000-N9.dat","Top_Xtr":1},
             {"CDp":0.000530495679687926,"CL":0.000182855153902232,"CD":0.00657939058037591,"n":10,"Cpmin":-0.279432672276809,"CDf":0.00483,"r":6,"id":1171,"good":120.865346500454,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt97.6761543523938>69.5848718673156) l1 Foil spline 17pts Re150000 N7","xver":6.991,"iver":1.2020052,"Cm":-2.99645586300471e-05,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re150000-N7.dat","diter":3,"src":"retest_82.txt","Re":225000,"xy":[1,0,0.888395795100267,0.00454557755311014,0.724782775337367,0.0134106678881808,0.573493663117091,0.0220363696389977,0.434846152115145,0.0282791918678105,0.296738332433587,0.0317933058851893,0.156304320466368,0.0300561745577847,0.0490216324689624,0.0199095695288857,0,0,0.0501864526744944,-0.0200539240298403,0.168411092824914,-0.0305437926401983,0.326746855954174,-0.0313090282891544,0.462695012305671,-0.0270996055799854,0.564195027615659,-0.0224658525345878,0.67400816885005,-0.0163189744873385,0.86979319971664,-0.00542986949809113,1,0],"Bot_Xtr":1,"sym":9.56357545512509e-06,"alpha":0,"clcd":151.989760720797,"CDpres":0.00175},
             {"Re":225000,"src":"retest_77.txt","diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re100000-N4.dat","Top_Xtr":1,"CDpres":0.00142,"clcd":153.601037225254,"alpha":-0.1,"sym":0.000233281447351466,"xy":[1,0,0.961992840051787,0.00147545460917483,0.838375902301386,0.00706473302365647,0.669468112967632,0.0166192976351929,0.498697719332731,0.0242291021350552,0.301319859646249,0.026403371336202,0.134615624611079,0.0216616792492199,0.0376550591335466,0.0123022838115679,0,0,0.0409493023355519,-0.0125539840682082,0.14830924318344,-0.0217371710240008,0.317279938768802,-0.0257023759113001,0.498956936169248,-0.0234693458229113,0.653261727003669,-0.0169865833128309,0.844873051243488,-0.00652854240001878,0.969355895385625,-0.00118175703008136,1,0],"Bot_Xtr":1,"CDf":0.00509,"Cpmin":-0.172515914226519,"n":11,"CD":0.00651037270362642,"CL":-0.00566774796048649,"CDp":0.000201696015840046,"Cm":-0.00086204792077628,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt76.7823995733815>63.9203580491261) l1 Foil spline 17pts Re100000 N4","iver":1.2020052,"xver":6.991,"good":133.489186652223,"id":1172,"r":6},
             {"Cpmin":-1.30393951816012,"CDf":0.00536,"CDp":0.00142878455678113,"n":12,"CL":0.43842916387553,"CD":0.00893211763931885,"Cm":-0.01921172070623,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn312s.dat-s17_n17s0.dat (opt110.113132737476>98.8639104953148) l1 Foil spline 17pts Re400000 N10","xver":6.991,"good":20.182728681909,"iver":1.2020052,"id":1173,"src":"retest_88.txt","Re":225000,"Foil_fn":"optbs_spline_sym_hn312s.dat-s17_n17s0_nsopt-Re400000-N10.dat","Top_Xtr":0.59792512113689,"diter":4,"alpha":3,"CDpres":0.00358,"clcd":49.0845711598761,"Bot_Xtr":1,"xy":[1,0,0.929329094131798,0.00682271712306304,0.872083689141921,0.0116320295380558,0.728962270696779,0.0229511892800708,0.521510065351771,0.0362794481516673,0.321117029255808,0.04248869308019,0.15871961398988,0.0393354344200351,0.049330363603105,0.0251030758052513,0,0,0.0363843110360385,-0.0243578481529198,0.136139586799562,-0.040301697046544,0.302488592894218,-0.0445841298139676,0.509903465583168,-0.0381047984803767,0.707120447355533,-0.0252869796630067,0.849461103630312,-0.0138536829715884,0.919373852324625,-0.0079165755464412,1,0],"sym":0.00389750012306747},
             {"Cm":0.00101672094747584,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt130.49607580208>103.990184835766) l1 Foil spline 17pts Re750000 N9","iver":1.2020052,"xver":6.991,"good":108.38167128943,"id":1174,"Cpmin":-0.323479768265948,"CDf":0.0049,"CDp":0.00128682755006641,"n":13,"CL":0.00483601152783966,"CD":0.00772485464895962,"alpha":0.1,"clcd":129.452273918795,"CDpres":0.00282,"Bot_Xtr":1,"xy":[1,0,0.969087652468728,0.00282170591849419,0.801860568053254,0.0144127501145726,0.696504319290661,0.0205422274982118,0.549776607886737,0.0275703166954039,0.338361913064034,0.0336875366703855,0.144153484994011,0.0319088396286196,0.0380479581477159,0.0200895459743905,0,0,0.039910401665453,-0.0212456995706645,0.148421317779882,-0.0329186778363065,0.328374676921391,-0.0346683056079229,0.517844762768298,-0.02956688996338,0.689480272273693,-0.0215504196481052,0.832528496272264,-0.0127089100715836,0.973498898866872,-0.002517398659709,1,0],"sym":0.000362452525413979,"src":"retest_80.txt","Re":225000,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re750000-N9.dat","Top_Xtr":1,"diter":3},
             {"CDpres":0.00282,"clcd":129.452273918795,"alpha":0.1,"sym":0.000362452525413979,"xy":[1,0,0.969087652468728,0.00282170591849419,0.801860568053254,0.0144127501145726,0.696504319290661,0.0205422274982118,0.549776607886737,0.0275703166954039,0.338361913064034,0.0336875366703855,0.144153484994011,0.0319088396286196,0.0380479581477159,0.0200895459743905,0,0,0.039910401665453,-0.0212456995706645,0.148421317779882,-0.0329186778363065,0.328374676921391,-0.0346683056079229,0.517844762768298,-0.02956688996338,0.689480272273693,-0.0215504196481052,0.832528496272264,-0.0127089100715836,0.973498898866872,-0.002517398659709,1,0],"Bot_Xtr":1,"Re":225000,"src":"retest_81.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re750000-N9.dat","Cm":0.00101672094747584,"id":1175,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt130.49607580208>103.990184835766) l1 Foil spline 17pts Re750000 N9","iver":1.2020052,"good":108.044600380923,"r":6,"CDf":0.0049,"Cpmin":-0.323479768265948,"CD":0.00772485464895962,"CL":0.00483601152783966,"n":14,"CDp":0.00128682755006641},
             {"CDf":0.00536,"Cpmin":-0.217379083763128,"n":3,"CD":0.0070894428520664,"CL":0.00362647140263811,"CDp":0.000435001083440769,"Cm":-0.000742144716848146,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca000834.dat-s17_n17s0.dat (opt78.6738667718895>75.5883934080798) l1 Foil spline 17pts Re275000 N3","xver":6.991,"good":78.6738667793814,"iver":1.2020052,"id":1176,"r":6,"Re":275000,"src":"retestc_21.txt","diter":5,"Foil_fn":"optbs_spline_sym_naca000834.dat-s17_n17s0_nsopt-Re275000-N3.dat","Top_Xtr":0.87041380986283,"clcd":141.054807954129,"CDpres":0.00173,"alpha":0,"sym":0.000164048194353575,"xy":[1,0,0.882475028942614,0.0142916373577392,0.699239640304744,0.0299994556851517,0.497717544683343,0.0390184490147964,0.305167273261072,0.0388797486042349,0.159866510817707,0.0308956731660402,0.0760104824652203,0.0208925384130744,0.0261521745928966,0.0115072919818916,0,0,0.0246906691091517,-0.0108606289100266,0.0735651603193743,-0.0202265327325657,0.15942101402779,-0.0303494242691685,0.305078501105519,-0.0382497670917014,0.499727822478872,-0.0383515362920261,0.703403311961931,-0.0292438776457425,0.885223603433491,-0.0137688321536957,1,0],"Bot_Xtr":0.874014772358452},
             {"clcd":165.577895557452,"CDpres":0.00133,"alpha":0,"sym":0.000188018531487083,"xy":[1,0,0.944740406454351,0.00235318972790567,0.814149693519042,0.00914294775821499,0.682864593067749,0.0158187204773199,0.52069384686288,0.0224481426547295,0.325213183352731,0.026292387648995,0.152815219118241,0.0236856401288733,0.0429551112266143,0.014393031876194,0,0,0.0408398189079085,-0.01442199983871,0.136824284769333,-0.0234899342329835,0.289192311415617,-0.0270676459052954,0.490511679687803,-0.0240299759211711,0.680813751073162,-0.016361711506112,0.840165601920523,-0.0079628293105642,0.955145580885723,-0.00191272846783096,1,0],"Bot_Xtr":0.938582382945671,"Re":275000,"src":"retestc_22.txt","diter":6,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re275000-N4.dat","Top_Xtr":0.947716041098165,"Cm":0.00123934867487345,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt97.1009110684734>64.1268138357685) l1 Foil spline 17pts Re275000 N4","iver":1.2020052,"good":97.1010308234131,"id":1177,"r":6,"CDf":0.00471,"Cpmin":-0.206936234119589,"n":4,"CL":-0.00689781034167062,"CD":0.00603945349488406,"CDp":0.00016445125635695},
             {"xy":[1,0,0.836603425815351,0.00695358342325052,0.803714437162079,0.00834125877682961,0.662807671328547,0.0143046016831253,0.520216031590305,0.019269989827017,0.349816623712441,0.0221321730125516,0.168769456385459,0.0198633242390425,0.0431801448644717,0.0116490613228366,0,0,0.0337930770596252,-0.0115450996694317,0.152912772871317,-0.0200477317389147,0.338443399173723,-0.0225485413787481,0.522479045575666,-0.0194016929551823,0.684363320479229,-0.0135154671977669,0.848263409871412,-0.00647394916386209,0.872525547148609,-0.00546222892833583,1,0],"Bot_Xtr":1,"sym":0.000584080294079328,"alpha":0,"CDpres":0.0011,"clcd":172.455436144999,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_bqm34.dat-s17_n17s0_nsopt-Re125000-N4.dat","diter":3,"src":"retest_75.txt","Re":275000,"r":6,"id":1178,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_bqm34.dat-s17_n17s0.dat (opt82.4648076537096>53.7676573505292) l1 Foil spline 17pts Re125000 N4","good":102.810356749234,"iver":1.2020052,"Cm":-0.000288145616661226,"CDp":1.09027423912615e-05,"CD":0.00579859946635262,"CL":0.00190458235501903,"n":5,"Cpmin":-0.165832656080653,"CDf":0.0047},
             {"Cpmin":-0.154448346320201,"CDf":0.00467,"CDp":-2.32946585260215e-05,"CD":0.00577587651542345,"CL":0.000313155689621666,"n":6,"Cm":-4.23904834489941e-05,"r":6,"id":1179,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt83.8762955150437>60.1043499133465) l1 Foil spline 17pts Re150000 N3","xver":6.991,"iver":1.2020052,"good":110.059284162164,"src":"retest_95.txt","Re":275000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re150000-N3.dat","diter":3,"alpha":0,"CDpres":0.00111,"clcd":173.133895319555,"Bot_Xtr":1,"xy":[1,0,0.961992840051787,0.00154606945883586,0.838375902301386,0.00637357446843835,0.669468112967632,0.0149933947590592,0.498697719332731,0.0218587151480562,0.301319859646249,0.0238202707541262,0.134615624611079,0.0195424689572873,0.0376550591335466,0.0110987240058944,0,0,0.0409493023355519,-0.011604671563851,0.14830924318344,-0.0200934403843633,0.317279938768802,-0.0237588027227634,0.498956936169248,-0.0216946308529287,0.653261727003669,-0.0157020846343586,0.844873051243488,-0.00603486430532861,0.969355895385625,-0.0012057445813033,1,0],"sym":1.90738035701545e-05},
             {"n":7,"CD":0.00595352408396605,"CL":-0.00596932304032932,"CDp":0.000430327691820552,"CDf":0.00436,"Cpmin":-0.278936384617176,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt101.163903228469>74.6608353346734) l1 Foil spline 17pts Re150000 N8","xver":6.991,"iver":1.2020052,"good":111.813299813105,"id":1180,"r":6,"Cm":0.00107627655687513,"diter":4,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re150000-N8.dat","Top_Xtr":0.994514359906688,"Re":275000,"src":"retest_94.txt","sym":9.83464389905156e-05,"Bot_Xtr":0.988965074761949,"xy":[1,0,0.888395795100267,0.00446394257540885,0.724782775337367,0.0131698228995694,0.573493663117091,0.0216406138691141,0.434846152115145,0.0277713199482214,0.296738332433587,0.0312223232572036,0.156304320466368,0.0295163894345209,0.0490216324689624,0.0195520094068676,0,0,0.0501864526744944,-0.0200593893477079,0.168411092824914,-0.030552116773441,0.326746855954174,-0.0313175609729061,0.462695012305671,-0.0271069910651584,0.564195027615659,-0.022471975177971,0.67400816885005,-0.0163234219153189,0.86979319971664,-0.0054313493063692,1,0],"clcd":167.967742449079,"CDpres":0.00159,"alpha":0},
             {"Cm":-0.0117111591526918,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt90.5036133856091>66.0506652020868) l1 Foil spline 17pts Re125000 N6","iver":1.2020052,"xver":6.991,"good":105.17129648565,"id":1181,"r":6,"CDf":0.00435,"Cpmin":-0.384764733251984,"n":8,"CD":0.0061512856167146,"CL":0.121118702988939,"CDp":0.000443870808361727,"CDpres":0.0018,"clcd":162.567642328743,"alpha":0.6,"sym":0.000202071460186809,"xy":[1,0,0.794574379082928,0.0104000499547449,0.546030639687268,0.0256117370856041,0.363514019175692,0.0339014105932658,0.221984972352103,0.0341882097752859,0.122670417262654,0.0287617343038946,0.0658532742824706,0.0218460347744632,0.0236940673606567,0.0131443803319131,0,0,0.0239783675371822,-0.013589826438053,0.0623361812874123,-0.021678271441372,0.114829236142557,-0.0286662543664534,0.214306107242777,-0.034721720880991,0.357389074847702,-0.0348020295505688,0.542695962832085,-0.0263887013429553,0.784157786565453,-0.0112283280402416,1,0],"Bot_Xtr":1,"Re":275000,"src":"retest_151.txt","diter":3,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re125000-N6.dat","Top_Xtr":0.905793972706533},
             {"CDf":0.00426,"Cpmin":-0.34600645852608,"n":9,"CD":0.00654965165236862,"CL":0.00128622358408951,"CDp":0.00117960837296501,"Cm":-0.000177700497547429,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt96.0481298445625>82.1760289384273) l1 Foil spline 17pts Re225000 N9","iver":1.2020052,"good":98.26629076985,"id":1182,"r":6,"Re":275000,"src":"retestc_6.txt","diter":5,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re225000-N9.dat","Top_Xtr":0.911444479262647,"CDpres":0.00229,"clcd":152.679875675275,"alpha":0,"sym":3.07920710730518e-05,"xy":[1,0,0.888395795100267,0.00575480041230236,0.724782775337367,0.0169781983016324,0.573493663117091,0.0278985250174388,0.434846152115145,0.0358020742400719,0.296738332433587,0.0402510192992651,0.156304320466368,0.0380517731171532,0.0490216324689624,0.0252059496499405,0,0,0.0501864526744944,-0.0253013363153792,0.168411092824914,-0.0385360375748375,0.326746855954174,-0.0395015086958982,0.462695012305671,-0.0341906269203513,0.564195027615659,-0.0283443823634475,0.67400816885005,-0.0205890807809913,0.86979319971664,-0.00685067691068327,1,0],"Bot_Xtr":0.912706295671783},
             {"Cm":-0.000341911848619227,"r":6,"id":1183,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt99.803176120639>91.7580939841511) l1 Foil spline 17pts Re275000 N11","xver":6.991,"good":94.3041466366061,"Cpmin":-0.373841013592959,"CDf":0.00425,"CDp":0.00145538363491753,"CD":0.00682281641119023,"CL":0.00542110458169047,"n":10,"alpha":0,"CDpres":0.00257,"clcd":146.567039142352,"Bot_Xtr":0.905494332893109,"xy":[1,0,0.888395795100267,0.00624013041922519,0.724782775337367,0.018410051451857,0.573493663117091,0.0302513418607311,0.434846152115145,0.038821435415768,0.296738332433587,0.0436455814170759,0.156304320466368,0.0412608622231619,0.0490216324689624,0.0273316886576653,0,0,0.0501864526744944,-0.0266797662949364,0.168411092824914,-0.0406355009717258,0.326746855954174,-0.0416535714622853,0.462695012305671,-0.036053350081666,0.564195027615659,-0.029888599076541,0.67400816885005,-0.0217107846248627,0.86979319971664,-0.00722390535665299,1,0],"sym":0.000745741043590005,"src":"retest_71.txt","Re":275000,"Top_Xtr":0.888683781692416,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re275000-N11.dat","diter":4},
             {"xy":[1,0,0.888395795100267,0.00624013041922519,0.724782775337367,0.018410051451857,0.573493663117091,0.0302513418607311,0.434846152115145,0.038821435415768,0.296738332433587,0.0436455814170759,0.156304320466368,0.0412608622231619,0.0490216324689624,0.0273316886576653,0,0,0.0501864526744944,-0.0266797662949364,0.168411092824914,-0.0406355009717258,0.326746855954174,-0.0416535714622853,0.462695012305671,-0.036053350081666,0.564195027615659,-0.029888599076541,0.67400816885005,-0.0217107846248627,0.86979319971664,-0.00722390535665299,1,0],"Bot_Xtr":0.927124523848135,"sym":0.000745741043590005,"alpha":0,"CDpres":0.00278,"clcd":145.331343985714,"Top_Xtr":0.91204075613338,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re275000-N11.dat","diter":5,"src":"retestc_5.txt","Re":275000,"r":6,"id":1184,"good":99.8031764920122,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt99.803176120639>91.7580939841511) l1 Foil spline 17pts Re275000 N11","xver":6.991,"iver":1.2020052,"Cm":-0.000928390284776527,"CDp":0.00161316016388058,"CD":0.00688082813091099,"CL":0.00830293786917316,"n":11,"Cpmin":-0.376027640323042,"CDf":0.00411},
             {"diter":3,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re100000-N10.dat","Top_Xtr":1,"Re":275000,"src":"retest_69.txt","sym":0.000266023145825941,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00568892648596997,0.751503599940214,0.0103025113211106,0.617882281805394,0.016528182096707,0.516474874255053,0.0211038571906242,0.425516435642791,0.0249590095276098,0.22020135983351,0.0301699901075962,0.0597789339840893,0.0228199245017938,0,0,0.0545974187204916,-0.0225633640973249,0.191614124162238,-0.0308699837563552,0.354272483283979,-0.0281556719868387,0.461006103363399,-0.0241421859209031,0.600655324159936,-0.0177764874932323,0.736649107785801,-0.0112705787770638,0.846409340674087,-0.00632600499605844,1,0],"clcd":170.465978763312,"CDpres":0.00153,"alpha":0,"n":12,"CD":0.00586627318397929,"CL":-0.00248035750941608,"CDp":0.000475428837105707,"CDf":0.00434,"Cpmin":-0.352223670674081,"good":128.299374702087,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt87.9757413044999>74.2884386597658) l1 Foil spline 17pts Re100000 N10","xver":6.991,"iver":1.2020052,"id":1185,"r":6,"Cm":0.000151357353184926},
             {"src":"retest_106.txt","Re":275000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re150000-N10.dat","diter":3,"alpha":0,"CDpres":0.00167,"clcd":168.381550997256,"Bot_Xtr":1,"xy":[1,0,0.857899050218291,0.00603237044939248,0.751503599940214,0.0109244802163061,0.617882281805394,0.0175259985356188,0.516474874255053,0.0223779099270984,0.425516435642791,0.0264658001631371,0.22020135983351,0.0319913708205523,0.0597789339840893,0.0241975772690122,0,0,0.0545974187204916,-0.0237660629022777,0.191614124162238,-0.0325154517110687,0.354272483283979,-0.0296564585231526,0.461006103363399,-0.0254290409320076,0.600655324159936,-0.0187240306065797,0.736649107785801,-0.01187133633998,0.846409340674087,-0.00666320110813053,1,0],"sym":0.000186621040472494,"Cpmin":-0.373540394299529,"CDf":0.00427,"CDp":0.000588341011947917,"CD":0.00593889291360842,"CL":-0.00188489343547334,"n":13,"Cm":9.26340249704133e-05,"r":6,"id":1186,"good":113.722247260607,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.6522676347788>76.0189035568534) l1 Foil spline 17pts Re150000 N10","xver":6.991,"iver":1.2020052},
             {"xy":[1,0,0.973567718468105,0.00138869244616322,0.834237354854635,0.0100131107637471,0.657635413429122,0.020973167669457,0.468217126180044,0.0304460342514144,0.27683446074619,0.0349511438409751,0.135057879764897,0.0311957062487024,0.0414172219284315,0.01966937321903,0,0,0.0330100133699133,-0.0201048550153464,0.133544237377044,-0.0335341150739123,0.289727763695042,-0.0366888938824928,0.459887457365246,-0.0320735164046085,0.630482985576981,-0.023494990428867,0.83576764460676,-0.0103604333232928,0.95008963679328,-0.0029326723602642,1,0],"Bot_Xtr":1,"sym":0.00296961046931696,"alpha":3,"clcd":49.5807726400223,"CDpres":0.00273,"Foil_fn":"optbs_spline_sym_s9026.dat-s17_n17s0_nsopt-Re275000-N8.dat","Top_Xtr":0.621749740163479,"diter":4,"src":"retest_78.txt","Re":275000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_s9026.dat-s17_n17s0.dat (opt100.749038346272>75.9400520031389) l1 Foil spline 17pts Re275000 N8","good":18.8973069101571,"iver":1.2020052,"id":1187,"Cm":-0.00567184874519628,"CDp":0.00104937090373506,"n":14,"CL":0.372647706763519,"CD":0.00751597215858457,"Cpmin":-1.45067800636289,"CDf":0.00479},
             {"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt87.4053968194369>61.1298541323217) l1 Foil spline 17pts Re350000 N3","iver":1.2020052,"good":87.4053968195048,"id":1188,"Cm":0.000855723402766425,"CDp":9.25630370099584e-05,"n":3,"CL":-0.00226012516053437,"CD":0.00547282681284685,"Cpmin":-0.146020076887653,"CDf":0.00439,"xy":[1,0,0.940815124572135,0.00234897810276392,0.814199390144812,0.0101961475872967,0.657124116507608,0.017202832163929,0.484682477036353,0.0220520971302935,0.306147230532409,0.0231969898267155,0.139302892624925,0.0193751072980111,0.0329460225561095,0.010699554451921,0,0,0.0346126218693256,-0.0106253979009305,0.13958388382745,-0.0192752869223956,0.303144461201187,-0.0233624410109752,0.484538976270729,-0.0224710672877478,0.663497007146588,-0.0173753651450064,0.818425675853368,-0.0101970669126586,0.939160686099656,-0.00248214763622649,1,0],"Bot_Xtr":0.915745673557521,"sym":9.77196597578967e-05,"alpha":0,"clcd":182.720929091455,"CDpres":0.00108,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re350000-N3.dat","Top_Xtr":0.916875292293237,"diter":3,"src":"retestc_7.txt","Re":350000},
             {"r":6,"id":1189,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt86.9865825583415>80.6093709343411) l1 Foil spline 17pts Re350000 N4","iver":1.2020052,"good":86.9865747252746,"Cm":0.00254311730731492,"CDp":0.000620344340033898,"CL":0.0359909879210456,"CD":0.00597059973505047,"n":4,"Cpmin":-0.258332722863543,"CDf":0.00443,"xy":[1,0,0.942889525368766,0.00306528307263454,0.829506244622028,0.0129622043792242,0.663520326400651,0.0232595063078709,0.483883529026766,0.0302296861134427,0.308064634878761,0.0317935659465107,0.141281933878215,0.0266809190056438,0.0337611204221739,0.0147186098131552,0,0,0.0332640042916588,-0.0146490097293471,0.137232488870993,-0.0267171704881538,0.301394215855595,-0.0324613008649969,0.486422871117426,-0.031159087423392,0.672870651601015,-0.0235877775163446,0.824138239185622,-0.0136152589602591,0.940657070540577,-0.00327998594197189,1,0],"Bot_Xtr":0.914433163939828,"sym":0.000333964770139273,"alpha":0.4,"clcd":167.487362137088,"CDpres":0.00154,"Top_Xtr":0.863593090439519,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re350000-N4.dat","diter":3,"src":"retestc_8.txt","Re":350000},
             {"n":5,"CL":0.00184907950222126,"CD":0.00514467327481457,"CDp":-7.59307632292038e-05,"CDf":0.00415,"Cpmin":-0.155123891087404,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hq07.dat-s17_n17s0.dat (opt83.8762955150437>60.1043499133465) l1 Foil spline 17pts Re150000 N3","xver":6.991,"good":100.59808312437,"iver":1.2020052,"id":1190,"r":6,"Cm":-0.000370186290735772,"diter":3,"Foil_fn":"optbs_spline_sym_hq07.dat-s17_n17s0_nsopt-Re150000-N3.dat","Top_Xtr":0.966417951646634,"Re":350000,"src":"retest_150.txt","sym":1.90738035701545e-05,"Bot_Xtr":0.968978861297723,"xy":[1,0,0.961992840051787,0.00154606945883586,0.838375902301386,0.00637357446843835,0.669468112967632,0.0149933947590592,0.498697719332731,0.0218587151480562,0.301319859646249,0.0238202707541262,0.134615624611079,0.0195424689572873,0.0376550591335466,0.0110987240058944,0,0,0.0409493023355519,-0.011604671563851,0.14830924318344,-0.0200934403843633,0.317279938768802,-0.0237588027227634,0.498956936169248,-0.0216946308529287,0.653261727003669,-0.0157020846343586,0.844873051243488,-0.00603486430532861,0.969355895385625,-0.0012057445813033,1,0],"CDpres":0.00099,"clcd":194.375803201233,"alpha":0},
             {"src":"retestc_10.txt","Re":350000,"Top_Xtr":0.928514718604372,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N6.dat","diter":4,"alpha":0.1,"CDpres":0.00151,"clcd":178.251136678299,"Bot_Xtr":0.941241011153683,"xy":[1,0,0.944740406454351,0.00275517426472391,0.814149693519042,0.0107047953118377,0.682864593067749,0.0185209594632907,0.52069384686288,0.0262828552240056,0.325213183352731,0.0307837948422151,0.152815219118241,0.0277317486782773,0.0429551112266143,0.0168517270606709,0,0,0.0408398189079085,-0.0171358097754144,0.136824284769333,-0.0279100713600759,0.289192311415617,-0.0321610065517032,0.490511679687803,-0.0285517335250371,0.680813751073162,-0.0194405199767373,0.840165601920523,-0.00946120717417282,0.955145580885723,-0.00227264953150234,1,0],"sym":0.000626793135305332,"Cpmin":-0.239988145601626,"CDf":0.0041,"CDp":0.000426565876879656,"CD":0.00561006240204101,"CL":0.0080995083372397,"n":6,"Cm":0.00044015912726537,"r":6,"id":1191,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt109.924282480044>88.3931031152266) l1 Foil spline 17pts Re350000 N6","xver":6.991,"good":109.924282401931},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt113.396160539739>95.195448993345) l1 Foil spline 17pts Re350000 N7","good":113.394622240248,"xver":6.991,"iver":1.2020052,"id":1192,"Cm":-0.00269048898000379,"CDp":0.000616434872229256,"n":7,"CD":0.00576741069833396,"CL":0.0372107070726075,"Cpmin":-0.284735077107232,"CDf":0.00403,"xy":[1,0,0.944740406454351,0.00300366568325902,0.814149693519042,0.0116702695492478,0.682864593067749,0.0201913799330919,0.52069384686288,0.0286533274156876,0.325213183352731,0.0335602104563476,0.152815219118241,0.0302328977546732,0.0429551112266143,0.0183715980959399,0,0,0.0408398189079085,-0.0177000509028784,0.136824284769333,-0.0288290830868753,0.289192311415617,-0.033219991381422,0.490511679687803,-0.0294918736483438,0.680813751073162,-0.0200806496848704,0.840165601920523,-0.0097727420402277,0.955145580885723,-0.00234748243118971,1,0],"Bot_Xtr":0.95854418870669,"sym":6.57085437030375e-05,"alpha":0.2,"CDpres":0.00174,"clcd":173.388033609063,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N7.dat","Top_Xtr":0.927586212642485,"diter":3,"src":"retestc_11.txt","Re":350000},
             {"r":6,"id":1193,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt103.816110716529>92.0222846548029) l1 Foil spline 17pts Re275000 N7","iver":1.2020052,"xver":6.991,"good":113.410675602835,"Cm":-0.00106275040847859,"CDp":0.000900939127702354,"CD":0.00598500690021337,"CL":-0.00400565470750248,"n":8,"Cpmin":-0.27628351931164,"CDf":0.00396,"xy":[1,0,0.944740406454351,0.00330455223661777,0.814149693519042,0.0128393168240534,0.682864593067749,0.0222140133937616,0.52069384686288,0.0315236205300038,0.325213183352731,0.0369220413386875,0.152815219118241,0.0332614213530722,0.0429551112266143,0.0202119383380609,0,0,0.0408398189079085,-0.0189882848892086,0.136824284769333,-0.0309273033027963,0.289192311415617,-0.0356377879266389,0.490511679687803,-0.0316383326705704,0.680813751073162,-0.0215421469163521,0.840165601920523,-0.0104840156125433,0.955145580885723,-0.00251833542289945,1,0],"Bot_Xtr":0.942378441113752,"sym":0.000690925028441966,"alpha":-0.1,"CDpres":0.00202,"clcd":167.084184976353,"Top_Xtr":0.941213820484104,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re275000-N7.dat","diter":4,"src":"retestc_17.txt","Re":350000},
             {"Re":350000,"src":"retest_83.txt","diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_naca0006.dat-s17_n17s0_nsopt-Re80000-N12.dat","clcd":174.273868014838,"CDpres":0.00157,"alpha":0,"sym":6.82108888167849e-06,"xy":[1,0,0.883609074234346,0.00725163682436915,0.672127682508641,0.0172461373093141,0.448051878989487,0.024561786445032,0.261607586958807,0.0262270778847413,0.14960260982261,0.0233237601969541,0.0876932172572549,0.0194823126411114,0.0269668136105797,0.0120037165777063,0,0,0.0260784653873372,-0.0117830874369398,0.0852103572234493,-0.0193294804241381,0.159346520639483,-0.0238415832996579,0.277295492850028,-0.0263745705795246,0.461088095254591,-0.024320540680037,0.679515403216876,-0.0169867344007858,0.887295989576364,-0.00707116713217503,1,0],"Bot_Xtr":1,"CDf":0.00416,"Cpmin":-0.216557426144969,"CD":0.00573809493867926,"CL":-0.00014938449213255,"n":9,"CDp":0.000190951334287775,"Cm":1.23586060192596e-05,"id":1194,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0006.dat-s17_n17s0.dat (opt83.1453911519864>78.3157980125232) l1 Foil spline 17pts Re80000 N12","xver":6.991,"good":125.585831881105,"r":6},
             {"Cm":2.05225000479303e-05,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt109.167051057235>88.3939307571193) l1 Foil spline 17pts Re275000 N10","xver":6.991,"good":104.502472200319,"id":1195,"r":6,"CDf":0.00392,"Cpmin":-0.348251697421191,"n":10,"CD":0.00591261963908533,"CL":6.53447743552806e-06,"CDp":0.0010002449137862,"CDpres":0.00199,"clcd":169.129770058183,"alpha":0,"sym":1.39614615890008e-05,"xy":[1,0,0.888395795100267,0.00580774188324011,0.724782775337367,0.0171343897813647,0.573493663117091,0.0281551783929858,0.434846152115145,0.0361314365701433,0.296738332433587,0.0406213098420772,0.156304320466368,0.0384018316241876,0.0490216324689624,0.0254378325920488,0,0,0.0501864526744944,-0.0256419721602494,0.168411092824914,-0.0390548542710638,0.326746855954174,-0.0400333236807098,0.462695012305671,-0.0346509406738418,0.564195027615659,-0.0287259872128257,0.67400816885005,-0.0208662747931776,0.86979319971664,-0.00694290864454569,1,0],"Bot_Xtr":0.891570859179679,"Re":350000,"src":"retestc_23.txt","diter":4,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re275000-N10.dat","Top_Xtr":0.890948515764744},
             {"Cm":-0.00783204080393876,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-s.dat-s17_n17s0.dat (opt75.792349965309>51.4087592390826) l1 Foil spline 17pts Re80000 N4","iver":1.2020052,"xver":6.991,"good":117.817582733117,"id":1196,"r":6,"CDf":0.00382,"Cpmin":-0.652025844251806,"n":11,"CD":0.00525722680039983,"CL":0.177546825959222,"CDp":0.000104053705470483,"CDpres":0.00143,"clcd":190.214354062858,"alpha":1.3,"sym":1.21470172848609e-05,"xy":[1,0,0.794574379082928,0.00861472502075508,0.546030639687268,0.0212150973559211,0.363514019175692,0.02808172377513,0.221984972352103,0.0283192895656821,0.122670417262654,0.0238243501931476,0.0658532742824706,0.0180958344618327,0.0236940673606567,0.0108879498291247,0,0,0.0239783675371822,-0.0109627017912082,0.0623361812874123,-0.0174875246747209,0.114829236142557,-0.0231246219017476,0.214306107242777,-0.0280094726324117,0.357389074847702,-0.0280742563881015,0.542695962832085,-0.0212873552726197,0.784157786565453,-0.00905771773319752,1,0],"Bot_Xtr":1,"Re":350000,"src":"retest_70.txt","diter":4,"Foil_fn":"optbs_spline_sym_tp28-s.dat-s17_n17s0_nsopt-Re80000-N4.dat","Top_Xtr":0.938515277053447},
             {"r":6,"id":1197,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt115.005518948493>101.680092053478) l1 Foil spline 17pts Re400000 N12","iver":1.2020052,"xver":6.991,"good":103.571703960547,"Cm":-0.0107368679967398,"CDp":0.000827038254273177,"CD":0.0055215572598082,"CL":0.11853347793963,"n":12,"Cpmin":-0.599879420596969,"CDf":0.00356,"xy":[1,0,0.857899050218291,0.00711786402201851,0.751503599940214,0.0128902834040521,0.617882281805394,0.0206797104841587,0.516474874255053,0.0264046980029395,0.425516435642791,0.0312281827476456,0.22020135983351,0.03774805100068,0.0597789339840893,0.0285518049841353,0,0,0.0545974187204916,-0.0276171736484734,0.191614124162238,-0.0377843347404871,0.354272483283979,-0.0344620633295623,0.461006103363399,-0.0295496246905114,0.600655324159936,-0.021758118153078,0.736649107785801,-0.0137949966087668,0.846409340674087,-0.00774292245268378,1,0],"Bot_Xtr":1,"sym":7.28145479600258e-05,"alpha":0.6,"clcd":181.108327405942,"CDpres":0.00196,"Top_Xtr":0.926051522583107,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re400000-N12.dat","diter":4,"src":"retest_97.txt","Re":350000},
             {"Cm":-0.030879432996251,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_j5012.dat-s17_n17s0.dat (opt104.932639943715>88.2232579200539) l1 Foil spline 17pts Re400000 N9","xver":6.991,"good":21.6885545527978,"iver":1.2020052,"id":1198,"Cpmin":-1.67180257584699,"CDf":0.00432,"CDp":0.00107144977897032,"n":13,"CL":0.469651477152693,"CD":0.00766905764827042,"alpha":2.8,"clcd":61.2397896446394,"CDpres":0.00335,"Bot_Xtr":1,"xy":[1,0,0.966540891483753,0.00366821451797614,0.837160757645877,0.0163699525025546,0.733710921866902,0.024833678165966,0.572210891635103,0.0353486226903328,0.347843476008578,0.0417832241620555,0.155585454264622,0.0353783428306276,0.0423406800649609,0.0197104576651541,0,0,0.0250578994295492,-0.0198885467746674,0.114234608979253,-0.035754397269946,0.276081430607418,-0.0445180457916245,0.488584537900447,-0.0413036683564463,0.690682603732797,-0.029473275869742,0.844612617984178,-0.0163245301194758,0.961362155963726,-0.00433102661613981,1,0],"sym":0.0101795790170933,"src":"retest_97.txt","Re":350000,"Foil_fn":"optbs_spline_sym_j5012.dat-s17_n17s0_nsopt-Re400000-N9.dat","Top_Xtr":0.666548508759631,"diter":4},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_b540ols.dat-s17_n17s0.dat (opt104.541702429544>59.5416659235907) l1 Foil spline 17pts Re225000 N10","xver":6.991,"good":120.43781705357,"id":1199,"r":6,"Cm":-6.77838632460565e-05,"n":14,"CL":0.000860479870639983,"CD":0.00554146569602212,"CDp":0.000573852932965169,"CDf":0.00386,"Cpmin":-0.374901032889489,"sym":5.49253257040878e-05,"Bot_Xtr":1,"xy":[1,0,0.920221173114614,0.0047766588405874,0.645313884538533,0.0166964914873713,0.34905035398236,0.0294600730898368,0.245681701944153,0.0318718917122123,0.186935146123869,0.0316712680649664,0.108528059881009,0.0284765698651714,0.0290146041711134,0.0180129095085317,0,0,0.0253926121749067,-0.0167649725306138,0.0869345356684127,-0.0262775762098752,0.154345254889348,-0.030548313400033,0.25014758254482,-0.0316249370472693,0.381402973649756,-0.027857727387719,0.730048776396412,-0.0128773672056991,0.928043174290564,-0.0044122169685736,1,0],"CDpres":0.00169,"clcd":180.457672185508,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_b540ols.dat-s17_n17s0_nsopt-Re225000-N10.dat","Top_Xtr":1,"Re":350000,"src":"retest_70.txt"},
             {"CDp":-4.84112272051752e-06,"n":3,"CL":-0.000374296168962851,"CD":0.00513037118436995,"Cpmin":-0.146015579848247,"CDf":0.00416,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt86.5586639257909>60.5661220893743) l1 Foil spline 17pts Re400000 N3","iver":1.2020052,"good":86.5586639257809,"id":1200,"Cm":0.000170278856789504,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re400000-N3.dat","Top_Xtr":0.911036474501495,"diter":3,"src":"retestc_17.txt","Re":400000,"xy":[1,0,0.942889525368766,0.00221117345888212,0.829506244622028,0.00935041939448421,0.663520326400651,0.0167784840081545,0.483883529026766,0.021806494871918,0.308064634878761,0.0229346156678838,0.141281933878215,0.0192465552335294,0.0337611204221739,0.0106174205120047,0,0,0.0332640042916588,-0.0103721975830253,0.137232488870993,-0.018917030999532,0.301394215855595,-0.0229841492766068,0.486422871117426,-0.0220621200499801,0.672870651601015,-0.0167012715169296,0.824138239185622,-0.00964025273305335,0.940657070540577,-0.00232238648811343,1,0],"Bot_Xtr":0.903954657727706,"sym":6.69700406447764e-05,"alpha":0,"clcd":194.91767048875,"CDpres":0.00097},
             {"CL":-0.0033314421317406,"CD":0.00622508926961985,"n":4,"CDp":0.00022126689528553,"CDf":0.00477,"Cpmin":-0.259346863011294,"id":1201,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001034.dat-s17_n17s0.dat (opt98.9311384222496>85.9718381096039) l1 Foil spline 17pts Re400000 N4","good":98.9311384223579,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.00155479296959431,"diter":3,"Top_Xtr":0.84435008563415,"Foil_fn":"optbs_spline_sym_naca001034.dat-s17_n17s0_nsopt-Re400000-N4.dat","Re":400000,"src":"retestc_18.txt","sym":0.000759657398591261,"Bot_Xtr":0.84177584341376,"xy":[1,0,0.883634367659494,0.0170689624803189,0.70164248505108,0.0359238806680649,0.496554902765126,0.0470456827303051,0.299506870119604,0.0466362565248076,0.154374148397343,0.0365951990741439,0.0730466351422189,0.0245925515816912,0.0257385478863017,0.0137252609750736,0,0,0.0250225911424601,-0.0130313589357144,0.0727127883532427,-0.0238510533272571,0.158833683809683,-0.0360064883870609,0.302994668722394,-0.0453481180026706,0.492522026648783,-0.0457345419676294,0.695128679656198,-0.0353915503334584,0.881491330660016,-0.016836031010218,1,0],"CDpres":0.00145,"clcd":160.640266619191,"alpha":-0.1},
             {"Cm":0.00299560864183182,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt105.983166243964>92.0408009521605) l1 Foil spline 17pts Re400000 N5","good":105.983166788197,"xver":6.991,"iver":1.2020052,"id":1202,"r":6,"CDf":0.00404,"Cpmin":-0.302329751906344,"n":5,"CD":0.00556360284349785,"CL":0.0574450484935497,"CDp":0.000578502921881314,"CDpres":0.00153,"clcd":179.73964499797,"alpha":0.6,"sym":0.000344406053325879,"xy":[1,0,0.942889525368766,0.00290566958113643,0.829506244622028,0.0122872446285406,0.663520326400651,0.0220483519301674,0.483883529026766,0.0286555849185043,0.308064634878761,0.0301380313848898,0.141281933878215,0.025291606978677,0.0337611204221739,0.0139521916238371,0,0,0.0332640042916588,-0.0139209307669828,0.137232488870993,-0.0253892848408834,0.301394215855595,-0.0308479228491823,0.486422871117426,-0.0296104314760898,0.672870651601015,-0.0224154276513449,0.824138239185622,-0.0129385590468003,0.940657070540577,-0.00311696545080406,1,0],"Bot_Xtr":0.944490027261832,"Re":400000,"src":"retest_75.txt","diter":4,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re400000-N5.dat","Top_Xtr":0.880134375918017},
             {"CDpres":0.00134,"clcd":185.155540710765,"alpha":0,"sym":0.000105921195113701,"xy":[1,0,0.944740406454351,0.00307837955151202,0.814149693519042,0.0119605585073164,0.682864593067749,0.020693624942773,0.52069384686288,0.0293660568454233,0.325213183352731,0.0343949948188529,0.152815219118241,0.0309849177788519,0.0429551112266143,0.0188285774353475,0,0,0.0408398189079085,-0.0180846458830243,0.136824284769333,-0.0294554948807316,0.289192311415617,-0.0339418108832917,0.490511679687803,-0.0301326868653502,0.680813751073162,-0.0205169714281945,0.840165601920523,-0.00998508874767818,0.955145580885723,-0.002398489626817,1,0],"Bot_Xtr":0.894553230045493,"Re":400000,"src":"retest_87.txt","diter":3,"Top_Xtr":0.877639708416304,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N8.dat","Cm":3.34216990743166e-06,"id":1203,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt121.888234841593>103.049528523023) l1 Foil spline 17pts Re350000 N8","xver":6.991,"good":101.05381164139,"r":6,"CDf":0.00406,"Cpmin":-0.251441881859,"CL":0.00159733319076878,"CD":0.00540086457127479,"n":6,"CDp":0.000393373129524542},
             {"Cpmin":-0.266218551600426,"CDf":0.00386,"CDp":0.000533862203443564,"n":7,"CL":-0.00901781931912361,"CD":0.00537851602376852,"Cm":-0.000320815468547726,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt121.888234841593>103.049528523023) l1 Foil spline 17pts Re350000 N8","iver":1.2020052,"xver":6.991,"good":111.83074307713,"id":1204,"src":"retest_88.txt","Re":400000,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N8.dat","Top_Xtr":0.922483945343653,"diter":3,"alpha":-0.1,"clcd":185.92488998468,"CDpres":0.00152,"Bot_Xtr":0.91789286023745,"xy":[1,0,0.944740406454351,0.00307837955151202,0.814149693519042,0.0119605585073164,0.682864593067749,0.020693624942773,0.52069384686288,0.0293660568454233,0.325213183352731,0.0343949948188529,0.152815219118241,0.0309849177788519,0.0429551112266143,0.0188285774353475,0,0,0.0408398189079085,-0.0180846458830243,0.136824284769333,-0.0294554948807316,0.289192311415617,-0.0339418108832917,0.490511679687803,-0.0301326868653502,0.680813751073162,-0.0205169714281945,0.840165601920523,-0.00998508874767818,0.955145580885723,-0.002398489626817,1,0],"sym":0.000105921195113701},
             {"diter":4,"Top_Xtr":0.916694910391787,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N4.dat","Re":400000,"src":"retest_80.txt","sym":0.000242793104898177,"Bot_Xtr":1,"xy":[1,0,0.944740406454351,0.00256095861038416,0.814149693519042,0.00995020100080596,0.682864593067749,0.0172153940378226,0.52069384686288,0.024430144130336,0.325213183352731,0.0286138069271528,0.152815219118241,0.0257769032862829,0.0429551112266143,0.015663827899537,0,0,0.0408398189079085,-0.0148489277829974,0.136824284769333,-0.0241852961415737,0.289192311415617,-0.0278689171958434,0.490511679687803,-0.0247413244398256,0.680813751073162,-0.0168460598583827,0.840165601920523,-0.00819854934844313,0.955145580885723,-0.00196935010435041,1,0],"CDpres":0.00139,"clcd":195.199294058139,"alpha":1,"CD":0.00512296934691862,"CL":0.173196058937617,"n":8,"CDp":9.44113961961382e-05,"CDf":0.00373,"Cpmin":-0.506068426720385,"id":1205,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt84.2885096025096>60.946319981499) l1 Foil spline 17pts Re350000 N4","xver":6.991,"good":131.107796832471,"r":6,"Cm":-0.0130780543133702},
             {"Cpmin":-0.165556612502259,"CDf":0.00388,"CDp":-5.99000376785104e-05,"CD":0.00485254460601431,"CL":0.00183454440378098,"n":9,"Cm":-0.00026775024170538,"r":6,"id":1206,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_bqm34.dat-s17_n17s0.dat (opt82.4648076537096>53.7676573505292) l1 Foil spline 17pts Re125000 N4","good":157.66353316037,"xver":6.991,"iver":1.2020052,"src":"retest_97.txt","Re":400000,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_bqm34.dat-s17_n17s0_nsopt-Re125000-N4.dat","diter":3,"alpha":0,"CDpres":0.00097,"clcd":206.077446204325,"Bot_Xtr":1,"xy":[1,0,0.836603425815351,0.00695358342325052,0.803714437162079,0.00834125877682961,0.662807671328547,0.0143046016831253,0.520216031590305,0.019269989827017,0.349816623712441,0.0221321730125516,0.168769456385459,0.0198633242390425,0.0431801448644717,0.0116490613228366,0,0,0.0337930770596252,-0.0115450996694317,0.152912772871317,-0.0200477317389147,0.338443399173723,-0.0225485413787481,0.522479045575666,-0.0194016929551823,0.684363320479229,-0.0135154671977669,0.848263409871412,-0.00647394916386209,0.872525547148609,-0.00546222892833583,1,0],"sym":0.000584080294079328},
             {"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_b540ols.dat-s17_n17s0_nsopt-Re225000-N10.dat","Re":400000,"src":"retest_76.txt","sym":5.49253257040878e-05,"Bot_Xtr":1,"xy":[1,0,0.920221173114614,0.0047766588405874,0.645313884538533,0.0166964914873713,0.34905035398236,0.0294600730898368,0.245681701944153,0.0318718917122123,0.186935146123869,0.0316712680649664,0.108528059881009,0.0284765698651714,0.0290146041711134,0.0180129095085317,0,0,0.0253926121749067,-0.0167649725306138,0.0869345356684127,-0.0262775762098752,0.154345254889348,-0.030548313400033,0.25014758254482,-0.0316249370472693,0.381402973649756,-0.027857727387719,0.730048776396412,-0.0128773672056991,0.928043174290564,-0.0044122169685736,1,0],"clcd":191.58559780728,"CDpres":0.00162,"alpha":0,"CL":0.000860019731472278,"CD":0.00521959902751104,"n":10,"CDp":0.000531710652739438,"CDf":0.0036,"Cpmin":-0.375655692635202,"id":1207,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_b540ols.dat-s17_n17s0.dat (opt104.541702429544>59.5416659235907) l1 Foil spline 17pts Re225000 N10","xver":6.991,"good":114.269982363987,"r":6,"Cm":-6.67240873580159e-05},
             {"id":1208,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_b540ols.dat-s17_n17s0.dat (opt99.0848665634441>0) l1 Foil spline 17pts Re200000 N9","xver":6.991,"good":116.777387190062,"iver":1.2020052,"r":6,"Cm":-0.000787091031115817,"CL":-0.00513289241045786,"CD":0.00528849254337267,"n":11,"CDp":0.000609787890354827,"CDf":0.00356,"Cpmin":-0.366717972492243,"sym":0.000612005033050303,"Bot_Xtr":1,"xy":[1,0,0.920221173114614,0.00504289812021751,0.645313884538533,0.0176271130817327,0.34905035398236,0.0311021055018322,0.245681701944153,0.03364835299469,0.186935146123869,0.0334365470760904,0.108528059881009,0.0300637842131627,0.0290146041711134,0.0190169050233138,0,0,0.0253926121749067,-0.0171856567449031,0.0869345356684127,-0.0269369606187128,0.154345254889348,-0.0313148636104248,0.25014758254482,-0.0324185030235561,0.381402973649756,-0.0285567626015607,0.730048776396412,-0.0132004995636646,0.928043174290564,-0.00452293292860925,1,0],"CDpres":0.00173,"clcd":189.08980050528,"alpha":-0.1,"diter":3,"Top_Xtr":1,"Foil_fn":"optbs_spline_sym_b540ols.dat-s17_n17s0_nsopt-Re200000-N9.dat","Re":400000,"src":"retest_73.txt"},
             {"n":12,"CD":0.00519632755350272,"CL":-0.116365129338924,"CDp":0.000712597524269369,"CDf":0.00338,"Cpmin":-0.580849061704601,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt115.005518948493>101.680092053478) l1 Foil spline 17pts Re400000 N12","good":114.944201807718,"xver":6.991,"iver":1.2020052,"id":1209,"r":6,"Cm":0.0121217773701265,"diter":4,"Foil_fn":"optbs_spline_sym_tp29-8.dat-s17_n17s0_nsopt-Re400000-N12.dat","Top_Xtr":1,"Re":400000,"src":"retest_106.txt","sym":7.28145479600258e-05,"Bot_Xtr":0.905034320617369,"xy":[1,0,0.857899050218291,0.00711786402201851,0.751503599940214,0.0128902834040521,0.617882281805394,0.0206797104841587,0.516474874255053,0.0264046980029395,0.425516435642791,0.0312281827476456,0.22020135983351,0.03774805100068,0.0597789339840893,0.0285518049841353,0,0,0.0545974187204916,-0.0276171736484734,0.191614124162238,-0.0377843347404871,0.354272483283979,-0.0344620633295623,0.461006103363399,-0.0295496246905114,0.600655324159936,-0.021758118153078,0.736649107785801,-0.0137949966087668,0.846409340674087,-0.00774292245268378,1,0],"CDpres":0.00181,"clcd":192.443603622702,"alpha":-0.5},
             {"CDpres":0.00197,"clcd":183.445512070192,"alpha":0.8,"sym":1.91865640021129e-05,"xy":[1,0,0.888395795100267,0.0053323706656314,0.724782775337367,0.0157319177195716,0.573493663117091,0.0258506404669309,0.434846152115145,0.0331740315508419,0.296738332433587,0.0372964028629613,0.156304320466368,0.0352585918203879,0.0490216324689624,0.0233557129497305,0,0,0.0501864526744944,-0.0236760190381935,0.168411092824914,-0.0360605443090295,0.326746855954174,-0.0369639951132926,0.462695012305671,-0.0319942758676331,0.564195027615659,-0.0265235846872999,0.67400816885005,-0.0192664712437876,0.86979319971664,-0.00641060041019491,1,0],"Bot_Xtr":1,"Re":400000,"src":"retest_67.txt","diter":4,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re200000-N8.dat","Top_Xtr":0.893094017698208,"Cm":-0.0142494919485848,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt95.5935597876006>76.4688231681566) l1 Foil spline 17pts Re200000 N8","iver":1.2020052,"xver":6.991,"good":133.002790513538,"id":1210,"r":6,"CDf":0.00349,"Cpmin":-0.53694967058398,"n":13,"CL":0.161475304696853,"CD":0.00545120994629384,"CDp":0.000703113572213497},
             {"id":1211,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_j5012.dat-s17_n17s0.dat (opt105.545410867842>86.2525484964525) l1 Foil spline 17pts Re400000 N8","iver":1.2020052,"xver":6.991,"good":20.435845091501,"r":6,"Cm":-0.0325904416545297,"CL":0.467357375323027,"CD":0.00740621630801678,"n":14,"CDp":0.00103617297372811,"CDf":0.00406,"Cpmin":-1.65874739901381,"sym":0.0144836170522906,"Bot_Xtr":1,"xy":[1,0,0.966540891483753,0.00366572499861269,0.837160757645877,0.0163588426523715,0.733710921866902,0.0248168242108996,0.572210891635103,0.0353246325228473,0.347843476008578,0.0417548670021596,0.155585454264622,0.0353543324928755,0.0423406800649609,0.0196970807032072,0,0,0.0250578994295492,-0.0204081022605003,0.114234608979253,-0.0366884219352328,0.276081430607418,-0.0456810063222078,0.488584537900447,-0.0423826585774386,0.690682603732797,-0.0302432165967887,0.844612617984178,-0.0167509815476928,0.961362155963726,-0.00444416754409186,1,0],"CDpres":0.00334,"clcd":63.1033925942915,"alpha":2.7,"diter":4,"Top_Xtr":0.67868476853091,"Foil_fn":"optbs_spline_sym_j5012.dat-s17_n17s0_nsopt-Re400000-N8.dat","Re":400000,"src":"retest_66.txt"},
             {"clcd":203.764591778556,"CDpres":0.00078,"alpha":0,"sym":0.000114565852758742,"xy":[1,0,0.940815124572135,0.00270817039661624,0.814199390144812,0.0117552841480116,0.657124116507608,0.0198333908474891,0.484682477036353,0.0254241776716848,0.306147230532409,0.0267441408097421,0.139302892624925,0.0223378378683041,0.0329460225561095,0.0123356691105724,0,0,0.0346126218693256,-0.0121235734864914,0.13958388382745,-0.021993092367525,0.303144461201187,-0.0266565330598654,0.484538976270729,-0.0256394761046121,0.663497007146588,-0.0198252826062786,0.818425675853368,-0.0116348480513337,0.939160686099656,-0.00283212916379136,1,0],"Bot_Xtr":0.848926604160981,"Re":500000,"src":"retestc_3.txt","diter":4,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re500000-N3.dat","Top_Xtr":0.839153063709688,"Cm":0.00086957998811418,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt77.5944134932145>51.895382196235) l1 Foil spline 17pts Re500000 N3","good":77.5943428202723,"iver":1.2020052,"id":1212,"r":6,"CDf":0.00413,"Cpmin":-0.168306395852301,"n":3,"CL":-0.00152827696114075,"CD":0.0049076239952757,"CDp":-4.67125253260303e-05},
             {"CDf":0.00387,"Cpmin":-0.184239407807335,"CD":0.00490226441068423,"CL":-0.00245879741523881,"n":4,"CDp":0.000215966240703462,"Cm":0.000682482037064443,"id":1213,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt96.4025751404603>66.0992780292648) l1 Foil spline 17pts Re500000 N4","xver":6.991,"good":96.4025751405173,"r":6,"Re":500000,"src":"retestc_4.txt","diter":3,"Top_Xtr":0.878008353547345,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re500000-N4.dat","CDpres":0.00103,"clcd":203.98736506757,"alpha":0,"sym":0.000171654852621555,"xy":[1,0,0.942889525368766,0.00280396029473479,0.829506244622028,0.0118571451805082,0.663520326400651,0.0212765772742644,0.483883529026766,0.0276525324336644,0.308064634878761,0.0290830877376124,0.141281933878215,0.0244063062843201,0.0337611204221739,0.0134638128133172,0,0,0.0332640042916588,-0.0132867768925363,0.137232488870993,-0.0242327017344249,0.301394215855595,-0.0294426770275573,0.486422871117426,-0.0282615583181879,0.672870651601015,-0.0213943155913533,0.824138239185622,-0.0123491561191783,0.940657070540577,-0.00297497525271823,1,0],"Bot_Xtr":0.87989623220003},
             {"CL":-0.00172392958808877,"CD":0.00496460175764121,"n":5,"CDp":0.00042430450080965,"CDf":0.00372,"Cpmin":-0.190013251169316,"id":1214,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt110.779619885329>74.8452255898505) l1 Foil spline 17pts Re500000 N5","good":110.779619913331,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000964472103244512,"diter":4,"Top_Xtr":0.904005550625894,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re500000-N5.dat","Re":500000,"src":"retestc_5.txt","sym":0.00014495215310851,"Bot_Xtr":0.906753165421475,"xy":[1,0,0.940815124572135,0.00306290567824115,0.814199390144812,0.0132950742727526,0.657124116507608,0.0224313084292821,0.484682477036353,0.0287544159896708,0.306147230532409,0.0302472772201444,0.139302892624925,0.0252638056054174,0.0329460225561095,0.0139514821559547,0,0,0.0346126218693256,-0.0137270233884967,0.13958388382745,-0.0249018734988305,0.303144461201187,-0.0301820954998728,0.484538976270729,-0.0290305237600923,0.663497007146588,-0.022447351708898,0.818425675853368,-0.0131736596887231,0.939160686099656,-0.00320670331350123,1,0],"CDpres":0.00125,"clcd":201.426025453273,"alpha":0},
             {"CDp":0.000480896680681638,"n":6,"CD":0.00500799752737202,"CL":0.0823758783150138,"Cpmin":-0.365396901064589,"CDf":0.00361,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt115.147803870618>103.13179785412) l1 Foil spline 17pts Re500000 N6","iver":1.2020052,"xver":6.991,"good":115.147796220765,"id":1215,"Cm":0.00280840977708286,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re500000-N6.dat","Top_Xtr":0.877025185906631,"diter":3,"src":"retest_94.txt","Re":500000,"xy":[1,0,0.942889525368766,0.00291808871450419,0.829506244622028,0.0123397615873699,0.663520326400651,0.0221425888747043,0.483883529026766,0.0287780618625947,0.308064634878761,0.0302668444590399,0.141281933878215,0.025399705931907,0.0337611204221739,0.0140118247389283,0,0,0.0332640042916588,-0.0136288993111167,0.137232488870993,-0.0248566717606526,0.301394215855595,-0.0302007991782955,0.486422871117426,-0.0289892677365722,0.672870651601015,-0.0219451997563532,0.824138239185622,-0.0126671356557575,0.940657070540577,-0.00305157815927027,1,0],"Bot_Xtr":0.956672333542788,"sym":0.000109706662542496,"alpha":0.8,"clcd":199.680609771538,"CDpres":0.00139},
             {"xy":[1,0,0.927533762368065,0.00640206951181962,0.828124577508512,0.0135465098083202,0.673910782200253,0.023012633460572,0.485356610471494,0.031682675904507,0.298817780508802,0.0353357028862502,0.140740099512849,0.0309175390905712,0.0345490619416974,0.0179150928263022,0,0,0.033827731492854,-0.0176156200657777,0.142528433402255,-0.0310463483937975,0.31046792119717,-0.0352688496515452,0.499715124890922,-0.0310964315288889,0.684159552318164,-0.0224123117140436,0.829477323686799,-0.013425142039961,0.922486667396241,-0.0068074132716306,1,0],"Bot_Xtr":0.940992792596286,"sym":0.000101313207168119,"alpha":0.1,"CDpres":0.00156,"clcd":200.029620759846,"Top_Xtr":0.930701820560967,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re500000-N7.dat","diter":4,"src":"retestc_7.txt","Re":500000,"r":6,"id":1216,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt120.702318388788>108.979290042927) l1 Foil spline 17pts Re500000 N7","xver":6.991,"good":120.702318772825,"Cm":-0.00105874725938316,"CDp":0.000632298031708017,"CD":0.0049992595906613,"CL":0.016386428118149,"n":7,"Cpmin":-0.266770799307753,"CDf":0.00344},
             {"CDpres":0.00135,"clcd":203.041411044867,"alpha":0,"sym":0.000818701141763744,"xy":[1,0,0.944740406454351,0.00328279954108474,0.814149693519042,0.0127548001544026,0.682864593067749,0.0220677864209915,0.52069384686288,0.0313161117147732,0.325213183352731,0.0366789966336292,0.152815219118241,0.033042473211272,0.0429551112266143,0.0200788903154186,0,0,0.0408398189079085,-0.0187936683835254,0.136824284769333,-0.0306103202927923,0.289192311415617,-0.0352725257770014,0.490511679687803,-0.0313140621118593,0.680813751073162,-0.0213213551290876,0.840165601920523,-0.0103765618590345,0.955145580885723,-0.00249252426391366,1,0],"Bot_Xtr":0.908939738767997,"Re":500000,"src":"retestc_8.txt","diter":4,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re500000-N8.dat","Top_Xtr":0.88984559123536,"Cm":-0.000526695985847719,"good":123.539635553137,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt123.539635553262>105.543448165352) l1 Foil spline 17pts Re500000 N8","xver":6.991,"iver":1.2020052,"id":1217,"r":6,"CDf":0.00357,"Cpmin":-0.265216347745038,"n":8,"CL":0.005606445012581,"CD":0.00492510367640731,"CDp":0.00046513727339766},
             {"src":"retestc_9.txt","Re":500000,"Top_Xtr":0.935595038546444,"Foil_fn":"optbs_spline_sym_fx76120.dat-s17_n17s0_nsopt-Re500000-N9.dat","diter":7,"alpha":0,"clcd":192.289370336317,"CDpres":0.00184,"Bot_Xtr":0.938351329171499,"xy":[1,0,0.958697949919804,0.00372890599655691,0.839534098645647,0.0136103905835443,0.689473001558313,0.0243226225111947,0.502749331332653,0.0341050820781055,0.31276546741024,0.0392563710937242,0.144955719062291,0.0361990212268811,0.0376596749358859,0.0213045841584671,0,0,0.0393131000478028,-0.0219216877787312,0.146218399310118,-0.036153245146023,0.306004793213774,-0.0393265043152189,0.501247539482914,-0.0341938845241474,0.692204662541298,-0.0241323571437463,0.835527625011643,-0.0139180842632882,0.973107828960817,-0.00251714011648575,1,0],"sym":4.81997893974101e-05,"Cpmin":-0.310430530796553,"CDf":0.00336,"CDp":0.000884923717941784,"CD":0.00520049547331183,"CL":-0.000968652227845404,"n":9,"Cm":0.000285802571614202,"r":6,"id":1218,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76120.dat-s17_n17s0.dat (opt117.430850516229>75.3821501071211) l1 Foil spline 17pts Re500000 N9","xver":6.991,"iver":1.2020052,"good":117.430850515603},
             {"CDp":0.00107597757952839,"CL":-0.00295265675287371,"CD":0.0053862206903396,"n":10,"Cpmin":-0.327154127014943,"CDf":0.00331,"r":6,"id":1219,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76120.dat-s17_n17s0.dat (opt131.898612953241>87.4594079019835) l1 Foil spline 17pts Re620000 N11","xver":6.991,"good":114.090440537303,"Cm":0.000575973941059032,"Top_Xtr":0.939142029639497,"Foil_fn":"optbs_spline_sym_fx76120.dat-s17_n17s0_nsopt-Re620000-N11.dat","diter":3,"src":"retest_106.txt","Re":500000,"xy":[1,0,0.958697949919804,0.00392301435054957,0.839534098645647,0.0143188800214139,0.689473001558313,0.0255887376196989,0.502749331332653,0.035880423519021,0.31276546741024,0.0412998630948001,0.144955719062291,0.0380833627557325,0.0376596749358859,0.0224135951572203,0,0,0.0393131000478028,-0.02327233182489,0.146218399310118,-0.0383807271628582,0.306004793213774,-0.0417494979024703,0.501247539482914,-0.036300645965773,0.692204662541298,-0.0256192054569316,0.835527625011643,-0.0147756084573143,0.973107828960817,-0.00267222672961495,1,0],"Bot_Xtr":0.939305991069151,"sym":0.000106873481173929,"alpha":0,"CDpres":0.00208,"clcd":185.658935548917},
             {"CL":-0.000201411478670634,"CD":0.00517153816317425,"n":11,"CDp":0.000674694094558113,"CDf":0.00363,"Cpmin":-0.348245342708023,"id":1220,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp28-0.dat-s17_n17s0.dat (opt109.167051057235>88.3939307571193) l1 Foil spline 17pts Re275000 N10","good":111.497987790475,"xver":6.991,"iver":1.2020052,"r":6,"Cm":8.09398938208833e-05,"diter":5,"Top_Xtr":0.856250185038904,"Foil_fn":"optbs_spline_sym_tp28-0.dat-s17_n17s0_nsopt-Re275000-N10.dat","Re":500000,"src":"retest_96.txt","sym":1.39614615890008e-05,"Bot_Xtr":0.858127365154212,"xy":[1,0,0.888395795100267,0.00580774188324011,0.724782775337367,0.0171343897813647,0.573493663117091,0.0281551783929858,0.434846152115145,0.0361314365701433,0.296738332433587,0.0406213098420772,0.156304320466368,0.0384018316241876,0.0490216324689624,0.0254378325920488,0,0,0.0501864526744944,-0.0256419721602494,0.168411092824914,-0.0390548542710638,0.326746855954174,-0.0400333236807098,0.462695012305671,-0.0346509406738418,0.564195027615659,-0.0287259872128257,0.67400816885005,-0.0208662747931776,0.86979319971664,-0.00694290864454569,1,0],"CDpres":0.00154,"clcd":193.36606797584,"alpha":0},
             {"Foil_fn":"optbs-spline_foil_sym_tp29-8.dat-s17_n17s0-Re200000-N10.dat","Top_Xtr":0.989389578373448,"diter":4,"src":"retest_82.txt","Re":500000,"xy":[1,0,0.857899050218291,0.00690861127145202,0.751503599940214,0.0125113316216725,0.617882281805394,0.0200717631721079,0.516474874255053,0.02562844607288,0.425516435642791,0.0303101288040856,0.22020135983351,0.0366383243360539,0.0597789339840893,0.027712431864884,0,0,0.0545974187204916,-0.0267830502629754,0.191614124162238,-0.0366431318928068,0.354272483283979,-0.0334212032726431,0.461006103363399,-0.0286571353539567,0.600655324159936,-0.021100956221632,0.736649107785801,-0.0133783453822257,0.846409340674087,-0.00750906243601124,1,0],"Bot_Xtr":0.974857103136018,"sym":6.53059873199423e-05,"alpha":-0.1,"CDpres":0.00163,"clcd":215.853971283573,"CDp":0.00063496845487694,"n":12,"CL":-0.0259197300095101,"CD":0.00463276164924606,"Cpmin":-0.441592202478861,"CDf":0.00301,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.9963777162855>86.4422066326818) l1 Foil spline 17pts Re200000 N10","xver":6.991,"good":116.991683954065,"id":1221,"Cm":0.00294279847235934},
             {"Re":500000,"src":"retest_78.txt","diter":5,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re620000-N12.dat","Top_Xtr":0.987140287687438,"clcd":157.875123352181,"CDpres":0.00309,"alpha":-1.3,"sym":0.000268115330785879,"xy":[1,0,0.92665990621884,0.00788325175139104,0.825921357659381,0.0166935871487504,0.672783569504887,0.0281088134070179,0.495512951249265,0.0381181023695616,0.312090510037109,0.0430179640097155,0.146453297160589,0.0381596474037436,0.0354870723445344,0.022034903907265,0,0,0.0345118418622416,-0.0219293680191003,0.143520041847869,-0.0384205526542922,0.311152398930403,-0.0435255445915813,0.501481865544773,-0.038288142387177,0.711715512073078,-0.0257740411885494,0.925495042077482,-0.00826004796199025,0.979243859290989,-0.00172366082538887,1,0],"Bot_Xtr":0.875586832567205,"CDf":0.00324,"Cpmin":-0.757278355683305,"n":13,"CD":0.00633412014994436,"CL":-0.276792984484924,"CDp":0.00127032229677464,"Cm":0.0254518336433051,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt128.929178354652>107.38562178186) l1 Foil spline 17pts Re620000 N12","good":103.576164858754,"iver":1.2020052,"id":1222,"r":6},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_b540ols.dat-s17_n17s0.dat (opt99.0848665634441>0) l1 Foil spline 17pts Re200000 N9","xver":6.991,"good":158.964420521007,"iver":1.2020052,"id":1223,"Cm":-0.000796229818611552,"CDp":0.000539337488098941,"n":14,"CD":0.00479686486163492,"CL":-0.0050969314106794,"Cpmin":-0.367789983950927,"CDf":0.00318,"xy":[1,0,0.920221173114614,0.00504289812021751,0.645313884538533,0.0176271130817327,0.34905035398236,0.0311021055018322,0.245681701944153,0.03364835299469,0.186935146123869,0.0334365470760904,0.108528059881009,0.0300637842131627,0.0290146041711134,0.0190169050233138,0,0,0.0253926121749067,-0.0171856567449031,0.0869345356684127,-0.0269369606187128,0.154345254889348,-0.0313148636104248,0.25014758254482,-0.0324185030235561,0.381402973649756,-0.0285567626015607,0.730048776396412,-0.0132004995636646,0.928043174290564,-0.00452293292860925,1,0],"Bot_Xtr":1,"sym":0.000612005033050303,"alpha":-0.1,"clcd":208.46949598225,"CDpres":0.00162,"Foil_fn":"optbs_spline_sym_b540ols.dat-s17_n17s0_nsopt-Re200000-N9.dat","Top_Xtr":1,"diter":3,"src":"retest_88.txt","Re":500000},
             {"r":6,"id":1224,"good":91.1403829684626,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt103.231339882123>96.3892287636684) l1 Foil spline 17pts Re750000 N3","xver":6.991,"iver":1.2020052,"Cm":-0.00187778153682681,"CDp":-0.00026485146459831,"CD":0.00586746483853523,"CL":0.0401413291531222,"n":3,"Cpmin":-0.300606261320835,"CDf":0.00415,"xy":[1,0,0.880300325419672,0.0281811997891934,0.704663862945517,0.0508996201639534,0.494561349047687,0.0583838767805817,0.292149054823316,0.0516910750563325,0.151132354125174,0.0384188982575565,0.0758230374101564,0.0266358518091129,0.0249798475564602,0.0147996766141952,0,0,0.0247348166511182,-0.0144423036809282,0.0790299712088116,-0.026922067653428,0.168051338348483,-0.0399889717041293,0.314517318069903,-0.0523271228927331,0.507756670437578,-0.0575507341902832,0.707646981873831,-0.0499691075301725,0.880289902407772,-0.0278306656153318,1,0],"Bot_Xtr":0.861816576321695,"sym":0.00024149012807245,"alpha":0.3,"CDpres":0.00172,"clcd":170.431357923509,"Top_Xtr":0.850272208705162,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re750000-N3.dat","diter":3,"src":"retest_108.txt","Re":620000},
             {"src":"retestc_23.txt","Re":620000,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re620000-N3.dat","Top_Xtr":0.892599574018123,"diter":4,"alpha":0,"clcd":238.989040058986,"CDpres":0.0007,"Bot_Xtr":0.90044029765797,"xy":[1,0,0.942889525368766,0.00217315404812205,0.829506244622028,0.00918964619312823,0.663520326400651,0.0164899910032865,0.483883529026766,0.021431549124246,0.308064634878761,0.0225402727590545,0.141281933878215,0.0189156256602747,0.0337611204221739,0.0104348622101959,0,0,0.0332640042916588,-0.00998367072017859,0.137232488870993,-0.0182084275767963,0.301394215855595,-0.0221231977432253,0.486422871117426,-0.0212357063394666,0.672870651601015,-0.0160756670993428,0.824138239185622,-0.00927914341929013,0.940657070540577,-0.00224286782025389,1,0],"sym":0.000113088421620355,"Cpmin":-0.143450075615296,"CDf":0.00348,"CDp":-0.000187235392010763,"n":4,"CD":0.00418429229956814,"CL":0.000991193137348643,"Cm":9.06477609860914e-05,"r":6,"good":100.856305632297,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt73.6365266379558>51.3081767286262) l1 Foil spline 17pts Re620000 N3","xver":6.991,"iver":1.2020052,"id":1225},
             {"n":5,"CD":0.00415658402518536,"CL":0.00342170331736301,"CDp":-7.86727333957278e-06,"CDf":0.00339,"Cpmin":-0.19472520583689,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt105.070828354684>77.9756394644854) l1 Foil spline 17pts Re620000 N5","xver":6.991,"good":105.070716403847,"id":1226,"r":6,"Cm":-0.000598759347970209,"diter":7,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re620000-N5.dat","Top_Xtr":0.898761261941909,"Re":620000,"src":"retestc_15.txt","sym":0.000205020382438626,"Bot_Xtr":0.898875250877625,"xy":[1,0,0.927533762368065,0.00481136733199327,0.828124577508512,0.0101806509026412,0.673910782200253,0.0172947564300753,0.485356610471494,0.0238105805561222,0.298817780508802,0.0265559513538619,0.140740099512849,0.0232355548922678,0.0345490619416974,0.0134637857672367,0,0,0.033827731492854,-0.01294668681354,0.142528433402255,-0.0228176668126159,0.31046792119717,-0.0259210149292139,0.499715124890922,-0.0228544756596646,0.684159552318164,-0.0164720389884468,0.829477323686799,-0.00986687432912632,0.922486667396241,-0.00500314194499211,1,0],"CDpres":0.00076,"clcd":240.582168901399,"alpha":0},
             {"xy":[1,0,0.940815124572135,0.00306425239018557,0.814199390144812,0.013300919909937,0.657124116507608,0.0224411711263953,0.484682477036353,0.0287670588587422,0.306147230532409,0.0302605764770585,0.139302892624925,0.0252749137074435,0.0329460225561095,0.0139576164054666,0,0,0.0346126218693256,-0.0138538788494925,0.13958388382745,-0.0251319990368258,0.303144461201187,-0.0304610171225797,0.484538976270729,-0.0292988033696121,0.663497007146588,-0.0226547942890245,0.818425675853368,-0.0132954013529949,0.939160686099656,-0.0032363374020868,1,0],"Bot_Xtr":0.905372558481444,"sym":0.000163540950837834,"alpha":0,"CDpres":0.00111,"clcd":222.272589261285,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re620000-N6.dat","Top_Xtr":0.903327041894583,"diter":4,"src":"retestc_16.txt","Re":620000,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt124.690752683057>97.039874028242) l1 Foil spline 17pts Re620000 N6","xver":6.991,"good":124.69075180221,"id":1227,"Cm":0.00117567935536381,"CDp":0.000341005373470789,"n":6,"CL":-0.00299289827642656,"CD":0.00449898029857601,"Cpmin":-0.189880769369114,"CDf":0.00339},
             {"CD":0.00454265055220883,"CL":0.0823707096133424,"n":7,"CDp":0.000423454797632526,"CDf":0.00327,"Cpmin":-0.359868807158436,"id":1228,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt137.071442746857>111.74250108652) l1 Foil spline 17pts Re1000000 N7","xver":6.991,"iver":1.2020052,"good":122.326844280426,"r":6,"Cm":0.00292491669805082,"diter":3,"Top_Xtr":0.881938461428285,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1000000-N7.dat","Re":620000,"src":"retest_74.txt","sym":0.000213373061389456,"Bot_Xtr":0.957673332705646,"xy":[1,0,0.942889525368766,0.00295627444189563,0.829506244622028,0.0125012380941357,0.663520326400651,0.022432343897678,0.483883529026766,0.0291546478175306,0.308064634878761,0.0306629124283815,0.141281933878215,0.0257320831628383,0.0337611204221739,0.0141951816454809,0,0,0.0332640042916588,-0.0135768697912139,0.137232488870993,-0.0247617792334892,0.301394215855595,-0.0300855049754361,0.486422871117426,-0.0288785986613787,0.672870651601015,-0.0218614220292288,0.824138239185622,-0.0126187777530636,0.940657070540577,-0.00303992849168169,1,0],"CDpres":0.00128,"clcd":220.135797043371,"alpha":0.8},
             {"Re":620000,"src":"retest_74.txt","diter":4,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1000000-N8.dat","Top_Xtr":0.904184007195579,"CDpres":0.00159,"clcd":203.394323496033,"alpha":0,"sym":0.000174946779475472,"xy":[1,0,0.942889525368766,0.00364463304434149,0.829506244622028,0.0154121095143832,0.663520326400651,0.0276556400423651,0.483883529026766,0.0359432099151713,0.308064634878761,0.0378026688890794,0.141281933878215,0.0317237125437133,0.0337611204221739,0.0175004821481915,0,0,0.0332640042916588,-0.016976487193019,0.137232488870993,-0.0309620725909685,0.301394215855595,-0.0376188471838716,0.486422871117426,-0.0361097342661777,0.672870651601015,-0.0273354725211077,0.824138239185622,-0.0157784910815796,0.940657070540577,-0.00380111969108849,1,0],"Bot_Xtr":0.901898178079464,"CDf":0.00333,"Cpmin":-0.241148550591553,"n":8,"CL":0.000333185639011122,"CD":0.00491655805733193,"CDp":0.000818511004085578,"Cm":0.000250154799186133,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt137.801472869791>126.314460171594) l1 Foil spline 17pts Re1000000 N8","good":124.26847853832,"iver":1.2020052,"id":1229,"r":6},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt111.504034663716>111.155750766854) l1 Foil spline 17pts Re500000 N9","iver":1.2020052,"xver":6.991,"good":120.941472950495,"id":1230,"r":6,"Cm":0.00127780553538799,"n":9,"CD":0.00523602736609534,"CL":-0.00189865769048849,"CDp":0.00106404180100614,"CDf":0.0034,"Cpmin":-0.279053682445554,"sym":0.000314022388154802,"Bot_Xtr":0.886765958972834,"xy":[1,0,0.940815124572135,0.00448595362723237,0.814199390144812,0.0194720611482972,0.657124116507608,0.0328530552301205,0.484682477036353,0.0421139239200745,0.306147230532409,0.0443003791868405,0.139302892624925,0.0370015509123989,0.0329460225561095,0.0204334408425897,0,0,0.0346126218693256,-0.0200838316986982,0.13958388382745,-0.0364336114377055,0.303144461201187,-0.0441590364624465,0.484538976270729,-0.0424741866333051,0.663497007146588,-0.0328424321168412,0.818425675853368,-0.01927421237338,0.939160686099656,-0.00469168645184844,1,0],"clcd":190.984486917556,"CDpres":0.00184,"alpha":0,"diter":4,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re500000-N9.dat","Top_Xtr":0.88574856494789,"Re":620000,"src":"retest_110.txt"},
             {"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N6.dat","Top_Xtr":0.969841714392109,"diter":4,"src":"retest_70.txt","Re":620000,"xy":[1,0,0.944740406454351,0.00275517426472391,0.814149693519042,0.0107047953118377,0.682864593067749,0.0185209594632907,0.52069384686288,0.0262828552240056,0.325213183352731,0.0307837948422151,0.152815219118241,0.0277317486782773,0.0429551112266143,0.0168517270606709,0,0,0.0408398189079085,-0.0171358097754144,0.136824284769333,-0.0279100713600759,0.289192311415617,-0.0321610065517032,0.490511679687803,-0.0285517335250371,0.680813751073162,-0.0194405199767373,0.840165601920523,-0.00946120717417282,0.955145580885723,-0.00227264953150234,1,0],"Bot_Xtr":0.944370971109211,"sym":0.000626793135305332,"alpha":-0.2,"clcd":231.823608351882,"CDpres":0.0013,"CDp":0.000299893323154856,"n":10,"CL":-0.040132208913045,"CD":0.00431362451438558,"Cpmin":-0.280428214811368,"CDf":0.00302,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt109.924282480044>88.3931031152266) l1 Foil spline 17pts Re350000 N6","xver":6.991,"iver":1.2020052,"good":150.247171465763,"id":1231,"Cm":0.0032171773694012},
             {"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt128.929178354652>107.38562178186) l1 Foil spline 17pts Re620000 N12","xver":6.991,"good":122.217964227215,"id":1232,"r":6,"Cm":-0.000571557100829829,"n":11,"CL":0.00122637663039299,"CD":0.00493249048879631,"CDp":0.000982037549152221,"CDf":0.00298,"Cpmin":-0.308152227581518,"sym":0.000268115330785879,"Bot_Xtr":0.932713672051344,"xy":[1,0,0.92665990621884,0.00788325175139104,0.825921357659381,0.0166935871487504,0.672783569504887,0.0281088134070179,0.495512951249265,0.0381181023695616,0.312090510037109,0.0430179640097155,0.146453297160589,0.0381596474037436,0.0354870723445344,0.022034903907265,0,0,0.0345118418622416,-0.0219293680191003,0.143520041847869,-0.0384205526542922,0.311152398930403,-0.0435255445915813,0.501481865544773,-0.038288142387177,0.711715512073078,-0.0257740411885494,0.925495042077482,-0.00826004796199025,0.979243859290989,-0.00172366082538887,1,0],"clcd":202.73733974174,"CDpres":0.00195,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re620000-N12.dat","Top_Xtr":0.939378783818211,"Re":620000,"src":"retest_85.txt"},
             {"CDp":0.000495143409897434,"CD":0.004149554590845,"CL":0.000494971709153178,"n":12,"Cpmin":-0.431756787118908,"CDf":0.00285,"r":6,"id":1233,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.9963777162855>86.4422066326818) l1 Foil spline 17pts Re200000 N10","good":111.824305083121,"xver":6.991,"iver":1.2020052,"Cm":-0.000151578966206601,"Top_Xtr":0.918339103167046,"Foil_fn":"optbs-spline_foil_sym_tp29-8.dat-s17_n17s0-Re200000-N10.dat","diter":4,"src":"retest_93.txt","Re":620000,"xy":[1,0,0.857899050218291,0.00690861127145202,0.751503599940214,0.0125113316216725,0.617882281805394,0.0200717631721079,0.516474874255053,0.02562844607288,0.425516435642791,0.0303101288040856,0.22020135983351,0.0366383243360539,0.0597789339840893,0.027712431864884,0,0,0.0545974187204916,-0.0267830502629754,0.191614124162238,-0.0366431318928068,0.354272483283979,-0.0334212032726431,0.461006103363399,-0.0286571353539567,0.600655324159936,-0.021100956221632,0.736649107785801,-0.0133783453822257,0.846409340674087,-0.00750906243601124,1,0],"Bot_Xtr":0.927613753844287,"sym":6.53059873199423e-05,"alpha":0,"clcd":240.989720247629,"CDpres":0.00129},
             {"sym":6.53059873199423e-05,"Bot_Xtr":0.951027846069493,"xy":[1,0,0.857899050218291,0.00690861127145202,0.751503599940214,0.0125113316216725,0.617882281805394,0.0200717631721079,0.516474874255053,0.02562844607288,0.425516435642791,0.0303101288040856,0.22020135983351,0.0366383243360539,0.0597789339840893,0.027712431864884,0,0,0.0545974187204916,-0.0267830502629754,0.191614124162238,-0.0366431318928068,0.354272483283979,-0.0334212032726431,0.461006103363399,-0.0286571353539567,0.600655324159936,-0.021100956221632,0.736649107785801,-0.0133783453822257,0.846409340674087,-0.00750906243601124,1,0],"clcd":241.378702916905,"CDpres":0.00141,"alpha":-0.1,"diter":4,"Top_Xtr":0.971987910236687,"Foil_fn":"optbs-spline_foil_sym_tp29-8.dat-s17_n17s0-Re200000-N10.dat","Re":620000,"src":"retestd_9.txt","id":1234,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_tp29-8.dat-s17_n17s0.dat (opt98.9963777162855>86.4422066326818) l1 Foil spline 17pts Re200000 N10","xver":6.991,"good":122.014489565991,"iver":1.2020052,"r":6,"Cm":0.00273419735962256,"CL":-0.0251088972689926,"CD":0.00414286756832996,"n":13,"CDp":0.00054225003080798,"CDf":0.00273,"Cpmin":-0.441369692121898},
             {"src":"retest_88.txt","Re":620000,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re620000-N12.dat","Top_Xtr":0.981315846078752,"diter":4,"alpha":-1.1,"clcd":170.602427613177,"CDpres":0.00296,"Bot_Xtr":0.901009484243933,"xy":[1,0,0.92665990621884,0.00788325175139104,0.825921357659381,0.0166935871487504,0.672783569504887,0.0281088134070179,0.495512951249265,0.0381181023695616,0.312090510037109,0.0430179640097155,0.146453297160589,0.0381596474037436,0.0354870723445344,0.022034903907265,0,0,0.0345118418622416,-0.0219293680191003,0.143520041847869,-0.0384205526542922,0.311152398930403,-0.0435255445915813,0.501481865544773,-0.038288142387177,0.711715512073078,-0.0257740411885494,0.925495042077482,-0.00826004796199025,0.979243859290989,-0.00172366082538887,1,0],"sym":0.000268115330785879,"Cpmin":-0.633839167655771,"CDf":0.0029,"CDp":0.00132278858415386,"n":14,"CD":0.00586158130332937,"CL":-0.220099253269532,"Cm":0.0185051598853111,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt128.929178354652>107.38562178186) l1 Foil spline 17pts Re620000 N12","good":115.233430302039,"xver":6.991,"iver":1.2020052,"id":1235},
             {"clcd":189.264912396393,"CDpres":0.00136,"alpha":-0.1,"sym":0.00024149012807245,"xy":[1,0,0.880300325419672,0.0281811997891934,0.704663862945517,0.0508996201639534,0.494561349047687,0.0583838767805817,0.292149054823316,0.0516910750563325,0.151132354125174,0.0384188982575565,0.0758230374101564,0.0266358518091129,0.0249798475564602,0.0147996766141952,0,0,0.0247348166511182,-0.0144423036809282,0.0790299712088116,-0.026922067653428,0.168051338348483,-0.0399889717041293,0.314517318069903,-0.0523271228927331,0.507756670437578,-0.0575507341902832,0.707646981873831,-0.0499691075301725,0.880289902407772,-0.0278306656153318,1,0],"Bot_Xtr":0.847875714537693,"Re":750000,"src":"retestc_23.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re750000-N3.dat","Top_Xtr":0.849246013622386,"Cm":-0.000949660637670821,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt103.231339882123>96.3892287636684) l1 Foil spline 17pts Re750000 N3","good":103.231339943623,"iver":1.2020052,"id":1236,"r":6,"CDf":0.00392,"Cpmin":-0.284295877355664,"n":3,"CD":0.00528359951846552,"CL":-0.00668160386006242,"CDp":-0.000456998748577714},
             {"Cpmin":-0.287922865861906,"CDf":0.00363,"CDp":-0.000151881507241822,"CD":0.00516388150029085,"CL":-0.0983908120069735,"n":4,"Cm":0.00281621586250538,"r":6,"id":1237,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt100.668798561802>99.5779124690093) l1 Foil spline 17pts Re1000000 N3","xver":6.991,"iver":1.2020052,"good":98.053975155579,"src":"retestc_14.txt","Re":750000,"Top_Xtr":0.890218075297048,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re1000000-N3.dat","diter":4,"alpha":-0.8,"CDpres":0.00153,"clcd":193.652778427173,"Bot_Xtr":0.86044780779572,"xy":[1,0,0.880300325419672,0.0251783263414234,0.704663862945517,0.0454759647115506,0.494561349047687,0.052162729537961,0.292149054823316,0.0461830854059816,0.151132354125174,0.0343251375116271,0.0758230374101564,0.023797644324881,0.0249798475564602,0.0132226835737005,0,0,0.0247348166511182,-0.013060641373455,0.0790299712088116,-0.0243464947436085,0.168051338348483,-0.0361633178376225,0.314517318069903,-0.0473211061964576,0.507756670437578,-0.0520449864955351,0.707646981873831,-0.0451886767943415,0.880289902407772,-0.0251681692074095,1,0],"sym":8.16407951963308e-06},
             {"Re":750000,"src":"retestc_1.txt","diter":5,"Top_Xtr":0.866454866105905,"Foil_fn":"optbs_spline_sym_naca16012.dat-s17_n17s0_nsopt-Re750000-N5.dat","clcd":176.324628094408,"CDpres":0.00201,"alpha":0,"sym":1.52649439073433e-05,"xy":[1,0,0.878175247413484,0.0301467894546009,0.703112195765058,0.0538042701747747,0.497409844593044,0.0615114932612131,0.289984193140673,0.0548844218043302,0.138935011398081,0.0409296339200784,0.0706796263555245,0.0298852702815018,0.0235527616953747,0.0181185350131515,0,0,0.0235522361629963,-0.0180759782857158,0.0745550964375219,-0.0307788264150056,0.145796055405051,-0.0418377498193127,0.285727317223195,-0.0546337985862229,0.483503181806403,-0.0615593866896087,0.69332798864512,-0.0547147195233147,0.87453012738683,-0.0309053166782813,1,0],"Bot_Xtr":0.87289298527452,"CDf":0.00366,"Cpmin":-0.29849867671203,"CL":-0.0104544428461188,"CD":0.00567135748878245,"n":5,"CDp":-4.41185823719184e-05,"Cm":0.00254004128935781,"id":1238,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16012.dat-s17_n17s0.dat (opt97.5825696589184>93.5701082046162) l1 Foil spline 17pts Re750000 N5","good":97.5825695926745,"iver":1.2020052,"r":6},
             {"Cm":0.000635307938213205,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt120.560990106017>94.9617310404439) l1 Foil spline 17pts Re750000 N6","good":120.560990105787,"xver":6.991,"iver":1.2020052,"id":1239,"r":6,"CDf":0.00323,"Cpmin":-0.191903994279642,"n":6,"CL":-0.0124695838225765,"CD":0.00408772420252917,"CDp":0.000126002255949576,"clcd":244.634899629793,"CDpres":0.00086,"alpha":-0.1,"sym":0.000157846551621202,"xy":[1,0,0.940815124572135,0.00296782470616318,0.814199390144812,0.0128823587932384,0.657124116507608,0.0217349792456614,0.484682477036353,0.0278618002479408,0.306147230532409,0.0293083189814909,0.139302892624925,0.0244795479600003,0.0329460225561095,0.0135183899798749,0,0,0.0346126218693256,-0.0134293098539094,0.13958388382745,-0.0243617983079194,0.303144461201187,-0.0295275021420696,0.484538976270729,-0.0284009058454918,0.663497007146588,-0.0219605105176037,0.818425675853368,-0.0128879475806875,0.939160686099656,-0.00313715589955603,1,0],"Bot_Xtr":0.881211537434878,"Re":750000,"src":"retestc_2.txt","diter":3,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re750000-N6.dat","Top_Xtr":0.895386260082027},
             {"clcd":240.278393564683,"CDpres":0.00102,"alpha":0,"sym":0.000832727302701922,"xy":[1,0,0.940815124572135,0.00323708634657193,0.814199390144812,0.0140511357273336,0.657124116507608,0.0237069273037066,0.484682477036353,0.0303896159992964,0.306147230532409,0.0319673729445471,0.139302892624925,0.0267005023265053,0.0329460225561095,0.0147448720743555,0,0,0.0346126218693256,-0.013930825967803,0.13958388382745,-0.0252715870124588,0.303144461201187,-0.030630203493693,0.484538976270729,-0.0294615345811183,0.663497007146588,-0.0227806233911407,0.818425675853368,-0.013369246579448,0.939160686099656,-0.0032543126449539,1,0],"Bot_Xtr":0.903917092895192,"Re":750000,"src":"retest_149.txt","diter":4,"Top_Xtr":0.897065388712642,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re750000-N7.dat","Cm":6.84036731224236e-05,"id":1240,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt143.891670068112>108.256451618365) l1 Foil spline 17pts Re750000 N7","good":126.516488988647,"iver":1.2020052,"r":6,"CDf":0.00314,"Cpmin":-0.20229889790562,"CD":0.0041618390449693,"CL":0.0040190833159274,"n":7,"CDp":0.00029559601851053},
             {"Cm":0.0014817781445495,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt134.107726964664>126.077788450727) l1 Foil spline 17pts Re750000 N8","iver":1.2020052,"xver":6.991,"good":133.534641483373,"id":1241,"Cpmin":-0.241610269583443,"CDf":0.00315,"CDp":0.000544881449250064,"n":8,"CL":0.00408038834309837,"CD":0.00440015676328562,"alpha":0.1,"CDpres":0.00125,"clcd":227.264630284057,"Bot_Xtr":0.889887914239807,"xy":[1,0,0.942889525368766,0.00352175375180888,0.829506244622028,0.014892488172393,0.663520326400651,0.0267232264244239,0.483883529026766,0.0347313797660196,0.308064634878761,0.0365281468309132,0.141281933878215,0.0306541433150823,0.0337611204221739,0.0169104510424021,0,0,0.0332640042916588,-0.0171068791485465,0.137232488870993,-0.0311998841680291,0.301394215855595,-0.037907787704559,0.486422871117426,-0.0363870836854663,0.672870651601015,-0.027545429132082,0.824138239185622,-0.0158996815424805,0.940657070540577,-0.00383031509671509,1,0],"sym":0.000992408820251446,"src":"retestc_4.txt","Re":750000,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re750000-N8.dat","Top_Xtr":0.89158692995587,"diter":3},
             {"sym":0.00012457073166761,"Bot_Xtr":0.932713534789921,"xy":[1,0,0.92665990621884,0.0068804558457515,0.825921357659381,0.0145700648547618,0.672783569504887,0.0245332073137621,0.495512951249265,0.0332692559553646,0.312090510037109,0.0375458264276219,0.146453297160589,0.0333055162172861,0.0354870723445344,0.0192319347625251,0,0,0.0345118418622416,-0.0189251157727784,0.143520041847869,-0.033157061635488,0.311152398930403,-0.0375626862457435,0.501481865544773,-0.0330427911452269,0.711715512073078,-0.0222430811959928,0.925495042077482,-0.00712844819938323,0.979243859290989,-0.00148752488649354,1,0],"clcd":242.34263224101,"CDpres":0.00125,"alpha":0.2,"diter":4,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re750000-N9.dat","Top_Xtr":0.908242981281461,"Re":750000,"src":"retestc_5.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt138.112625358929>88.5013851126544) l1 Foil spline 17pts Re750000 N9","good":138.112625384113,"iver":1.2020052,"id":1242,"r":6,"Cm":-0.00222323198668612,"n":9,"CD":0.00412638911590883,"CL":0.0330909804385742,"CDp":0.000465293963853785,"CDf":0.00288,"Cpmin":-0.300730767466291},
             {"alpha":0,"clcd":252.790257565165,"CDpres":0.00105,"Bot_Xtr":0.920588918951255,"xy":[1,0,0.944740406454351,0.00300366568325902,0.814149693519042,0.0116702695492478,0.682864593067749,0.0201913799330919,0.52069384686288,0.0286533274156876,0.325213183352731,0.0335602104563476,0.152815219118241,0.0302328977546732,0.0429551112266143,0.0183715980959399,0,0,0.0408398189079085,-0.0177000509028784,0.136824284769333,-0.0288290830868753,0.289192311415617,-0.033219991381422,0.490511679687803,-0.0294918736483438,0.680813751073162,-0.0200806496848704,0.840165601920523,-0.0097727420402277,0.955145580885723,-0.00234748243118971,1,0],"sym":6.57085437030375e-05,"src":"retest_72.txt","Re":750000,"Foil_fn":"optbs_spline_sym_hn153s.dat-s17_n17s0_nsopt-Re350000-N7.dat","Top_Xtr":0.916494336700063,"diter":4,"Cm":-0.000215499882309403,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_hn153s.dat-s17_n17s0.dat (opt113.396160539739>95.195448993345) l1 Foil spline 17pts Re350000 N7","good":160.657496952342,"iver":1.2020052,"id":1243,"Cpmin":-0.245990665910801,"CDf":0.00291,"CDp":0.000228172688783637,"n":10,"CD":0.003955848653472,"CL":0.00179154159040734},
             {"Top_Xtr":0.963213552141743,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re750000-N11.dat","diter":4,"src":"retestc_7.txt","Re":750000,"xy":[1,0,0.969087652468728,0.00297906759557478,0.801860568053254,0.0152165243543002,0.696504319290661,0.0216878321301129,0.549776607886737,0.0291078657519502,0.338361913064034,0.0355662325445447,0.144153484994011,0.0336883406335772,0.0380479581477159,0.0212099053377096,0,0,0.039910401665453,-0.0217877473450536,0.148421317779882,-0.0337585417342992,0.328374676921391,-0.0355528082732322,0.517844762768298,-0.0303212387127329,0.689480272273693,-0.0221002418353461,0.832528496272264,-0.0130331562276727,0.973498898866872,-0.00258162579123775,1,0],"Bot_Xtr":0.93398602930044,"sym":4.45550353827396e-05,"alpha":-0.3,"CDpres":0.00146,"clcd":238.888658517362,"CDp":0.000584191325803799,"CL":-0.0553588335205971,"CD":0.00418605054842871,"n":11,"Cpmin":-0.418611667320131,"CDf":0.00272,"r":6,"id":1244,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt149.152917855808>121.525625507262) l1 Foil spline 17pts Re750000 N11","iver":1.2020052,"good":149.15291785592,"Cm":0.0044365531736228},
             {"xy":[1,0,0.958697949919804,0.00399587626193949,0.839534098645647,0.0145848237254375,0.689473001558313,0.0260639957162606,0.502749331332653,0.0365468284835375,0.31276546741024,0.0420669229871014,0.144955719062291,0.0387906827792113,0.0376596749358859,0.0228298815223329,0,0,0.0393131000478028,-0.02376346415276,0.146218399310118,-0.0391907025455862,0.306004793213774,-0.0426305668149681,0.501247539482914,-0.0370667239372673,0.692204662541298,-0.0261598655037596,0.835527625011643,-0.015087428477411,0.973107828960817,-0.0027286206030002,1,0],"Bot_Xtr":0.925035939895356,"sym":0.000146047382559437,"alpha":0,"clcd":230.298860825919,"CDpres":0.00155,"Top_Xtr":0.92570957271362,"Foil_fn":"optbs_spline_sym_fx76120.dat-s17_n17s0_nsopt-Re1000000-N12.dat","diter":4,"src":"retest_65.txt","Re":750000,"r":6,"id":1245,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76120.dat-s17_n17s0.dat (opt150.018918645777>90.0920342791563) l1 Foil spline 17pts Re1000000 N12","iver":1.2020052,"good":133.358230170812,"Cm":0.000766927885452652,"CDp":0.000761826972353105,"CL":-0.0040640497138446,"CD":0.00434218387539438,"n":12,"Cpmin":-0.333030895162433,"CDf":0.00279},
             {"alpha":5.1,"CDpres":0.00487,"clcd":65.4342647633362,"Bot_Xtr":0.79810371631575,"xy":[1,0,0.91221192907363,0.0127346923247513,0.734521294155728,0.0546890432894877,0.595398618250498,0.0797635279808799,0.426150873151079,0.0849880115896746,0.247961170452198,0.072753760989298,0.108768025340124,0.0481975912131958,0.0274552076733582,0.0217348629437536,0,0,0.0107467209884378,-0.023807562168938,0.0754785878921827,-0.0501605921064706,0.190099935807211,-0.0740321390725792,0.339568554063187,-0.0888768144737601,0.507337345622005,-0.090522429240359,0.66391387623878,-0.073560318956898,0.90508274684817,-0.0153783552201884,1,0],"sym":0.05715979794712,"src":"retestd_5.txt","Re":750000,"Top_Xtr":0.627420839881398,"Foil_fn":"optbs-spline_foil_sym_n66021.dat-s17_n17s0-Re30000000-N10.dat","diter":3,"Cm":-0.0036703804985966,"r":6,"id":1246,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_n66021.dat-s17_n17s0.dat (opt4.38850801379915>0.218981197665125) l1 Foil spline 17pts Re30000000 N10","good":16.0102027301293,"xver":6.991,"iver":1.2020052,"Cpmin":-1.93379288258083,"CDf":0.00389,"CDp":0.00269843545009355,"CL":0.573506795472238,"CD":0.0087646250408178,"n":13},
             {"CDp":0.000634165306153454,"CD":0.00399406303820709,"CL":0.0184488292943232,"n":14,"Cpmin":-0.468967473070728,"CDf":0.00247,"r":6,"id":1247,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_b540ols.dat-s17_n17s0.dat (opt75.2340456249175>53.9462461907376) l1 Foil spline 17pts Re150000 N8","iver":1.2020052,"good":88.8117326882858,"Cm":-0.00386809615461965,"Top_Xtr":0.937043992953135,"Foil_fn":"optbs_spline_sym_b540ols.dat-s17_n17s0_nsopt-Re150000-N8.dat","diter":7,"src":"retestd_0.txt","Re":750000,"xy":[1,0,0.920221173114614,0.0060785132462634,0.645313884538533,0.0212470364870417,0.34905035398236,0.0374892682288443,0.245681701944153,0.0405584159182554,0.186935146123869,0.0403031133023483,0.108528059881009,0.036237716133879,0.0290146041711134,0.0229222376362741,0,0,0.0253926121749067,-0.0214307803127376,0.0869345356684127,-0.0335908073739287,0.154345254889348,-0.0390501202555085,0.25014758254482,-0.040426375708435,0.381402973649756,-0.0356107255510356,0.730048776396412,-0.016461227543788,0.928043174290564,-0.00564016746063657,1,0],"Bot_Xtr":0.954984901608527,"sym":5.01009286498665e-05,"alpha":0,"clcd":250.371611673133,"CDpres":0.00153},
             {"xy":[1,0,0.913162369486509,0.0236783859076674,0.813710842258612,0.0423855629763144,0.673782501507511,0.0579961524314081,0.492724758079874,0.0636797170371839,0.299655576439083,0.057427531272102,0.141435325331645,0.0427188100457337,0.0380604371432103,0.0232937086787603,0,0,0.0380279452424157,-0.0230631674035169,0.14605649423593,-0.0430809054381989,0.312666093446018,-0.0577828686951513,0.510591162367989,-0.0632371465162768,0.699485607975073,-0.0557015914841885,0.843999845282038,-0.0372073574309883,0.923962179670343,-0.0208896951227616,1,0],"Bot_Xtr":0.833201025948601,"sym":9.17717859013611e-05,"alpha":0.2,"clcd":204.921035049647,"CDpres":0.00125,"Top_Xtr":0.826442207531192,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1000000-N3.dat","diter":3,"src":"retestc_9.txt","Re":1000000,"r":6,"id":1248,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt106.870341901737>91.1229528472496) l1 Foil spline 17pts Re1000000 N3","iver":1.2020052,"good":106.870341901987,"Cm":0.00230434092367816,"CDp":-0.000585877412392415,"CL":0.0121016660837732,"CD":0.00487992850396117,"n":3,"Cpmin":-0.311140690698666,"CDf":0.00363},
             {"sym":1.84263101159936e-05,"Bot_Xtr":0.886714373820191,"xy":[1,0,0.913162369486509,0.0168126581649367,0.813710842258612,0.0300955472314696,0.673782501507511,0.0411797277700033,0.492724758079874,0.0452152996729132,0.299655576439083,0.0407759826323895,0.141435325331645,0.0303321667833455,0.0380604371432103,0.0165395210187363,0,0,0.0380279452424157,-0.0164320451007639,0.14605649423593,-0.0306942827390778,0.312666093446018,-0.0411691372584608,0.510591162367989,-0.0450552010232828,0.699485607975073,-0.0396862689082741,0.843999845282038,-0.0265094973595436,0.923962179670343,-0.014883489608894,1,0],"CDpres":0.00109,"clcd":238.250262960699,"alpha":0,"diter":6,"Top_Xtr":0.888295878237356,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1000000-N4.dat","Re":1000000,"src":"retestc_10.txt","id":1249,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt111.874741348425>111.757888586175) l1 Foil spline 17pts Re1000000 N4","iver":1.2020052,"xver":6.991,"good":111.874741348266,"r":6,"Cm":-0.000633619396311067,"CL":0.00259137418366548,"CD":0.00419726714075004,"n":4,"CDp":-2.9339331355518e-05,"CDf":0.00311,"Cpmin":-0.215907479565991},
             {"Cm":0.00128673632421942,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt106.870341901737>91.1229528472496) l1 Foil spline 17pts Re1000000 N3","iver":1.2020052,"xver":6.991,"good":116.298228043675,"id":1250,"r":6,"CDf":0.00333,"Cpmin":-0.328127553286174,"n":5,"CL":0.0597370916184456,"CD":0.00489061877954402,"CDp":-0.000289613393048953,"CDpres":0.00156,"clcd":204.473103522748,"alpha":0.6,"sym":9.17717859013611e-05,"xy":[1,0,0.913162369486509,0.0236783859076674,0.813710842258612,0.0423855629763144,0.673782501507511,0.0579961524314081,0.492724758079874,0.0636797170371839,0.299655576439083,0.057427531272102,0.141435325331645,0.0427188100457337,0.0380604371432103,0.0232937086787603,0,0,0.0380279452424157,-0.0230631674035169,0.14605649423593,-0.0430809054381989,0.312666093446018,-0.0577828686951513,0.510591162367989,-0.0632371465162768,0.699485607975073,-0.0557015914841885,0.843999845282038,-0.0372073574309883,0.923962179670343,-0.0208896951227616,1,0],"Bot_Xtr":0.871816025889475,"Re":1000000,"src":"retest_72.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1000000-N3.dat","Top_Xtr":0.850819412068297},
             {"CDf":0.00308,"Cpmin":-0.313436934814037,"n":6,"CD":0.00460679971855298,"CL":0.0962558387229957,"CDp":0.000195811535182941,"Cm":-0.00188087631744485,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt162.65189326284>143.252279398219) l1 Foil spline 17pts Re2500000 N7","xver":6.991,"good":123.870753957818,"id":1251,"r":6,"Re":1000000,"src":"retest_111.txt","diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N7.dat","Top_Xtr":0.869378617948815,"clcd":217.070430905146,"CDpres":0.00153,"alpha":0.8,"sym":1.18486023509406e-05,"xy":[1,0,0.913162369486509,0.0190540108668918,0.813710842258612,0.0341076870990815,0.673782501507511,0.0466695374834706,0.492724758079874,0.0512431052166523,0.299655576439083,0.0462119677069321,0.141435325331645,0.0343758512090355,0.0380604371432103,0.0187444608777826,0,0,0.0380279452424157,-0.0186849250495967,0.14605649423593,-0.0349025558847899,0.312666093446018,-0.0468135426426708,0.510591162367989,-0.0512323967620693,0.699485607975073,-0.0451273688394861,0.843999845282038,-0.0301440245707777,0.923962179670343,-0.0169240582114583,1,0],"Bot_Xtr":0.909301465343894},
             {"Cpmin":-0.196011943549396,"CDf":0.00291,"CDp":4.02078252797719e-05,"CL":0.00279523405279532,"CD":0.00363247167538243,"n":7,"Cm":-0.000277950439123671,"r":6,"id":1252,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt137.071442746857>111.74250108652) l1 Foil spline 17pts Re1000000 N7","good":137.07144274539,"xver":6.991,"iver":1.2020052,"src":"retest_96.txt","Re":1000000,"Top_Xtr":0.882747640394222,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1000000-N7.dat","diter":3,"alpha":0,"CDpres":0.00072,"clcd":275.294644904484,"Bot_Xtr":0.878909209967115,"xy":[1,0,0.942889525368766,0.00295627444189563,0.829506244622028,0.0125012380941357,0.663520326400651,0.022432343897678,0.483883529026766,0.0291546478175306,0.308064634878761,0.0306629124283815,0.141281933878215,0.0257320831628383,0.0337611204221739,0.0141951816454809,0,0,0.0332640042916588,-0.0135768697912139,0.137232488870993,-0.0247617792334892,0.301394215855595,-0.0300855049754361,0.486422871117426,-0.0288785986613787,0.672870651601015,-0.0218614220292288,0.824138239185622,-0.0126187777530636,0.940657070540577,-0.00303992849168169,1,0],"sym":0.000213373061389456},
             {"CDf":0.00298,"Cpmin":-0.241773063652655,"CL":0.000918125703375756,"CD":0.00385448162849723,"n":8,"CDp":0.000227632836760315,"Cm":8.83110842151302e-05,"id":1253,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt137.801472869791>126.314460171594) l1 Foil spline 17pts Re1000000 N8","good":137.801472870498,"iver":1.2020052,"r":6,"Re":1000000,"src":"retestc_14.txt","diter":4,"Top_Xtr":0.865956269852289,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1000000-N8.dat","CDpres":0.00087,"clcd":259.438258210061,"alpha":0,"sym":0.000174946779475472,"xy":[1,0,0.942889525368766,0.00364463304434149,0.829506244622028,0.0154121095143832,0.663520326400651,0.0276556400423651,0.483883529026766,0.0359432099151713,0.308064634878761,0.0378026688890794,0.141281933878215,0.0317237125437133,0.0337611204221739,0.0175004821481915,0,0,0.0332640042916588,-0.016976487193019,0.137232488870993,-0.0309620725909685,0.301394215855595,-0.0376188471838716,0.486422871117426,-0.0361097342661777,0.672870651601015,-0.0273354725211077,0.824138239185622,-0.0157784910815796,0.940657070540577,-0.00380111969108849,1,0],"Bot_Xtr":0.86076111971637},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt151.044437049265>95.7691206539157) l1 Foil spline 17pts Re1000000 N9","xver":6.991,"good":151.044437049524,"iver":1.2020052,"id":1254,"r":6,"Cm":-0.000462205758933481,"n":9,"CD":0.00344100852567994,"CL":0.0250426627859297,"CDp":0.000119433957891312,"CDf":0.00264,"Cpmin":-0.318445517785275,"sym":0.000115415208706502,"Bot_Xtr":0.937593113645495,"xy":[1,0,0.969087652468728,0.00253260426995343,0.801860568053254,0.0129360725519609,0.696504319290661,0.0184375461437489,0.549776607886737,0.0247455630755492,0.338361913064034,0.0302360351078545,0.144153484994011,0.0286395768471249,0.0380479581477159,0.0180312447100508,0,0,0.039910401665453,-0.0188567987773579,0.148421317779882,-0.0292172485029867,0.328374676921391,-0.0307701453005203,0.517844762768298,-0.026242341075065,0.689480272273693,-0.0191272556368559,0.832528496272264,-0.0112798996852186,0.973498898866872,-0.00223433828623221,1,0],"CDpres":0.0008,"clcd":290.612473795717,"alpha":0.2,"diter":4,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re1000000-N9.dat","Top_Xtr":0.88976429509373,"Re":1000000,"src":"retestc_15.txt"},
             {"CDf":0.00283,"Cpmin":-0.259979547398583,"n":10,"CD":0.00394806575407163,"CL":0.00848806282405324,"CDp":0.000475567906438533,"Cm":0.000747811718854459,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt107.025500115941>107.000017612955) l1 Foil spline 17pts Re1000000 N6","xver":6.991,"good":146.933919131445,"iver":1.2020052,"id":1255,"r":6,"Re":1000000,"src":"retest_111.txt","diter":3,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1000000-N6.dat","Top_Xtr":0.886698103763493,"CDpres":0.00112,"clcd":253.288587954419,"alpha":0.1,"sym":0.000328826354660855,"xy":[1,0,0.942889525368766,0.00379421827913106,0.829506244622028,0.0160446626390087,0.663520326400651,0.0287906995555349,0.483883529026766,0.0374184128859063,0.308064634878761,0.0393541889001885,0.141281933878215,0.0330257363500923,0.0337611204221739,0.0182187475261374,0,0,0.0332640042916588,-0.0179934173866899,0.137232488870993,-0.0328167711583691,0.301394215855595,-0.0398723016893539,0.486422871117426,-0.0382727894756093,0.672870651601015,-0.0289729294960941,0.824138239185622,-0.0167236585834892,0.940657070540577,-0.00402881540573637,1,0],"Bot_Xtr":0.885693755065763},
             {"Cpmin":-0.324617044253585,"CDf":0.00244,"CDp":0.000307685570394692,"n":11,"CL":-0.00721580663415003,"CD":0.00345934651514264,"Cm":0.00126673487509776,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt152.998647055644>122.687301368297) l1 Foil spline 17pts Re1000000 N11","xver":6.991,"good":152.99979839377,"iver":1.2020052,"id":1256,"src":"retest_98.txt","Re":1000000,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re1000000-N11.dat","Top_Xtr":0.943589585793578,"diter":6,"alpha":0,"CDpres":0.00102,"clcd":289.071937610958,"Bot_Xtr":0.939411874320364,"xy":[1,0,0.969087652468728,0.0027418242755465,0.801860568053254,0.0140047295086687,0.696504319290661,0.0199606832374839,0.549776607886737,0.0267898093506157,0.338361913064034,0.032733852674313,0.144153484994011,0.0310055100089799,0.0380479581477159,0.0195208169909804,0,0,0.039910401665453,-0.0206458228095732,0.148421317779882,-0.0319892120978793,0.328374676921391,-0.0336894387642385,0.517844762768298,-0.0287320626550213,0.689480272273693,-0.0209419390520361,0.832528496272264,-0.0123500713435207,0.973498898866872,-0.00244631938320229,1,0],"sym":0.000344037908997536},
             {"good":150.01909665587,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx76120.dat-s17_n17s0.dat (opt150.018918645777>90.0920342791563) l1 Foil spline 17pts Re1000000 N12","xver":6.991,"iver":1.2020052,"id":1257,"r":6,"Cm":0.000952091109744513,"n":12,"CD":0.0037685250810897,"CL":0.00698295552457688,"CDp":0.000428306114994093,"CDf":0.00266,"Cpmin":-0.344135669190246,"sym":0.000146047382559437,"Bot_Xtr":0.900881286820425,"xy":[1,0,0.958697949919804,0.00399587626193949,0.839534098645647,0.0145848237254375,0.689473001558313,0.0260639957162606,0.502749331332653,0.0365468284835375,0.31276546741024,0.0420669229871014,0.144955719062291,0.0387906827792113,0.0376596749358859,0.0228298815223329,0,0,0.0393131000478028,-0.02376346415276,0.146218399310118,-0.0391907025455862,0.306004793213774,-0.0426305668149681,0.501247539482914,-0.0370667239372673,0.692204662541298,-0.0261598655037596,0.835527625011643,-0.015087428477411,0.973107828960817,-0.0027286206030002,1,0],"CDpres":0.00111,"clcd":265.355803260527,"alpha":0.1,"diter":4,"Foil_fn":"optbs_spline_sym_fx76120.dat-s17_n17s0_nsopt-Re1000000-N12.dat","Top_Xtr":0.886972564238966,"Re":1000000,"src":"retestc_18.txt"},
             {"CDf":0.0025,"Cpmin":-0.313188129283249,"n":13,"CD":0.00375075929662283,"CL":-0.00225521543217009,"CDp":0.000553643151188379,"Cm":0.00031218568338315,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0013.dat-s17_n17s0.dat (opt158.312279974596>85.3248511439717) l1 Foil spline 17pts Re750000 N12","good":148.963416253451,"xver":6.991,"iver":1.2020052,"id":1258,"r":6,"Re":1000000,"src":"retestc_23.txt","diter":4,"Foil_fn":"optbs_spline_sym_naca0013.dat-s17_n17s0_nsopt-Re750000-N12.dat","Top_Xtr":0.917078581551595,"clcd":266.612683170684,"CDpres":0.00126,"alpha":0,"sym":0.000242568625782047,"xy":[1,0,0.926624813612928,0.00801278603902204,0.836471491410797,0.0160451291686269,0.682547580933488,0.027852618051475,0.495106406050575,0.0386965202306413,0.309374998263626,0.0436348202350051,0.147490753592901,0.0387265566163452,0.036405348669114,0.0226601190547848,0,0,0.0352814504913503,-0.022398648836978,0.147765612228726,-0.0391922419969763,0.320350088906264,-0.0439826696017745,0.511571300638545,-0.0382529478676205,0.698983317593558,-0.026952190995202,0.860095066512714,-0.0141782152923983,0.932751973790206,-0.00746028484043246,1,0],"Bot_Xtr":0.912902207636644},
             {"cmt":"NEWv1.20200520 s(0) foildb2020/sym_naca0271.dat (sim 0.037906869302 ) l1 Foil spline 17pts","xver":6.991,"good":-0.0557472385844168,"iver":1.2020052,"id":1259,"r":6,"Cm":0.0144604002359789,"n":14,"CD":0.128661389409053,"CL":-0.0569176605737354,"CDp":-0.00735507926808985,"CDf":0.0052,"Cpmin":-2.69338634404414,"sym":2.63109580115182,"Bot_Xtr":0.340878390071972,"xy":[1,0,0.774308064362175,0.177302458231605,0.476549240587967,0.335013084015135,0.2750001789753,0.376976246882067,0.152944977499202,0.349977145154059,0.0827088741865725,0.296330615163647,0.0639422053983168,0.269685898850667,0.0162006843593955,0.180854206302966,0,0.0195891067146921,0.0179501503148745,-0.0827556995585564,0.0605705853745504,-0.189249248790496,0.144216310426108,-0.27970500314024,0.232139419890303,-0.32039184463339,0.325531789055377,-0.332703223448258,0.513036411470645,-0.297730942928788,0.801692896548123,-0.15287526332924,1,0],"CDpres":0.12346,"clcd":-0.442383381954449,"alpha":4.1,"diter":4,"Foil_fn":"spline_foil_sym_naca0271.dat-s17_n17s0.dat","Top_Xtr":0.292582504610545,"Re":1000000,"src":"retest_81.txt"},
             {"alpha":0,"clcd":214.680282132313,"CDpres":0.00114,"Bot_Xtr":0.825705907099666,"xy":[1,0,0.913162369486509,0.0236783859076674,0.813710842258612,0.0423855629763144,0.673782501507511,0.0579961524314081,0.492724758079874,0.0636797170371839,0.299655576439083,0.057427531272102,0.141435325331645,0.0427188100457337,0.0380604371432103,0.0232937086787603,0,0,0.0380279452424157,-0.0230631674035169,0.14605649423593,-0.0430809054381989,0.312666093446018,-0.0577828686951513,0.510591162367989,-0.0632371465162768,0.699485607975073,-0.0557015914841885,0.843999845282038,-0.0372073574309883,0.923962179670343,-0.0208896951227616,1,0],"sym":9.17717859013611e-05,"src":"retest_77.txt","Re":1125000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1000000-N3.dat","Top_Xtr":0.825260568518516,"diter":3,"Cm":0.00150230061408228,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt106.870341901737>91.1229528472496) l1 Foil spline 17pts Re1000000 N3","xver":6.991,"iver":1.2020052,"good":104.994655142676,"id":1260,"Cpmin":-0.309893356599854,"CDf":0.00352,"CDp":-0.000634449041192941,"n":3,"CD":0.00465808964879073,"CL":-0.00615592934393491},
             {"Cpmin":-0.30746450366768,"CDf":0.00336,"CDp":-0.000517661285508457,"n":4,"CD":0.00459327545653329,"CL":0.00221275190669683,"Cm":0.0020794433845844,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt106.870341901737>91.1229528472496) l1 Foil spline 17pts Re1000000 N3","xver":6.991,"good":116.714092540275,"iver":1.2020052,"id":1261,"src":"retestc_2.txt","Re":1125000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1000000-N3.dat","Top_Xtr":0.843016478585886,"diter":3,"alpha":0.1,"clcd":217.70956465884,"CDpres":0.00123,"Bot_Xtr":0.84541431579744,"xy":[1,0,0.913162369486509,0.0236783859076674,0.813710842258612,0.0423855629763144,0.673782501507511,0.0579961524314081,0.492724758079874,0.0636797170371839,0.299655576439083,0.057427531272102,0.141435325331645,0.0427188100457337,0.0380604371432103,0.0232937086787603,0,0,0.0380279452424157,-0.0230631674035169,0.14605649423593,-0.0430809054381989,0.312666093446018,-0.0577828686951513,0.510591162367989,-0.0632371465162768,0.699485607975073,-0.0557015914841885,0.843999845282038,-0.0372073574309883,0.923962179670343,-0.0208896951227616,1,0],"sym":9.17717859013611e-05},
             {"Cpmin":-0.31000053015934,"CDf":0.00323,"CDp":-0.000372586884109872,"CL":0.00945079176448028,"CD":0.00459052511701018,"n":5,"Cm":0.000329529940635589,"r":6,"id":1262,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt106.870341901737>91.1229528472496) l1 Foil spline 17pts Re1000000 N3","xver":6.991,"iver":1.2020052,"good":125.149200531717,"src":"retest_79.txt","Re":1125000,"Top_Xtr":0.858683405897957,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1000000-N3.dat","diter":3,"alpha":0.1,"CDpres":0.00136,"clcd":217.840001853928,"Bot_Xtr":0.859122365800769,"xy":[1,0,0.913162369486509,0.0236783859076674,0.813710842258612,0.0423855629763144,0.673782501507511,0.0579961524314081,0.492724758079874,0.0636797170371839,0.299655576439083,0.057427531272102,0.141435325331645,0.0427188100457337,0.0380604371432103,0.0232937086787603,0,0,0.0380279452424157,-0.0230631674035169,0.14605649423593,-0.0430809054381989,0.312666093446018,-0.0577828686951513,0.510591162367989,-0.0632371465162768,0.699485607975073,-0.0557015914841885,0.843999845282038,-0.0372073574309883,0.923962179670343,-0.0208896951227616,1,0],"sym":9.17717859013611e-05},
             {"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"Bot_Xtr":0.901251762626866,"sym":7.97215012165649e-05,"alpha":0.6,"clcd":232.807142246962,"CDpres":0.00133,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","Top_Xtr":0.873465994320954,"diter":4,"src":"retest_150.txt","Re":1125000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","good":128.221107458444,"iver":1.2020052,"id":1263,"Cm":-0.00225731939674297,"CDp":6.35385680791247e-05,"n":6,"CL":0.0755093211736537,"CD":0.00429540086420201,"Cpmin":-0.276563252047312,"CDf":0.00296},
             {"Cpmin":-0.309826141018627,"CDf":0.00293,"CDp":0.000198893113887007,"n":7,"CD":0.00440905517871985,"CL":0.0908701368276335,"Cm":-0.00054203180263747,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","xver":6.991,"good":134.089671213975,"id":1264,"src":"retest_151.txt","Re":1125000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","Top_Xtr":0.871621843580725,"diter":4,"alpha":0.8,"CDpres":0.00148,"clcd":226.805961700471,"Bot_Xtr":0.913561221268701,"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"sym":7.97215012165649e-05},
             {"src":"retestc_0.txt","Re":1125000,"Top_Xtr":0.865895797810523,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re1125000-N8.dat","diter":3,"alpha":-0.1,"clcd":275.534569989432,"CDpres":0.00075,"Bot_Xtr":0.860359040876319,"xy":[1,0,0.940815124572135,0.00365262540406036,0.814199390144812,0.0158548552057965,0.657124116507608,0.0267501436943232,0.484682477036353,0.0342906773358764,0.306147230532409,0.0360709681538085,0.139302892624925,0.030127998656028,0.0329460225561095,0.0166376452625201,0,0,0.0346126218693256,-0.0159150073193053,0.13958388382745,-0.0288710442010621,0.303144461201187,-0.0349928937394381,0.484538976270729,-0.0336577701552042,0.663497007146588,-0.026025290161996,0.818425675853368,-0.0152734416220023,0.939160686099656,-0.0037178276208067,1,0],"sym":0.000635601022662814,"Cpmin":-0.22565567366895,"CDf":0.00288,"CDp":0.000119031729587206,"CD":0.00362930865639965,"CL":-0.00750540633885951,"n":8,"Cm":5.10426496974468e-05,"r":6,"id":1265,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt133.662353310711>115.35069599973) l1 Foil spline 17pts Re1125000 N8","good":133.662354154612,"iver":1.2020052},
             {"alpha":0,"CDpres":0.00086,"clcd":269.253968985381,"Bot_Xtr":0.86343371343304,"xy":[1,0,0.940815124572135,0.00389476240139652,0.814199390144812,0.0169058929137596,0.657124116507608,0.0285234433776836,0.484682477036353,0.036563848200182,0.306147230532409,0.0384621566698996,0.139302892624925,0.0321252204686479,0.0329460225561095,0.0177405750790112,0,0,0.0346126218693256,-0.0178534089442645,0.13958388382745,-0.0323874534537128,0.303144461201187,-0.0392549264690287,0.484538976270729,-0.0377571887135741,0.663497007146588,-0.0291950948455826,0.818425675853368,-0.0171337024101262,0.939160686099656,-0.00417064821692093,1,0],"sym":0.00049492682022947,"src":"retest_72.txt","Re":1125000,"Top_Xtr":0.867155661039187,"Foil_fn":"optbs_spline_sym_mh52.dat-s17_n17s0_nsopt-Re1125000-N9.dat","diter":3,"Cm":0.00170291013774467,"r":6,"id":1266,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh52.dat-s17_n17s0.dat (opt154.189022853474>118.848554540016) l1 Foil spline 17pts Re1125000 N9","iver":1.2020052,"good":142.45708036966,"Cpmin":-0.244118439377381,"CDf":0.00285,"CDp":0.000241585889884968,"CL":-0.00571445704356759,"CD":0.00371396567994247,"n":9},
             {"diter":3,"Top_Xtr":0.922571965082274,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re1125000-N10.dat","Re":1125000,"src":"retestc_2.txt","sym":0.000144471262613293,"Bot_Xtr":0.919184252372955,"xy":[1,0,0.927533762368065,0.00628482060719756,0.828124577508512,0.0132984160577689,0.673910782200253,0.022591175046111,0.485356610471494,0.0311024324319173,0.298817780508802,0.0346885570766313,0.140740099512849,0.0303513085013396,0.0345490619416974,0.0175869918885963,0,0,0.033827731492854,-0.0174967758058452,0.142528433402255,-0.0308368933598735,0.31046792119717,-0.0350309073980304,0.499715124890922,-0.0308866386077317,0.684159552318164,-0.0222611064434322,0.829477323686799,-0.0133345689540139,0.922486667396241,-0.00676148687282652,1,0],"CDpres":0.00086,"clcd":303.656033223325,"alpha":0,"CD":0.00329319983991408,"CL":-0.00169071842320087,"n":10,"CDp":0.000223077106285716,"CDf":0.00244,"Cpmin":-0.248611662105753,"id":1267,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt150.883913614821>139.373514438845) l1 Foil spline 17pts Re1125000 N10","good":150.883913614331,"iver":1.2020052,"r":6,"Cm":0.000236418076536881},
             {"diter":4,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re750000-N10.dat","Top_Xtr":0.919537999741699,"Re":1125000,"src":"retest_149.txt","sym":0.00036258364397881,"Bot_Xtr":0.919588314553355,"xy":[1,0,0.92665990621884,0.00691401986104908,0.825921357659381,0.0146411400699271,0.672783569504887,0.0246528844055185,0.495512951249265,0.0334315489546743,0.312090510037109,0.0377289812535272,0.146453297160589,0.0334679861002229,0.0354870723445344,0.0193257513594254,0,0,0.0345118418622416,-0.0186027744562153,0.143520041847869,-0.0325923152408413,0.311152398930403,-0.0369229012170295,0.501481865544773,-0.0324799910583712,0.711715512073078,-0.0218642267592105,0.925495042077482,-0.00700703317581193,0.979243859290989,-0.00146218867528671,1,0],"CDpres":0.00094,"clcd":298.569041614351,"alpha":0,"n":11,"CL":0.00904135159500816,"CD":0.00334930907301387,"CDp":0.000286933773374387,"CDf":0.00241,"Cpmin":-0.268213992482964,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt145.419143162815>92.2710911539519) l1 Foil spline 17pts Re750000 N10","xver":6.991,"good":147.69729612346,"id":1268,"r":6,"Cm":-0.00188433034308387},
             {"Re":1125000,"src":"retestc_4.txt","diter":8,"Foil_fn":"optbs_spline_sym_fx77080.dat-s17_n17s0_nsopt-Re1125000-N12.dat","Top_Xtr":0.939963869901148,"clcd":305.04850760849,"CDpres":0.00097,"alpha":0,"sym":0.000590762982766643,"xy":[1,0,0.969087652468728,0.00285638733072224,0.801860568053254,0.0145898963312592,0.696504319290661,0.0207947107408058,0.549776607886737,0.0279091817459055,0.338361913064034,0.0341015880917458,0.144153484994011,0.0323010291950892,0.0380479581477159,0.0203364653364848,0,0,0.039910401665453,-0.0202276732096045,0.148421317779882,-0.0313413194774,0.328374676921391,-0.0330071106501027,0.517844762768298,-0.0281501386204944,0.689480272273693,-0.020517792069959,0.832528496272264,-0.0120999395159104,0.973498898866872,-0.0023967729213869,1,0],"Bot_Xtr":0.944150750428573,"CDf":0.00231,"Cpmin":-0.317916083898721,"n":12,"CD":0.00327816716049447,"CL":0.00982066122319799,"CDp":0.00028986441497796,"Cm":-0.00174026031336449,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx77080.dat-s17_n17s0.dat (opt161.886914219713>130.921222994948) l1 Foil spline 17pts Re1125000 N12","iver":1.2020052,"good":161.886914260158,"id":1269,"r":6},
             {"Cm":0.00025519629884832,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0013.dat-s17_n17s0.dat (opt158.312279974596>85.3248511439717) l1 Foil spline 17pts Re750000 N12","iver":1.2020052,"xver":6.991,"good":148.281922493091,"id":1270,"Cpmin":-0.313157520267819,"CDf":0.00247,"CDp":0.000413559632651469,"n":13,"CD":0.00354013037283815,"CL":-0.0019977537038793,"alpha":0,"clcd":282.475472562411,"CDpres":0.00107,"Bot_Xtr":0.8979630685443,"xy":[1,0,0.926624813612928,0.00801278603902204,0.836471491410797,0.0160451291686269,0.682547580933488,0.027852618051475,0.495106406050575,0.0386965202306413,0.309374998263626,0.0436348202350051,0.147490753592901,0.0387265566163452,0.036405348669114,0.0226601190547848,0,0,0.0352814504913503,-0.022398648836978,0.147765612228726,-0.0391922419969763,0.320350088906264,-0.0439826696017745,0.511571300638545,-0.0382529478676205,0.698983317593558,-0.026952190995202,0.860095066512714,-0.0141782152923983,0.932751973790206,-0.00746028484043246,1,0],"sym":0.000242568625782047,"src":"retest_68.txt","Re":1125000,"Foil_fn":"optbs_spline_sym_naca0013.dat-s17_n17s0_nsopt-Re750000-N12.dat","Top_Xtr":0.903333449051448,"diter":4},
             {"CDf":0.00236,"Cpmin":-0.313068738084189,"CD":0.00354754096879279,"CL":-0.00194586108284505,"n":14,"CDp":0.000515741469384499,"Cm":0.000244769098573244,"id":1271,"good":144.193493592439,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0013.dat-s17_n17s0.dat (opt158.312279974596>85.3248511439717) l1 Foil spline 17pts Re750000 N12","xver":6.991,"iver":1.2020052,"r":6,"Re":1125000,"src":"retest_69.txt","diter":4,"Top_Xtr":0.919014910015359,"Foil_fn":"optbs_spline_sym_naca0013.dat-s17_n17s0_nsopt-Re750000-N12.dat","clcd":281.885398589293,"CDpres":0.00119,"alpha":0,"sym":0.000242568625782047,"xy":[1,0,0.926624813612928,0.00801278603902204,0.836471491410797,0.0160451291686269,0.682547580933488,0.027852618051475,0.495106406050575,0.0386965202306413,0.309374998263626,0.0436348202350051,0.147490753592901,0.0387265566163452,0.036405348669114,0.0226601190547848,0,0,0.0352814504913503,-0.022398648836978,0.147765612228726,-0.0391922419969763,0.320350088906264,-0.0439826696017745,0.511571300638545,-0.0382529478676205,0.698983317593558,-0.026952190995202,0.860095066512714,-0.0141782152923983,0.932751973790206,-0.00746028484043246,1,0],"Bot_Xtr":0.914534247641876},
             {"CDpres":0.00104,"clcd":227.055150756971,"alpha":-0.2,"sym":0.000806419477493791,"xy":[1,0,0.913162369486509,0.0241507056221996,0.813710842258612,0.0432310402433597,0.673782501507511,0.0591530187088302,0.492724758079874,0.0649499550462178,0.299655576439083,0.0585730550963397,0.141435325331645,0.043570934689898,0.0380604371432103,0.0237583551236848,0,0,0.0380279452424157,-0.0242009839410453,0.14605649423593,-0.0452062928926475,0.312666093446018,-0.0606335744302686,0.510591162367989,-0.0663569379063075,0.699485607975073,-0.0584496178436424,0.843999845282038,-0.0390429746236317,0.923962179670343,-0.0219202838601516,1,0],"Bot_Xtr":0.807166883540984,"Re":1400000,"src":"retest_152.txt","diter":3,"Top_Xtr":0.818404344628749,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1400000-N3.dat","Cm":-0.00122993695349536,"id":1272,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt113.026894678467>81.3010436776499) l1 Foil spline 17pts Re1400000 N3","xver":6.991,"iver":1.2020052,"good":113.02660859904,"r":6,"CDf":0.00336,"Cpmin":-0.328235511368394,"CL":-0.0169130178378992,"CD":0.00440421631778067,"n":3,"CDp":-0.000815618284156734},
             {"id":1273,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt134.938032667707>102.876578376775) l1 Foil spline 17pts Re3000000 N6","good":115.463014234595,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000228597866703674,"CL":-0.0228025861601146,"CD":0.00431202202073077,"n":4,"CDp":-0.000718752325595802,"CDf":0.00321,"Cpmin":-0.330450473243931,"sym":0.00018083601519809,"Bot_Xtr":0.825846494845109,"xy":[1,0,0.913162369486509,0.0243969243238081,0.813710842258612,0.0436717847402045,0.673782501507511,0.0597560892646372,0.492724758079874,0.0656121259099258,0.299655576439083,0.059170212868898,0.141435325331645,0.0440151444424012,0.0380604371432103,0.024000573775281,0,0,0.0380279452424157,-0.0241596614287933,0.14605649423593,-0.0451291043950031,0.312666093446018,-0.0605300442751154,0.510591162367989,-0.0662436352659554,0.699485607975073,-0.0583498167340944,0.843999845282038,-0.0389763098218547,0.923962179670343,-0.0218828555803517,1,0],"clcd":231.909761868639,"CDpres":0.00111,"alpha":-0.2,"diter":3,"Top_Xtr":0.836558323313512,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re3000000-N6.dat","Re":1400000,"src":"retest_91.txt"},
             {"xy":[1,0,0.913162369486509,0.021694982993299,0.813710842258612,0.0388351668698321,0.673782501507511,0.0531381465604353,0.492724758079874,0.0583456314770356,0.299655576439083,0.0526171555423447,0.141435325331645,0.0391404997388803,0.0380604371432103,0.0213425279749716,0,0,0.0380279452424157,-0.0214505663182961,0.14605649423593,-0.0400686429138702,0.312666093446018,-0.053742629332766,0.510591162367989,-0.0588155382733924,0.699485607975073,-0.0518068772281479,0.843999845282038,-0.0346057796025127,0.923962179670343,-0.0194290655207859,1,0],"Bot_Xtr":0.859901687419936,"sym":0.000105276207160423,"alpha":0.2,"clcd":251.491959145268,"CDpres":0.00099,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N5.dat","Top_Xtr":0.851919264069286,"diter":4,"src":"retest_81.txt","Re":1400000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt137.984778561906>109.238664609646) l1 Foil spline 17pts Re2000000 N5","iver":1.2020052,"xver":6.991,"good":129.712993901489,"id":1274,"Cm":0.00151206137160369,"CDp":-0.000384677273140813,"n":5,"CL":0.0152801929885418,"CD":0.00397627026883343,"Cpmin":-0.285649325522664,"CDf":0.00298},
             {"clcd":261.867859274897,"CDpres":0.00094,"alpha":0,"sym":7.71225216088215e-06,"xy":[1,0,0.880300325419672,0.0259144365850049,0.704663862945517,0.0468054940459072,0.494561349047687,0.0536877522509638,0.292149054823316,0.0475332880281319,0.151132354125174,0.0353286627258144,0.0758230374101564,0.0244933891302788,0.0249798475564602,0.0136092602148263,0,0,0.0247348166511182,-0.0134754346597937,0.0790299712088116,-0.0251197157728647,0.168051338348483,-0.0373118296925813,0.314517318069903,-0.0488239785739432,0.507756670437578,-0.0536978847237807,0.707646981873831,-0.0466238252848986,0.880289902407772,-0.0259674858196769,1,0],"Bot_Xtr":0.876524864970079,"Re":1400000,"src":"retest_148.txt","diter":5,"Top_Xtr":0.875470730934041,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re2000000-N8.dat","Cm":-0.000333841397216039,"id":1275,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt174.372754097114>163.426969909152) l1 Foil spline 17pts Re2000000 N8","iver":1.2020052,"good":146.26462240136,"r":6,"CDf":0.00288,"Cpmin":-0.262896408516249,"CL":0.00139384441232614,"CD":0.00381871987944212,"n":6,"CDp":-0.000407434935117283},
             {"Re":1400000,"src":"retest_94.txt","diter":7,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re3000000-N6.dat","Top_Xtr":0.855691740339575,"CDpres":0.00133,"clcd":235.096901162969,"alpha":0.5,"sym":0.00018083601519809,"xy":[1,0,0.913162369486509,0.0243969243238081,0.813710842258612,0.0436717847402045,0.673782501507511,0.0597560892646372,0.492724758079874,0.0656121259099258,0.299655576439083,0.059170212868898,0.141435325331645,0.0440151444424012,0.0380604371432103,0.024000573775281,0,0,0.0380279452424157,-0.0241596614287933,0.14605649423593,-0.0451291043950031,0.312666093446018,-0.0605300442751154,0.510591162367989,-0.0662436352659554,0.699485607975073,-0.0583498167340944,0.843999845282038,-0.0389763098218547,0.923962179670343,-0.0218828555803517,1,0],"Bot_Xtr":0.87246665174832,"CDf":0.00293,"Cpmin":-0.332498399457218,"n":7,"CL":0.0412200830347465,"CD":0.00425356521099697,"CDp":-0.000414997360886315,"Cm":0.0030758071981882,"good":143.269554882907,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt134.938032667707>102.876578376775) l1 Foil spline 17pts Re3000000 N6","xver":6.991,"iver":1.2020052,"id":1276,"r":6},
             {"CDf":0.0028,"Cpmin":-0.273146927993641,"CD":0.00396898599690651,"CL":-0.000763329372326602,"n":8,"CDp":-0.000216974775634359,"Cm":0.000274888155243751,"id":1277,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16012.dat-s17_n17s0.dat (opt149.199960276367>133.46141857931) l1 Foil spline 17pts Re1400000 N8","good":149.199960277325,"xver":6.991,"iver":1.2020052,"r":6,"Re":1400000,"src":"retestc_10.txt","diter":3,"Top_Xtr":0.874603665550316,"Foil_fn":"optbs_spline_sym_naca16012.dat-s17_n17s0_nsopt-Re1400000-N8.dat","clcd":251.953521826334,"CDpres":0.00117,"alpha":0,"sym":1.35886142825695e-05,"xy":[1,0,0.878175247413484,0.0278833388010722,0.703112195765058,0.0497645925609072,0.497409844593044,0.0568931497446908,0.289984193140673,0.0507636453419267,0.138935011398081,0.0378565966805872,0.0706796263555245,0.0276414547451438,0.0235527616953747,0.0167581775535866,0,0,0.0235522361629963,-0.0167210512708294,0.0745550964375219,-0.0284717278592863,0.145796055405051,-0.0387017039259051,0.285727317223195,-0.0505385950813133,0.483503181806403,-0.0569450596126893,0.69332798864512,-0.0506134504012638,0.87453012738683,-0.0285887367505375,1,0],"Bot_Xtr":0.882784227399501},
             {"src":"retestc_8.txt","Re":1400000,"Top_Xtr":0.867181303775574,"Foil_fn":"optbs_spline_sym_naca16015.dat-s17_n17s0_nsopt-Re1400000-N10.dat","diter":6,"alpha":0.1,"CDpres":0.00148,"clcd":227.828823572287,"Bot_Xtr":0.872144062691188,"xy":[1,0,0.881378085901864,0.0322188863616567,0.708264425131009,0.0582826715062332,0.504578033652195,0.0671575155368838,0.301447118046149,0.0606680349724161,0.153596331087593,0.0466304798417699,0.0793933303985656,0.034523108787143,0.0249716898551199,0.0203393018301225,0,0,0.0240459717505669,-0.0199618868117807,0.0757248169078826,-0.0339407626069971,0.144402105518112,-0.0455472293444729,0.292739854559687,-0.0603510688073083,0.508143642305824,-0.0674796285348309,0.716403649601715,-0.0577031074675845,0.885618983407823,-0.0313724044474632,1,0],"sym":4.23468552895325e-05,"Cpmin":-0.337236606566949,"CDf":0.00291,"CDp":-0.000365593662158018,"CD":0.00438926025390599,"CL":-0.0138929930389623,"n":9,"Cm":0.00589584897228599,"r":6,"id":1278,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16015.dat-s17_n17s0.dat (opt148.477865777851>117.310890410729) l1 Foil spline 17pts Re1400000 N10","iver":1.2020052,"good":146.878533799682},
             {"xy":[1,0,0.942889525368766,0.00353351842913543,0.829506244622028,0.0149422376240256,0.663520326400651,0.026812497326981,0.483883529026766,0.0348474024935721,0.308064634878761,0.0366501717909439,0.141281933878215,0.0307565457345128,0.0337611204221739,0.0169669416473623,0,0,0.0332640042916588,-0.0165312744240226,0.137232488870993,-0.0301500842263932,0.301394215855595,-0.0366322831832772,0.486422871117426,-0.0351627471423055,0.672870651601015,-0.0266185926816817,0.824138239185622,-0.0153646960705655,0.940657070540577,-0.00370143434371862,1,0],"Bot_Xtr":0.875538732616898,"sym":0.000162477019803827,"alpha":0.1,"clcd":302.602154286671,"CDpres":0.00073,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1400000-N10.dat","Top_Xtr":0.873539217509914,"diter":3,"src":"retestc_12.txt","Re":1400000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt157.415252069672>130.995700728254) l1 Foil spline 17pts Re1400000 N10","xver":6.991,"iver":1.2020052,"good":157.415141832797,"id":1279,"Cm":0.000331453033230405,"CDp":0.000143228256983522,"n":10,"CD":0.00330466913679883,"CL":0.0109739459661733,"Cpmin":-0.243620400281384,"CDf":0.00257},
             {"clcd":302.137175059081,"CDpres":0.00082,"alpha":0.2,"sym":0.000162477019803827,"xy":[1,0,0.942889525368766,0.00353351842913543,0.829506244622028,0.0149422376240256,0.663520326400651,0.026812497326981,0.483883529026766,0.0348474024935721,0.308064634878761,0.0366501717909439,0.141281933878215,0.0307565457345128,0.0337611204221739,0.0169669416473623,0,0,0.0332640042916588,-0.0165312744240226,0.137232488870993,-0.0301500842263932,0.301394215855595,-0.0366322831832772,0.486422871117426,-0.0351627471423055,0.672870651601015,-0.0266185926816817,0.824138239185622,-0.0153646960705655,0.940657070540577,-0.00370143434371862,1,0],"Bot_Xtr":0.891404050687496,"Re":1400000,"src":"retest_148.txt","diter":3,"Foil_fn":"optbs_spline_sym_mh50.dat-s17_n17s0_nsopt-Re1400000-N10.dat","Top_Xtr":0.884029850701418,"Cm":0.000494721345729699,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_mh50.dat-s17_n17s0.dat (opt157.415252069672>130.995700728254) l1 Foil spline 17pts Re1400000 N10","iver":1.2020052,"good":165.059008112067,"id":1280,"r":6,"CDf":0.00249,"Cpmin":-0.25338916627395,"n":11,"CD":0.00330975491448365,"CL":0.0216878827137022,"CDp":0.000229114345804071},
             {"CDpres":0.00091,"clcd":336.142995163164,"alpha":0.1,"sym":7.99206904647645e-05,"xy":[1,0,0.927533762368065,0.00571426574647672,0.828124577508512,0.0120911459707025,0.673910782200253,0.0205402804323184,0.485356610471494,0.0282788603503293,0.298817780508802,0.0315394258462509,0.140740099512849,0.0275959257025299,0.0345490619416974,0.0159903920276543,0,0,0.033827731492854,-0.0157396627062901,0.142528433402255,-0.0277400994206087,0.31046792119717,-0.0315129297453811,0.499715124890922,-0.0277848490036873,0.684159552318164,-0.0200255356059024,0.829477323686799,-0.011995445332267,0.922486667396241,-0.00608246478964112,1,0],"Bot_Xtr":0.965622302413837,"Re":1400000,"src":"retest_87.txt","diter":4,"Top_Xtr":0.955872152487252,"Foil_fn":"optbs_spline_sym_naca0007.dat-s17_n17s0_nsopt-Re620000-N7.dat","Cm":-0.000418311549250631,"id":1281,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0007.dat-s17_n17s0.dat (opt126.953399704874>110.526786915818) l1 Foil spline 17pts Re620000 N7","iver":1.2020052,"good":167.624553979302,"r":6,"CDf":0.00206,"Cpmin":-0.244873560754067,"CD":0.00297492440535493,"CL":0.013430060468231,"n":12,"CDp":0.000227306067023764},
             {"CDp":0.000233112215834663,"CD":0.00311650082054299,"CL":0.00278452542746019,"n":13,"Cpmin":-0.286166055472286,"CDf":0.00228,"r":6,"id":1282,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt133.488879979998>92.9033842456197) l1 Foil spline 17pts Re620000 N10","iver":1.2020052,"xver":6.991,"good":158.221132653214,"Cm":-0.00104361545395988,"Top_Xtr":0.91015650755732,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re620000-N10.dat","diter":12,"src":"retest_98.txt","Re":1400000,"xy":[1,0,0.92665990621884,0.00730956658978416,0.825921357659381,0.0154787504870214,0.672783569504887,0.0260632604206964,0.495512951249265,0.0353441468487106,0.312090510037109,0.039887432547168,0.146453297160589,0.0353826685404445,0.0354870723445344,0.020431365442722,0,0,0.0345118418622416,-0.0204277908465362,0.143520041847869,-0.0357897689138426,0.311152398930403,-0.040545204979185,0.501481865544773,-0.0356664252205722,0.711715512073078,-0.0240092063852963,0.925495042077482,-0.00769445485172796,0.979243859290989,-0.001605636003771,1,0],"Bot_Xtr":0.896937314185817,"sym":0.000313188974654683,"alpha":0,"CDpres":0.00083,"clcd":320.872689462591},
             {"Re":1400000,"src":"retest_77.txt","diter":4,"Top_Xtr":0.892271333679547,"Foil_fn":"optbs_spline_sym_naca0013.dat-s17_n17s0_nsopt-Re750000-N12.dat","CDpres":0.00089,"clcd":308.62191634292,"alpha":0,"sym":0.000242568625782047,"xy":[1,0,0.926624813612928,0.00801278603902204,0.836471491410797,0.0160451291686269,0.682547580933488,0.027852618051475,0.495106406050575,0.0386965202306413,0.309374998263626,0.0436348202350051,0.147490753592901,0.0387265566163452,0.036405348669114,0.0226601190547848,0,0,0.0352814504913503,-0.022398648836978,0.147765612228726,-0.0391922419969763,0.320350088906264,-0.0439826696017745,0.511571300638545,-0.0382529478676205,0.698983317593558,-0.026952190995202,0.860095066512714,-0.0141782152923983,0.932751973790206,-0.00746028484043246,1,0],"Bot_Xtr":0.885926374380953,"CDf":0.00235,"Cpmin":-0.313068040170318,"CD":0.00324021058468469,"CL":-0.00163118968888596,"n":14,"CDp":0.00028502675348652,"Cm":0.000181816333452015,"id":1283,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0013.dat-s17_n17s0.dat (opt158.312279974596>85.3248511439717) l1 Foil spline 17pts Re750000 N12","iver":1.2020052,"xver":6.991,"good":156.752991210098,"r":6},
             {"alpha":0.1,"CDpres":0.00074,"clcd":252.85674592477,"Bot_Xtr":0.812498626165971,"xy":[1,0,0.913162369486509,0.0216637968310114,0.813710842258612,0.0387793419900963,0.673782501507511,0.0530617613951272,0.492724758079874,0.0582617606423556,0.299655576439083,0.0525415192926015,0.141435325331645,0.0390842359484338,0.0380604371432103,0.0213118484606682,0,0,0.0380279452424157,-0.021246681223679,0.14605649423593,-0.039687795204283,0.312666093446018,-0.0532318120003055,0.510591162367989,-0.0582565035417269,0.699485607975073,-0.0513144589903849,0.843999845282038,-0.0342768557622812,0.923962179670343,-0.0192443945520457,1,0],"sym":1.53176467799983e-05,"src":"retestc_15.txt","Re":1700000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1700000-N3.dat","Top_Xtr":0.795913085746608,"diter":3,"Cm":0.0020106867079795,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt95.5201398701152>68.7150705611193) l1 Foil spline 17pts Re1700000 N3","good":95.5201418516271,"iver":1.2020052,"id":1284,"Cpmin":-0.281314823605811,"CDf":0.00321,"CDp":-0.000632079825047118,"n":3,"CD":0.00395480846810202,"CL":0.00249983036811617},
             {"Top_Xtr":0.821139014476868,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1700000-N4.dat","diter":3,"src":"retestc_16.txt","Re":1700000,"xy":[1,0,0.913162369486509,0.0249389811043402,0.813710842258612,0.0446420950433465,0.673782501507511,0.0610837645459172,0.492724758079874,0.0670699120333961,0.299655576439083,0.0604848710063508,0.141435325331645,0.0449930835946665,0.0380604371432103,0.0245338243432166,0,0,0.0380279452424157,-0.0241596614287933,0.14605649423593,-0.0451291043950031,0.312666093446018,-0.0605300442751154,0.510591162367989,-0.0662436352659554,0.699485607975073,-0.0583498167340944,0.843999845282038,-0.0389763098218547,0.923962179670343,-0.0218828555803517,1,0],"Bot_Xtr":0.817485546044768,"sym":0.000281459362978508,"alpha":-0.1,"CDpres":0.00098,"clcd":245.323607721508,"CDp":-0.000841501175094418,"CL":-0.00772181143290517,"CD":0.00407624854895826,"n":4,"Cpmin":-0.326283100621908,"CDf":0.0031,"r":6,"id":1285,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt114.913017624354>94.6023665654467) l1 Foil spline 17pts Re1700000 N4","good":114.913017624132,"xver":6.991,"iver":1.2020052,"Cm":-0.000686821054702239},
             {"Cm":0.00152444241337865,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt131.217388497058>123.872562912545) l1 Foil spline 17pts Re1700000 N5","iver":1.2020052,"xver":6.991,"good":131.217388495602,"id":1286,"Cpmin":-0.282899971564226,"CDf":0.00287,"CDp":-0.000478850397161165,"n":5,"CL":0.0153651913256201,"CD":0.00368174306651215,"alpha":0.2,"CDpres":0.00081,"clcd":271.610479583882,"Bot_Xtr":0.851483773847235,"xy":[1,0,0.913162369486509,0.021486655901575,0.813710842258612,0.0384622503585305,0.673782501507511,0.052627885015821,0.492724758079874,0.05778536481427,0.299655576439083,0.0521118968384171,0.141435325331645,0.0387646512543831,0.0380604371432103,0.0211375853490918,0,0,0.0380279452424157,-0.0211768000224679,0.14605649423593,-0.0395572604269642,0.312666093446018,-0.053056730399275,0.510591162367989,-0.0580648955252561,0.699485607975073,-0.0511456836416142,0.843999845282038,-0.034164117785503,0.923962179670343,-0.0191810989533722,1,0],"sym":4.76750069861328e-05,"src":"retestc_17.txt","Re":1700000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1700000-N5.dat","Top_Xtr":0.83801868549159,"diter":3},
             {"xy":[1,0,0.913162369486509,0.0206442934134991,0.813710842258612,0.0369543769575962,0.673782501507511,0.0505646623176415,0.492724758079874,0.0555199483668573,0.299655576439083,0.0500689029318619,0.141435325331645,0.0372449225339336,0.0380604371432103,0.0203089078169462,0,0,0.0380279452424157,-0.0206409288331337,0.14605649423593,-0.0385562784009117,0.312666093446018,-0.0517141492165147,0.510591162367989,-0.0565955845533117,0.699485607975073,-0.0498514607990099,0.843999845282038,-0.0332996072640434,0.923962179670343,-0.0186957282506232,1,0],"Bot_Xtr":0.863926640974581,"sym":0.000474863040166281,"alpha":0.1,"CDpres":0.00085,"clcd":280.401629885593,"Top_Xtr":0.861737247760144,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N10.dat","diter":3,"src":"retest_95.txt","Re":1700000,"r":6,"id":1287,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt145.329143420532>113.137456361935) l1 Foil spline 17pts Re7000000 N10","good":145.400308433612,"iver":1.2020052,"Cm":0.001293214692589,"CDp":-0.000346694723697509,"CL":0.00518174373194608,"CD":0.00356631307887908,"n":6,"Cpmin":-0.270269669816908,"CDf":0.00272},
             {"Cm":4.49305279542418e-05,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt144.946537841301>134.705052565041) l1 Foil spline 17pts Re1400000 N6","xver":6.991,"good":164.202235852533,"iver":1.2020052,"id":1288,"r":6,"CDf":0.00266,"Cpmin":-0.288603384231068,"n":7,"CL":0.021709692090106,"CD":0.00363003759470541,"CDp":-0.000301775542796817,"CDpres":0.00097,"clcd":275.479240616833,"alpha":0.2,"sym":6.74674694220246e-05,"xy":[1,0,0.913162369486509,0.0217865821418588,0.813710842258612,0.0389991341898596,0.673782501507511,0.0533625029926337,0.492724758079874,0.0585919746139319,0.299655576439083,0.052839312280094,0.141435325331645,0.0393057562155226,0.0380604371432103,0.0214326390108376,0,0,0.0380279452424157,-0.0212329908789359,0.14605649423593,-0.0396622222880839,0.312666093446018,-0.0531975119677538,0.510591162367989,-0.0582189658383735,0.699485607975073,-0.051281394408369,0.843999845282038,-0.0342547693965492,0.923962179670343,-0.0192319943850259,1,0],"Bot_Xtr":0.874524332919101,"Re":1700000,"src":"retestc_3.txt","diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1400000-N6.dat","Top_Xtr":0.864944347422924},
             {"Re":1700000,"src":"retest_97.txt","diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N10.dat","Top_Xtr":0.883669647777266,"CDpres":0.00103,"clcd":278.577147836293,"alpha":0.1,"sym":0.000474863040166281,"xy":[1,0,0.913162369486509,0.0206442934134991,0.813710842258612,0.0369543769575962,0.673782501507511,0.0505646623176415,0.492724758079874,0.0555199483668573,0.299655576439083,0.0500689029318619,0.141435325331645,0.0372449225339336,0.0380604371432103,0.0203089078169462,0,0,0.0380279452424157,-0.0206409288331337,0.14605649423593,-0.0385562784009117,0.312666093446018,-0.0517141492165147,0.510591162367989,-0.0565955845533117,0.699485607975073,-0.0498514607990099,0.843999845282038,-0.0332996072640434,0.923962179670343,-0.0186957282506232,1,0],"Bot_Xtr":0.884802224772243,"CDf":0.00256,"Cpmin":-0.269502775242533,"n":8,"CL":0.00651338507926729,"CD":0.0035896698913281,"CDp":-0.000132583397096592,"Cm":0.000974387158127319,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt145.329143420532>113.137456361935) l1 Foil spline 17pts Re7000000 N10","good":168.75624451359,"iver":1.2020052,"id":1289,"r":6},
             {"alpha":0,"clcd":286.120656345813,"CDpres":0.00093,"Bot_Xtr":0.886820904972776,"xy":[1,0,0.878175247413484,0.0257788463514625,0.703112195765058,0.0460086144820443,0.497409844593044,0.0525991444633859,0.289984193140673,0.0469322638456532,0.138935011398081,0.0349993735033128,0.0706796263555245,0.0255552184725656,0.0235527616953747,0.0154933556331433,0,0,0.0235522361629963,-0.0155718824568851,0.0745550964375219,-0.0265149835610326,0.145796055405051,-0.0360418956113558,0.285727317223195,-0.0470652861112412,0.483503181806403,-0.0530314607871617,0.69332798864512,-0.0471349969341232,0.87453012738683,-0.0266239509143086,1,0],"sym":9.54618006160785e-05,"src":"retestc_21.txt","Re":1700000,"Foil_fn":"optbs_spline_sym_naca16012.dat-s17_n17s0_nsopt-Re1700000-N9.dat","Top_Xtr":0.881225035325192,"diter":7,"Cm":0.00188480442593933,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16012.dat-s17_n17s0.dat (opt168.420212348118>157.76955504337) l1 Foil spline 17pts Re1700000 N9","good":168.420212348054,"iver":1.2020052,"id":1290,"Cpmin":-0.256216175167727,"CDf":0.00256,"CDp":-0.000246240712649467,"n":9,"CD":0.00349502902996061,"CL":-0.0078321880345877},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt114.399566445024>82.2983595147123) l1 Foil spline 17pts Re2000000 N4","good":172.558216197238,"xver":6.991,"iver":1.2020052,"id":1291,"Cm":0.000334555404317794,"CDp":-1.20690770670423e-05,"n":10,"CL":0.064796052017809,"CD":0.0038078823283631,"Cpmin":-0.309462431528661,"CDf":0.00254,"xy":[1,0,0.913162369486509,0.0221592412196006,0.813710842258612,0.0396662136466229,0.673782501507511,0.0542752676026005,0.492724758079874,0.0595941892376173,0.299655576439083,0.0537431277227639,0.141435325331645,0.0399780804362674,0.0380604371432103,0.0217992438979807,0,0,0.0380279452424157,-0.0216352367744736,0.14605649423593,-0.0404135985880244,0.312666093446018,-0.0542053059692609,0.510591162367989,-0.0593218881814603,0.699485607975073,-0.0522528887463937,0.843999845282038,-0.0349037048419095,0.923962179670343,-0.0195963326381005,1,0],"Bot_Xtr":0.901204088704138,"sym":4.31892247721825e-05,"alpha":0.6,"clcd":262.613157069345,"CDpres":0.00126,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N4.dat","Top_Xtr":0.872048310895363,"diter":4,"src":"retest_156.txt","Re":1700000},
             {"Foil_fn":"optbs_spline_sym_naca16018.dat-s17_n17s0_nsopt-Re1400000-N6.dat","Top_Xtr":0.900345922541533,"diter":3,"src":"retest_92.txt","Re":1700000,"xy":[1,0,0.877123666606771,0.0279466859189968,0.695859714622481,0.0501600812999143,0.479877195824706,0.0566476338770516,0.274497141549504,0.0495862048716706,0.139205816317275,0.0376827742634217,0.0744501035942717,0.0283028612462258,0.0236602829230092,0.0167022262494452,0,0,0.0229978627553462,-0.0162307670352894,0.0717939569787735,-0.0275056630007054,0.143757146164907,-0.0378278812135084,0.285791864816473,-0.0497103035314257,0.487026177050199,-0.0560202740584946,0.696741109676034,-0.0495217350525482,0.876148870780171,-0.0278215852368776,1,0],"Bot_Xtr":0.882608844201096,"sym":0.000166956659752325,"alpha":-0.3,"CDpres":0.00119,"clcd":269.73411195696,"CDp":-5.46810940015768e-05,"n":11,"CD":0.00370735459725451,"CL":-0.017326122989334,"Cpmin":-0.274272866668547,"CDf":0.00251,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16018.dat-s17_n17s0.dat (opt130.996351470315>106.175250220652) l1 Foil spline 17pts Re1400000 N6","xver":6.991,"iver":1.2020052,"good":174.235920531737,"id":1292,"Cm":-0.00379352164512208},
             {"xy":[1,0,0.913162369486509,0.021486655901575,0.813710842258612,0.0384622503585305,0.673782501507511,0.052627885015821,0.492724758079874,0.05778536481427,0.299655576439083,0.0521118968384171,0.141435325331645,0.0387646512543831,0.0380604371432103,0.0211375853490918,0,0,0.0380279452424157,-0.0211768000224679,0.14605649423593,-0.0395572604269642,0.312666093446018,-0.053056730399275,0.510591162367989,-0.0580648955252561,0.699485607975073,-0.0511456836416142,0.843999845282038,-0.034164117785503,0.923962179670343,-0.0191810989533722,1,0],"Bot_Xtr":0.914080020974637,"sym":4.76750069861328e-05,"alpha":0.7,"clcd":248.386614734184,"CDpres":0.00159,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1700000-N5.dat","Top_Xtr":0.883805043640316,"diter":4,"src":"retest_153.txt","Re":1700000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt131.217388497058>123.872562912545) l1 Foil spline 17pts Re1700000 N5","iver":1.2020052,"xver":6.991,"good":164.864565644851,"id":1293,"Cm":0.00114993170255053,"CDp":0.000358554988182929,"n":12,"CL":0.0730220945314526,"CD":0.0040259818391187,"Cpmin":-0.303473315042611,"CDf":0.00244},
             {"Cm":-0.00125435981921202,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0011.dat-s17_n17s0.dat (opt133.488879979998>92.9033842456197) l1 Foil spline 17pts Re620000 N10","iver":1.2020052,"xver":6.991,"good":155.880340477506,"id":1294,"r":6,"CDf":0.00234,"Cpmin":-0.285729040953952,"n":13,"CD":0.00300000160648335,"CL":0.00379747238972968,"CDp":0.000100285735781776,"CDpres":0.00066,"clcd":333.333154835279,"alpha":0,"sym":0.000313188974654683,"xy":[1,0,0.92665990621884,0.00730956658978416,0.825921357659381,0.0154787504870214,0.672783569504887,0.0260632604206964,0.495512951249265,0.0353441468487106,0.312090510037109,0.039887432547168,0.146453297160589,0.0353826685404445,0.0354870723445344,0.020431365442722,0,0,0.0345118418622416,-0.0204277908465362,0.143520041847869,-0.0357897689138426,0.311152398930403,-0.040545204979185,0.501481865544773,-0.0356664252205722,0.711715512073078,-0.0240092063852963,0.925495042077482,-0.00769445485172796,0.979243859290989,-0.001605636003771,1,0],"Bot_Xtr":0.867155349469684,"Re":1700000,"src":"retest_109.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca0011.dat-s17_n17s0_nsopt-Re620000-N10.dat","Top_Xtr":0.880315895662153},
             {"Cpmin":-0.313107057381691,"CDf":0.00242,"CDp":0.000150415052392915,"n":14,"CL":-0.00154924374512219,"CD":0.00313297503506396,"Cm":0.000177167212555884,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca0013.dat-s17_n17s0.dat (opt158.312279974596>85.3248511439717) l1 Foil spline 17pts Re750000 N12","xver":6.991,"good":153.87764230428,"iver":1.2020052,"id":1295,"src":"retest_85.txt","Re":1700000,"Foil_fn":"optbs_spline_sym_naca0013.dat-s17_n17s0_nsopt-Re750000-N12.dat","Top_Xtr":0.863102263241532,"diter":3,"alpha":0,"clcd":319.185435187991,"CDpres":0.00072,"Bot_Xtr":0.85715018285884,"xy":[1,0,0.926624813612928,0.00801278603902204,0.836471491410797,0.0160451291686269,0.682547580933488,0.027852618051475,0.495106406050575,0.0386965202306413,0.309374998263626,0.0436348202350051,0.147490753592901,0.0387265566163452,0.036405348669114,0.0226601190547848,0,0,0.0352814504913503,-0.022398648836978,0.147765612228726,-0.0391922419969763,0.320350088906264,-0.0439826696017745,0.511571300638545,-0.0382529478676205,0.698983317593558,-0.026952190995202,0.860095066512714,-0.0141782152923983,0.932751973790206,-0.00746028484043246,1,0],"sym":0.000242568625782047},
             {"alpha":0,"clcd":239.919027212171,"CDpres":0.00097,"Bot_Xtr":0.789512521019537,"xy":[1,0,0.913162369486509,0.0259000053782785,0.813710842258612,0.0463623793162532,0.673782501507511,0.0634376289731187,0.492724758079874,0.0696544528069476,0.299655576439083,0.0628156570557059,0.141435325331645,0.0467268932203645,0.0380604371432103,0.025479235891015,0,0,0.0380279452424157,-0.0254723727742349,0.14605649423593,-0.047581187075199,0.312666093446018,-0.0638189345641709,0.510591162367989,-0.0698429726090392,0.699485607975073,-0.0615202447078904,0.843999845282038,-0.0410940813915183,0.923962179670343,-0.0230718570436236,1,0],"sym":3.74433007236193e-05,"src":"retest_72.txt","Re":2000000,"Top_Xtr":0.782071615130127,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re6000000-N8.dat","diter":3,"Cm":0.00146311909093725,"r":6,"id":1296,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.808549300944>55.2313282245345) l1 Foil spline 17pts Re6000000 N8","xver":6.991,"good":93.0029153745203,"iver":1.2020052,"Cpmin":-0.34356914980688,"CDf":0.0032,"CDp":-0.00112217981510546,"CD":0.00416807291868376,"CL":-0.00617906001607854,"n":3},
             {"xy":[1,0,0.913162369486509,0.0221592412196006,0.813710842258612,0.0396662136466229,0.673782501507511,0.0542752676026005,0.492724758079874,0.0595941892376173,0.299655576439083,0.0537431277227639,0.141435325331645,0.0399780804362674,0.0380604371432103,0.0217992438979807,0,0,0.0380279452424157,-0.0216352367744736,0.14605649423593,-0.0404135985880244,0.312666093446018,-0.0542053059692609,0.510591162367989,-0.0593218881814603,0.699485607975073,-0.0522528887463937,0.843999845282038,-0.0349037048419095,0.923962179670343,-0.0195963326381005,1,0],"Bot_Xtr":0.819569587842749,"sym":4.31892247721825e-05,"alpha":0.1,"clcd":270.655621756238,"CDpres":0.00072,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N4.dat","Top_Xtr":0.806941385544153,"diter":3,"src":"retestc_2.txt","Re":2000000,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt114.399566445024>82.2983595147123) l1 Foil spline 17pts Re2000000 N4","xver":6.991,"good":114.399566445264,"id":1297,"Cm":0.00159238234127878,"CDp":-0.000647241655172921,"n":4,"CD":0.00369473204920398,"CL":0.00431771736103413,"Cpmin":-0.288177810381901,"CDf":0.00298},
             {"Cm":0.00155893262650999,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt137.984778561906>109.238664609646) l1 Foil spline 17pts Re2000000 N5","iver":1.2020052,"xver":6.991,"good":137.984778576111,"id":1298,"Cpmin":-0.282483962168995,"CDf":0.00282,"CDp":-0.000563237839475057,"n":5,"CL":0.00425973923684718,"CD":0.00354278538913482,"alpha":0.1,"CDpres":0.00072,"clcd":282.263781223341,"Bot_Xtr":0.836432358010154,"xy":[1,0,0.913162369486509,0.021694982993299,0.813710842258612,0.0388351668698321,0.673782501507511,0.0531381465604353,0.492724758079874,0.0583456314770356,0.299655576439083,0.0526171555423447,0.141435325331645,0.0391404997388803,0.0380604371432103,0.0213425279749716,0,0,0.0380279452424157,-0.0214505663182961,0.14605649423593,-0.0400686429138702,0.312666093446018,-0.053742629332766,0.510591162367989,-0.0588155382733924,0.699485607975073,-0.0518068772281479,0.843999845282038,-0.0346057796025127,0.923962179670343,-0.0194290655207859,1,0],"sym":0.000105276207160423,"src":"retestc_3.txt","Re":2000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N5.dat","Top_Xtr":0.828596097292695,"diter":3},
             {"Re":2000000,"src":"retestc_4.txt","diter":7,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N6.dat","Top_Xtr":0.849303793715943,"clcd":289.39341960803,"CDpres":0.00075,"alpha":0,"sym":2.71136441808759e-05,"xy":[1,0,0.913162369486509,0.0217095296714573,0.813710842258612,0.0388612061930182,0.673782501507511,0.0531737761581253,0.492724758079874,0.0583847527394631,0.299655576439083,0.0526524358109449,0.141435325331645,0.0391667437904582,0.0380604371432103,0.0213568383289199,0,0,0.0380279452424157,-0.0212271111479268,0.14605649423593,-0.0396512392287681,0.312666093446018,-0.0531827807853922,0.510591162367989,-0.0582028441407424,0.699485607975073,-0.0512671938274612,0.843999845282038,-0.0342452837413735,0.923962179670343,-0.0192266687597103,1,0],"Bot_Xtr":0.845373397209261,"CDf":0.00271,"Cpmin":-0.281700757509097,"n":6,"CD":0.00345550358869408,"CL":0.000599316325909128,"CDp":-0.000492479378898785,"Cm":-0.000152674892383735,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt148.071965039792>132.817955323348) l1 Foil spline 17pts Re2000000 N6","iver":1.2020052,"good":148.071965040751,"id":1299,"r":6},
             {"Re":2000000,"src":"retestc_5.txt","diter":4,"Top_Xtr":0.867288316597575,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","CDpres":0.00071,"clcd":311.038033786182,"alpha":0.1,"sym":7.97215012165649e-05,"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"Bot_Xtr":0.872423349095766,"CDf":0.00251,"Cpmin":-0.254646692061673,"CL":0.0125708428626556,"CD":0.00321504089974872,"n":7,"CDp":-0.000317665517978636,"Cm":-0.000381426842693189,"id":1300,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","iver":1.2020052,"good":164.309094540161,"r":6},
             {"r":6,"id":1301,"good":178.457504046272,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt179.604294799114>164.472076296931) l1 Foil spline 17pts Re2500000 N8","xver":6.991,"iver":1.2020052,"Cm":0.000745305165088247,"CDp":-0.000321776422022481,"CD":0.00335505807066347,"CL":0.0186910389717864,"n":8,"Cpmin":-0.282913020613732,"CDf":0.0025,"xy":[1,0,0.913162369486509,0.021412438997227,0.813710842258612,0.03832939817488,0.673782501507511,0.0524461034148986,0.492724758079874,0.057585768799293,0.299655576439083,0.0519318975085647,0.141435325331645,0.0386307545499629,0.0380604371432103,0.0210645741668405,0,0,0.0380279452424157,-0.0210581698446901,0.14605649423593,-0.0393356648680567,0.312666093446018,-0.0527595122476706,0.510591162367989,-0.0577396221661319,0.699485607975073,-0.0508591709703639,0.843999845282038,-0.0339727340371456,0.923962179670343,-0.019073648480383,1,0],"Bot_Xtr":0.875556729420388,"sym":2.53350805752694e-05,"alpha":0.2,"CDpres":0.00086,"clcd":298.057434160073,"Top_Xtr":0.865485055498292,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N8.dat","diter":4,"src":"retestc_17.txt","Re":2000000},
             {"Re":2000000,"src":"retest_96.txt","diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1700000-N3.dat","Top_Xtr":0.877357661333808,"CDpres":0.00095,"clcd":295.538318951774,"alpha":0.1,"sym":1.53176467799983e-05,"xy":[1,0,0.913162369486509,0.0216637968310114,0.813710842258612,0.0387793419900963,0.673782501507511,0.0530617613951272,0.492724758079874,0.0582617606423556,0.299655576439083,0.0525415192926015,0.141435325331645,0.0390842359484338,0.0380604371432103,0.0213118484606682,0,0,0.0380279452424157,-0.021246681223679,0.14605649423593,-0.039687795204283,0.312666093446018,-0.0532318120003055,0.510591162367989,-0.0582565035417269,0.699485607975073,-0.0513144589903849,0.843999845282038,-0.0342768557622812,0.923962179670343,-0.0192443945520457,1,0],"Bot_Xtr":0.879405925346016,"CDf":0.00243,"Cpmin":-0.283860370388464,"n":9,"CD":0.00338365597918685,"CL":0.0126853345871548,"CDp":-0.000233488537078823,"Cm":-0.000439244347332696,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt95.5201398701152>68.7150705611193) l1 Foil spline 17pts Re1700000 N3","xver":6.991,"good":185.45031856112,"id":1302,"r":6},
             {"diter":3,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re8192000-N10.dat","Top_Xtr":0.888067161908521,"Re":2000000,"src":"retest_98.txt","sym":1.91925477398936e-05,"Bot_Xtr":0.883908534995225,"xy":[1,0,0.913162369486509,0.021539191372516,0.813710842258612,0.0385562916297869,0.673782501507511,0.0527565616575748,0.492724758079874,0.0579266516374928,0.299655576439083,0.0522393118747342,0.141435325331645,0.0388594319042357,0.0380604371432103,0.0211892673328289,0,0,0.0380279452424157,-0.021160240854982,0.14605649423593,-0.0395263286856247,0.312666093446018,-0.0530152427673379,0.510591162367989,-0.058019491765999,0.699485607975073,-0.0511056903498654,0.843999845282038,-0.0341374032040829,0.923962179670343,-0.0191661003213883,1,0],"clcd":293.296594279891,"CDpres":0.00102,"alpha":0,"n":10,"CD":0.00340951794021074,"CL":0.00347948381241847,"CDp":-0.000128937290905669,"CDf":0.00239,"Cpmin":-0.279358131628983,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt124.178877069878>89.1540023126822) l1 Foil spline 17pts Re8192000 N10","xver":6.991,"good":188.73167262618,"id":1303,"r":6,"Cm":-0.000882658831505624},
             {"Top_Xtr":0.875973421361741,"Foil_fn":"optbs_spline_sym_naca16012.dat-s17_n17s0_nsopt-Re2000000-N11.dat","diter":4,"src":"retestc_9.txt","Re":2000000,"xy":[1,0,0.878175247413484,0.0297520383596567,0.703112195765058,0.0530997409380494,0.497409844593044,0.0607060433358376,0.289984193140673,0.054165748738488,0.138935011398081,0.0403936890285022,0.0706796263555245,0.0294939435969773,0.0235527616953747,0.0178812854862658,0,0,0.0235522361629963,-0.0176003030573279,0.0745550964375219,-0.0299688716201363,0.145796055405051,-0.040736775870021,0.285727317223195,-0.0531960924654574,0.483503181806403,-0.0599394314727928,0.69332798864512,-0.053274883941857,0.87453012738683,-0.0300920332511288,1,0],"Bot_Xtr":0.87318756432493,"sym":0.000217366359061227,"alpha":-0.1,"CDpres":0.00098,"clcd":288.371453877246,"CDp":-0.000361481342748234,"CD":0.00346774962138132,"CL":-0.00872820950555667,"n":11,"Cpmin":-0.29042819252469,"CDf":0.00249,"r":6,"id":1304,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16012.dat-s17_n17s0.dat (opt180.144166732833>176.653943079358) l1 Foil spline 17pts Re2000000 N11","iver":1.2020052,"xver":6.991,"good":181.722710321533,"Cm":-0.000473752386076831},
             {"alpha":0,"CDpres":0.00103,"clcd":293.89646150895,"Bot_Xtr":0.889809987721468,"xy":[1,0,0.877123666606771,0.0279466859189968,0.695859714622481,0.0501600812999143,0.479877195824706,0.0566476338770516,0.274497141549504,0.0495862048716706,0.139205816317275,0.0376827742634217,0.0744501035942717,0.0283028612462258,0.0236602829230092,0.0167022262494452,0,0,0.0229978627553462,-0.0162307670352894,0.0717939569787735,-0.0275056630007054,0.143757146164907,-0.0378278812135084,0.285791864816473,-0.0497103035314257,0.487026177050199,-0.0560202740584946,0.696741109676034,-0.0495217350525482,0.876148870780171,-0.0278215852368776,1,0],"sym":0.000166956659752325,"src":"retest_103.txt","Re":2000000,"Foil_fn":"optbs_spline_sym_naca16018.dat-s17_n17s0_nsopt-Re1400000-N6.dat","Top_Xtr":0.888600291330497,"diter":3,"Cm":-0.00142425831079296,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16018.dat-s17_n17s0.dat (opt130.996351470315>106.175250220652) l1 Foil spline 17pts Re1400000 N6","xver":6.991,"good":182.381110348862,"id":1305,"Cpmin":-0.273015916475464,"CDf":0.00237,"CDp":-0.000153026489382795,"n":12,"CD":0.00340255882927515,"CL":0.00610197175620836},
             {"xy":[1,0,0.878175247413484,0.0297520383596567,0.703112195765058,0.0530997409380494,0.497409844593044,0.0607060433358376,0.289984193140673,0.054165748738488,0.138935011398081,0.0403936890285022,0.0706796263555245,0.0294939435969773,0.0235527616953747,0.0178812854862658,0,0,0.0235522361629963,-0.0176003030573279,0.0745550964375219,-0.0299688716201363,0.145796055405051,-0.040736775870021,0.285727317223195,-0.0531960924654574,0.483503181806403,-0.0599394314727928,0.69332798864512,-0.053274883941857,0.87453012738683,-0.0300920332511288,1,0],"Bot_Xtr":0.888562627262199,"sym":0.000217366359061227,"alpha":0,"CDpres":0.00116,"clcd":280.813471385204,"Top_Xtr":0.885602148312126,"Foil_fn":"optbs_spline_sym_naca16012.dat-s17_n17s0_nsopt-Re2000000-N11.dat","diter":3,"src":"retest_68.txt","Re":2000000,"r":6,"id":1306,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16012.dat-s17_n17s0.dat (opt180.144166732833>176.653943079358) l1 Foil spline 17pts Re2000000 N11","xver":6.991,"good":183.330668434574,"Cm":-0.0018155105281405,"CDp":-0.000123394492023873,"CD":0.00356108271824416,"CL":0.00793803022574337,"n":13,"Cpmin":-0.294731629087885,"CDf":0.0024},
             {"xy":[1,0,0.913162369486509,0.0259000053782785,0.813710842258612,0.0463623793162532,0.673782501507511,0.0634376289731187,0.492724758079874,0.0696544528069476,0.299655576439083,0.0628156570557059,0.141435325331645,0.0467268932203645,0.0380604371432103,0.025479235891015,0,0,0.0380279452424157,-0.0254723727742349,0.14605649423593,-0.047581187075199,0.312666093446018,-0.0638189345641709,0.510591162367989,-0.0698429726090392,0.699485607975073,-0.0615202447078904,0.843999845282038,-0.0410940813915183,0.923962179670343,-0.0230718570436236,1,0],"Bot_Xtr":0.900279520635255,"sym":3.74433007236193e-05,"alpha":1,"clcd":247.896263123621,"CDpres":0.00159,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re6000000-N8.dat","Top_Xtr":0.857954788687933,"diter":4,"src":"retest_83.txt","Re":2000000,"r":6,"good":164.325030751027,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.808549300944>55.2313282245345) l1 Foil spline 17pts Re6000000 N8","xver":6.991,"iver":1.2020052,"id":1307,"Cm":0.00692590434184687,"CDp":-6.96338067591961e-05,"n":14,"CD":0.00403394543911022,"CL":0.0809920375006027,"Cpmin":-0.367847227643022,"CDf":0.00244},
             {"Cm":-0.00300025671981657,"r":6,"id":1308,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt74.0902316727326>37.1404622711758) l1 Foil spline 17pts Re3000000 N3","xver":6.991,"iver":1.2020052,"good":81.2749915052862,"Cpmin":-0.479497851869767,"CDf":0.00325,"CDp":-0.00317231638248215,"CD":0.00500338654812115,"CL":-0.0186776628210042,"n":3,"alpha":-0.3,"clcd":199.864629762718,"CDpres":0.00176,"Bot_Xtr":0.749216532061318,"xy":[1,0,0.880300325419672,0.0444274385401519,0.704663862945517,0.0802428485467915,0.494561349047687,0.0920417198986593,0.292149054823316,0.0814905709238195,0.151132354125174,0.0605670891901652,0.0758230374101564,0.0419912096740373,0.0249798475564602,0.0233315731093683,0,0,0.0247348166511182,-0.0234194786785516,0.0790299712088116,-0.0436565248399111,0.168051338348483,-0.0648456708079602,0.314517318069903,-0.0848530792573358,0.507756670437578,-0.0933236291163286,0.707646981873831,-0.0810293478272794,0.880289902407772,-0.0451298971679201,1,0],"sym":0.000725716220303653,"src":"retest_89.txt","Re":2500000,"Top_Xtr":0.763784517816179,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re3000000-N3.dat","diter":4},
             {"src":"retest_91.txt","Re":2500000,"Top_Xtr":0.780869438433296,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N4.dat","diter":4,"alpha":0.1,"CDpres":0.00107,"clcd":247.371087662755,"Bot_Xtr":0.794021901713527,"xy":[1,0,0.913162369486509,0.0285583118429417,0.813710842258612,0.0511208884691867,0.673782501507511,0.0699486955439224,0.492724758079874,0.0768035973528624,0.299655576439083,0.0692628861120092,0.141435325331645,0.0515228150940139,0.0380604371432103,0.0280943557141393,0,0,0.0380279452424157,-0.02760515589807,0.14605649423593,-0.0515651250343934,0.312666093446018,-0.069162447232817,0.510591162367989,-0.0756908735729301,0.699485607975073,-0.0666712897577615,0.843999845282038,-0.0445348587410861,0.923962179670343,-0.0250036467427736,1,0],"sym":0.000502024749331122,"Cpmin":-0.37529151526576,"CDf":0.00297,"CDp":-0.00149585950243058,"CD":0.00404250961358636,"CL":-0.00306392169980066,"n":4,"Cm":0.00336062067168388,"r":6,"id":1309,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt104.366457223021>63.39957801653) l1 Foil spline 17pts Re2500000 N4","xver":6.991,"good":104.366457225912},
             {"Cpmin":-0.317867311825489,"CDf":0.0028,"CDp":-0.000861651266776886,"CD":0.00357560630282165,"CL":0.00196545669065809,"n":5,"Cm":-0.000488678387105162,"r":6,"id":1310,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt122.257295992304>102.620243468481) l1 Foil spline 17pts Re2500000 N5","iver":1.2020052,"xver":6.991,"good":122.257300024303,"src":"retestc_13.txt","Re":2500000,"Top_Xtr":0.809582179631513,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N5.dat","diter":4,"alpha":0,"clcd":279.672848549031,"CDpres":0.00077,"Bot_Xtr":0.806980550352077,"xy":[1,0,0.913162369486509,0.0242151077541339,0.813710842258612,0.0433463234653476,0.673782501507511,0.0593107607050598,0.492724758079874,0.065123155599421,0.299655576439083,0.0587292505169258,0.141435325331645,0.0436871243005991,0.0380604371432103,0.0238217109835571,0,0,0.0380279452424157,-0.0237781506871603,0.14605649423593,-0.0444164603814389,0.312666093446018,-0.0595742004959905,0.510591162367989,-0.0651975668641583,0.699485607975073,-0.0574284014269312,0.843999845282038,-0.0383608259952258,0.923962179670343,-0.0215372984008311,1,0],"sym":2.19226920853482e-05},
             {"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N6.dat","Top_Xtr":0.829583952345575,"diter":3,"src":"retest_85.txt","Re":2500000,"xy":[1,0,0.913162369486509,0.0217095296714573,0.813710842258612,0.0388612061930182,0.673782501507511,0.0531737761581253,0.492724758079874,0.0583847527394631,0.299655576439083,0.0526524358109449,0.141435325331645,0.0391667437904582,0.0380604371432103,0.0213568383289199,0,0,0.0380279452424157,-0.0212271111479268,0.14605649423593,-0.0396512392287681,0.312666093446018,-0.0531827807853922,0.510591162367989,-0.0582028441407424,0.699485607975073,-0.0512671938274612,0.843999845282038,-0.0342452837413735,0.923962179670343,-0.0192266687597103,1,0],"Bot_Xtr":0.82318775800562,"sym":2.71136441808759e-05,"alpha":0,"clcd":303.46097192212,"CDpres":0.00063,"CDp":-0.000594303302017402,"n":6,"CL":0.00401907273221464,"CD":0.00329531667174862,"Cpmin":-0.283626064134924,"CDf":0.00266,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt148.071965039792>132.817955323348) l1 Foil spline 17pts Re2000000 N6","xver":6.991,"good":138.810227292333,"iver":1.2020052,"id":1311,"Cm":-0.000972305959690006},
             {"clcd":329.986730523135,"CDpres":0.00053,"alpha":0,"sym":1.18486023509406e-05,"xy":[1,0,0.913162369486509,0.0190540108668918,0.813710842258612,0.0341076870990815,0.673782501507511,0.0466695374834706,0.492724758079874,0.0512431052166523,0.299655576439083,0.0462119677069321,0.141435325331645,0.0343758512090355,0.0380604371432103,0.0187444608777826,0,0,0.0380279452424157,-0.0186849250495967,0.14605649423593,-0.0349025558847899,0.312666093446018,-0.0468135426426708,0.510591162367989,-0.0512323967620693,0.699485607975073,-0.0451273688394861,0.843999845282038,-0.0301440245707777,0.923962179670343,-0.0169240582114583,1,0],"Bot_Xtr":0.841913493065168,"Re":2500000,"src":"retestc_15.txt","diter":9,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N7.dat","Top_Xtr":0.851104532030087,"Cm":-0.00080308865466706,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt162.65189326284>143.252279398219) l1 Foil spline 17pts Re2500000 N7","xver":6.991,"good":162.651893354721,"id":1312,"r":6,"CDf":0.0025,"Cpmin":-0.247770811670645,"n":7,"CL":0.00321262642804321,"CD":0.00303042488531184,"CDp":-0.000445869542210186},
             {"alpha":0.1,"CDpres":0.00067,"clcd":321.17791394847,"Bot_Xtr":0.853835618255154,"xy":[1,0,0.913162369486509,0.021412438997227,0.813710842258612,0.03832939817488,0.673782501507511,0.0524461034148986,0.492724758079874,0.057585768799293,0.299655576439083,0.0519318975085647,0.141435325331645,0.0386307545499629,0.0380604371432103,0.0210645741668405,0,0,0.0380279452424157,-0.0210581698446901,0.14605649423593,-0.0393356648680567,0.312666093446018,-0.0527595122476706,0.510591162367989,-0.0577396221661319,0.699485607975073,-0.0508591709703639,0.843999845282038,-0.0339727340371456,0.923962179670343,-0.019073648480383,1,0],"sym":2.53350805752694e-05,"src":"retestc_16.txt","Re":2500000,"Top_Xtr":0.8513294376355,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N8.dat","diter":4,"Cm":0.000461590037760058,"r":6,"id":1313,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt179.604294799114>164.472076296931) l1 Foil spline 17pts Re2500000 N8","xver":6.991,"good":179.60429482122,"Cpmin":-0.279746538360845,"CDf":0.00245,"CDp":-0.000478341578930279,"CD":0.00311353912137445,"CL":0.00887171009711169,"n":8},
             {"Re":2500000,"src":"retest_158.txt","diter":3,"Top_Xtr":0.857866355024847,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N10.dat","clcd":329.704076922992,"CDpres":0.00067,"alpha":0.2,"sym":0.000474863040166281,"xy":[1,0,0.913162369486509,0.0206442934134991,0.813710842258612,0.0369543769575962,0.673782501507511,0.0505646623176415,0.492724758079874,0.0555199483668573,0.299655576439083,0.0500689029318619,0.141435325331645,0.0372449225339336,0.0380604371432103,0.0203089078169462,0,0,0.0380279452424157,-0.0206409288331337,0.14605649423593,-0.0385562784009117,0.312666093446018,-0.0517141492165147,0.510591162367989,-0.0565955845533117,0.699485607975073,-0.0498514607990099,0.843999845282038,-0.0332996072640434,0.923962179670343,-0.0186957282506232,1,0],"Bot_Xtr":0.8705446493527,"CDf":0.00236,"Cpmin":-0.270759479612209,"CL":0.0116798738367784,"CD":0.00303302285289474,"n":9,"CDp":-0.000399634012193877,"Cm":0.0023798196939774,"id":1314,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt145.329143420532>113.137456361935) l1 Foil spline 17pts Re7000000 N10","good":191.315470219459,"iver":1.2020052,"r":6},
             {"src":"retest_99.txt","Re":2500000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1125000-N3.dat","Top_Xtr":0.880585387337519,"diter":4,"alpha":0.1,"clcd":348.339292370394,"CDpres":0.00066,"Bot_Xtr":0.885910510325659,"xy":[1,0,0.913162369486509,0.0189880504879407,0.813710842258612,0.0339896145325275,0.673782501507511,0.0465079788279524,0.492724758079874,0.0510657139753889,0.299655576439083,0.0460519930473541,0.141435325331645,0.0342568503231666,0.0380604371432103,0.0186795720860541,0,0,0.0380279452424157,-0.0184238777013787,0.14605649423593,-0.0344149317902018,0.312666093446018,-0.0461595099861242,0.510591162367989,-0.0505166282330496,0.699485607975073,-0.0444968937406384,0.843999845282038,-0.0297228819834816,0.923962179670343,-0.0166876119583713,1,0],"sym":0.000126673094436538,"Cpmin":-0.248151949852682,"CDf":0.00221,"CDp":-0.000259987553259887,"n":10,"CD":0.00287076428615089,"CL":0.0135713009835103,"Cm":-0.000610023321134559,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt100.412996051257>89.2620549029785) l1 Foil spline 17pts Re1125000 N3","iver":1.2020052,"good":202.141196435703,"id":1315},
             {"xy":[1,0,0.913162369486509,0.0206442934134991,0.813710842258612,0.0369543769575962,0.673782501507511,0.0505646623176415,0.492724758079874,0.0555199483668573,0.299655576439083,0.0500689029318619,0.141435325331645,0.0372449225339336,0.0380604371432103,0.0203089078169462,0,0,0.0380279452424157,-0.0206409288331337,0.14605649423593,-0.0385562784009117,0.312666093446018,-0.0517141492165147,0.510591162367989,-0.0565955845533117,0.699485607975073,-0.0498514607990099,0.843999845282038,-0.0332996072640434,0.923962179670343,-0.0186957282506232,1,0],"Bot_Xtr":0.886055764382148,"sym":0.000474863040166281,"alpha":0.2,"CDpres":0.00077,"clcd":332.399451131344,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N10.dat","Top_Xtr":0.875825744724722,"diter":4,"src":"retest_149.txt","Re":2500000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt145.329143420532>113.137456361935) l1 Foil spline 17pts Re7000000 N10","good":207.30251545245,"iver":1.2020052,"id":1316,"Cm":0.00275863390997688,"CDp":-0.000257517272978974,"n":11,"CL":0.0101564687301203,"CD":0.00300842855364662,"Cpmin":-0.270056473511346,"CDf":0.00224},
             {"alpha":0.1,"clcd":341.973917610592,"CDpres":0.00081,"Bot_Xtr":0.898549971675778,"xy":[1,0,0.913162369486509,0.0191154509787391,0.813710842258612,0.034217668148471,0.673782501507511,0.0468200245186085,0.492724758079874,0.0514083398298739,0.299655576439083,0.0463609792974277,0.141435325331645,0.0344866969599844,0.0380604371432103,0.0188049028383175,0,0,0.0380279452424157,-0.0187754769688162,0.14605649423593,-0.0350717025852793,0.312666093446018,-0.0470404130272457,0.510591162367989,-0.051480682042353,0.699485607975073,-0.045346067595135,0.843999845282038,-0.0302901102131144,0.923962179670343,-0.0170060765202265,1,0],"sym":1.4444323836262e-05,"src":"retest_106.txt","Re":2500000,"Top_Xtr":0.8943216803317,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re6000000-N10.dat","diter":4,"Cm":0.000520031781311131,"r":6,"id":1317,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt169.648403891223>134.487525431626) l1 Foil spline 17pts Re6000000 N10","good":213.755393228298,"xver":6.991,"iver":1.2020052,"Cpmin":-0.24786849126918,"CDf":0.00212,"CDp":-0.000103246373582641,"CD":0.00292419962021404,"CL":0.00871919707876923,"n":12},
             {"CDp":-0.000101765529812634,"CD":0.00311097576936899,"CL":0.0136446444505423,"n":13,"Cpmin":-0.282507122068169,"CDf":0.00216,"r":6,"id":1318,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt124.178877069878>89.1540023126822) l1 Foil spline 17pts Re8192000 N10","iver":1.2020052,"xver":6.991,"good":210.276151341143,"Cm":-0.000677356680618262,"Top_Xtr":0.889154464766098,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re8192000-N10.dat","diter":3,"src":"retest_154.txt","Re":2500000,"xy":[1,0,0.913162369486509,0.021539191372516,0.813710842258612,0.0385562916297869,0.673782501507511,0.0527565616575748,0.492724758079874,0.0579266516374928,0.299655576439083,0.0522393118747342,0.141435325331645,0.0388594319042357,0.0380604371432103,0.0211892673328289,0,0,0.0380279452424157,-0.021160240854982,0.14605649423593,-0.0395263286856247,0.312666093446018,-0.0530152427673379,0.510591162367989,-0.058019491765999,0.699485607975073,-0.0511056903498654,0.843999845282038,-0.0341374032040829,0.923962179670343,-0.0191661003213883,1,0],"Bot_Xtr":0.890473574418778,"sym":1.91925477398936e-05,"alpha":0.1,"clcd":321.442555048518,"CDpres":0.00095},
             {"r":6,"id":1319,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt124.178877069878>89.1540023126822) l1 Foil spline 17pts Re8192000 N10","iver":1.2020052,"good":212.059994357467,"Cm":-0.00265074914041886,"CDp":3.44381830905919e-06,"CL":-0.000535392169912742,"CD":0.0031773872841491,"n":14,"Cpmin":-0.279599541616676,"CDf":0.00215,"xy":[1,0,0.913162369486509,0.021539191372516,0.813710842258612,0.0385562916297869,0.673782501507511,0.0527565616575748,0.492724758079874,0.0579266516374928,0.299655576439083,0.0522393118747342,0.141435325331645,0.0388594319042357,0.0380604371432103,0.0211892673328289,0,0,0.0380279452424157,-0.021160240854982,0.14605649423593,-0.0395263286856247,0.312666093446018,-0.0530152427673379,0.510591162367989,-0.058019491765999,0.699485607975073,-0.0511056903498654,0.843999845282038,-0.0341374032040829,0.923962179670343,-0.0191661003213883,1,0],"Bot_Xtr":0.888010044209044,"sym":1.91925477398936e-05,"alpha":-0.1,"CDpres":0.00103,"clcd":314.72398879062,"Top_Xtr":0.900283324370164,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re8192000-N10.dat","diter":4,"src":"retest_155.txt","Re":2500000},
             {"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re3000000-N3.dat","Top_Xtr":0.741304372160263,"diter":4,"src":"retest_96.txt","Re":3000000,"xy":[1,0,0.880300325419672,0.0444274385401519,0.704663862945517,0.0802428485467915,0.494561349047687,0.0920417198986593,0.292149054823316,0.0814905709238195,0.151132354125174,0.0605670891901652,0.0758230374101564,0.0419912096740373,0.0249798475564602,0.0233315731093683,0,0,0.0247348166511182,-0.0234194786785516,0.0790299712088116,-0.0436565248399111,0.168051338348483,-0.0648456708079602,0.314517318069903,-0.0848530792573358,0.507756670437578,-0.0933236291163286,0.707646981873831,-0.0810293478272794,0.880289902407772,-0.0451298971679201,1,0],"Bot_Xtr":0.729813488268048,"sym":0.000725716220303653,"alpha":-0.3,"clcd":199.54857396688,"CDpres":0.00178,"CDp":-0.00322358965650067,"n":3,"CD":0.00501131118163727,"CL":-0.0193427850660274,"Cpmin":-0.479670643179215,"CDf":0.00323,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt74.0902316727326>37.1404622711758) l1 Foil spline 17pts Re3000000 N3","xver":6.991,"good":74.0902316715808,"iver":1.2020052,"id":1320,"Cm":-0.0028276007857558},
             {"Cpmin":-0.374868976142736,"CDf":0.00292,"CDp":-0.00154723484569594,"n":4,"CL":-0.00180051420303931,"CD":0.00394291632575143,"Cm":0.00304696717061887,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt104.366457223021>63.39957801653) l1 Foil spline 17pts Re2500000 N4","iver":1.2020052,"xver":6.991,"good":93.2269479705735,"id":1321,"src":"retestc_21.txt","Re":3000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N4.dat","Top_Xtr":0.766472645716094,"diter":4,"alpha":0.1,"CDpres":0.00103,"clcd":253.619381539734,"Bot_Xtr":0.778085291094746,"xy":[1,0,0.913162369486509,0.0285583118429417,0.813710842258612,0.0511208884691867,0.673782501507511,0.0699486955439224,0.492724758079874,0.0768035973528624,0.299655576439083,0.0692628861120092,0.141435325331645,0.0515228150940139,0.0380604371432103,0.0280943557141393,0,0,0.0380279452424157,-0.02760515589807,0.14605649423593,-0.0515651250343934,0.312666093446018,-0.069162447232817,0.510591162367989,-0.0756908735729301,0.699485607975073,-0.0666712897577615,0.843999845282038,-0.0445348587410861,0.923962179670343,-0.0250036467427736,1,0],"sym":0.000502024749331122},
             {"id":1322,"good":115.992581593744,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt115.992581593673>72.5504590669971) l1 Foil spline 17pts Re3000000 N5","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.0087480298242927,"CL":0.0146831927099072,"CD":0.00345594943556245,"n":5,"CDp":-0.000735172392264806,"CDf":0.00287,"Cpmin":-0.292591177588481,"sym":4.90257375147681e-05,"Bot_Xtr":0.754274166016082,"xy":[1,0,0.913162369486509,0.0217752177918085,0.813710842258612,0.0389787914022802,0.673782501507511,0.0533346679628148,0.492724758079874,0.0585614117791873,0.299655576439083,0.0528117501578089,0.141435325331645,0.0392852534872967,0.0380604371432103,0.0214214592851406,0,0,0.0380279452424157,-0.0212479428773729,0.14605649423593,-0.0396901519136859,0.312666093446018,-0.0532349729698485,0.510591162367989,-0.0582599628835464,0.699485607975073,-0.0513175061051813,0.843999845282038,-0.034278891163539,0.923962179670343,-0.0192455373075291,1,0],"clcd":289.356085395749,"CDpres":0.00058,"alpha":-0.2,"diter":4,"Top_Xtr":0.799863004813391,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re3000000-N5.dat","Re":3000000,"src":"retestc_23.txt"},
             {"diter":4,"Top_Xtr":0.807396107896655,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re3000000-N6.dat","Re":3000000,"src":"retestc_0.txt","sym":0.00018083601519809,"Bot_Xtr":0.802333288764969,"xy":[1,0,0.913162369486509,0.0243969243238081,0.813710842258612,0.0436717847402045,0.673782501507511,0.0597560892646372,0.492724758079874,0.0656121259099258,0.299655576439083,0.059170212868898,0.141435325331645,0.0440151444424012,0.0380604371432103,0.024000573775281,0,0,0.0380279452424157,-0.0241596614287933,0.14605649423593,-0.0451291043950031,0.312666093446018,-0.0605300442751154,0.510591162367989,-0.0662436352659554,0.699485607975073,-0.0583498167340944,0.843999845282038,-0.0389763098218547,0.923962179670343,-0.0218828555803517,1,0],"clcd":293.583517254847,"CDpres":0.00073,"alpha":0,"CL":0.00372665408398315,"CD":0.00340618577415551,"n":6,"CDp":-0.00091297000038201,"CDf":0.00267,"Cpmin":-0.321934372590991,"id":1323,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt134.938032667707>102.876578376775) l1 Foil spline 17pts Re3000000 N6","good":134.936968980409,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.000954847575444865},
             {"CDp":-0.000477809895436179,"n":7,"CD":0.00287694810180845,"CL":-0.0113882221813725,"Cpmin":-0.224826808160181,"CDf":0.00247,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt147.961813772399>130.083615503889) l1 Foil spline 17pts Re3000000 N7","xver":6.991,"good":147.961811943817,"id":1324,"Cm":-0.00510439338198898,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re3000000-N7.dat","Top_Xtr":0.858822203772657,"diter":4,"src":"retestc_1.txt","Re":3000000,"xy":[1,0,0.913162369486509,0.0174502332520039,0.813710842258612,0.0312368403546747,0.673782501507511,0.0427413587899642,0.492724758079874,0.0469299689621426,0.299655576439083,0.0423223026980241,0.141435325331645,0.0314824330700985,0.0380604371432103,0.0171667381101754,0,0,0.0380279452424157,-0.0167045155039952,0.14605649423593,-0.0312032445599301,0.312666093446018,-0.0418517894396538,0.510591162367989,-0.0458022905495835,0.699485607975073,-0.0403443326870597,0.843999845282038,-0.0269490685383422,0.923962179670343,-0.0151302824085946,1,0],"Bot_Xtr":0.80250934563278,"sym":0.000502356676513469,"alpha":-0.3,"CDpres":0.00041,"clcd":347.590559374846},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt178.866090072452>157.341645319683) l1 Foil spline 17pts Re3000000 N8","good":178.866090072301,"xver":6.991,"iver":1.2020052,"id":1325,"r":6,"Cm":-0.00428251404352966,"n":8,"CD":0.00273355549917982,"CL":-0.0149760554890488,"CDp":-0.000432098519914754,"CDf":0.00231,"Cpmin":-0.21985887355094,"sym":0.000417957171140777,"Bot_Xtr":0.825881677242813,"xy":[1,0,0.913162369486509,0.0170910724195071,0.813710842258612,0.0305939234707376,0.673782501507511,0.0418616558207627,0.492724758079874,0.0459640559867641,0.299655576439083,0.0414512247444697,0.141435325331645,0.0308344613950389,0.0380604371432103,0.0168134121768274,0,0,0.0380279452424157,-0.0163887739446848,0.14605649423593,-0.0306134542669677,0.312666093446018,-0.0410607249364991,0.510591162367989,-0.0449365553754831,0.699485607975073,-0.0395817614823514,0.843999845282038,-0.0264396888487472,0.923962179670343,-0.0148442963254093,1,0],"CDpres":0.00042,"clcd":365.823924299339,"alpha":-0.3,"diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re3000000-N8.dat","Top_Xtr":0.876396119254817,"Re":3000000,"src":"retestc_2.txt"},
             {"clcd":356.104082303086,"CDpres":0.00052,"alpha":-0.2,"sym":7.97215012165649e-05,"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"Bot_Xtr":0.839203036063657,"Re":3000000,"src":"retest_88.txt","diter":3,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","Top_Xtr":0.871213730607488,"Cm":-0.00326235165640565,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","xver":6.991,"good":183.351418270235,"id":1326,"r":6,"CDf":0.00229,"Cpmin":-0.252747886622427,"n":9,"CL":-0.00840477558492188,"CD":0.00280816775121629,"CDp":-0.000428118684767728},
             {"CDp":-0.000398098752624061,"n":10,"CL":0.00854381328267829,"CD":0.00273003063303142,"Cpmin":-0.249285733813208,"CDf":0.00221,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","good":203.330146927193,"iver":1.2020052,"id":1327,"Cm":0.000539095862723531,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","Top_Xtr":0.862259455885272,"diter":4,"src":"retest_69.txt","Re":3000000,"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"Bot_Xtr":0.865845001411966,"sym":5.02138354065566e-05,"alpha":0.1,"CDpres":0.00052,"clcd":366.296256130138},
             {"Top_Xtr":0.863093200712578,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N7.dat","diter":4,"src":"retest_70.txt","Re":3000000,"xy":[1,0,0.913162369486509,0.0214328164147398,0.813710842258612,0.0383658748298621,0.673782501507511,0.052496014410388,0.492724758079874,0.05764057102214,0.299655576439083,0.051981319153521,0.141435325331645,0.0386675179945384,0.0380604371432103,0.0210846205344021,0,0,0.0380279452424157,-0.0213866511372108,0.14605649423593,-0.0399492523798544,0.312666093446018,-0.0535824951043809,0.510591162367989,-0.0586402885516092,0.699485607975073,-0.0516525108636256,0.843999845282038,-0.0345026664894568,0.923962179670343,-0.0193711737046608,1,0],"Bot_Xtr":0.862487539450305,"sym":0.000413902458737372,"alpha":0.1,"clcd":349.1534394758,"CDpres":0.00064,"CDp":-0.000440941899554286,"CL":0.00550522464100157,"CD":0.0028640703110396,"n":11,"Cpmin":-0.280556651185292,"CDf":0.00222,"r":6,"id":1328,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt152.010645627129>97.6435267515532) l1 Foil spline 17pts Re4000000 N7","good":212.486989166609,"xver":6.991,"iver":1.2020052,"Cm":0.00120683872380538},
             {"r":6,"id":1329,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","good":221.439487855679,"xver":6.991,"iver":1.2020052,"Cm":0.000466322942818457,"CDp":-0.000285085533795326,"CD":0.00267247573684251,"CL":0.00884478371268278,"n":12,"Cpmin":-0.248970449036631,"CDf":0.00207,"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"Bot_Xtr":0.884135768972218,"sym":5.02138354065566e-05,"alpha":0.1,"CDpres":0.0006,"clcd":374.184875175512,"Top_Xtr":0.881159489252412,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","diter":3,"src":"retest_71.txt","Re":3000000},
             {"sym":5.02138354065566e-05,"Bot_Xtr":0.895351320850669,"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"CDpres":0.00066,"clcd":372.999428633724,"alpha":0.2,"diter":4,"Top_Xtr":0.88366610061142,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","Re":3000000,"src":"retest_72.txt","id":1330,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","iver":1.2020052,"good":228.167895128734,"r":6,"Cm":0.000797193586850331,"CL":0.018578145564127,"CD":0.00268096925419683,"n":13,"CDp":-0.000217241208223353,"CDf":0.00202,"Cpmin":-0.251736404198095},
             {"Top_Xtr":0.891857416136958,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","diter":3,"src":"retest_98.txt","Re":3000000,"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"Bot_Xtr":0.896176983810383,"sym":7.97215012165649e-05,"alpha":0.1,"clcd":369.499065512901,"CDpres":0.00072,"CDp":-0.000156205446820377,"CD":0.00270636679043261,"CL":0.013230319146572,"n":14,"Cpmin":-0.254479805587195,"CDf":0.00198,"r":6,"id":1331,"good":229.972399850792,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","xver":6.991,"iver":1.2020052,"Cm":-0.000529406559538641},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt48.8352366403963>27.1369023540978) l1 Foil spline 17pts Re10000000 N6","good":42.4393156080372,"xver":6.991,"iver":1.2020052,"id":1332,"r":6,"Cm":-0.000874205712159416,"n":3,"CD":0.00488921382664503,"CL":0.0045639643783155,"CDp":1.58054950028414e-05,"CDf":0.00395,"Cpmin":-0.466540300958008,"sym":0.000291833128254308,"Bot_Xtr":0.56474219620424,"xy":[1,0,0.910673421760927,0.014779067524005,0.849186318940748,0.029551175851234,0.695794612861528,0.0661900769530461,0.498442662240797,0.0847902236920406,0.302873885493542,0.0808699106599605,0.139977327975174,0.060354528252266,0.0380656693660804,0.0309733937048017,0,0,0.0396582029585364,-0.0315251984703351,0.144634720957126,-0.0606318997414456,0.306852823166501,-0.0803781697409137,0.500818080902831,-0.083882263762875,0.698940635957709,-0.065034120422648,0.860665749892887,-0.0262521256539404,0.919783730358342,-0.0129648243284087,1,0],"clcd":204.531860429225,"CDpres":0.00094,"alpha":0,"diter":4,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N6.dat","Top_Xtr":0.56577481132126,"Re":4000000,"src":"retest_106.txt"},
             {"Cm":-0.00291310745911701,"r":6,"id":1333,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt74.0902316727326>37.1404622711758) l1 Foil spline 17pts Re3000000 N3","xver":6.991,"good":75.0066365734018,"iver":1.2020052,"Cpmin":-0.483669688832619,"CDf":0.00298,"CDp":-0.00321016281249999,"CL":-0.0294499917327981,"CD":0.00465983617085978,"n":4,"alpha":-0.4,"CDpres":0.00168,"clcd":214.599819249759,"Bot_Xtr":0.72797550948968,"xy":[1,0,0.880300325419672,0.0444274385401519,0.704663862945517,0.0802428485467915,0.494561349047687,0.0920417198986593,0.292149054823316,0.0814905709238195,0.151132354125174,0.0605670891901652,0.0758230374101564,0.0419912096740373,0.0249798475564602,0.0233315731093683,0,0,0.0247348166511182,-0.0234194786785516,0.0790299712088116,-0.0436565248399111,0.168051338348483,-0.0648456708079602,0.314517318069903,-0.0848530792573358,0.507756670437578,-0.0933236291163286,0.707646981873831,-0.0810293478272794,0.880289902407772,-0.0451298971679201,1,0],"sym":0.000725716220303653,"src":"retest_104.txt","Re":4000000,"Top_Xtr":0.739513270151099,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re3000000-N3.dat","diter":4},
             {"Re":4000000,"src":"retest_108.txt","diter":4,"Top_Xtr":0.747178574595576,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N4.dat","clcd":263.600794722534,"CDpres":0.00098,"alpha":0.1,"sym":0.000502024749331122,"xy":[1,0,0.913162369486509,0.0285583118429417,0.813710842258612,0.0511208884691867,0.673782501507511,0.0699486955439224,0.492724758079874,0.0768035973528624,0.299655576439083,0.0692628861120092,0.141435325331645,0.0515228150940139,0.0380604371432103,0.0280943557141393,0,0,0.0380279452424157,-0.02760515589807,0.14605649423593,-0.0515651250343934,0.312666093446018,-0.069162447232817,0.510591162367989,-0.0756908735729301,0.699485607975073,-0.0666712897577615,0.843999845282038,-0.0445348587410861,0.923962179670343,-0.0250036467427736,1,0],"Bot_Xtr":0.757554639185415,"CDf":0.00281,"Cpmin":-0.376868137875429,"CD":0.00379361526983482,"CL":0.00401979729901347,"n":5,"CDp":-0.00158339932768178,"Cm":0.0016487574865902,"id":1334,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt104.366457223021>63.39957801653) l1 Foil spline 17pts Re2500000 N4","iver":1.2020052,"good":94.5739592935036,"r":6},
             {"sym":8.99286746240594e-05,"Bot_Xtr":0.771768878119107,"xy":[1,0,0.913162369486509,0.0280819120317966,0.813710842258612,0.0502681076134336,0.673782501507511,0.0687818357683786,0.492724758079874,0.0755223864929423,0.299655576439083,0.0681074667705373,0.141435325331645,0.0506633294382987,0.0380604371432103,0.0276256954575364,0,0,0.0380279452424157,-0.0273919421128079,0.14605649423593,-0.0511668517720836,0.312666093446018,-0.068628257633347,0.510591162367989,-0.0751062604041486,0.699485607975073,-0.0661563410970821,0.843999845282038,-0.0441908851064738,0.923962179670343,-0.0248105262189458,1,0],"CDpres":0.00091,"clcd":280.302719845948,"alpha":0,"diter":4,"Top_Xtr":0.775284052901647,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N6.dat","Re":4000000,"src":"retest_88.txt","id":1335,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt119.186597085207>69.3342101446003) l1 Foil spline 17pts Re4000000 N6","xver":6.991,"good":119.186597092675,"r":6,"Cm":-0.00222450810678879,"CD":0.00356757151892637,"CL":0.00937365156145119,"n":6,"CDp":-0.00147358512703772,"CDf":0.00266,"Cpmin":-0.374817543589283},
             {"Cpmin":-0.286476012788775,"CDf":0.00255,"CDp":-0.000761143200718676,"n":7,"CL":-0.0055583555508193,"CD":0.00305606713072587,"Cm":-0.0118194638322233,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt152.010645627129>97.6435267515532) l1 Foil spline 17pts Re4000000 N7","xver":6.991,"iver":1.2020052,"good":152.010645626462,"id":1336,"src":"retestc_11.txt","Re":4000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N7.dat","Top_Xtr":0.82437678818124,"diter":4,"alpha":-0.5,"clcd":327.217942939128,"CDpres":0.00051,"Bot_Xtr":0.753153696529388,"xy":[1,0,0.913162369486509,0.0214328164147398,0.813710842258612,0.0383658748298621,0.673782501507511,0.052496014410388,0.492724758079874,0.05764057102214,0.299655576439083,0.051981319153521,0.141435325331645,0.0386675179945384,0.0380604371432103,0.0210846205344021,0,0,0.0380279452424157,-0.0213866511372108,0.14605649423593,-0.0399492523798544,0.312666093446018,-0.0535824951043809,0.510591162367989,-0.0586402885516092,0.699485607975073,-0.0516525108636256,0.843999845282038,-0.0345026664894568,0.923962179670343,-0.0193711737046608,1,0],"sym":0.000413902458737372},
             {"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"Bot_Xtr":0.778741935991188,"sym":5.02138354065566e-05,"alpha":-0.4,"clcd":354.364172700241,"CDpres":0.00042,"Top_Xtr":0.838821154407667,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","diter":4,"src":"retestc_12.txt","Re":4000000,"r":6,"id":1337,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","xver":6.991,"iver":1.2020052,"good":167.608356235346,"Cm":-0.00508499554973626,"CDp":-0.000553770672415465,"CD":0.00282195570838903,"CL":-0.0225530463712856,"n":8,"Cpmin":-0.255459697721941,"CDf":0.00241},
             {"Cpmin":-0.256625188254326,"CDf":0.00227,"CDp":-0.00052488680188147,"CL":-0.0202788885611122,"CD":0.0026954640076117,"n":9,"Cm":-0.00560715529885621,"r":6,"id":1338,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","xver":6.991,"good":186.050214865918,"src":"retest_99.txt","Re":4000000,"Top_Xtr":0.853624571040109,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","diter":4,"alpha":-0.4,"clcd":370.993638637396,"CDpres":0.00043,"Bot_Xtr":0.801343300044255,"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"sym":7.97215012165649e-05},
             {"xy":[1,0,0.913162369486509,0.021694982993299,0.813710842258612,0.0388351668698321,0.673782501507511,0.0531381465604353,0.492724758079874,0.0583456314770356,0.299655576439083,0.0526171555423447,0.141435325331645,0.0391404997388803,0.0380604371432103,0.0213425279749716,0,0,0.0380279452424157,-0.0214505663182961,0.14605649423593,-0.0400686429138702,0.312666093446018,-0.053742629332766,0.510591162367989,-0.0588155382733924,0.699485607975073,-0.0518068772281479,0.843999845282038,-0.0346057796025127,0.923962179670343,-0.0194290655207859,1,0],"Bot_Xtr":0.808987660999417,"sym":0.000105276207160423,"alpha":-0.5,"clcd":367.696160606319,"CDpres":0.00052,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N5.dat","Top_Xtr":0.862735345780292,"diter":3,"src":"retest_158.txt","Re":4000000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt137.984778561906>109.238664609646) l1 Foil spline 17pts Re2000000 N5","iver":1.2020052,"good":198.576290823585,"id":1339,"Cm":-0.0095457939586114,"CDp":-0.000634384275250984,"n":10,"CL":-0.0151523279276056,"CD":0.00271963677388154,"Cpmin":-0.288654835932894,"CDf":0.0022},
             {"Cm":-0.0166685675938113,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt114.913017624354>94.6023665654467) l1 Foil spline 17pts Re1700000 N4","good":203.776825540229,"xver":6.991,"iver":1.2020052,"id":1340,"Cpmin":-0.336615402888212,"CDf":0.00219,"CDp":-0.000879731517782919,"n":11,"CL":-0.00662665408359918,"CD":0.00289201907309134,"alpha":-0.7,"CDpres":0.0007,"clcd":345.779185657679,"Bot_Xtr":0.806947879445243,"xy":[1,0,0.913162369486509,0.0249389811043402,0.813710842258612,0.0446420950433465,0.673782501507511,0.0610837645459172,0.492724758079874,0.0670699120333961,0.299655576439083,0.0604848710063508,0.141435325331645,0.0449930835946665,0.0380604371432103,0.0245338243432166,0,0,0.0380279452424157,-0.0241596614287933,0.14605649423593,-0.0451291043950031,0.312666093446018,-0.0605300442751154,0.510591162367989,-0.0662436352659554,0.699485607975073,-0.0583498167340944,0.843999845282038,-0.0389763098218547,0.923962179670343,-0.0218828555803517,1,0],"sym":0.000281459362978508,"src":"retest_83.txt","Re":4000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re1700000-N4.dat","Top_Xtr":0.864037464529418,"diter":3},
             {"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N7.dat","Top_Xtr":0.866520558080248,"diter":3,"src":"retest_152.txt","Re":4000000,"xy":[1,0,0.913162369486509,0.0194897055037273,0.813710842258612,0.0348876035401786,0.673782501507511,0.0477366969034576,0.492724758079874,0.0524148451864496,0.299655576439083,0.0472686642013436,0.141435325331645,0.0351618995698273,0.0380604371432103,0.0191730772531943,0,0,0.0380279452424157,-0.0189621445345881,0.14605649423593,-0.0354203887656594,0.312666093446018,-0.0475080932575422,0.510591162367989,-0.0519925078466766,0.699485607975073,-0.045796902483078,0.843999845282038,-0.0305912573504061,0.923962179670343,-0.0171751525395806,1,0],"Bot_Xtr":0.852512806146974,"sym":7.97215012165649e-05,"alpha":-0.1,"clcd":402.673273992563,"CDpres":0.00045,"CDp":-0.000435134382317956,"n":12,"CD":0.00248340295864401,"CL":-0.00291473605269835,"Cpmin":-0.252652667789912,"CDf":0.00204,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt164.309094347762>151.943623179798) l1 Foil spline 17pts Re2000000 N7","good":223.500277374572,"xver":6.991,"iver":1.2020052,"id":1341,"Cm":-0.00192339748052761},
             {"diter":3,"Top_Xtr":0.867608459245502,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","Re":4000000,"src":"retest_84.txt","sym":5.02138354065566e-05,"Bot_Xtr":0.869508879323707,"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"CDpres":0.00045,"clcd":413.024481541448,"alpha":0.1,"CD":0.00242116398589232,"CL":0.00893262984612599,"n":13,"CDp":-0.000399994570799075,"CDf":0.00197,"Cpmin":-0.249546689909537,"id":1342,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","iver":1.2020052,"good":239.029319313468,"r":6,"Cm":0.000440159422139209},
             {"Cm":0.00101432211573827,"r":6,"id":1343,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","xver":6.991,"good":248.593990411701,"iver":1.2020052,"Cpmin":-0.251410926621083,"CDf":0.00191,"CDp":-0.000361431205914644,"CD":0.0023923944163393,"CL":0.0175236202771842,"n":14,"alpha":0.2,"CDpres":0.00048,"clcd":417.991278181522,"Bot_Xtr":0.881040522571139,"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"sym":5.02138354065566e-05,"src":"retest_85.txt","Re":4000000,"Top_Xtr":0.871188625438041,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","diter":3},
             {"id":1344,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt43.2056215540169>28.8981055342443) l1 Foil spline 17pts Re8192000 N5","good":34.3187088433728,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000927317136680204,"CD":0.00521885868931032,"CL":-0.00487232416179437,"n":3,"CDp":0.000108371755584003,"CDf":0.0041,"Cpmin":-0.495540755065796,"sym":0.000262698448801819,"Bot_Xtr":0.520158934496668,"xy":[1,0,0.910673421760927,0.0154762291440661,0.849186318940748,0.0309451708105029,0.695794612861528,0.069312410700125,0.498442662240797,0.0887899678990738,0.302873885493542,0.0846847249463371,0.139977327975174,0.0632015861350474,0.0380656693660804,0.0324344778563531,0,0,0.0396582029585364,-0.0336034992758357,0.144634720957126,-0.0646290617637641,0.306852823166501,-0.0856771059260227,0.500818080902831,-0.089412207579395,0.698940635957709,-0.0693214991361109,0.860665749892887,-0.0279827987833746,0.919783730358342,-0.0138195312343861,1,0],"clcd":191.612775806381,"CDpres":0.00112,"alpha":0,"diter":6,"Top_Xtr":0.512712386999253,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N5.dat","Re":5000000,"src":"retest_78.txt"},
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001035.dat-s17_n17s0.dat (opt74.0902316727326>37.1404622711758) l1 Foil spline 17pts Re3000000 N3","iver":1.2020052,"good":65.1254011005454,"id":1345,"r":6,"Cm":0.0160296124173705,"n":4,"CL":-0.0583841545981516,"CD":0.0050629451008986,"CDp":-0.00319051206329292,"CDf":0.00322,"Cpmin":-0.496944121726154,"sym":0.000725716220303653,"Bot_Xtr":0.726207156084563,"xy":[1,0,0.880300325419672,0.0444274385401519,0.704663862945517,0.0802428485467915,0.494561349047687,0.0920417198986593,0.292149054823316,0.0814905709238195,0.151132354125174,0.0605670891901652,0.0758230374101564,0.0419912096740373,0.0249798475564602,0.0233315731093683,0,0,0.0247348166511182,-0.0234194786785516,0.0790299712088116,-0.0436565248399111,0.168051338348483,-0.0648456708079602,0.314517318069903,-0.0848530792573358,0.507756670437578,-0.0933236291163286,0.707646981873831,-0.0810293478272794,0.880289902407772,-0.0451298971679201,1,0],"CDpres":0.00184,"clcd":197.513498580602,"alpha":0.1,"diter":4,"Foil_fn":"optbs_spline_sym_naca001035.dat-s17_n17s0_nsopt-Re3000000-N3.dat","Top_Xtr":0.626662716563361,"Re":5000000,"src":"retest_111.txt"},
             {"n":5,"CD":0.00423460846321622,"CL":0.0962317835682015,"CDp":-9.03198337062211e-05,"CDf":0.00338,"Cpmin":-0.52920827075506,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt43.2056215540169>28.8981055342443) l1 Foil spline 17pts Re8192000 N5","xver":6.991,"iver":1.2020052,"good":66.052199669315,"id":1346,"r":6,"Cm":0.00431847993976144,"diter":4,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N5.dat","Top_Xtr":0.527166262302352,"Re":5000000,"src":"retest_80.txt","sym":0.000262698448801819,"Bot_Xtr":0.705190785774273,"xy":[1,0,0.910673421760927,0.0154762291440661,0.849186318940748,0.0309451708105029,0.695794612861528,0.069312410700125,0.498442662240797,0.0887899678990738,0.302873885493542,0.0846847249463371,0.139977327975174,0.0632015861350474,0.0380656693660804,0.0324344778563531,0,0,0.0396582029585364,-0.0336034992758357,0.144634720957126,-0.0646290617637641,0.306852823166501,-0.0856771059260227,0.500818080902831,-0.089412207579395,0.698940635957709,-0.0693214991361109,0.860665749892887,-0.0279827987833746,0.919783730358342,-0.0138195312343861,1,0],"clcd":236.14934147666,"CDpres":0.00086,"alpha":1.1},
             {"sym":0.000349355903431288,"Bot_Xtr":0.724946348042327,"xy":[1,0,0.913162369486509,0.028453918015721,0.813710842258612,0.0509340179977258,0.673782501507511,0.0696930007368526,0.492724758079874,0.0765228447118775,0.299655576439083,0.069009698255341,0.141435325331645,0.051334475395,0.0380604371432103,0.027991657860974,0,0,0.0380279452424157,-0.0282352629918988,0.14605649423593,-0.0527421352711157,0.312666093446018,-0.0707411287222053,0.510591162367989,-0.0774185709839684,0.699485607975073,-0.0681931088261342,0.843999845282038,-0.0455513982063599,0.923962179670343,-0.025574372560892,1,0],"clcd":266.897884867389,"CDpres":0.00098,"alpha":-0.1,"diter":4,"Top_Xtr":0.74459728383396,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N8.dat","Re":5000000,"src":"retest_66.txt","id":1347,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt115.304398195442>44.5066666593964) l1 Foil spline 17pts Re7000000 N8","good":97.6759151876306,"xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.00376340519656209,"CD":0.00374675131088753,"CL":0.00489821219235743,"n":6,"CDp":-0.00164491954246771,"CDf":0.00276,"Cpmin":-0.381606400096993},
             {"Re":5000000,"src":"retestc_21.txt","diter":4,"Top_Xtr":0.789122475773119,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N7.dat","clcd":291.892068636887,"CDpres":0.00088,"alpha":-0.4,"sym":0.000716732971777374,"xy":[1,0,0.913162369486509,0.027817551435875,0.813710842258612,0.0497948881663569,0.673782501507511,0.0681343297484279,0.492724758079874,0.0748114255342976,0.299655576439083,0.0674663091997214,0.141435325331645,0.0501863894084846,0.0380604371432103,0.027365629643441,0,0,0.0380279452424157,-0.0277645111088732,0.14605649423593,-0.0518627930280208,0.312666093446018,-0.0695616986045226,0.510591162367989,-0.0761278113376951,0.699485607975073,-0.0670561605215094,0.843999845282038,-0.0447919433896561,0.923962179670343,-0.0251479843227625,1,0],"Bot_Xtr":0.741266943972291,"CDf":0.00255,"Cpmin":-0.377880922920922,"CL":0.00321680017460392,"CD":0.00342592385147675,"n":7,"CDp":-0.00153590188320518,"Cm":-0.0111035075728396,"id":1348,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.832735417199>73.7966339079156) l1 Foil spline 17pts Re5000000 N7","iver":1.2020052,"xver":6.991,"good":126.832735420639,"r":6},
             {"CDp":-0.000798859765329458,"CL":0.0039977061401152,"CD":0.00299295423070384,"n":8,"Cpmin":-0.305434416787371,"CDf":0.00246,"r":6,"id":1349,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt150.322790998904>108.456421412499) l1 Foil spline 17pts Re5000000 N8","iver":1.2020052,"good":150.322665885255,"Cm":-0.0113223355672572,"Top_Xtr":0.801011239305566,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N8.dat","diter":3,"src":"retestc_22.txt","Re":5000000,"xy":[1,0,0.913162369486509,0.0227729539364055,0.813710842258612,0.040764791865127,0.673782501507511,0.0557784518319523,0.492724758079874,0.0612446840095436,0.299655576439083,0.0552315740372142,0.141435325331645,0.0410852959818739,0.0380604371432103,0.022402986285382,0,0,0.0380279452424157,-0.0218785018925023,0.14605649423593,-0.0408680063180143,0.312666093446018,-0.0548147867108793,0.510591162367989,-0.0599888994224547,0.699485607975073,-0.0528404166427017,0.843999845282038,-0.0352961597046187,0.923962179670343,-0.0198166724578968,1,0],"Bot_Xtr":0.756280068544859,"sym":0.000626233944886703,"alpha":-0.4,"clcd":334.118039541432,"CDpres":0.00053},
             {"CDp":-0.00055512286870803,"CD":0.00270988685231335,"CL":0.0018617826085132,"n":9,"Cpmin":-0.251865214675342,"CDf":0.00232,"r":6,"id":1350,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt154.011715822924>96.0139234956795) l1 Foil spline 17pts Re5000000 N9","good":154.011715821011,"iver":1.2020052,"Cm":-0.000416316813314242,"Top_Xtr":0.795147909858444,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N9.dat","diter":4,"src":"retestc_23.txt","Re":5000000,"xy":[1,0,0.913162369486509,0.0193776932184914,0.813710842258612,0.0346870956259778,0.673782501507511,0.0474623419877947,0.492724758079874,0.0521136037649978,0.299655576439083,0.0469969991884357,0.141435325331645,0.0349598152067107,0.0380604371432103,0.0190628847108942,0,0,0.0380279452424157,-0.0187799099415963,0.14605649423593,-0.0350799831686792,0.312666093446018,-0.0470515194758787,0.510591162367989,-0.0514928368580508,0.699485607975073,-0.0453567740013513,0.843999845282038,-0.030297261841502,0.923962179670343,-0.0170100917297701,1,0],"Bot_Xtr":0.801763271217624,"sym":0.000159533599296801,"alpha":0,"CDpres":0.00039,"clcd":369.019097290475},
             {"id":1351,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt187.482230927312>157.096800504803) l1 Foil spline 17pts Re5000000 N10","xver":6.991,"good":187.482231031778,"iver":1.2020052,"r":6,"Cm":-0.000299435626653239,"CL":0.00128678317906482,"CD":0.0025779597351963,"n":10,"CDp":-0.000531965140442987,"CDf":0.00221,"Cpmin":-0.24877378899863,"sym":4.02815166606564e-05,"Bot_Xtr":0.817785005694865,"xy":[1,0,0.913162369486509,0.0191517322848922,0.813710842258612,0.0342826136051763,0.673782501507511,0.0469088893665028,0.492724758079874,0.0515059133434817,0.299655576439083,0.0464489728731649,0.141435325331645,0.0345521530359099,0.0380604371432103,0.0188405947211726,0,0,0.0380279452424157,-0.0186838155819723,0.14605649423593,-0.0349004834517638,0.312666093446018,-0.0468107629628055,0.510591162367989,-0.0512293547008688,0.699485607975073,-0.0451246892807204,0.843999845282038,-0.0301422346883328,0.923962179670343,-0.0169230533000332,1,0],"clcd":387.903653554874,"CDpres":0.00037,"alpha":0,"diter":3,"Top_Xtr":0.814698076410089,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N10.dat","Re":5000000,"src":"retestc_0.txt"},
             {"CDp":-0.000519480834013234,"CL":-0.0270888119836577,"CD":0.00247668350430782,"n":11,"Cpmin":-0.25712715747938,"CDf":0.0021,"r":6,"id":1352,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt167.60835887641>126.63377856111) l1 Foil spline 17pts Re4000000 N8","iver":1.2020052,"good":199.087877174905,"Cm":-0.00401227905657917,"Top_Xtr":0.853928660760751,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N8.dat","diter":4,"src":"retest_94.txt","Re":5000000,"xy":[1,0,0.913162369486509,0.0191218676247863,0.813710842258612,0.0342291542842317,0.673782501507511,0.0468357409945416,0.492724758079874,0.0514255965046409,0.299655576439083,0.0463765416817462,0.141435325331645,0.0344982734029349,0.0380604371432103,0.0188112152400285,0,0,0.0380279452424157,-0.0188664677257646,0.14605649423593,-0.0352416690138821,0.312666093446018,-0.0472683828836506,0.510591162367989,-0.0517301705765209,0.699485607975073,-0.0455658262208129,0.843999845282038,-0.0304369038237864,0.923962179670343,-0.0170884923106679,1,0],"Bot_Xtr":0.806629166323464,"sym":5.02138354065566e-05,"alpha":-0.4,"CDpres":0.00038,"clcd":403.76576105128},
             {"id":1353,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt122.599931443436>85.5888907693963) l1 Foil spline 17pts Re7000000 N9","xver":6.991,"good":210.121530925554,"iver":1.2020052,"r":6,"Cm":0.0125242704692287,"CL":0.0351894228387242,"CD":0.0025583325234778,"n":12,"CDp":-0.000697281237510993,"CDf":0.0021,"Cpmin":-0.293433551622055,"sym":4.59167910680498e-05,"Bot_Xtr":0.862249523832385,"xy":[1,0,0.913162369486509,0.0217687851237351,0.813710842258612,0.0389672765862454,0.673782501507511,0.0533189122436717,0.492724758079874,0.0585441120154152,0.299655576439083,0.0527961489150389,0.141435325331645,0.0392736481385798,0.0380604371432103,0.021415131121696,0,0,0.0380279452424157,-0.021246681223679,0.14605649423593,-0.039687795204283,0.312666093446018,-0.0532318120003055,0.510591162367989,-0.0582565035417269,0.699485607975073,-0.0513144589903849,0.843999845282038,-0.0342768557622812,0.923962179670343,-0.0192443945520457,1,0],"clcd":390.879602562609,"CDpres":0.00046,"alpha":0.8,"diter":5,"Top_Xtr":0.794826270467757,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N9.dat","Re":5000000,"src":"retest_80.txt"},
             {"Cm":-0.000160409774060104,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001066.dat-s17_n17s0.dat (opt138.277288094115>98.3566437408768) l1 Foil spline 17pts Re5000000 N12","xver":6.991,"good":154.490955593627,"iver":1.2020052,"id":1354,"Cpmin":-0.310582510263878,"CDf":0.00166,"CDp":-0.000611647955813622,"n":13,"CL":0.000696168381526464,"CD":0.00206123499441096,"alpha":0,"clcd":485.146042402492,"CDpres":0.0004,"Bot_Xtr":0.89402261856983,"xy":[1,0,0.884615607831572,0.0243095169657895,0.71311306945101,0.0376992226011456,0.441045312523178,0.0379267074264667,0.244177459414419,0.0340110212100284,0.143733883449667,0.0294924920588747,0.084559753204033,0.024893109141252,0.0249274401675381,0.0157961780765312,0,0,0.0231037840650006,-0.0152179001009913,0.0714830670908357,-0.0233625950405864,0.144140580017158,-0.0296160837370215,0.281976243120757,-0.03511107877808,0.499922389643121,-0.0384625090044511,0.732768656055785,-0.0370887417014501,0.891593565155033,-0.0232629972517414,1,0],"sym":5.07949867603002e-06,"src":"retestc_16.txt","Re":5000000,"Foil_fn":"optbs_spline_sym_naca001066.dat-s17_n17s0_nsopt-Re5000000-N12.dat","Top_Xtr":0.893391410253611,"diter":4},
             {"clcd":386.799341091527,"CDpres":0.0005,"alpha":-0.8,"sym":0.000228003270218699,"xy":[1,0,0.878175247413484,0.0290835591357462,0.703112195765058,0.0519066773508417,0.497409844593044,0.0593420786808699,0.289984193140673,0.0529487337144575,0.138935011398081,0.0394861094681966,0.0706796263555245,0.0288312633366392,0.0235527616953747,0.0174795224977981,0,0,0.0235522361629963,-0.017630630217279,0.0745550964375219,-0.0300205111152187,0.145796055405051,-0.0408069695884857,0.285727317223195,-0.0532877548873893,0.483503181806403,-0.0600427133719584,0.69332798864512,-0.05336668212973,0.87453012738683,-0.0301438849665615,1,0],"Bot_Xtr":0.794332842168006,"Re":5000000,"src":"retest_105.txt","diter":3,"Top_Xtr":0.866335979634189,"Foil_fn":"optbs_spline_sym_naca16012.dat-s17_n17s0_nsopt-Re1700000-N10.dat","Cm":-0.0142823723675932,"id":1355,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16012.dat-s17_n17s0.dat (opt168.063383493916>133.020897897281) l1 Foil spline 17pts Re1700000 N10","iver":1.2020052,"xver":6.991,"good":197.076100130309,"r":6,"CDf":0.00208,"Cpmin":-0.297321059650665,"CL":-0.0281259655533144,"CD":0.00258531981253653,"n":14,"CDp":-0.000837282390466749},
             {"Re":6000000,"src":"retest_94.txt","diter":4,"Top_Xtr":0.528187806355061,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","clcd":190.791523276824,"CDpres":0.00136,"alpha":0,"sym":8.14582294892033e-05,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"Bot_Xtr":0.527387026776193,"CDf":0.00388,"Cpmin":-0.583084670367773,"CD":0.00524132300442445,"CL":0.000451393120625031,"n":3,"CDp":4.85165166072856e-05,"Cm":-0.000102012785116657,"id":1356,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","iver":1.2020052,"good":36.3969416553823,"r":6},
             {"sym":0.000306475799801595,"Bot_Xtr":0.601430832955551,"xy":[1,0,0.910673421760927,0.0154546404831392,0.849186318940748,0.0309020036543607,0.695794612861528,0.0692157229269792,0.498442662240797,0.0886661097878476,0.302873885493542,0.0845665934689895,0.139977327975174,0.0631134226941721,0.0380656693660804,0.0323892331821973,0,0,0.0396582029585364,-0.0329739989977944,0.144634720957126,-0.0634183541521587,0.306852823166501,-0.0840721015912217,0.500818080902831,-0.0877372329266218,0.698940635957709,-0.0680228872676799,0.860665749892887,-0.0274585920788909,0.919783730358342,-0.0135606475186446,1,0],"clcd":199.234958951737,"CDpres":0.00108,"alpha":0.7,"diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re3000000-N3.dat","Top_Xtr":0.431019710380815,"Re":6000000,"src":"retest_111.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt58.3757572959639>32.6408587917731) l1 Foil spline 17pts Re3000000 N3","good":42.2955811074394,"iver":1.2020052,"id":1357,"r":6,"Cm":0.00342756857592707,"n":4,"CD":0.00501919946811264,"CL":0.0580261866169733,"CDp":9.27551142490954e-05,"CDf":0.00394,"Cpmin":-0.508788121699139},
             {"CDf":0.00342,"Cpmin":-0.543201966207507,"n":5,"CD":0.00440411555580852,"CL":-0.00131103373072974,"CDp":-6.49714791947744e-05,"Cm":0.000252569045684045,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt67.8462156431864>37.3379899972252) l1 Foil spline 17pts Re20000000 N10","xver":6.991,"iver":1.2020052,"good":63.4418753644505,"id":1358,"r":6,"Re":6000000,"src":"retest_103.txt","diter":4,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N10.dat","Top_Xtr":0.587725919116522,"CDpres":0.00099,"clcd":227.060345562712,"alpha":0,"sym":7.85400925867198e-05,"xy":[1,0,0.910673421760927,0.0170236138564171,0.849186318940748,0.034039211599607,0.695794612861528,0.0762425849496249,0.498442662240797,0.0976675980800562,0.302873885493542,0.0931518940178065,0.139977327975174,0.0695207719826673,0.0380656693660804,0.0356774264274041,0,0,0.0396582029585364,-0.0367065728461499,0.144634720957126,-0.0705971525208346,0.306852823166501,-0.0935888522830824,0.500818080902831,-0.0976688672780052,0.698940635957709,-0.075722907217397,0.860665749892887,-0.0305668357199847,0.919783730358342,-0.0150956787503204,1,0],"Bot_Xtr":0.59183797509227},
             {"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re7000000-N6.dat","Top_Xtr":0.550657491481309,"diter":5,"src":"retestc_23.txt","Re":6000000,"xy":[1,0,0.910673421760927,0.0131319436195127,0.849186318940748,0.0262577036432368,0.695794612861528,0.0588132070786467,0.498442662240797,0.0753403714545049,0.302873885493542,0.0718569764686914,0.139977327975174,0.0536280290284689,0.0380656693660804,0.0275214156221814,0,0,0.0396582029585364,-0.0285245094593507,0.144634720957126,-0.0548607235364659,0.306852823166501,-0.0727274680049182,0.500818080902831,-0.075898028950631,0.698940635957709,-0.0588439240096133,0.860665749892887,-0.0237533478892616,0.919783730358342,-0.0117307827432873,1,0],"Bot_Xtr":0.708976070773579,"sym":0.000203316839002897,"alpha":0.8,"clcd":268.673686622761,"CDpres":0.00058,"CDp":-0.000125760278604869,"n":6,"CL":0.0752557066588581,"CD":0.00372198711593249,"Cpmin":-0.438319078914899,"CDf":0.00314,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1726343664041>51.9250677619875) l1 Foil spline 17pts Re7000000 N6","xver":6.991,"good":69.8943805796621,"iver":1.2020052,"id":1359,"Cm":0.00209714941829783},
             {"xy":[1,0,0.913162369486509,0.028453918015721,0.813710842258612,0.0509340179977258,0.673782501507511,0.0696930007368526,0.492724758079874,0.0765228447118775,0.299655576439083,0.069009698255341,0.141435325331645,0.051334475395,0.0380604371432103,0.027991657860974,0,0,0.0380279452424157,-0.0282352629918988,0.14605649423593,-0.0527421352711157,0.312666093446018,-0.0707411287222053,0.510591162367989,-0.0774185709839684,0.699485607975073,-0.0681931088261342,0.843999845282038,-0.0455513982063599,0.923962179670343,-0.025574372560892,1,0],"Bot_Xtr":0.720179580637349,"sym":0.000349355903431288,"alpha":-0.2,"CDpres":0.00094,"clcd":279.330565330965,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N8.dat","Top_Xtr":0.745061383726892,"diter":4,"src":"retest_79.txt","Re":6000000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt115.304398195442>44.5066666593964) l1 Foil spline 17pts Re7000000 N8","good":99.3523100000432,"iver":1.2020052,"id":1360,"Cm":-0.00494568221322778,"CDp":-0.00163361784240731,"n":7,"CL":-0.000864181234644721,"CD":0.00357998774253419,"Cpmin":-0.381218522849289,"CDf":0.00264},
             {"Top_Xtr":0.764204067484225,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re6000000-N8.dat","diter":4,"src":"retestc_8.txt","Re":6000000,"xy":[1,0,0.913162369486509,0.0259000053782785,0.813710842258612,0.0463623793162532,0.673782501507511,0.0634376289731187,0.492724758079874,0.0696544528069476,0.299655576439083,0.0628156570557059,0.141435325331645,0.0467268932203645,0.0380604371432103,0.025479235891015,0,0,0.0380279452424157,-0.0254723727742349,0.14605649423593,-0.047581187075199,0.312666093446018,-0.0638189345641709,0.510591162367989,-0.0698429726090392,0.699485607975073,-0.0615202447078904,0.843999845282038,-0.0410940813915183,0.923962179670343,-0.0230718570436236,1,0],"Bot_Xtr":0.748333879072961,"sym":3.74433007236193e-05,"alpha":-0.2,"clcd":314.639940267403,"CDpres":0.0007,"CDp":-0.0011690189523792,"CD":0.00317823604705153,"CL":-0.00959181539383842,"n":8,"Cpmin":-0.344724883512642,"CDf":0.00248,"r":6,"id":1361,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.808549300944>55.2313282245345) l1 Foil spline 17pts Re6000000 N8","xver":6.991,"iver":1.2020052,"good":126.808549299581,"Cm":-0.00288040980127488},
             {"src":"retest_79.txt","Re":6000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N3.dat","Top_Xtr":0.78879000450737,"diter":4,"alpha":-0.3,"clcd":333.433014805582,"CDpres":0.00066,"Bot_Xtr":0.764284897925687,"xy":[1,0,0.913162369486509,0.0258972039917992,0.813710842258612,0.0463573646863075,0.673782501507511,0.063430767456548,0.492724758079874,0.0696469188686543,0.299655576439083,0.062808862812624,0.141435325331645,0.0467218391640053,0.0380604371432103,0.0254764800156441,0,0,0.0380279452424157,-0.0250358376501835,0.14605649423593,-0.0467657601188458,0.312666093446018,-0.0627252317213411,0.510591162367989,-0.0686460322618546,0.699485607975073,-0.0604659358732459,0.843999845282038,-0.04038982780364,0.923962179670343,-0.0226764609780155,1,0],"sym":0.00040646685299989,"Cpmin":-0.342339462914598,"CDf":0.00234,"CDp":-0.00111308281938935,"n":9,"CD":0.00299910313495225,"CL":-0.00969494645956035,"Cm":-0.00536604974967351,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt92.8568347622691>56.8428292109818) l1 Foil spline 17pts Re2000000 N3","xver":6.991,"good":141.258860267221,"id":1362},
             {"r":6,"id":1363,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt169.648403891223>134.487525431626) l1 Foil spline 17pts Re6000000 N10","xver":6.991,"iver":1.2020052,"good":169.648403892695,"Cm":0.00058032061753748,"CDp":-0.000551821678917357,"CD":0.00259026504810544,"CL":-0.00249105333780283,"n":10,"Cpmin":-0.249057246304801,"CDf":0.00223,"xy":[1,0,0.913162369486509,0.0191154509787391,0.813710842258612,0.034217668148471,0.673782501507511,0.0468200245186085,0.492724758079874,0.0514083398298739,0.299655576439083,0.0463609792974277,0.141435325331645,0.0344866969599844,0.0380604371432103,0.0188049028383175,0,0,0.0380279452424157,-0.0187754769688162,0.14605649423593,-0.0350717025852793,0.312666093446018,-0.0470404130272457,0.510591162367989,-0.051480682042353,0.699485607975073,-0.045346067595135,0.843999845282038,-0.0302901102131144,0.923962179670343,-0.0170060765202265,1,0],"Bot_Xtr":0.79731325231659,"sym":1.4444323836262e-05,"alpha":0,"CDpres":0.00036,"clcd":386.060878492499,"Top_Xtr":0.791561359289573,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re6000000-N10.dat","diter":5,"src":"retestc_10.txt","Re":6000000},
             {"xy":[1,0,0.913162369486509,0.0190540108668918,0.813710842258612,0.0341076870990815,0.673782501507511,0.0466695374834706,0.492724758079874,0.0512431052166523,0.299655576439083,0.0462119677069321,0.141435325331645,0.0343758512090355,0.0380604371432103,0.0187444608777826,0,0,0.0380279452424157,-0.0186849250495967,0.14605649423593,-0.0349025558847899,0.312666093446018,-0.0468135426426708,0.510591162367989,-0.0512323967620693,0.699485607975073,-0.0451273688394861,0.843999845282038,-0.0301440245707777,0.923962179670343,-0.0169240582114583,1,0],"Bot_Xtr":0.813349315028417,"sym":1.18486023509406e-05,"alpha":0,"CDpres":0.00035,"clcd":406.924159845587,"Top_Xtr":0.810244032139804,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N7.dat","diter":3,"src":"retest_67.txt","Re":6000000,"r":6,"id":1364,"good":176.20486965127,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt162.65189326284>143.252279398219) l1 Foil spline 17pts Re2500000 N7","xver":6.991,"iver":1.2020052,"Cm":0.000154189277233399,"CDp":-0.000534436290047449,"CL":-0.000680417961357409,"CD":0.00245746037880735,"n":11,"Cpmin":-0.247005531499249,"CDf":0.00211},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt152.010645627129>97.6435267515532) l1 Foil spline 17pts Re4000000 N7","xver":6.991,"iver":1.2020052,"good":203.006629327156,"id":1365,"r":6,"Cm":-0.0122281001675503,"n":12,"CD":0.00246860691397372,"CL":-0.0258134257074518,"CDp":-0.000720654752686948,"CDf":0.00204,"Cpmin":-0.290955869033634,"sym":0.000413902458737372,"Bot_Xtr":0.78555146264936,"xy":[1,0,0.913162369486509,0.0214328164147398,0.813710842258612,0.0383658748298621,0.673782501507511,0.052496014410388,0.492724758079874,0.05764057102214,0.299655576439083,0.051981319153521,0.141435325331645,0.0386675179945384,0.0380604371432103,0.0210846205344021,0,0,0.0380279452424157,-0.0213866511372108,0.14605649423593,-0.0399492523798544,0.312666093446018,-0.0535824951043809,0.510591162367989,-0.0586402885516092,0.699485607975073,-0.0516525108636256,0.843999845282038,-0.0345026664894568,0.923962179670343,-0.0193711737046608,1,0],"clcd":405.086769521479,"CDpres":0.00043,"alpha":-0.7,"diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re4000000-N7.dat","Top_Xtr":0.853861747514061,"Re":6000000,"src":"retest_104.txt"},
             {"Cm":-0.0148660984651513,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt148.071965039792>132.817955323348) l1 Foil spline 17pts Re2000000 N6","xver":6.991,"good":222.633715019146,"iver":1.2020052,"id":1366,"Cpmin":-0.289317004299067,"CDf":0.00197,"CDp":-0.000702341499373293,"n":13,"CD":0.00240183384716477,"CL":-0.0254684394464053,"alpha":-0.8,"CDpres":0.00043,"clcd":416.348533509279,"Bot_Xtr":0.792334747430672,"xy":[1,0,0.913162369486509,0.0217095296714573,0.813710842258612,0.0388612061930182,0.673782501507511,0.0531737761581253,0.492724758079874,0.0583847527394631,0.299655576439083,0.0526524358109449,0.141435325331645,0.0391667437904582,0.0380604371432103,0.0213568383289199,0,0,0.0380279452424157,-0.0212271111479268,0.14605649423593,-0.0396512392287681,0.312666093446018,-0.0531827807853922,0.510591162367989,-0.0582028441407424,0.699485607975073,-0.0512671938274612,0.843999845282038,-0.0342452837413735,0.923962179670343,-0.0192266687597103,1,0],"sym":2.71136441808759e-05,"src":"retest_65.txt","Re":6000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2000000-N6.dat","Top_Xtr":0.867467682734556,"diter":3},
             {"Re":6000000,"src":"retest_85.txt","diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re7000000-N11.dat","Top_Xtr":0.746651646341839,"clcd":358.419289530276,"CDpres":0.00046,"alpha":0.5,"sym":9.37263290884569e-05,"xy":[1,0,0.910673421760927,0.0125317442180273,0.849186318940748,0.0250575874633567,0.695794612861528,0.0561251319002255,0.498442662240797,0.0718969172968517,0.302873885493542,0.0685727319182525,0.139977327975174,0.0511769439600028,0.0380656693660804,0.0262635411092328,0,0,0.0396582029585364,-0.0271293417769831,0.144634720957126,-0.0521774203014547,0.306852823166501,-0.0691702810487154,0.500818080902831,-0.0721857660877684,0.698940635957709,-0.0559657977021688,0.860665749892887,-0.0225915433937151,0.919783730358342,-0.0111570162076828,1,0],"Bot_Xtr":0.760485742551125,"CDf":0.00233,"Cpmin":-0.410859740679878,"n":14,"CD":0.00279002840865664,"CL":0.0568639665706589,"CDp":-9.3862520325089e-05,"Cm":-0.000621357999769682,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt145.125118273948>132.047211914936) l1 Foil spline 17pts Re7000000 N11","good":159.703776716446,"iver":1.2020052,"id":1367,"r":6},
             {"CD":0.00578507070358914,"CL":0.000183702613659328,"n":3,"CDp":0.000166765470441546,"CDf":0.0042,"Cpmin":-0.584381192644384,"id":1368,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","xver":6.991,"iver":1.2020052,"good":31.3145099878573,"r":6,"Cm":-0.00666652141171158,"diter":4,"Top_Xtr":0.518328934858273,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","Re":7000000,"src":"retest_106.txt","sym":8.14582294892033e-05,"Bot_Xtr":0.410812093705012,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"clcd":172.858734359043,"CDpres":0.00158,"alpha":-0.3},
             {"clcd":202.688754135987,"CDpres":0.00125,"alpha":0,"sym":8.14582294892033e-05,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"Bot_Xtr":0.5392607627152,"Re":7000000,"src":"retest_107.txt","diter":4,"Top_Xtr":0.535738441496051,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","Cm":0.000125538639333684,"id":1369,"good":43.8042672364842,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00368,"Cpmin":-0.58231247066957,"CD":0.00493367283381241,"CL":-0.000639187673417876,"n":4,"CDp":1.61439230218345e-05},
             {"CDf":0.00342,"Cpmin":-0.582018461047734,"CD":0.00453354312027167,"CL":-0.00774029487974555,"n":5,"CDp":-5.85293578482248e-05,"Cm":-0.000608131821320517,"id":1370,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","iver":1.2020052,"good":59.9053450189343,"r":6,"Re":7000000,"src":"retest_108.txt","diter":4,"Top_Xtr":0.580170989733044,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","CDpres":0.00111,"clcd":220.578027708287,"alpha":-0.1,"sym":8.14582294892033e-05,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"Bot_Xtr":0.566037887908174},
             {"id":1371,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1726343664041>51.9250677619875) l1 Foil spline 17pts Re7000000 N6","xver":6.991,"iver":1.2020052,"good":60.1726343666556,"r":6,"Cm":0.00241577104492364,"CD":0.00388748086749969,"CL":0.0949362766595353,"n":6,"CDp":-8.85182015371606e-05,"CDf":0.00326,"Cpmin":-0.450812211080303,"sym":0.000203316839002897,"Bot_Xtr":0.693441186370648,"xy":[1,0,0.910673421760927,0.0131319436195127,0.849186318940748,0.0262577036432368,0.695794612861528,0.0588132070786467,0.498442662240797,0.0753403714545049,0.302873885493542,0.0718569764686914,0.139977327975174,0.0536280290284689,0.0380656693660804,0.0275214156221814,0,0,0.0396582029585364,-0.0285245094593507,0.144634720957126,-0.0548607235364659,0.306852823166501,-0.0727274680049182,0.500818080902831,-0.075898028950631,0.698940635957709,-0.0588439240096133,0.860665749892887,-0.0237533478892616,0.919783730358342,-0.0117307827432873,1,0],"CDpres":0.00062,"clcd":257.235992686228,"alpha":1,"diter":8,"Top_Xtr":0.49769022297202,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re7000000-N6.dat","Re":7000000,"src":"retest_101.txt"},
             {"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt78.6427211338459>57.6985303181253) l1 Foil spline 17pts Re7000000 N7","xver":6.991,"good":78.6427211345561,"iver":1.2020052,"id":1372,"Cm":0.00149629588885912,"CDp":-0.000143461485422672,"n":7,"CD":0.00349811631058762,"CL":0.0783296958491169,"Cpmin":-0.444849223495036,"CDf":0.00296,"xy":[1,0,0.910673421760927,0.0133008506699842,0.849186318940748,0.0265954382088914,0.695794612861528,0.0595696804251867,0.498442662240797,0.0763094222129093,0.302873885493542,0.0727812227419619,0.139977327975174,0.0543178090388204,0.0380656693660804,0.027875404435432,0,0,0.0396582029585364,-0.0287960514343733,0.144634720957126,-0.0553829757855882,0.306852823166501,-0.0734198045489905,0.500818080902831,-0.0766205479727703,0.698940635957709,-0.0594040947416085,0.860665749892887,-0.0239794703054399,0.919783730358342,-0.011842455125216,1,0],"Bot_Xtr":0.711587952391969,"sym":0.000106967969585732,"alpha":0.8,"clcd":285.868139081978,"CDpres":0.00054,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re7000000-N7.dat","Top_Xtr":0.568044255399038,"diter":5,"src":"retest_90.txt","Re":7000000},
             {"src":"retest_92.txt","Re":7000000,"Top_Xtr":0.750478880004338,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N8.dat","diter":4,"alpha":-0.3,"CDpres":0.00088,"clcd":293.873211697504,"Bot_Xtr":0.721771582094731,"xy":[1,0,0.913162369486509,0.028453918015721,0.813710842258612,0.0509340179977258,0.673782501507511,0.0696930007368526,0.492724758079874,0.0765228447118775,0.299655576439083,0.069009698255341,0.141435325331645,0.051334475395,0.0380604371432103,0.027991657860974,0,0,0.0380279452424157,-0.0282352629918988,0.14605649423593,-0.0527421352711157,0.312666093446018,-0.0707411287222053,0.510591162367989,-0.0774185709839684,0.699485607975073,-0.0681931088261342,0.843999845282038,-0.0455513982063599,0.923962179670343,-0.025574372560892,1,0],"sym":0.000349355903431288,"Cpmin":-0.382535522899786,"CDf":0.00252,"CDp":-0.00161833777602039,"CD":0.00340282802309093,"CL":-0.00474357877120029,"n":8,"Cm":-0.00658782860810234,"r":6,"id":1373,"good":115.304398198627,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt115.304398195442>44.5066666593964) l1 Foil spline 17pts Re7000000 N8","xver":6.991,"iver":1.2020052},
             {"xy":[1,0,0.913162369486509,0.027817551435875,0.813710842258612,0.0497948881663569,0.673782501507511,0.0681343297484279,0.492724758079874,0.0748114255342976,0.299655576439083,0.0674663091997214,0.141435325331645,0.0501863894084846,0.0380604371432103,0.027365629643441,0,0,0.0380279452424157,-0.0277645111088732,0.14605649423593,-0.0518627930280208,0.312666093446018,-0.0695616986045226,0.510591162367989,-0.0761278113376951,0.699485607975073,-0.0670561605215094,0.843999845282038,-0.0447919433896561,0.923962179670343,-0.0251479843227625,1,0],"Bot_Xtr":0.745022706667321,"sym":0.000716732971777374,"alpha":-0.4,"CDpres":0.0008,"clcd":317.946790595723,"Top_Xtr":0.775733441987828,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N7.dat","diter":4,"src":"retest_159.txt","Re":7000000,"r":6,"id":1374,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.832735417199>73.7966339079156) l1 Foil spline 17pts Re5000000 N7","xver":6.991,"good":128.159664213475,"Cm":-0.00766197891669181,"CDp":-0.00150537039450748,"CD":0.00314518035589019,"CL":-0.0112720549076836,"n":9,"Cpmin":-0.37750749763163,"CDf":0.00235},
             {"CDpres":0.00043,"clcd":370.650457454802,"alpha":-0.2,"sym":2.53350805752694e-05,"xy":[1,0,0.913162369486509,0.021412438997227,0.813710842258612,0.03832939817488,0.673782501507511,0.0524461034148986,0.492724758079874,0.057585768799293,0.299655576439083,0.0519318975085647,0.141435325331645,0.0386307545499629,0.0380604371432103,0.0210645741668405,0,0,0.0380279452424157,-0.0210581698446901,0.14605649423593,-0.0393356648680567,0.312666093446018,-0.0527595122476706,0.510591162367989,-0.0577396221661319,0.699485607975073,-0.0508591709703639,0.843999845282038,-0.0339727340371456,0.923962179670343,-0.019073648480383,1,0],"Bot_Xtr":0.764654115752211,"Re":7000000,"src":"retest_83.txt","diter":4,"Top_Xtr":0.782184021736714,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N8.dat","Cm":-0.00438674026918349,"id":1375,"good":149.950116794685,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt179.604294799114>164.472076296931) l1 Foil spline 17pts Re2500000 N8","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00227,"Cpmin":-0.281086842689066,"CL":-0.0036320887133563,"CD":0.0026979597080949,"n":10,"CDp":-0.000688777422447249},
             {"src":"retest_69.txt","Re":7000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N9.dat","Top_Xtr":0.797444730267901,"diter":4,"alpha":-0.1,"CDpres":0.00034,"clcd":402.472395785443,"Bot_Xtr":0.788615676340373,"xy":[1,0,0.913162369486509,0.0193776932184914,0.813710842258612,0.0346870956259778,0.673782501507511,0.0474623419877947,0.492724758079874,0.0521136037649978,0.299655576439083,0.0469969991884357,0.141435325331645,0.0349598152067107,0.0380604371432103,0.0190628847108942,0,0,0.0380279452424157,-0.0187799099415963,0.14605649423593,-0.0350799831686792,0.312666093446018,-0.0470515194758787,0.510591162367989,-0.0514928368580508,0.699485607975073,-0.0453567740013513,0.843999845282038,-0.030297261841502,0.923962179670343,-0.0170100917297701,1,0],"sym":0.000159533599296801,"Cpmin":-0.251456855169962,"CDf":0.00214,"CDp":-0.000554244148775252,"n":11,"CD":0.00248464245118837,"CL":-0.00363825602894043,"Cm":-0.00170658928498444,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt154.011715822924>96.0139234956795) l1 Foil spline 17pts Re5000000 N9","xver":6.991,"good":156.180762844268,"id":1376},
             {"CDp":-0.000542233370356307,"CD":0.00237482876521229,"CL":-0.00309672266002675,"n":12,"Cpmin":-0.251601019632695,"CDf":0.00204,"r":6,"id":1377,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt154.011715822924>96.0139234956795) l1 Foil spline 17pts Re5000000 N9","good":182.995821897953,"iver":1.2020052,"Cm":-0.00183898597156916,"Top_Xtr":0.813224713212907,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N9.dat","diter":4,"src":"retest_70.txt","Re":7000000,"xy":[1,0,0.913162369486509,0.0193776932184914,0.813710842258612,0.0346870956259778,0.673782501507511,0.0474623419877947,0.492724758079874,0.0521136037649978,0.299655576439083,0.0469969991884357,0.141435325331645,0.0349598152067107,0.0380604371432103,0.0190628847108942,0,0,0.0380279452424157,-0.0187799099415963,0.14605649423593,-0.0350799831686792,0.312666093446018,-0.0470515194758787,0.510591162367989,-0.0514928368580508,0.699485607975073,-0.0453567740013513,0.843999845282038,-0.030297261841502,0.923962179670343,-0.0170100917297701,1,0],"Bot_Xtr":0.803964112927171,"sym":0.000159533599296801,"alpha":-0.1,"clcd":421.082991181728,"CDpres":0.00033},
             {"sym":4.02815166606564e-05,"Bot_Xtr":0.81662141240352,"xy":[1,0,0.913162369486509,0.0191517322848922,0.813710842258612,0.0342826136051763,0.673782501507511,0.0469088893665028,0.492724758079874,0.0515059133434817,0.299655576439083,0.0464489728731649,0.141435325331645,0.0345521530359099,0.0380604371432103,0.0188405947211726,0,0,0.0380279452424157,-0.0186838155819723,0.14605649423593,-0.0349004834517638,0.312666093446018,-0.0468107629628055,0.510591162367989,-0.0512293547008688,0.699485607975073,-0.0451246892807204,0.843999845282038,-0.0301422346883328,0.923962179670343,-0.0169230533000332,1,0],"CDpres":0.00032,"clcd":439.415305356225,"alpha":-0.1,"diter":3,"Top_Xtr":0.826647951739022,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N10.dat","Re":7000000,"src":"retest_70.txt","id":1378,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt187.482230927312>157.096800504803) l1 Foil spline 17pts Re5000000 N10","good":205.69479296,"iver":1.2020052,"r":6,"Cm":-0.00142084316261155,"CD":0.00227575140831592,"CL":-0.00494564966637642,"n":13,"CDp":-0.000524532849295856,"CDf":0.00195,"Cpmin":-0.248086472758756},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca001066.dat-s17_n17s0.dat (opt165.279595738441>142.862432350544) l1 Foil spline 17pts Re4000000 N12","good":104.414735444379,"xver":6.991,"iver":1.2020052,"id":1379,"r":6,"Cm":-0.00251146263211953,"n":14,"CD":0.0024710398003454,"CL":-0.000751266613537102,"CDp":-0.000749880759613035,"CDf":0.0021,"Cpmin":-0.307916111318192,"sym":3.15652220280815e-05,"Bot_Xtr":0.796275037533728,"xy":[1,0,0.884615607831572,0.0239762251996759,0.71311306945101,0.0371823534054503,0.441045312523178,0.0374067193362537,0.244177459414419,0.0335447185129254,0.143733883449667,0.0290881399370605,0.084559753204033,0.0245518161274326,0.0249274401675381,0.0155796070892762,0,0,0.0231037840650006,-0.0151051247668549,0.0714830670908357,-0.0231894617932584,0.144140580017158,-0.0293966077438102,0.281976243120757,-0.0348508810100034,0.499922389643121,-0.0381774747831776,0.732768656055785,-0.0368138880613076,0.891593565155033,-0.0230906020940211,1,0],"clcd":404.6879373858,"CDpres":0.00037,"alpha":-0.1,"diter":10,"Foil_fn":"optbs_spline_sym_naca001066.dat-s17_n17s0_nsopt-Re4000000-N12.dat","Top_Xtr":0.807094540078354,"Re":7000000,"src":"retest_84.txt"},
             {"src":"retest_108.txt","Re":8192000,"Top_Xtr":0.278361581875106,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N5.dat","diter":4,"alpha":1.3,"clcd":173.956895021201,"CDpres":0.00136,"Bot_Xtr":0.550757811599333,"xy":[1,0,0.910673421760927,0.0154762291440661,0.849186318940748,0.0309451708105029,0.695794612861528,0.069312410700125,0.498442662240797,0.0887899678990738,0.302873885493542,0.0846847249463371,0.139977327975174,0.0632015861350474,0.0380656693660804,0.0324344778563531,0,0,0.0396582029585364,-0.0336034992758357,0.144634720957126,-0.0646290617637641,0.306852823166501,-0.0856771059260227,0.500818080902831,-0.089412207579395,0.698940635957709,-0.0693214991361109,0.860665749892887,-0.0279827987833746,0.919783730358342,-0.0138195312343861,1,0],"sym":0.000262698448801819,"Cpmin":-0.528039433753957,"CDf":0.00439,"CDp":0.000264651427764629,"CL":0.0997411636133615,"CD":0.00574855052384169,"n":3,"Cm":0.00778058073287587,"r":6,"id":1380,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt43.2056215540169>28.8981055342443) l1 Foil spline 17pts Re8192000 N5","xver":6.991,"good":18.1268047113119},
             {"CDf":0.00397,"Cpmin":-0.540232101890574,"n":4,"CL":-0.0797192703084327,"CD":0.0051852913432086,"CDp":0.000146210133714225,"Cm":-0.00552193389905607,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt53.8397164573885>29.101597490812) l1 Foil spline 17pts Re13000000 N7","iver":1.2020052,"xver":6.991,"good":29.467197778964,"id":1381,"r":6,"Re":8192000,"src":"retest_78.txt","diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.580133320570216,"clcd":192.853194509455,"CDpres":0.00122,"alpha":-1,"sym":0.000178743568622424,"xy":[1,0,0.910673421760927,0.0160297874819887,0.849186318940748,0.0320520268256944,0.695794612861528,0.0717915974908736,0.498442662240797,0.0919658337121781,0.302873885493542,0.0877137532162304,0.139977327975174,0.0654621991467383,0.0380656693660804,0.0335946038461154,0,0,0.0396582029585364,-0.0347266127131365,0.144634720957126,-0.0667891275090369,0.306852823166501,-0.0885406502296888,0.500818080902831,-0.0924005883717301,0.698940635957709,-0.0716383979368734,0.860665749892887,-0.0289180542777181,0.919783730358342,-0.0142814147156014,1,0],"Bot_Xtr":0.374821400758366},
             {"Cm":-0.00264509948621992,"r":6,"id":1382,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt43.2056215540169>28.8981055342443) l1 Foil spline 17pts Re8192000 N5","good":43.2056215773878,"iver":1.2020052,"Cpmin":-0.52576313505089,"CDf":0.00365,"CDp":5.91201040844646e-05,"CL":-0.0833082772288087,"CD":0.00463452876845483,"n":5,"alpha":-0.9,"CDpres":0.00099,"clcd":215.771667403718,"Bot_Xtr":0.445057281293759,"xy":[1,0,0.910673421760927,0.0154762291440661,0.849186318940748,0.0309451708105029,0.695794612861528,0.069312410700125,0.498442662240797,0.0887899678990738,0.302873885493542,0.0846847249463371,0.139977327975174,0.0632015861350474,0.0380656693660804,0.0324344778563531,0,0,0.0396582029585364,-0.0336034992758357,0.144634720957126,-0.0646290617637641,0.306852823166501,-0.0856771059260227,0.500818080902831,-0.089412207579395,0.698940635957709,-0.0693214991361109,0.860665749892887,-0.0279827987833746,0.919783730358342,-0.0138195312343861,1,0],"sym":0.000262698448801819,"src":"retest_110.txt","Re":8192000,"Top_Xtr":0.602741752495047,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N5.dat","diter":3},
             {"xy":[1,0,0.910673421760927,0.0154762291440661,0.849186318940748,0.0309451708105029,0.695794612861528,0.069312410700125,0.498442662240797,0.0887899678990738,0.302873885493542,0.0846847249463371,0.139977327975174,0.0632015861350474,0.0380656693660804,0.0324344778563531,0,0,0.0396582029585364,-0.0336034992758357,0.144634720957126,-0.0646290617637641,0.306852823166501,-0.0856771059260227,0.500818080902831,-0.089412207579395,0.698940635957709,-0.0693214991361109,0.860665749892887,-0.0279827987833746,0.919783730358342,-0.0138195312343861,1,0],"Bot_Xtr":0.63533722883621,"sym":0.000262698448801819,"alpha":0.9,"clcd":240.981511775108,"CDpres":0.00083,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N5.dat","Top_Xtr":0.506568104639379,"diter":3,"src":"retest_111.txt","Re":8192000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt43.2056215540169>28.8981055342443) l1 Foil spline 17pts Re8192000 N5","good":56.5757338429846,"iver":1.2020052,"id":1383,"Cm":0.00271936104198062,"CDp":-4.34773116639417e-05,"n":6,"CL":0.0824038689697154,"CD":0.00414969593573317,"Cpmin":-0.527061430122234,"CDf":0.00332},
             {"Cm":0.000864252132272541,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt56.8918830711609>40.8855049514154) l1 Foil spline 17pts Re13000000 N8","xver":6.991,"iver":1.2020052,"good":66.0507619164849,"id":1384,"r":6,"CDf":0.00304,"Cpmin":-0.474524835436249,"n":7,"CD":0.00363693320513236,"CL":0.103010143373546,"CDp":-0.000113395508247836,"CDpres":0.0006,"clcd":274.956933107494,"alpha":1,"sym":0.000149457883209312,"xy":[1,0,0.910673421760927,0.0138728376042232,0.849186318940748,0.0277391427390215,0.695794612861528,0.0621314022071542,0.498442662240797,0.079591016266409,0.302873885493542,0.0759110908608696,0.139977327975174,0.0566536804682173,0.0380656693660804,0.0290741523591023,0,0,0.0396582029585364,-0.0296775786343715,0.144634720957126,-0.0570784026632316,0.306852823166501,-0.0756673889053383,0.500818080902831,-0.0789661159847838,0.698940635957709,-0.0612226192509615,0.860665749892887,-0.0247135485648835,0.919783730358342,-0.0122049856037931,1,0],"Bot_Xtr":0.696528824266088,"Re":8192000,"src":"retest_80.txt","diter":8,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N8.dat","Top_Xtr":0.529570906928408},
             {"alpha":0.8,"clcd":287.108350766559,"CDpres":0.00067,"Bot_Xtr":0.706585855164552,"xy":[1,0,0.910673421760927,0.0160297874819887,0.849186318940748,0.0320520268256944,0.695794612861528,0.0717915974908736,0.498442662240797,0.0919658337121781,0.302873885493542,0.0877137532162304,0.139977327975174,0.0654621991467383,0.0380656693660804,0.0335946038461154,0,0,0.0396582029585364,-0.0347266127131365,0.144634720957126,-0.0667891275090369,0.306852823166501,-0.0885406502296888,0.500818080902831,-0.0924005883717301,0.698940635957709,-0.0716383979368734,0.860665749892887,-0.0289180542777181,0.919783730358342,-0.0142814147156014,1,0],"sym":0.000178743568622424,"src":"retest_82.txt","Re":8192000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.581155241503347,"diter":4,"Cm":0.00265587110941049,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt53.8397164573885>29.101597490812) l1 Foil spline 17pts Re13000000 N7","xver":6.991,"good":88.484997368919,"id":1385,"Cpmin":-0.538821661918229,"CDf":0.00281,"CDp":-0.000160848702825906,"n":8,"CD":0.00348300562254657,"CL":0.0723378144577019},
             {"alpha":-0.1,"CDpres":0.00081,"clcd":310.38739407522,"Bot_Xtr":0.73887710758944,"xy":[1,0,0.913162369486509,0.027817551435875,0.813710842258612,0.0497948881663569,0.673782501507511,0.0681343297484279,0.492724758079874,0.0748114255342976,0.299655576439083,0.0674663091997214,0.141435325331645,0.0501863894084846,0.0380604371432103,0.027365629643441,0,0,0.0380279452424157,-0.0277645111088732,0.14605649423593,-0.0518627930280208,0.312666093446018,-0.0695616986045226,0.510591162367989,-0.0761278113376951,0.699485607975073,-0.0670561605215094,0.843999845282038,-0.0447919433896561,0.923962179670343,-0.0251479843227625,1,0],"sym":0.000716732971777374,"src":"retest_67.txt","Re":8192000,"Top_Xtr":0.734034480082133,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N7.dat","diter":3,"Cm":-0.000699590950911825,"r":6,"id":1386,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.832735417199>73.7966339079156) l1 Foil spline 17pts Re5000000 N7","xver":6.991,"good":109.001588580417,"Cpmin":-0.377181218015122,"CDf":0.00242,"CDp":-0.00149494060994808,"CL":-0.00827116781383893,"CD":0.00322178032706334,"n":9},
             {"sym":1.91925477398936e-05,"Bot_Xtr":0.750935649961417,"xy":[1,0,0.913162369486509,0.021539191372516,0.813710842258612,0.0385562916297869,0.673782501507511,0.0527565616575748,0.492724758079874,0.0579266516374928,0.299655576439083,0.0522393118747342,0.141435325331645,0.0388594319042357,0.0380604371432103,0.0211892673328289,0,0,0.0380279452424157,-0.021160240854982,0.14605649423593,-0.0395263286856247,0.312666093446018,-0.0530152427673379,0.510591162367989,-0.058019491765999,0.699485607975073,-0.0511056903498654,0.843999845282038,-0.0341374032040829,0.923962179670343,-0.0191661003213883,1,0],"CDpres":0.00044,"clcd":357.715128517245,"alpha":0,"diter":5,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re8192000-N10.dat","Top_Xtr":0.741097663124297,"Re":8192000,"src":"retestc_6.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt124.178877069878>89.1540023126822) l1 Foil spline 17pts Re8192000 N10","iver":1.2020052,"good":124.178877036057,"id":1387,"r":6,"Cm":0.00160549020141493,"n":10,"CL":-0.00675965698342567,"CD":0.00279552057008344,"CDp":-0.00068840128848902,"CDf":0.00235,"Cpmin":-0.284284735177649},
             {"Cm":-0.00186855191978586,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt151.804676818436>113.046316185753) l1 Foil spline 17pts Re8192000 N11","iver":1.2020052,"xver":6.991,"good":151.804676817265,"id":1388,"Cpmin":-0.275662785508316,"CDf":0.00219,"CDp":-0.000639846669521072,"n":11,"CD":0.00258732012279297,"CL":-0.00284018100513554,"alpha":-0.1,"CDpres":0.0004,"clcd":386.50029858714,"Bot_Xtr":0.767486369261069,"xy":[1,0,0.913162369486509,0.0211759954930003,0.813710842258612,0.0379061517982976,0.673782501507511,0.0518669755315192,0.492724758079874,0.056949886965829,0.299655576439083,0.0513584476633763,0.141435325331645,0.038204180492804,0.0380604371432103,0.0208319719055242,0,0,0.0380279452424157,-0.0204238232588127,0.14605649423593,-0.0381507354607861,0.312666093446018,-0.0511702090597058,0.510591162367989,-0.0560003004462923,0.699485607975073,-0.0493271127856521,0.843999845282038,-0.0329493550821687,0.923962179670343,-0.0184990826998335,1,0],"sym":0.000361831036318983,"src":"retestc_7.txt","Re":8192000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re8192000-N11.dat","Top_Xtr":0.774346537589248,"diter":5},
             {"Cpmin":-0.252421331321852,"CDf":0.00208,"CDp":-0.000552424541454465,"CL":0.00292109037387064,"CD":0.002407008328406,"n":12,"Cm":-0.000672874521127847,"r":6,"id":1389,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt154.011715822924>96.0139234956795) l1 Foil spline 17pts Re5000000 N9","iver":1.2020052,"xver":6.991,"good":172.86287149179,"src":"retest_82.txt","Re":8192000,"Top_Xtr":0.786089505582634,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N9.dat","diter":4,"alpha":0,"CDpres":0.00033,"clcd":415.453485639675,"Bot_Xtr":0.791315074133844,"xy":[1,0,0.913162369486509,0.0193776932184914,0.813710842258612,0.0346870956259778,0.673782501507511,0.0474623419877947,0.492724758079874,0.0521136037649978,0.299655576439083,0.0469969991884357,0.141435325331645,0.0349598152067107,0.0380604371432103,0.0190628847108942,0,0,0.0380279452424157,-0.0187799099415963,0.14605649423593,-0.0350799831686792,0.312666093446018,-0.0470515194758787,0.510591162367989,-0.0514928368580508,0.699485607975073,-0.0453567740013513,0.843999845282038,-0.030297261841502,0.923962179670343,-0.0170100917297701,1,0],"sym":0.000159533599296801},
             {"src":"retest_97.txt","Re":8192000,"Top_Xtr":0.609815885449572,"Foil_fn":"optbs_spline_sym_n66021.dat-s17_n17s0_nsopt-Re13000000-N10.dat","diter":3,"alpha":4.3,"CDpres":0.00135,"clcd":128.275811208158,"Bot_Xtr":0.685241208343708,"xy":[1,0,0.91221192907363,0.0188164339450754,0.734521294155728,0.080807038311867,0.595398618250498,0.117856412797764,0.426150873151079,0.125575967241254,0.247961170452198,0.107498972334824,0.108768025340124,0.0712154458268436,0.0274552076733582,0.0321148405047466,0,0,0.0107467209884378,-0.0350065167445476,0.0754785878921827,-0.0737558761804931,0.190099935807211,-0.108856475841118,0.339568554063187,-0.130684010063703,0.507337345622005,-0.133103713537466,0.66391387623878,-0.108162713974077,0.90508274684817,-0.022612254278664,1,0],"sym":0.118095470681182,"Cpmin":-1.05403127509172,"CDf":0.00262,"CDp":-0.000256287821819171,"CL":0.509619304803368,"CD":0.00397284024169132,"n":13,"Cm":-0.0135313618271234,"r":6,"id":1390,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_n66021.dat-s17_n17s0.dat (opt119.695715540161>102.989978677505) l1 Foil spline 17pts Re13000000 N10","iver":1.2020052,"xver":6.991,"good":31.0311954168373},
             {"CDp":-0.000171883791913606,"n":14,"CD":0.00264601482653473,"CL":0.0460795622300266,"Cpmin":-0.467719074208225,"CDf":0.00222,"r":6,"good":162.466121919888,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt140.153193061032>122.222167846533) l1 Foil spline 17pts Re10000000 N12","xver":6.991,"iver":1.2020052,"id":1391,"Cm":-0.000680346273812074,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N12.dat","Top_Xtr":0.728942897527722,"diter":3,"src":"retest_151.txt","Re":8192000,"xy":[1,0,0.910673421760927,0.0142936372940059,0.849186318940748,0.0285805439715901,0.695794612861528,0.064016011219414,0.498442662240797,0.0820052213418147,0.302873885493542,0.078213674109995,0.139977327975174,0.0583721357580578,0.0380656693660804,0.0299560479483422,0,0,0.0396582029585364,-0.0308701649557934,0.144634720957126,-0.0593720844727693,0.306852823166501,-0.0787080646322221,0.500818080902831,-0.0821393502617272,0.698940635957709,-0.0636828354020108,0.860665749892887,-0.0257066565382591,0.919783730358342,-0.0126954399991318,1,0],"Bot_Xtr":0.741424155085995,"sym":7.26514479541518e-05,"alpha":0.4,"CDpres":0.00043,"clcd":377.926831691121},
             {"Re":10000000,"src":"retest_150.txt","diter":4,"Top_Xtr":0.378362916176601,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","clcd":160.83135106839,"CDpres":0.00202,"alpha":0.5,"sym":0.000990696463258582,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"Bot_Xtr":0.394551159767438,"CDf":0.0042,"Cpmin":-1.08542419383447,"CL":0.0545140570662119,"CD":0.00621769321315202,"n":3,"CDp":0.000446863884287687,"Cm":6.01603935779802e-05,"id":1392,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"good":19.4242777955386,"r":6},
             {"Re":10000000,"src":"retest_105.txt","diter":5,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re30000000-N11.dat","Top_Xtr":0.52975483119863,"clcd":177.528139432856,"CDpres":0.00174,"alpha":-0.5,"sym":0.00057709854695603,"xy":[1,0,0.910673421760927,0.0203623790435987,0.849186318940748,0.0407151698095633,0.695794612861528,0.0911957018704826,0.498442662240797,0.116822706926843,0.302873885493542,0.111421358039363,0.139977327975174,0.0831555698134592,0.0380656693660804,0.0426746803788114,0,0,0.0396582029585364,-0.0434244814899449,0.144634720957126,-0.0835175965823067,0.306852823166501,-0.110717156860864,0.500818080902831,-0.115543881937278,0.698940635957709,-0.0895814489848668,0.860665749892887,-0.0361610711381868,0.919783730358342,-0.0178584371038659,1,0],"Bot_Xtr":0.41533793745348,"CDf":0.00389,"Cpmin":-0.682434996427627,"n":4,"CD":0.00563290982035114,"CL":0.0315704758450004,"CDp":-0.000153831606871146,"Cm":-0.0178995834714179,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt61.637674525234>20.9692188621533) l1 Foil spline 17pts Re30000000 N11","iver":1.2020052,"good":34.0110322892033,"id":1393,"r":6},
             {"CDf":0.00374,"Cpmin":-0.542753589052602,"CL":0.090102664617608,"CD":0.00486418992423722,"n":5,"CDp":0.000112984059946063,"Cm":0.0054805324863557,"id":1394,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt53.8397164573885>29.101597490812) l1 Foil spline 17pts Re13000000 N7","iver":1.2020052,"xver":6.991,"good":30.9003894596786,"r":6,"Re":10000000,"src":"retest_90.txt","diter":3,"Top_Xtr":0.390529011790517,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N7.dat","CDpres":0.00112,"clcd":205.584077837342,"alpha":1.1,"sym":0.000178743568622424,"xy":[1,0,0.910673421760927,0.0160297874819887,0.849186318940748,0.0320520268256944,0.695794612861528,0.0717915974908736,0.498442662240797,0.0919658337121781,0.302873885493542,0.0877137532162304,0.139977327975174,0.0654621991467383,0.0380656693660804,0.0335946038461154,0,0,0.0396582029585364,-0.0347266127131365,0.144634720957126,-0.0667891275090369,0.306852823166501,-0.0885406502296888,0.500818080902831,-0.0924005883717301,0.698940635957709,-0.0716383979368734,0.860665749892887,-0.0289180542777181,0.919783730358342,-0.0142814147156014,1,0],"Bot_Xtr":0.586748461690551},
             {"Re":10000000,"src":"retest_73.txt","diter":4,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Top_Xtr":0.614291537337973,"clcd":225.731088892586,"CDpres":0.00103,"alpha":-1.1,"sym":7.36215012470816e-05,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"Bot_Xtr":0.466148155957462,"CDf":0.0034,"Cpmin":-0.579774948601212,"n":6,"CL":-0.097154420384798,"CD":0.00443004995415518,"CDp":-7.60969785093242e-06,"Cm":-0.00410200321947963,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","good":51.8723257789686,"iver":1.2020052,"id":1395,"r":6},
             {"n":7,"CL":0.0192592761085283,"CD":0.00384936081227708,"CDp":-4.98104276417175e-05,"CDf":0.00325,"Cpmin":-0.410686686466121,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt63.3151811470369>51.8407949487457) l1 Foil spline 17pts Re5000000 N5","good":57.1303127954157,"xver":6.991,"iver":1.2020052,"id":1396,"r":6,"Cm":0.000405886999914813,"diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re5000000-N5.dat","Top_Xtr":0.54635450605917,"Re":10000000,"src":"retest_105.txt","sym":0.000107533783001579,"Bot_Xtr":0.571411879247311,"xy":[1,0,0.910673421760927,0.0129674132871274,0.849186318940748,0.0259287204528371,0.695794612861528,0.0580763354631672,0.498442662240797,0.0743964307312883,0.302873885493542,0.0709566792571629,0.139977327975174,0.0529561225920057,0.0380656693660804,0.027176599364114,0,0,0.0396582029585364,-0.0280813797942241,0.144634720957126,-0.0540084594831974,0.306852823166501,-0.071597643192735,0.500818080902831,-0.0747189493173565,0.698940635957709,-0.0579297807400059,0.860665749892887,-0.0233843384550834,0.919783730358342,-0.0115485444532261,1,0],"clcd":259.78338970216,"CDpres":0.00059,"alpha":0.2},
             {"src":"retestc_14.txt","Re":10000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","Top_Xtr":0.543486947532213,"diter":5,"alpha":1.2,"CDpres":0.0007,"clcd":283.424471094612,"Bot_Xtr":0.702564567445402,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"sym":0.000250140694931259,"Cpmin":-0.554006886889412,"CDf":0.00283,"CDp":-0.000141911586445869,"n":8,"CD":0.00352827684969441,"CL":0.113685539652637,"Cm":0.00289282854688755,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","good":76.6295329106654,"xver":6.991,"iver":1.2020052,"id":1397},
             {"sym":0.000149457883209312,"Bot_Xtr":0.714483958754775,"xy":[1,0,0.910673421760927,0.0138728376042232,0.849186318940748,0.0277391427390215,0.695794612861528,0.0621314022071542,0.498442662240797,0.079591016266409,0.302873885493542,0.0759110908608696,0.139977327975174,0.0566536804682173,0.0380656693660804,0.0290741523591023,0,0,0.0396582029585364,-0.0296775786343715,0.144634720957126,-0.0570784026632316,0.306852823166501,-0.0756673889053383,0.500818080902831,-0.0789661159847838,0.698940635957709,-0.0612226192509615,0.860665749892887,-0.0247135485648835,0.919783730358342,-0.0122049856037931,1,0],"clcd":306.534517179119,"CDpres":0.00052,"alpha":1,"diter":4,"Top_Xtr":0.561329635119217,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N8.dat","Re":10000000,"src":"retestc_2.txt","id":1398,"good":82.2988248438185,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt56.8918830711609>40.8855049514154) l1 Foil spline 17pts Re13000000 N8","xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000270321716945423,"CD":0.00326227535222621,"CL":0.106035369450924,"n":9,"CDp":-0.000144948378139623,"CDf":0.00274,"Cpmin":-0.474875710447626},
             {"CDp":-0.00153111733197091,"n":10,"CL":-0.00644770203965951,"CD":0.00314065170124636,"Cpmin":-0.37734630861904,"CDf":0.00235,"r":6,"good":109.243174871385,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt104.366457223021>63.39957801653) l1 Foil spline 17pts Re2500000 N4","xver":6.991,"iver":1.2020052,"id":1399,"Cm":0.00158859027327253,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re2500000-N4.dat","Top_Xtr":0.722087267067684,"diter":4,"src":"retest_94.txt","Re":10000000,"xy":[1,0,0.913162369486509,0.0285583118429417,0.813710842258612,0.0511208884691867,0.673782501507511,0.0699486955439224,0.492724758079874,0.0768035973528624,0.299655576439083,0.0692628861120092,0.141435325331645,0.0515228150940139,0.0380604371432103,0.0280943557141393,0,0,0.0380279452424157,-0.02760515589807,0.14605649423593,-0.0515651250343934,0.312666093446018,-0.069162447232817,0.510591162367989,-0.0756908735729301,0.699485607975073,-0.0666712897577615,0.843999845282038,-0.0445348587410861,0.923962179670343,-0.0250036467427736,1,0],"Bot_Xtr":0.735953011372867,"sym":0.000502024749331122,"alpha":0,"CDpres":0.0008,"clcd":318.405253152762},
             {"CDp":-0.0015633225597297,"CL":-0.00862116641337595,"CD":0.00295989631985633,"n":11,"Cpmin":-0.384325370276191,"CDf":0.00219,"r":6,"id":1400,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt115.304398195442>44.5066666593964) l1 Foil spline 17pts Re7000000 N8","xver":6.991,"iver":1.2020052,"good":138.471003329481,"Cm":-0.00570340313014128,"Top_Xtr":0.760074523456904,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re7000000-N8.dat","diter":4,"src":"retest_152.txt","Re":10000000,"xy":[1,0,0.913162369486509,0.028453918015721,0.813710842258612,0.0509340179977258,0.673782501507511,0.0696930007368526,0.492724758079874,0.0765228447118775,0.299655576439083,0.069009698255341,0.141435325331645,0.051334475395,0.0380604371432103,0.027991657860974,0,0,0.0380279452424157,-0.0282352629918988,0.14605649423593,-0.0527421352711157,0.312666093446018,-0.0707411287222053,0.510591162367989,-0.0774185709839684,0.699485607975073,-0.0681931088261342,0.843999845282038,-0.0455513982063599,0.923962179670343,-0.025574372560892,1,0],"Bot_Xtr":0.742618265363737,"sym":0.000349355903431288,"alpha":-0.3,"clcd":337.849671723818,"CDpres":0.00077},
             {"src":"retest_86.txt","Re":10000000,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N8.dat","Top_Xtr":0.759108183109021,"diter":4,"alpha":0,"CDpres":0.00044,"clcd":389.42228476138,"Bot_Xtr":0.766537877456158,"xy":[1,0,0.913162369486509,0.0227729539364055,0.813710842258612,0.040764791865127,0.673782501507511,0.0557784518319523,0.492724758079874,0.0612446840095436,0.299655576439083,0.0552315740372142,0.141435325331645,0.0410852959818739,0.0380604371432103,0.022402986285382,0,0,0.0380279452424157,-0.0218785018925023,0.14605649423593,-0.0408680063180143,0.312666093446018,-0.0548147867108793,0.510591162367989,-0.0599888994224547,0.699485607975073,-0.0528404166427017,0.843999845282038,-0.0352961597046187,0.923962179670343,-0.0198166724578968,1,0],"sym":0.000626233944886703,"Cpmin":-0.29665492479265,"CDf":0.00213,"CDp":-0.000766687598447509,"n":12,"CD":0.00256790645818524,"CL":-0.000622428327602821,"Cm":0.000233636351322535,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt150.322790998904>108.456421412499) l1 Foil spline 17pts Re5000000 N8","iver":1.2020052,"xver":6.991,"good":146.279024557411,"id":1401},
             {"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N6.dat","Top_Xtr":0.77448884023219,"diter":4,"src":"retest_92.txt","Re":10000000,"xy":[1,0,0.913162369486509,0.0192004915234514,0.813710842258612,0.0343698952207679,0.673782501507511,0.0470283167735457,0.492724758079874,0.0516370445162947,0.299655576439083,0.0465672293585553,0.141435325331645,0.0346401208838073,0.0380604371432103,0.0188885618209075,0,0,0.0380279452424157,-0.0190612524771997,0.14605649423593,-0.035605517713003,0.312666093446018,-0.0477564000548859,0.510591162367989,-0.0522642529794331,0.699485607975073,-0.0460362655348046,0.843999845282038,-0.0307511462581385,0.923962179670343,-0.0172649205523248,1,0],"Bot_Xtr":0.778518562876739,"sym":0.000170221802984099,"alpha":0,"CDpres":0.00032,"clcd":423.374092130016,"CDp":-0.000553089756599746,"n":13,"CL":-0.00411408927042825,"CD":0.00236197731176452,"Cpmin":-0.253654128313215,"CDf":0.00205,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt60.6753358678865>37.2063036526446) l1 Foil spline 17pts Re5000000 N6","xver":6.991,"good":157.425110524648,"iver":1.2020052,"id":1402,"Cm":0.000929785262464974},
             {"Cm":0.000126502480470132,"r":6,"id":1403,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","good":154.923063079878,"xver":6.991,"iver":1.2020052,"Cpmin":-0.542675218237347,"CDf":0.00218,"CDp":-0.000237992638979949,"CL":-0.0112311111395775,"CD":0.00266048747711686,"n":14,"alpha":-0.1,"CDpres":0.00048,"clcd":375.870966731138,"Bot_Xtr":0.716710974908114,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"sym":7.36215012470816e-05,"src":"retest_81.txt","Re":10000000,"Top_Xtr":0.71748268921632,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","diter":3},
             {"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re13000000-N3.dat","Top_Xtr":0.31349167705274,"diter":3,"src":"retestc_19.txt","Re":13000000,"xy":[1,0,0.934059429447841,0.0214982346490348,0.803112667984734,0.0524752948222562,0.640336773132615,0.09288580067504,0.409507830013704,0.144813746221689,0.253558173430737,0.152619700296329,0.123492454733844,0.122295002874509,0.0350150102873282,0.0667399664410622,0,0,0.033652356669074,-0.0643356024248087,0.123386675148442,-0.121421031074122,0.261115618487171,-0.151972683576315,0.416397663171949,-0.142241496798142,0.629871409666205,-0.0945792249635018,0.80244136469583,-0.0521842765797054,0.93425668155926,-0.0212406048482992,1,0],"Bot_Xtr":0.324641303630167,"sym":0.000954205432861013,"alpha":0.2,"clcd":151.013957792065,"CDpres":0.00198,"CDp":-0.00108163307190929,"n":3,"CL":0.0100311375268645,"CD":0.00662190445585781,"Cpmin":-1.24167764199904,"CDf":0.00464,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt14.3818030575382>13.3942518623213) l1 Foil spline 17pts Re13000000 N3","good":14.3818030576805,"xver":6.991,"iver":1.2020052,"id":1404,"Cm":0.00316905018215346},
             {"Re":13000000,"src":"retest_67.txt","diter":3,"Top_Xtr":0.393801312732227,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","CDpres":0.00181,"clcd":173.600380019852,"alpha":0.2,"sym":0.000990696463258582,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"Bot_Xtr":0.394185877643021,"CDf":0.00395,"Cpmin":-1.0604047533324,"CL":0.0216730084749302,"CD":0.00576035605386142,"n":4,"CDp":0.000366929524993722,"Cm":5.61377563144253e-05,"id":1405,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"iver":1.2020052,"good":22.9937030150165,"r":6},
             {"Cpmin":-0.576848421805813,"CDf":0.00383,"CDp":0.000154264801062893,"n":5,"CL":0.096756556930825,"CD":0.00511786803458967,"Cm":0.00635389948368716,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","good":28.3054678255564,"xver":6.991,"iver":1.2020052,"id":1406,"src":"retest_82.txt","Re":13000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Top_Xtr":0.351164248506815,"diter":5,"alpha":1.2,"clcd":195.393861905268,"CDpres":0.00128,"Bot_Xtr":0.546511792778346,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"sym":7.36215012470816e-05},
             {"src":"retest_86.txt","Re":13000000,"Top_Xtr":0.431337838659985,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re30000000-N11.dat","diter":3,"alpha":1.2,"CDpres":0.00146,"clcd":203.915021530254,"Bot_Xtr":0.58730216520106,"xy":[1,0,0.910673421760927,0.0203623790435987,0.849186318940748,0.0407151698095633,0.695794612861528,0.0911957018704826,0.498442662240797,0.116822706926843,0.302873885493542,0.111421358039363,0.139977327975174,0.0831555698134592,0.0380656693660804,0.0426746803788114,0,0,0.0396582029585364,-0.0434244814899449,0.144634720957126,-0.0835175965823067,0.306852823166501,-0.110717156860864,0.500818080902831,-0.115543881937278,0.698940635957709,-0.0895814489848668,0.860665749892887,-0.0361610711381868,0.919783730358342,-0.0178584371038659,1,0],"sym":0.00057709854695603,"Cpmin":-0.671072820449235,"CDf":0.00345,"CDp":-0.000447774864908894,"CL":0.0321202446342556,"CD":0.00490400360157692,"n":6,"Cm":0.0204689595630377,"r":6,"id":1407,"good":44.8293359029469,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt61.637674525234>20.9692188621533) l1 Foil spline 17pts Re30000000 N11","xver":6.991,"iver":1.2020052},
             {"Re":13000000,"src":"retest_103.txt","diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N7.dat","Top_Xtr":0.518372009219308,"clcd":237.664166918601,"CDpres":0.00089,"alpha":0,"sym":0.000178743568622424,"xy":[1,0,0.910673421760927,0.0160297874819887,0.849186318940748,0.0320520268256944,0.695794612861528,0.0717915974908736,0.498442662240797,0.0919658337121781,0.302873885493542,0.0877137532162304,0.139977327975174,0.0654621991467383,0.0380656693660804,0.0335946038461154,0,0,0.0396582029585364,-0.0347266127131365,0.144634720957126,-0.0667891275090369,0.306852823166501,-0.0885406502296888,0.500818080902831,-0.0924005883717301,0.698940635957709,-0.0716383979368734,0.860665749892887,-0.0289180542777181,0.919783730358342,-0.0142814147156014,1,0],"Bot_Xtr":0.531331454324576,"CDf":0.00332,"Cpmin":-0.512238884341503,"n":7,"CD":0.00420761788773356,"CL":-0.00458393074174396,"CDp":3.52058152124961e-05,"Cm":0.000885227404031591,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt53.8397164573885>29.101597490812) l1 Foil spline 17pts Re13000000 N7","xver":6.991,"good":53.8397164539367,"id":1408,"r":6},
             {"id":1409,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt56.8918830711609>40.8855049514154) l1 Foil spline 17pts Re13000000 N8","good":56.8918830715939,"iver":1.2020052,"r":6,"Cm":-0.00063705893271183,"CD":0.0037172707275991,"CL":0.013983111754611,"n":8,"CDp":-4.11756443208142e-05,"CDf":0.0031,"Cpmin":-0.439482705956484,"sym":0.000149457883209312,"Bot_Xtr":0.561876666396607,"xy":[1,0,0.910673421760927,0.0138728376042232,0.849186318940748,0.0277391427390215,0.695794612861528,0.0621314022071542,0.498442662240797,0.079591016266409,0.302873885493542,0.0759110908608696,0.139977327975174,0.0566536804682173,0.0380656693660804,0.0290741523591023,0,0,0.0396582029585364,-0.0296775786343715,0.144634720957126,-0.0570784026632316,0.306852823166501,-0.0756673889053383,0.500818080902831,-0.0789661159847838,0.698940635957709,-0.0612226192509615,0.860665749892887,-0.0247135485648835,0.919783730358342,-0.0122049856037931,1,0],"CDpres":0.00062,"clcd":269.014573669719,"alpha":0.1,"diter":3,"Top_Xtr":0.55183253611472,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N8.dat","Re":13000000,"src":"retestc_0.txt"},
             {"CDf":0.00292,"Cpmin":-0.447523763721866,"CD":0.00349574154621923,"CL":0.0111472365036997,"n":9,"CDp":-8.36424532175232e-05,"Cm":-9.5057115977174e-05,"id":1410,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt150.131343797999>136.756291997743) l1 Foil spline 17pts Re8192000 N12","xver":6.991,"good":71.7545693089599,"r":6,"Re":13000000,"src":"retest_154.txt","diter":3,"Top_Xtr":0.578578053350412,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N12.dat","CDpres":0.00057,"clcd":286.062338070026,"alpha":0.1,"sym":5.08464157721832e-05,"xy":[1,0,0.910673421760927,0.0141251116048153,0.849186318940748,0.0282435719489214,0.695794612861528,0.0632612458515737,0.498442662240797,0.0810383585230937,0.302873885493542,0.0772915146160609,0.139977327975174,0.0576839131450298,0.0380656693660804,0.0296028583772007,0,0,0.0396582029585364,-0.0303973922757204,0.144634720957126,-0.0584628084926147,0.306852823166501,-0.0775026605563832,0.500818080902831,-0.0808813964795462,0.698940635957709,-0.062707540815449,0.860665749892887,-0.0253129623378973,0.919783730358342,-0.0125010109378783,1,0],"Bot_Xtr":0.591396505165573},
             {"Cm":0.00188586002163195,"r":6,"id":1411,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","iver":1.2020052,"good":87.0061738926371,"Cpmin":-0.593188927359452,"CDf":0.00262,"CDp":-0.000174849071013273,"CD":0.00330149620145205,"CL":0.129334921106308,"n":10,"alpha":1.3,"clcd":302.892973058755,"CDpres":0.00068,"Bot_Xtr":0.706647537376962,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"sym":7.36215012470816e-05,"src":"retest_87.txt","Re":13000000,"Top_Xtr":0.555993930503179,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","diter":3},
             {"Re":13000000,"src":"retest_91.txt","diter":6,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N7.dat","Top_Xtr":0.653265940040543,"CDpres":0.0008,"clcd":304.643803232915,"alpha":0.2,"sym":0.000716732971777374,"xy":[1,0,0.913162369486509,0.027817551435875,0.813710842258612,0.0497948881663569,0.673782501507511,0.0681343297484279,0.492724758079874,0.0748114255342976,0.299655576439083,0.0674663091997214,0.141435325331645,0.0501863894084846,0.0380604371432103,0.027365629643441,0,0,0.0380279452424157,-0.0277645111088732,0.14605649423593,-0.0518627930280208,0.312666093446018,-0.0695616986045226,0.510591162367989,-0.0761278113376951,0.699485607975073,-0.0670561605215094,0.843999845282038,-0.0447919433896561,0.923962179670343,-0.0251479843227625,1,0],"Bot_Xtr":0.717457061966293,"CDf":0.00248,"Cpmin":-0.390907381490738,"n":11,"CL":-0.0239634322203703,"CD":0.00328252204505027,"CDp":-0.00146352214381029,"Cm":0.0106614117848974,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.832735417199>73.7966339079156) l1 Foil spline 17pts Re5000000 N7","good":97.1823847564653,"iver":1.2020052,"id":1412,"r":6},
             {"src":"retest_107.txt","Re":13000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re5000000-N5.dat","Top_Xtr":0.645100212929964,"diter":4,"alpha":0.2,"clcd":361.775065146679,"CDpres":0.00034,"Bot_Xtr":0.682985072845957,"xy":[1,0,0.910673421760927,0.0129674132871274,0.849186318940748,0.0259287204528371,0.695794612861528,0.0580763354631672,0.498442662240797,0.0743964307312883,0.302873885493542,0.0709566792571629,0.139977327975174,0.0529561225920057,0.0380656693660804,0.027176599364114,0,0,0.0396582029585364,-0.0280813797942241,0.144634720957126,-0.0540084594831974,0.306852823166501,-0.071597643192735,0.500818080902831,-0.0747189493173565,0.698940635957709,-0.0579297807400059,0.860665749892887,-0.0233843384550834,0.919783730358342,-0.0115485444532261,1,0],"sym":0.000107533783001579,"Cpmin":-0.410674070400515,"CDf":0.00243,"CDp":-0.00022615732363534,"n":12,"CL":0.0186096243729095,"CD":0.00276414848987604,"Cm":0.000549783760099788,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt63.3151811470369>51.8407949487457) l1 Foil spline 17pts Re5000000 N5","iver":1.2020052,"good":112.271438871133,"id":1413},
             {"alpha":-0.1,"clcd":390.701002110455,"CDpres":0.00031,"Bot_Xtr":0.685043209029401,"xy":[1,0,0.910673421760927,0.0138728376042232,0.849186318940748,0.0277391427390215,0.695794612861528,0.0621314022071542,0.498442662240797,0.079591016266409,0.302873885493542,0.0759110908608696,0.139977327975174,0.0566536804682173,0.0380656693660804,0.0290741523591023,0,0,0.0396582029585364,-0.0296775786343715,0.144634720957126,-0.0570784026632316,0.306852823166501,-0.0756673889053383,0.500818080902831,-0.0789661159847838,0.698940635957709,-0.0612226192509615,0.860665749892887,-0.0247135485648835,0.919783730358342,-0.0122049856037931,1,0],"sym":0.000149457883209312,"src":"retest_110.txt","Re":13000000,"Top_Xtr":0.69801152171057,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N8.dat","diter":4,"Cm":-0.000635048094700897,"r":6,"id":1414,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt56.8918830711609>40.8855049514154) l1 Foil spline 17pts Re13000000 N8","iver":1.2020052,"good":133.368546345676,"Cpmin":-0.432943856386647,"CDf":0.00224,"CDp":-0.000253733958921902,"CD":0.00255950200946065,"CL":-0.00747770602002162,"n":13},
             {"Cm":0.00462963423439055,"good":145.431132056906,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt151.804676818436>113.046316185753) l1 Foil spline 17pts Re8192000 N11","xver":6.991,"iver":1.2020052,"id":1415,"r":6,"CDf":0.00205,"Cpmin":-0.276861964563171,"n":14,"CD":0.00240601436769528,"CL":0.0134359051792983,"CDp":-0.000641452782782663,"clcd":415.625115721108,"CDpres":0.00036,"alpha":0.3,"sym":0.000361831036318983,"xy":[1,0,0.913162369486509,0.0211759954930003,0.813710842258612,0.0379061517982976,0.673782501507511,0.0518669755315192,0.492724758079874,0.056949886965829,0.299655576439083,0.0513584476633763,0.141435325331645,0.038204180492804,0.0380604371432103,0.0208319719055242,0,0,0.0380279452424157,-0.0204238232588127,0.14605649423593,-0.0381507354607861,0.312666093446018,-0.0511702090597058,0.510591162367989,-0.0560003004462923,0.699485607975073,-0.0493271127856521,0.843999845282038,-0.0329493550821687,0.923962179670343,-0.0184990826998335,1,0],"Bot_Xtr":0.781268044787437,"Re":13000000,"src":"retest_155.txt","diter":4,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re8192000-N11.dat","Top_Xtr":0.725078364553167},
             {"sym":0.000241453892187005,"Bot_Xtr":0.334379322848436,"xy":[1,0,0.94211262451681,0.0233074572670906,0.870368703940721,0.0435896313513886,0.612947600635354,0.114794676853088,0.407050317206713,0.163914151934885,0.25912563537128,0.170918861013242,0.123234615368669,0.135145705795004,0.0345811184073606,0.0724164907839465,0,0,0.0345316777956586,-0.0724787571474731,0.128173188513251,-0.13770695745918,0.264469450799845,-0.171751260497599,0.407758505638372,-0.164154696171204,0.611699288725026,-0.11545038901228,0.879132615239467,-0.0412435776285379,0.940446499493271,-0.0240501591203231,1,0],"CDpres":0.00237,"clcd":146.333405241963,"alpha":-0.4,"diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re30000000-N5.dat","Top_Xtr":0.32895225929977,"Re":16000000,"src":"retest_77.txt","xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.8671396896891>15.3139051035643) l1 Foil spline 17pts Re30000000 N5","good":14.3973887619312,"iver":1.2020052,"id":1416,"r":6,"Cm":-0.00124237999509181,"n":3,"CL":-0.038261918895661,"CD":0.00683370962594968,"CDp":-0.00272218816539166,"CDf":0.00447,"Cpmin":-1.44618669007832},
             {"CDf":0.00443,"Cpmin":-1.43143245233275,"CD":0.00676093049137516,"CL":0.013954684015151,"n":4,"CDp":-0.00273273410914607,"Cm":0.00152809385788833,"id":1417,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.8671396896891>15.3139051035643) l1 Foil spline 17pts Re30000000 N5","iver":1.2020052,"good":15.8818613173338,"r":6,"Re":16000000,"src":"retest_78.txt","diter":3,"Top_Xtr":0.332957213539112,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re30000000-N5.dat","CDpres":0.00233,"clcd":147.90863495427,"alpha":0.2,"sym":0.000241453892187005,"xy":[1,0,0.94211262451681,0.0233074572670906,0.870368703940721,0.0435896313513886,0.612947600635354,0.114794676853088,0.407050317206713,0.163914151934885,0.25912563537128,0.170918861013242,0.123234615368669,0.135145705795004,0.0345811184073606,0.0724164907839465,0,0,0.0345316777956586,-0.0724787571474731,0.128173188513251,-0.13770695745918,0.264469450799845,-0.171751260497599,0.407758505638372,-0.164154696171204,0.611699288725026,-0.11545038901228,0.879132615239467,-0.0412435776285379,0.940446499493271,-0.0240501591203231,1,0],"Bot_Xtr":0.33864859649557},
             {"CDpres":0.00166,"clcd":185.380936008737,"alpha":-0.5,"sym":0.000990696463258582,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"Bot_Xtr":0.379044793346834,"Re":16000000,"src":"retest_80.txt","diter":3,"Top_Xtr":0.42807613598612,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Cm":1.78522227684858e-05,"id":1418,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"good":25.3703222012218,"r":6,"CDf":0.00374,"Cpmin":-1.09046684770398,"CD":0.0053942979333801,"CL":-0.0548740429189194,"n":5,"CDp":0.000295346565465656},
             {"alpha":-0.3,"CDpres":0.00148,"clcd":198.744355533601,"Bot_Xtr":0.409818711008776,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"sym":0.000990696463258582,"src":"retest_153.txt","Re":16000000,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.443947312465903,"diter":3,"Cm":0.000183520403263442,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"good":30.2196492617305,"id":1419,"Cpmin":-1.07653093936561,"CDf":0.00355,"CDp":0.000186758321639952,"n":6,"CD":0.00503158943716986,"CL":-0.0338961913063545},
             {"Cm":0.00122092349403718,"r":6,"id":1420,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt63.0705525476291>40.2214842027205) l1 Foil spline 17pts Re16000000 N9","good":36.6058810593828,"xver":6.991,"iver":1.2020052,"Cpmin":-0.474410889640825,"CDf":0.00351,"CDp":0.000120307603164617,"CL":-0.0171596174778885,"CD":0.0043810069888048,"n":7,"alpha":-0.1,"clcd":228.258024366406,"CDpres":0.00087,"Bot_Xtr":0.469765114878918,"xy":[1,0,0.910673421760927,0.014722606251893,0.849186318940748,0.0294382798936063,0.695794612861528,0.0659372074171373,0.498442662240797,0.0844662950081411,0.302873885493542,0.0805609589602657,0.139977327975174,0.0601239525791183,0.0380656693660804,0.0308550643712792,0,0,0.0396582029585364,-0.032163775830461,0.144634720957126,-0.0618600651568908,0.306852823166501,-0.0820063174429243,0.500818080902831,-0.0855813907201719,0.698940635957709,-0.0663514576307446,0.860665749892887,-0.0267838911593523,0.919783730358342,-0.0132274410190513,1,0],"sym":0.000613495700008926,"src":"retest_154.txt","Re":16000000,"Top_Xtr":0.475630885928656,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re16000000-N9.dat","diter":4},
             {"sym":7.36215012470816e-05,"Bot_Xtr":0.544504737686537,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"CDpres":0.00089,"clcd":248.242997303314,"alpha":0.2,"diter":3,"Top_Xtr":0.523714354582826,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Re":16000000,"src":"retest_95.txt","id":1421,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","iver":1.2020052,"xver":6.991,"good":57.0177518166404,"r":6,"Cm":0.000208975571482414,"CL":0.0202435507037437,"CD":0.00402831101325351,"n":8,"CDp":3.01373126835615e-06,"CDf":0.00313,"Cpmin":-0.548911034379305},
             {"CDp":-4.39507214790788e-05,"n":9,"CL":-0.00665912685860376,"CD":0.00360327120299795,"Cpmin":-0.469787091131877,"CDf":0.00296,"r":6,"good":63.0705525492789,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt63.0705525476291>40.2214842027205) l1 Foil spline 17pts Re16000000 N9","xver":6.991,"iver":1.2020052,"id":1422,"Cm":0.00125609466674021,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re16000000-N9.dat","Top_Xtr":0.558499989196747,"diter":3,"src":"retest_156.txt","Re":16000000,"xy":[1,0,0.910673421760927,0.014722606251893,0.849186318940748,0.0294382798936063,0.695794612861528,0.0659372074171373,0.498442662240797,0.0844662950081411,0.302873885493542,0.0805609589602657,0.139977327975174,0.0601239525791183,0.0380656693660804,0.0308550643712792,0,0,0.0396582029585364,-0.032163775830461,0.144634720957126,-0.0618600651568908,0.306852823166501,-0.0820063174429243,0.500818080902831,-0.0855813907201719,0.698940635957709,-0.0663514576307446,0.860665749892887,-0.0267838911593523,0.919783730358342,-0.0132274410190513,1,0],"Bot_Xtr":0.561644113943523,"sym":0.000613495700008926,"alpha":0,"CDpres":0.00064,"clcd":277.525599285447},
             {"src":"retest_75.txt","Re":16000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N7.dat","Top_Xtr":0.571872910645471,"diter":3,"alpha":0.1,"clcd":300.409762590446,"CDpres":0.00049,"Bot_Xtr":0.585422287990142,"xy":[1,0,0.910673421760927,0.0131396913441706,0.849186318940748,0.0262731954442887,0.695794612861528,0.058847906324082,0.498442662240797,0.0753848215732816,0.302873885493542,0.071899371416809,0.139977327975174,0.0536596690670572,0.0380656693660804,0.0275376530015531,0,0,0.0396582029585364,-0.0280521288954652,0.144634720957126,-0.0539522017069756,0.306852823166501,-0.0715230636874632,0.500818080902831,-0.0746411185113967,0.698940635957709,-0.0578694383293422,0.860665749892887,-0.0233599802176427,0.919783730358342,-0.0115365149408913,1,0],"sym":0.000198583008031534,"Cpmin":-0.41370393497379,"CDf":0.00284,"CDp":-9.57324743437683e-05,"n":10,"CD":0.00332878662589711,"CL":0.014509904630253,"Cm":-0.000734345395340633,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt55.8977449753318>37.3416634457127) l1 Foil spline 17pts Re10000000 N7","good":68.918657475453,"xver":6.991,"iver":1.2020052,"id":1423},
             {"Cpmin":-0.606864876093136,"CDf":0.00259,"CDp":-0.000170128972655915,"n":11,"CD":0.00327592500980728,"CL":0.14840506265589,"Cm":0.00230592629910147,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt67.8462156431864>37.3379899972252) l1 Foil spline 17pts Re20000000 N10","good":81.3889238700596,"xver":6.991,"iver":1.2020052,"id":1424,"src":"retestc_7.txt","Re":16000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N10.dat","Top_Xtr":0.533279047580485,"diter":4,"alpha":1.5,"CDpres":0.00069,"clcd":305.2572928276,"Bot_Xtr":0.704423695989221,"xy":[1,0,0.910673421760927,0.0170236138564171,0.849186318940748,0.034039211599607,0.695794612861528,0.0762425849496249,0.498442662240797,0.0976675980800562,0.302873885493542,0.0931518940178065,0.139977327975174,0.0695207719826673,0.0380656693660804,0.0356774264274041,0,0,0.0396582029585364,-0.0367065728461499,0.144634720957126,-0.0705971525208346,0.306852823166501,-0.0935888522830824,0.500818080902831,-0.0976688672780052,0.698940635957709,-0.075722907217397,0.860665749892887,-0.0305668357199847,0.919783730358342,-0.0150956787503204,1,0],"sym":7.85400925867198e-05},
             {"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"Bot_Xtr":0.706232572006952,"sym":7.36215012470816e-05,"alpha":1.3,"clcd":322.85797032617,"CDpres":0.00062,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Top_Xtr":0.564485826660385,"diter":4,"src":"retest_99.txt","Re":16000000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","good":96.1565956314273,"iver":1.2020052,"id":1425,"Cm":0.00117375502609194,"CDp":-0.000185698733092345,"n":12,"CD":0.00309733719440082,"CL":0.132720292416115,"Cpmin":-0.594674914473971,"CDf":0.00248},
             {"diter":5,"Top_Xtr":0.703712772683719,"Foil_fn":"optbs_spline_sym_naca16009.dat-s17_n17s0_nsopt-Re5000000-N7.dat","Re":16000000,"src":"retest_104.txt","sym":0.000716732971777374,"Bot_Xtr":0.720241550153813,"xy":[1,0,0.913162369486509,0.027817551435875,0.813710842258612,0.0497948881663569,0.673782501507511,0.0681343297484279,0.492724758079874,0.0748114255342976,0.299655576439083,0.0674663091997214,0.141435325331645,0.0501863894084846,0.0380604371432103,0.027365629643441,0,0,0.0380279452424157,-0.0277645111088732,0.14605649423593,-0.0518627930280208,0.312666093446018,-0.0695616986045226,0.510591162367989,-0.0761278113376951,0.699485607975073,-0.0670561605215094,0.843999845282038,-0.0447919433896561,0.923962179670343,-0.0251479843227625,1,0],"clcd":344.581738304495,"CDpres":0.0007,"alpha":0,"CL":-0.00221505685737775,"CD":0.00290206905601113,"n":13,"CDp":-0.00142817576682421,"CDf":0.0022,"Cpmin":-0.376592779599634,"id":1426,"good":115.165652188446,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca16009.dat-s17_n17s0.dat (opt126.832735417199>73.7966339079156) l1 Foil spline 17pts Re5000000 N7","xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000390816780915457},
             {"CDpres":0.00053,"clcd":349.446913012944,"alpha":0.8,"sym":7.36215012470816e-05,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"Bot_Xtr":0.704167440932086,"Re":16000000,"src":"retest_101.txt","diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Top_Xtr":0.61073796423916,"Cm":0.000709386689151344,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","xver":6.991,"good":124.990028462487,"id":1427,"r":6,"CDf":0.00233,"Cpmin":-0.574179698672277,"n":14,"CD":0.0028616649990637,"CL":0.0817904219872169,"CDp":-0.000216893102923282},
             {"Cm":-6.82678335518121e-05,"r":6,"id":1428,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt16.344500788256>16.2000027753785) l1 Foil spline 17pts Re45000000 N7","iver":1.2020052,"xver":6.991,"good":13.7352917393133,"Cpmin":-1.45857328944066,"CDf":0.00435,"CDp":-0.00292379421464087,"CL":-0.0188115834163674,"CD":0.0067179431031676,"n":3,"alpha":-0.2,"clcd":148.85508624336,"CDpres":0.00237,"Bot_Xtr":0.331249021853157,"xy":[1,0,0.94211262451681,0.023884399485241,0.870368703940721,0.0446686293009307,0.612947600635354,0.117636252179668,0.407050317206713,0.167971608452764,0.25912563537128,0.175149708920274,0.123234615368669,0.138491041254869,0.0345811184073606,0.0742090557276374,0,0,0.0345316777956586,-0.0735903176821595,0.128173188513251,-0.139818881356439,0.264469450799845,-0.174385300186819,0.407758505638372,-0.166672232191807,0.611699288725026,-0.117220978095081,0.879132615239467,-0.0418761041094746,0.940446499493271,-0.0244190010925535,1,0],"sym":0.000719117405195286,"src":"retest_153.txt","Re":20000000,"Top_Xtr":0.32449845668049,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re45000000-N7.dat","diter":3},
             {"src":"retest_87.txt","Re":20000000,"Top_Xtr":0.331756916664256,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re30000000-N5.dat","diter":3,"alpha":-0.2,"CDpres":0.00222,"clcd":153.671427141636,"Bot_Xtr":0.335390932568542,"xy":[1,0,0.94211262451681,0.0233074572670906,0.870368703940721,0.0435896313513886,0.612947600635354,0.114794676853088,0.407050317206713,0.163914151934885,0.25912563537128,0.170918861013242,0.123234615368669,0.135145705795004,0.0345811184073606,0.0724164907839465,0,0,0.0345316777956586,-0.0724787571474731,0.128173188513251,-0.13770695745918,0.264469450799845,-0.171751260497599,0.407758505638372,-0.164154696171204,0.611699288725026,-0.11545038901228,0.879132615239467,-0.0412435776285379,0.940446499493271,-0.0240501591203231,1,0],"sym":0.000241453892187005,"Cpmin":-1.42902926805158,"CDf":0.00429,"CDp":-0.00272055780609397,"CD":0.00650739059694108,"CL":-0.0203706183968631,"n":4,"Cm":-0.000413161872121601,"r":6,"id":1429,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.8671396896891>15.3139051035643) l1 Foil spline 17pts Re30000000 N5","good":15.3347356559551,"xver":6.991,"iver":1.2020052},
             {"CDf":0.00429,"Cpmin":-1.07934370425552,"n":5,"CD":0.00571017622339986,"CL":-0.0764226538638217,"CDp":-0.000654499698621341,"Cm":-0.00488125001249395,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt17.2291233740456>15.5071997018388) l1 Foil spline 17pts Re20000000 N5","xver":6.991,"iver":1.2020052,"good":17.2291233740002,"id":1430,"r":6,"Re":20000000,"src":"retestc_17.txt","diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re20000000-N5.dat","Top_Xtr":0.341735587339187,"clcd":175.125943732188,"CDpres":0.00143,"alpha":-0.9,"sym":0.000282422749798419,"xy":[1,0,0.94211262451681,0.0178798659616771,0.870368703940721,0.033438944323721,0.612947600635354,0.0880625205798547,0.407050317206713,0.12574357778426,0.25912563537128,0.131117105148757,0.123234615368669,0.103674419616884,0.0345811184073606,0.0555529131210809,0,0,0.0345316777956586,-0.0551813673329278,0.128173188513251,-0.104842556673446,0.264469450799845,-0.130762029709305,0.407758505638372,-0.124978420510404,0.611699288725026,-0.087897620979531,0.879132615239467,-0.0314006075271646,0.940446499493271,-0.0183104776773919,1,0],"Bot_Xtr":0.304650641430982},
             {"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re65536000-N11.dat","Top_Xtr":0.331275441663261,"diter":3,"src":"retest_158.txt","Re":20000000,"xy":[1,0,0.867935867415093,0.0195910806779479,0.765256324145788,0.040372601554045,0.608365821336593,0.085773514036814,0.435418780836389,0.117196662932154,0.270182631260474,0.118634635736159,0.123421225360211,0.0927527287026748,0.0257824653263784,0.0477047174799002,0,0,0.0262080994032648,-0.0484087656842255,0.120992516399386,-0.0919989546232345,0.245670511459264,-0.116092284443336,0.396783126454799,-0.120344740273802,0.570306654876705,-0.0950308005337515,0.7408836798323,-0.0476773973570985,0.825204455146615,-0.0267533162799515,1,0],"Bot_Xtr":0.415789124065245,"sym":0.000615778978064873,"alpha":1,"CDpres":0.00122,"clcd":199.620563673869,"CDp":0.000369597083968027,"n":6,"CD":0.00500950393885148,"CL":0.11267207571535,"Cpmin":-0.888359130874661,"CDf":0.00379,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt21.2031568209603>6.3962531633) l1 Foil spline 17pts Re65536000 N11","xver":6.991,"iver":1.2020052,"good":21.6735274350447,"id":1431,"Cm":-0.000119842626761414},
             {"id":1432,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_lwk80150k25.dat-s17_n17s0.dat (opt68.0519978083812>33.6685189384632) l1 Foil spline 17pts Re8192000 N8","good":22.8085126415229,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.0211754385208556,"CL":0.089315511929188,"CD":0.00541103107608932,"n":7,"CDp":-0.000293205486666894,"CDf":0.00366,"Cpmin":-0.789531394209567,"sym":0.001108763928049,"Bot_Xtr":0.560793404777328,"xy":[1,0,0.926314285121259,0.015071037056992,0.842733452367159,0.0385959801015493,0.674308409570227,0.0962360022672035,0.513424713240155,0.125625011958448,0.31748205604605,0.126478044551933,0.145841001298451,0.100415556882043,0.0357200213933211,0.0560484246059092,0,0,0.0382503902699745,-0.0582117646665964,0.147625762912976,-0.10001208891461,0.309075945539364,-0.125356144903867,0.51433944613801,-0.125191683277664,0.681400098170481,-0.0936784640663441,0.852932303366737,-0.0349097417935355,0.939083797033727,-0.0123093604480144,1,0],"clcd":184.807661596858,"CDpres":0.00175,"alpha":1.8,"diter":5,"Top_Xtr":0.286508762344916,"Foil_fn":"optbs_spline_sym_lwk80150k25.dat-s17_n17s0_nsopt-Re8192000-N8.dat","Re":20000000,"src":"retest_94.txt"},
             {"Cpmin":-0.5118055248317,"CDf":0.00333,"CDp":0.000104418362779954,"CD":0.00426095889559479,"CL":-0.00390317912565739,"n":8,"Cm":0.000730829172238267,"r":6,"id":1433,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","xver":6.991,"iver":1.2020052,"good":39.0528994193847,"src":"retest_153.txt","Re":20000000,"Top_Xtr":0.478770067422256,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","diter":4,"alpha":0,"clcd":234.688957228349,"CDpres":0.00093,"Bot_Xtr":0.482977969342343,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"sym":0.000250140694931259},
             {"src":"retestc_21.txt","Re":20000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","Top_Xtr":0.523933370002354,"diter":3,"alpha":0.3,"clcd":253.60736207162,"CDpres":0.00094,"Bot_Xtr":0.547396208048979,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"sym":8.14582294892033e-05,"Cpmin":-0.595379256947256,"CDf":0.003,"CDp":-2.74957652573067e-05,"n":9,"CD":0.00394310319634016,"CL":0.0305486406827311,"Cm":0.000245437132923928,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","xver":6.991,"good":60.1540588985185,"id":1434},
             {"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N10.dat","Top_Xtr":0.549123629115367,"diter":3,"src":"retestc_22.txt","Re":20000000,"xy":[1,0,0.910673421760927,0.0170236138564171,0.849186318940748,0.034039211599607,0.695794612861528,0.0762425849496249,0.498442662240797,0.0976675980800562,0.302873885493542,0.0931518940178065,0.139977327975174,0.0695207719826673,0.0380656693660804,0.0356774264274041,0,0,0.0396582029585364,-0.0367065728461499,0.144634720957126,-0.0705971525208346,0.306852823166501,-0.0935888522830824,0.500818080902831,-0.0976688672780052,0.698940635957709,-0.075722907217397,0.860665749892887,-0.0305668357199847,0.919783730358342,-0.0150956787503204,1,0],"Bot_Xtr":0.56502533563283,"sym":7.85400925867198e-05,"alpha":0.2,"CDpres":0.00078,"clcd":274.95883000356,"CDp":-5.12855025051475e-05,"n":10,"CD":0.0036369081145241,"CL":0.0206049078530767,"Cpmin":-0.552382553863166,"CDf":0.00286,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt67.8462156431864>37.3379899972252) l1 Foil spline 17pts Re20000000 N10","iver":1.2020052,"xver":6.991,"good":67.8462156447723,"id":1435,"Cm":0.000110132361331754},
             {"CDf":0.00276,"Cpmin":-0.451149215760498,"n":11,"CD":0.00330265335342179,"CL":0.00979994366409038,"CDp":-7.62925405981393e-05,"Cm":0.000157632665757242,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt72.2068193960119>47.7320396835587) l1 Foil spline 17pts Re20000000 N11","xver":6.991,"good":72.2068193950419,"id":1436,"r":6,"Re":20000000,"src":"retestc_23.txt","diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N11.dat","Top_Xtr":0.566033255369307,"CDpres":0.00054,"clcd":302.786848327247,"alpha":0.1,"sym":6.87781482133858e-05,"xy":[1,0,0.910673421760927,0.0142385217004873,0.849186318940748,0.0284703387374935,0.695794612861528,0.0637691684892904,0.498442662240797,0.0816890130630604,0.302873885493542,0.077912085859141,0.139977327975174,0.0581470555464169,0.0380656693660804,0.0298405388355682,0,0,0.0396582029585364,-0.0307438722871965,0.144634720957126,-0.0591291878442944,0.306852823166501,-0.0783860627402097,0.500818080902831,-0.0818033106663372,0.698940635957709,-0.0634223030971704,0.860665749892887,-0.025601488254916,0.919783730358342,-0.0126435017928151,1,0],"Bot_Xtr":0.578189751800614},
             {"id":1437,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","good":89.4944618853223,"xver":6.991,"iver":1.2020052,"r":6,"Cm":1.20831335937311e-05,"CD":0.00331060326861543,"CL":-5.79573766473591e-05,"n":12,"CDp":-0.000110072966566984,"CDf":0.00264,"Cpmin":-0.54059848392221,"sym":7.36215012470816e-05,"Bot_Xtr":0.593509380481293,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"clcd":302.059751308777,"CDpres":0.00067,"alpha":0,"diter":3,"Top_Xtr":0.589468625003483,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","Re":20000000,"src":"retest_109.txt"},
             {"Re":20000000,"src":"retest_90.txt","diter":4,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N7.dat","Top_Xtr":0.553426037612952,"clcd":337.681557608181,"CDpres":0.00041,"alpha":0.8,"sym":0.000198583008031534,"xy":[1,0,0.910673421760927,0.0131396913441706,0.849186318940748,0.0262731954442887,0.695794612861528,0.058847906324082,0.498442662240797,0.0753848215732816,0.302873885493542,0.071899371416809,0.139977327975174,0.0536596690670572,0.0380656693660804,0.0275376530015531,0,0,0.0396582029585364,-0.0280521288954652,0.144634720957126,-0.0539522017069756,0.306852823166501,-0.0715230636874632,0.500818080902831,-0.0746411185113967,0.698940635957709,-0.0578694383293422,0.860665749892887,-0.0233599802176427,0.919783730358342,-0.0115365149408913,1,0],"Bot_Xtr":0.663180840874458,"CDf":0.00255,"Cpmin":-0.443102881453758,"n":13,"CL":0.0896636488315701,"CD":0.00296136989856082,"CDp":-0.000146920115445305,"Cm":-0.00075635938006149,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt55.8977449753318>37.3416634457127) l1 Foil spline 17pts Re10000000 N7","xver":6.991,"good":86.1599431173413,"iver":1.2020052,"id":1438,"r":6},
             {"Cm":-0.00053033487467782,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt55.8977449753318>37.3416634457127) l1 Foil spline 17pts Re10000000 N7","good":97.4528482073323,"xver":6.991,"iver":1.2020052,"id":1439,"r":6,"CDf":0.00237,"Cpmin":-0.442718297568725,"n":14,"CL":0.0886204724029782,"CD":0.00273029555305828,"CDp":-0.000182947650395836,"clcd":366.260714478281,"CDpres":0.00036,"alpha":0.8,"sym":0.000198583008031534,"xy":[1,0,0.910673421760927,0.0131396913441706,0.849186318940748,0.0262731954442887,0.695794612861528,0.058847906324082,0.498442662240797,0.0753848215732816,0.302873885493542,0.071899371416809,0.139977327975174,0.0536596690670572,0.0380656693660804,0.0275376530015531,0,0,0.0396582029585364,-0.0280521288954652,0.144634720957126,-0.0539522017069756,0.306852823166501,-0.0715230636874632,0.500818080902831,-0.0746411185113967,0.698940635957709,-0.0578694383293422,0.860665749892887,-0.0233599802176427,0.919783730358342,-0.0115365149408913,1,0],"Bot_Xtr":0.701042100550182,"Re":20000000,"src":"retest_91.txt","diter":5,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N7.dat","Top_Xtr":0.574563492311668},
             {"src":"retest_153.txt","Re":25000000,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N3.dat","Top_Xtr":0.317913960549607,"diter":3,"alpha":0.5,"clcd":138.957277275121,"CDpres":0.00295,"Bot_Xtr":0.331418776278463,"xy":[1,0,0.94211262451681,0.0268340574624991,0.870368703940721,0.0501850827848079,0.612947600635354,0.132164007414666,0.407050317206713,0.18871564244582,0.25912563537128,0.196780218678343,0.123234615368669,0.155594305871952,0.0345811184073606,0.083373671038442,0,0,0.0345316777956586,-0.082697415786458,0.128173188513251,-0.157122030866487,0.264469450799845,-0.195966183199285,0.407758505638372,-0.187298591985348,0.611699288725026,-0.131727546092307,0.879132615239467,-0.0470584405956135,0.940446499493271,-0.0274409507941345,1,0],"sym":0.00086608867785912,"Cpmin":-1.7275101529632,"CDf":0.00425,"CDp":-0.00482298093557157,"n":3,"CD":0.00719645649086883,"CL":0.0333293911252812,"Cm":0.00445397624938576,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt12.7873196579229>12.1660261200543) l1 Foil spline 17pts Re36000000 N3","xver":6.991,"good":13.7316669530143,"id":1440},
             {"Re":25000000,"src":"retestc_2.txt","diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re25000000-N4.dat","Top_Xtr":0.324735709799361,"CDpres":0.00194,"clcd":163.107943186399,"alpha":0.4,"sym":0.000349060530452803,"xy":[1,0,0.94211262451681,0.0220141438247601,0.870368703940721,0.0411708751770469,0.612947600635354,0.108424805743565,0.407050317206713,0.154818677741528,0.25912563537128,0.161434700730843,0.123234615368669,0.12764657124871,0.0345811184073606,0.0683981536524431,0,0,0.0345316777956586,-0.0680022217417774,0.128173188513251,-0.129201705783543,0.264469450799845,-0.161143316475794,0.407758505638372,-0.154015941888671,0.611699288725026,-0.108319778963832,0.879132615239467,-0.0386962335131298,0.940446499493271,-0.0225647392117603,1,0],"Bot_Xtr":0.326092135629125,"CDf":0.00419,"Cpmin":-1.35588364966243,"n":4,"CL":0.0398381567745561,"CD":0.00613090926453044,"CDp":-0.00203860909356091,"Cm":0.00129205029544368,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.1518401370576>14.6720785089457) l1 Foil spline 17pts Re25000000 N4","iver":1.2020052,"xver":6.991,"good":15.1518401375772,"id":1441,"r":6},
             {"n":5,"CD":0.00616791723720977,"CL":0.0251341067453115,"CDp":-0.00250502178549724,"CDf":0.00413,"Cpmin":-1.41255520280584,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt16.6710807910008>15.6147977640707) l1 Foil spline 17pts Re25000000 N5","xver":6.991,"good":16.6710807910317,"iver":1.2020052,"id":1442,"r":6,"Cm":0.00182139746522883,"diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re25000000-N5.dat","Top_Xtr":0.331336050833914,"Re":25000000,"src":"retestc_3.txt","sym":0.000232851561140792,"Bot_Xtr":0.337074945098951,"xy":[1,0,0.94211262451681,0.0229396273807778,0.870368703940721,0.0429017155070877,0.612947600635354,0.112983028656019,0.407050317206713,0.16132731789373,0.25912563537128,0.168221481179193,0.123234615368669,0.133012884997412,0.0345811184073606,0.0712736398385608,0,0,0.0345316777956586,-0.0710223191584533,0.128173188513251,-0.134939779156332,0.264469450799845,-0.168299972557579,0.407758505638372,-0.160856058818837,0.611699288725026,-0.113130449501418,0.879132615239467,-0.0404148008168844,0.940446499493271,-0.0235668786839114,1,0],"clcd":162.129283118004,"CDpres":0.00204,"alpha":0.3},
             {"src":"retest_98.txt","Re":25000000,"Top_Xtr":0.333096128656305,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re30000000-N5.dat","diter":3,"alpha":0.8,"CDpres":0.00208,"clcd":162.377982424959,"Bot_Xtr":0.34655608385594,"xy":[1,0,0.94211262451681,0.0233074572670906,0.870368703940721,0.0435896313513886,0.612947600635354,0.114794676853088,0.407050317206713,0.163914151934885,0.25912563537128,0.170918861013242,0.123234615368669,0.135145705795004,0.0345811184073606,0.0724164907839465,0,0,0.0345316777956586,-0.0724787571474731,0.128173188513251,-0.13770695745918,0.264469450799845,-0.171751260497599,0.407758505638372,-0.164154696171204,0.611699288725026,-0.11545038901228,0.879132615239467,-0.0412435776285379,0.940446499493271,-0.0240501591203231,1,0],"sym":0.000241453892187005,"Cpmin":-1.48336576275748,"CDf":0.00408,"CDp":-0.00276499378590787,"CL":0.064536173505556,"CD":0.0061584704100024,"n":6,"Cm":0.00463750710790638,"r":6,"id":1443,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.8671396896891>15.3139051035643) l1 Foil spline 17pts Re30000000 N5","good":17.4398530558993,"iver":1.2020052},
             {"Cpmin":-0.507728020991081,"CDf":0.00379,"CDp":0.000282897646254716,"n":7,"CD":0.00492219174158088,"CL":-0.0062540663735919,"Cm":0.00116666065640237,"r":6,"good":22.7323243616287,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt121.166970570197>107.079217347325) l1 Foil spline 17pts Re8192000 N10","xver":6.991,"iver":1.2020052,"id":1444,"src":"retest_70.txt","Re":25000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N10.dat","Top_Xtr":0.382642554550198,"diter":4,"alpha":0,"CDpres":0.00113,"clcd":203.161528949058,"Bot_Xtr":0.384944027421338,"xy":[1,0,0.910673421760927,0.0158252047798378,0.849186318940748,0.0316429577557032,0.695794612861528,0.070875345854792,0.498442662240797,0.0907921051903536,0.302873885493542,0.0865942925453429,0.139977327975174,0.0646267274597164,0.0380656693660804,0.0331658473925287,0,0,0.0396582029585364,-0.0345424669123108,0.144634720957126,-0.0664349628954824,0.306852823166501,-0.0880711431955055,0.500818080902831,-0.0919106131333434,0.698940635957709,-0.0712585189585541,0.860665749892887,-0.0287647096855668,0.919783730358342,-0.0142056842499942,1,0],"sym":0.000632587599920376},
             {"CDpres":0.00132,"clcd":216.770281302238,"alpha":-0.9,"sym":0.000990696463258582,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"Bot_Xtr":0.405273345280756,"Re":25000000,"src":"retest_107.txt","diter":2,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.446032771751488,"Cm":0.00196411253182097,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","good":32.2648539100274,"iver":1.2020052,"id":1445,"r":6,"CDf":0.00329,"Cpmin":-1.12723876678134,"n":8,"CD":0.00461317849472973,"CL":-0.109890023557849,"CDp":0.00014559465608913},
             {"diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","Top_Xtr":0.50349696521145,"Re":25000000,"src":"retestc_4.txt","sym":8.14582294892033e-05,"Bot_Xtr":0.47603527714397,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"CDpres":0.00105,"clcd":237.044626241851,"alpha":-0.3,"n":9,"CL":-0.0283214849844619,"CD":0.00421861493278369,"CDp":5.64295891942123e-05,"CDf":0.00317,"Cpmin":-0.591195897663313,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","xver":6.991,"iver":1.2020052,"good":43.8575919930561,"id":1446,"r":6,"Cm":-0.000732195299784941},
             {"CDp":-3.54481498878888e-06,"n":10,"CD":0.00373971174866551,"CL":0.00344660243032166,"Cpmin":-0.54411749026576,"CDf":0.00293,"r":6,"good":52.0270320532066,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt2.75887459370442>0) l1 Foil spline 17pts Re65536000 N3","xver":6.991,"iver":1.2020052,"id":1447,"Cm":-0.000659164693803787,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re65536000-N3.dat","Top_Xtr":0.527334495241425,"diter":4,"src":"retest_101.txt","Re":25000000,"xy":[1,0,0.910673421760927,0.016998297247575,0.849186318940748,0.0339885903030581,0.695794612861528,0.0761292010514374,0.498442662240797,0.0975223520472225,0.302873885493542,0.0930133634987499,0.139977327975174,0.069417384405533,0.0380656693660804,0.035624368865304,0,0,0.0396582029585364,-0.0363705244715021,0.144634720957126,-0.0699508361660275,0.306852823166501,-0.0927320471047102,0.500818080902831,-0.0967747095956732,0.698940635957709,-0.0750296646202015,0.860665749892887,-0.0302869965885877,0.919783730358342,-0.0149574779346378,1,0],"Bot_Xtr":0.528405889261382,"sym":0.000215913119795892,"alpha":0,"clcd":267.400288366301,"CDpres":0.00081},
             {"Re":25000000,"src":"retestc_9.txt","diter":4,"Top_Xtr":0.547441517364521,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re25000000-N11.dat","clcd":283.707978581445,"CDpres":0.00074,"alpha":0.1,"sym":7.36215012470816e-05,"xy":[1,0,0.910673421760927,0.016922704535841,0.849186318940748,0.0338374404748369,0.695794612861528,0.0757906487443561,0.498442662240797,0.0970886627818474,0.302873885493542,0.092599726046012,0.139977327975174,0.0691086800540166,0.0380656693660804,0.0354659446062668,0,0,0.0396582029585364,-0.0364131128747539,0.144634720957126,-0.0700327457469787,0.306852823166501,-0.0928406325560844,0.500818080902831,-0.0968880288402187,0.698940635957709,-0.0751175213024772,0.860665749892887,-0.0303224614283925,0.919783730358342,-0.0149749925322733,1,0],"Bot_Xtr":0.554919452907004,"CDf":0.00278,"Cpmin":-0.545255580714461,"CL":0.0116625647972381,"CD":0.00352475106621976,"n":11,"CDp":-4.61199107630595e-05,"Cm":-0.000217587093150755,"id":1448,"good":65.4897530525591,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt65.4897530521685>33.3154821646732) l1 Foil spline 17pts Re25000000 N11","xver":6.991,"iver":1.2020052,"r":6},
             {"CDp":-6.93828085801232e-05,"CL":-0.00674077430639562,"CD":0.00330424885370227,"n":12,"Cpmin":-0.509423613034913,"CDf":0.00268,"r":6,"id":1449,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt121.166970570197>107.079217347325) l1 Foil spline 17pts Re8192000 N10","xver":6.991,"iver":1.2020052,"good":72.2063248217081,"Cm":0.00126667284115468,"Top_Xtr":0.56630284257192,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N10.dat","diter":3,"src":"retest_75.txt","Re":25000000,"xy":[1,0,0.910673421760927,0.0158252047798378,0.849186318940748,0.0316429577557032,0.695794612861528,0.070875345854792,0.498442662240797,0.0907921051903536,0.302873885493542,0.0865942925453429,0.139977327975174,0.0646267274597164,0.0380656693660804,0.0331658473925287,0,0,0.0396582029585364,-0.0345424669123108,0.144634720957126,-0.0664349628954824,0.306852823166501,-0.0880711431955055,0.500818080902831,-0.0919106131333434,0.698940635957709,-0.0712585189585541,0.860665749892887,-0.0287647096855668,0.919783730358342,-0.0142056842499942,1,0],"Bot_Xtr":0.568697000982966,"sym":0.000632587599920376,"alpha":0,"CDpres":0.00063,"clcd":302.64064369109},
             {"n":13,"CD":0.00316265625885717,"CL":-0.00677850725675465,"CDp":-9.65073295593745e-05,"CDf":0.00258,"Cpmin":-0.509527526263774,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt121.166970570197>107.079217347325) l1 Foil spline 17pts Re8192000 N10","xver":6.991,"good":81.7633480946108,"id":1450,"r":6,"Cm":0.00127458097303314,"diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N10.dat","Top_Xtr":0.582494970385754,"Re":25000000,"src":"retest_76.txt","sym":0.000632587599920376,"Bot_Xtr":0.585003685208294,"xy":[1,0,0.910673421760927,0.0158252047798378,0.849186318940748,0.0316429577557032,0.695794612861528,0.070875345854792,0.498442662240797,0.0907921051903536,0.302873885493542,0.0865942925453429,0.139977327975174,0.0646267274597164,0.0380656693660804,0.0331658473925287,0,0,0.0396582029585364,-0.0345424669123108,0.144634720957126,-0.0664349628954824,0.306852823166501,-0.0880711431955055,0.500818080902831,-0.0919106131333434,0.698940635957709,-0.0712585189585541,0.860665749892887,-0.0287647096855668,0.919783730358342,-0.0142056842499942,1,0],"CDpres":0.00059,"clcd":316.189910680129,"alpha":0},
             {"CL":-0.00451393664662097,"CD":0.0029395837693983,"n":14,"CDp":-0.000173314724690682,"CDf":0.00262,"Cpmin":-0.325255391795463,"id":1451,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt80.1513198013399>68.8486657114519) l1 Foil spline 17pts Re10000000 N9","good":62.2764797211208,"xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000860735231271565,"diter":5,"Top_Xtr":0.576684816333613,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N9.dat","Re":25000000,"src":"retest_64.txt","sym":0.000351088115273873,"Bot_Xtr":0.573087011165716,"xy":[1,0,0.910673421760927,0.0105017342192691,0.849186318940748,0.0209985233609951,0.695794612861528,0.0470334542409271,0.498442662240797,0.0602503772419929,0.302873885493542,0.0574646747304933,0.139977327975174,0.0428868204035991,0.0380656693660804,0.0220091252731799,0,0,0.0396582029585364,-0.0229643812578523,0.144634720957126,-0.0441670197052255,0.306852823166501,-0.0585510964023152,0.500818080902831,-0.0611036370678213,0.698940635957709,-0.0473737964745918,0.860665749892887,-0.0191232363822681,0.919783730358342,-0.00944416477183535,1,0],"clcd":340.184216013918,"CDpres":0.00032,"alpha":0},
             {"diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N4.dat","Top_Xtr":0.3148101633885,"Re":30000000,"src":"retest_82.txt","sym":0.00117229540331301,"Bot_Xtr":0.329080174103607,"xy":[1,0,0.94211262451681,0.0272417719626303,0.870368703940721,0.0509475908762603,0.612947600635354,0.134172096660719,0.407050317206713,0.191582972663558,0.25912563537128,0.199770081415511,0.123234615368669,0.157958393178931,0.0345811184073606,0.0846404438572396,0,0,0.0345316777956586,-0.085214770528189,0.128173188513251,-0.161904911754247,0.264469450799845,-0.201931501411519,0.407758505638372,-0.193000063962071,0.611699288725026,-0.135737404920645,0.879132615239467,-0.0484909253648804,0.940446499493271,-0.0282762684028201,1,0],"CDpres":0.003,"clcd":139.531509518867,"alpha":0.5,"n":3,"CL":0.0249337762051214,"CD":0.00716683997362464,"CDp":-0.00525149529554365,"CDf":0.00416,"Cpmin":-1.76062820937859,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.21287648185>13.5199346256169) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"iver":1.2020052,"good":13.3395024174225,"id":1452,"r":6,"Cm":0.0048361106983779},
             {"xy":[1,0,0.94211262451681,0.0260546369739481,0.870368703940721,0.0487274097587749,0.612947600635354,0.128325179262347,0.407050317206713,0.183234218757365,0.25912563537128,0.191064551772815,0.123234615368669,0.151074922619235,0.0345811184073606,0.0809520041882505,0,0,0.0345316777956586,-0.0807172280260153,0.128173188513251,-0.153359747372392,0.264469450799845,-0.191273777351515,0.407758505638372,-0.182813731414188,0.611699288725026,-0.128573332964793,0.879132615239467,-0.0459316272942937,0.940446499493271,-0.026783877844748,1,0],"Bot_Xtr":0.335839156480837,"sym":0.000270962425159531,"alpha":1.1,"CDpres":0.00261,"clcd":149.169057727109,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re30000000-N4.dat","Top_Xtr":0.32060472689286,"diter":5,"src":"retestc_12.txt","Re":30000000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.4909453117729>14.3090020000295) l1 Foil spline 17pts Re30000000 N4","good":14.4909453118816,"iver":1.2020052,"id":1453,"Cm":0.0113911990506498,"CDp":-0.00435444060230869,"n":4,"CL":0.0616840042586336,"CD":0.00670380315621091,"Cpmin":-1.70587050708808,"CDf":0.00409},
             {"xy":[1,0,0.94211262451681,0.0233074572670906,0.870368703940721,0.0435896313513886,0.612947600635354,0.114794676853088,0.407050317206713,0.163914151934885,0.25912563537128,0.170918861013242,0.123234615368669,0.135145705795004,0.0345811184073606,0.0724164907839465,0,0,0.0345316777956586,-0.0724787571474731,0.128173188513251,-0.13770695745918,0.264469450799845,-0.171751260497599,0.407758505638372,-0.164154696171204,0.611699288725026,-0.11545038901228,0.879132615239467,-0.0412435776285379,0.940446499493271,-0.0240501591203231,1,0],"Bot_Xtr":0.335055348185344,"sym":0.000241453892187005,"alpha":0.6,"clcd":162.643574114869,"CDpres":0.00208,"Top_Xtr":0.319717575515498,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re30000000-N5.dat","diter":3,"src":"retest_106.txt","Re":30000000,"r":6,"id":1454,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.8671396896891>15.3139051035643) l1 Foil spline 17pts Re30000000 N5","iver":1.2020052,"good":15.8322365369163,"Cm":0.00420153644819694,"CDp":-0.00269113453583372,"CL":0.0446418437755258,"CD":0.00614841382724248,"n":5,"Cpmin":-1.46426385027002,"CDf":0.00407},
             {"id":1455,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt18.7235239474156>17.0399242179934) l1 Foil spline 17pts Re55000000 N9","xver":6.991,"iver":1.2020052,"good":17.095773258116,"r":6,"Cm":0.00301824411338952,"CD":0.00603380636042197,"CL":0.0409719541693233,"n":6,"CDp":-0.00253201600843117,"CDf":0.00404,"Cpmin":-1.43484643772455,"sym":0.000208796576696122,"Bot_Xtr":0.336498172254963,"xy":[1,0,0.94211262451681,0.0230140174956533,0.870368703940721,0.0430408399789876,0.612947600635354,0.113349417365879,0.407050317206713,0.161850480607382,0.25912563537128,0.168767000733706,0.123234615368669,0.13344422782747,0.0345811184073606,0.0715047706310179,0,0,0.0345316777956586,-0.0713036911767481,0.128173188513251,-0.13547437558263,0.264469450799845,-0.168966733422594,0.407758505638372,-0.161493328827211,0.611699288725026,-0.113578643016978,0.879132615239467,-0.0405749137815071,0.940446499493271,-0.0236602445483153,1,0],"clcd":165.732862519318,"CDpres":0.002,"alpha":0.5,"diter":3,"Top_Xtr":0.326456715025431,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N9.dat","Re":30000000,"src":"retest_153.txt"},
             {"sym":0.000918659341396021,"Bot_Xtr":0.35703532763111,"xy":[1,0,0.853694247755346,0.0161755229516158,0.766409503853615,0.0320054103325881,0.583893795685248,0.0785659338051314,0.444207114147005,0.102388518951634,0.300186235321574,0.106831018897361,0.144251593783031,0.087559737627556,0.0289129616777066,0.04487412729606,0,0,0.0259166339183309,-0.0432617880933848,0.114364051808134,-0.0803391028716537,0.242100554077629,-0.103853878148252,0.400816303377971,-0.107232822053974,0.562528610462096,-0.084237243610787,0.754321232202995,-0.035342196214169,0.842007085235557,-0.017868989002118,1,0],"clcd":212.274463718095,"CDpres":0.00101,"alpha":0,"diter":3,"Top_Xtr":0.321511827604705,"Foil_fn":"optbs_spline_sym_fx711520.dat-s17_n17s0_nsopt-Re30000000-N7.dat","Re":30000000,"src":"retestc_15.txt","id":1456,"good":19.4125984980318,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711520.dat-s17_n17s0.dat (opt19.4125984978855>6.77310804867891) l1 Foil spline 17pts Re30000000 N7","xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000819495724831702,"CL":-0.00673088804794035,"CD":0.00471088223465269,"n":7,"CDp":0.000389156214462902,"CDf":0.0037,"Cpmin":-0.718570558274163},
             {"r":6,"id":1457,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt21.2031568209603>6.3962531633) l1 Foil spline 17pts Re65536000 N11","xver":6.991,"iver":1.2020052,"good":25.3876093425239,"Cm":2.86593076265391e-05,"CDp":0.000291885100738587,"CL":0.0784197557556528,"CD":0.00454351980250736,"n":8,"Cpmin":-0.863461701238979,"CDf":0.00349,"xy":[1,0,0.867935867415093,0.0195910806779479,0.765256324145788,0.040372601554045,0.608365821336593,0.085773514036814,0.435418780836389,0.117196662932154,0.270182631260474,0.118634635736159,0.123421225360211,0.0927527287026748,0.0257824653263784,0.0477047174799002,0,0,0.0262080994032648,-0.0484087656842255,0.120992516399386,-0.0919989546232345,0.245670511459264,-0.116092284443336,0.396783126454799,-0.120344740273802,0.570306654876705,-0.0950308005337515,0.7408836798323,-0.0476773973570985,0.825204455146615,-0.0267533162799515,1,0],"Bot_Xtr":0.414688723426267,"sym":0.000615778978064873,"alpha":0.7,"CDpres":0.00105,"clcd":220.093681433532,"Top_Xtr":0.349432800499589,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re65536000-N11.dat","diter":3,"src":"retest_152.txt","Re":30000000},
             {"src":"retest_153.txt","Re":30000000,"Top_Xtr":0.382180244936015,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re65536000-N11.dat","diter":4,"alpha":0,"clcd":230.042993585213,"CDpres":0.00097,"Bot_Xtr":0.414743042747213,"xy":[1,0,0.867935867415093,0.0195910806779479,0.765256324145788,0.040372601554045,0.608365821336593,0.085773514036814,0.435418780836389,0.117196662932154,0.270182631260474,0.118634635736159,0.123421225360211,0.0927527287026748,0.0257824653263784,0.0477047174799002,0,0,0.0262080994032648,-0.0484087656842255,0.120992516399386,-0.0919989546232345,0.245670511459264,-0.116092284443336,0.396783126454799,-0.120344740273802,0.570306654876705,-0.0950308005337515,0.7408836798323,-0.0476773973570985,0.825204455146615,-0.0267533162799515,1,0],"sym":0.000615778978064873,"Cpmin":-0.812044343429085,"CDf":0.00338,"CDp":0.000225191164651105,"CL":-0.00540972096642205,"CD":0.0043470135056714,"n":9,"Cm":0.00101347114807741,"r":6,"id":1458,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt21.2031568209603>6.3962531633) l1 Foil spline 17pts Re65536000 N11","good":28.9124619977937,"iver":1.2020052},
             {"CDf":0.00312,"Cpmin":-0.542782957387419,"CL":0.00382806709671967,"CD":0.00403996104783749,"n":10,"CDp":8.19842030748214e-05,"Cm":-0.000737858238888999,"id":1459,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt2.75887459370442>0) l1 Foil spline 17pts Re65536000 N3","good":40.5887195721673,"xver":6.991,"iver":1.2020052,"r":6,"Re":30000000,"src":"retest_102.txt","diter":4,"Top_Xtr":0.481514332920332,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re65536000-N3.dat","clcd":247.527139038947,"CDpres":0.00092,"alpha":0,"sym":0.000215913119795892,"xy":[1,0,0.910673421760927,0.016998297247575,0.849186318940748,0.0339885903030581,0.695794612861528,0.0761292010514374,0.498442662240797,0.0975223520472225,0.302873885493542,0.0930133634987499,0.139977327975174,0.069417384405533,0.0380656693660804,0.035624368865304,0,0,0.0396582029585364,-0.0363705244715021,0.144634720957126,-0.0699508361660275,0.306852823166501,-0.0927320471047102,0.500818080902831,-0.0967747095956732,0.698940635957709,-0.0750296646202015,0.860665749892887,-0.0302869965885877,0.919783730358342,-0.0149574779346378,1,0],"Bot_Xtr":0.48042556410622},
             {"sym":0.000250140694931259,"Bot_Xtr":0.507205535784256,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"CDpres":0.00076,"clcd":269.533877681629,"alpha":0,"diter":4,"Top_Xtr":0.507764025773877,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","Re":30000000,"src":"retest_65.txt","id":1460,"good":48.420040030379,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","xver":6.991,"iver":1.2020052,"r":6,"Cm":0.000610467773609317,"CL":-0.00332270336569715,"CD":0.00371010875739038,"n":11,"CDp":3.01306813584839e-05,"CDf":0.00295,"Cpmin":-0.51182299664968},
             {"Cpmin":-0.466728401131535,"CDf":0.00287,"CDp":8.71530166936772e-09,"n":12,"CL":0.0048211830870366,"CD":0.00349796144462446,"Cm":-0.000929615444104771,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt48.8352366403963>27.1369023540978) l1 Foil spline 17pts Re10000000 N6","good":52.0471746419701,"xver":6.991,"iver":1.2020052,"id":1461,"src":"retest_67.txt","Re":30000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N6.dat","Top_Xtr":0.520155396688865,"diter":10,"alpha":0,"clcd":285.880795380625,"CDpres":0.00063,"Bot_Xtr":0.518791363813408,"xy":[1,0,0.910673421760927,0.014779067524005,0.849186318940748,0.029551175851234,0.695794612861528,0.0661900769530461,0.498442662240797,0.0847902236920406,0.302873885493542,0.0808699106599605,0.139977327975174,0.060354528252266,0.0380656693660804,0.0309733937048017,0,0,0.0396582029585364,-0.0315251984703351,0.144634720957126,-0.0606318997414456,0.306852823166501,-0.0803781697409137,0.500818080902831,-0.083882263762875,0.698940635957709,-0.065034120422648,0.860665749892887,-0.0262521256539404,0.919783730358342,-0.0129648243284087,1,0],"sym":0.000291833128254308},
             {"Cpmin":-0.511935495391163,"CDf":0.00265,"CDp":-5.87016802018765e-05,"CL":0.00700993389915396,"CD":0.00328007077356843,"n":13,"Cm":0.000675221262505795,"r":6,"id":1462,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","xver":6.991,"iver":1.2020052,"good":68.19456849043,"src":"retest_67.txt","Re":30000000,"Top_Xtr":0.551953595737746,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","diter":4,"alpha":0.1,"clcd":304.871470475037,"CDpres":0.00063,"Bot_Xtr":0.563758121410821,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"sym":0.000250140694931259},
             {"CDp":-0.000104964052458911,"CD":0.00308626554149137,"CL":0.0125821520313863,"n":14,"Cpmin":-0.366315069044798,"CDf":0.00269,"r":6,"id":1463,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt86.7203906558262>71.0127337618216) l1 Foil spline 17pts Re13000000 N11","good":57.6443595236678,"iver":1.2020052,"Cm":-0.000365510422302739,"Top_Xtr":0.540911298870308,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re13000000-N11.dat","diter":4,"src":"retest_92.txt","Re":30000000,"xy":[1,0,0.910673421760927,0.0117468454761114,0.849186318940748,0.0234881595742091,0.695794612861528,0.0526098554429404,0.498442662240797,0.0673938091139739,0.302873885493542,0.0642778269093435,0.139977327975174,0.0479715865707639,0.0380656693660804,0.0246185809172398,0,0,0.0396582029585364,-0.0252068200563929,0.144634720957126,-0.0484798656509022,0.306852823166501,-0.0642685267478311,0.500818080902831,-0.0670703193378247,0.698940635957709,-0.0519997795592641,0.860665749892887,-0.0209905929086973,0.919783730358342,-0.010366373877597,1,0],"Bot_Xtr":0.553931359025903,"sym":5.52234539730649e-05,"alpha":0.1,"CDpres":0.00039,"clcd":324.016189325294},
             {"diter":3,"Top_Xtr":0.316477257500875,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N3.dat","Re":36000000,"src":"retestc_21.txt","sym":0.00086608867785912,"Bot_Xtr":0.32503028397802,"xy":[1,0,0.94211262451681,0.0268340574624991,0.870368703940721,0.0501850827848079,0.612947600635354,0.132164007414666,0.407050317206713,0.18871564244582,0.25912563537128,0.196780218678343,0.123234615368669,0.155594305871952,0.0345811184073606,0.083373671038442,0,0,0.0345316777956586,-0.082697415786458,0.128173188513251,-0.157122030866487,0.264469450799845,-0.195966183199285,0.407758505638372,-0.187298591985348,0.611699288725026,-0.131727546092307,0.879132615239467,-0.0470584405956135,0.940446499493271,-0.0274409507941345,1,0],"CDpres":0.00278,"clcd":146.33740786706,"alpha":0.8,"CL":0.0649519772934498,"CD":0.0068335227101224,"n":3,"CDp":-0.00478972487808324,"CDf":0.00406,"Cpmin":-1.75977390186378,"id":1464,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt12.7873196579229>12.1660261200543) l1 Foil spline 17pts Re36000000 N3","good":12.7873196578417,"iver":1.2020052,"r":6,"Cm":0.00457745977267739},
             {"diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N4.dat","Top_Xtr":0.319412965151436,"Re":36000000,"src":"retestc_22.txt","sym":0.00117229540331301,"Bot_Xtr":0.330974639560643,"xy":[1,0,0.94211262451681,0.0272417719626303,0.870368703940721,0.0509475908762603,0.612947600635354,0.134172096660719,0.407050317206713,0.191582972663558,0.25912563537128,0.199770081415511,0.123234615368669,0.157958393178931,0.0345811184073606,0.0846404438572396,0,0,0.0345316777956586,-0.085214770528189,0.128173188513251,-0.161904911754247,0.264469450799845,-0.201931501411519,0.407758505638372,-0.193000063962071,0.611699288725026,-0.135737404920645,0.879132615239467,-0.0484909253648804,0.940446499493271,-0.0282762684028201,1,0],"CDpres":0.00285,"clcd":145.453767821719,"alpha":0.2,"n":4,"CD":0.00687503675549807,"CL":0.0019290960759072,"CDp":-0.00523756101839132,"CDf":0.00402,"Cpmin":-1.73516825050529,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.21287648185>13.5199346256169) l1 Foil spline 17pts Re36000000 N4","iver":1.2020052,"good":14.2128763282731,"id":1465,"r":6,"Cm":0.00315342289387134},
             {"CL":0.085498435803501,"CD":0.00598085740684017,"n":5,"CDp":-0.00172563932129277,"CDf":0.00405,"Cpmin":-1.44796678556768,"id":1466,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt14.8473834171576>14.4622137947907) l1 Foil spline 17pts Re36000000 N5","xver":6.991,"good":14.8473834171065,"iver":1.2020052,"r":6,"Cm":0.00466470666957111,"diter":15,"Top_Xtr":0.299171649686496,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re36000000-N5.dat","Re":36000000,"src":"retestc_23.txt","sym":0.000902203136885201,"Bot_Xtr":0.316971035053533,"xy":[1,0,0.934059429447841,0.0232691417222156,0.803112667984734,0.0567979228093944,0.640336773132615,0.100537225273333,0.409507830013704,0.156742711165297,0.253558173430737,0.165191677073671,0.123492454733844,0.132368996815908,0.0350150102873282,0.0722376401135204,0,0,0.033652356669074,-0.0707988210891594,0.123386675148442,-0.13361910872794,0.261115618487171,-0.167240010654038,0.416397663171949,-0.156531219164935,0.629871409666205,-0.104080748054987,0.80244136469583,-0.0574267609532648,0.93425668155926,-0.0233744571559398,1,0],"CDpres":0.00193,"clcd":167.20010727163,"alpha":1},
             {"xy":[1,0,0.934059429447841,0.0227295946280538,0.803112667984734,0.0554809359358745,0.640336773132615,0.098206044845671,0.409507830013704,0.153108280839079,0.253558173430737,0.161361338576066,0.123492454733844,0.129299725570679,0.0350150102873282,0.070562648862118,0,0,0.033652356669074,-0.0691328935412532,0.123386675148442,-0.130474992050118,0.261115618487171,-0.163304779296021,0.416397663171949,-0.152847970403126,0.629871409666205,-0.101631682057502,0.80244136469583,-0.0560754838897867,0.93425668155926,-0.0228244458493335,1,0],"Bot_Xtr":0.320445863713221,"sym":0.000814351727252612,"alpha":1,"CDpres":0.00181,"clcd":172.121742665505,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N12.dat","Top_Xtr":0.304956515726478,"diter":13,"src":"retest_109.txt","Re":36000000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt19.9565963460249>18.8009946499824) l1 Foil spline 17pts Re45000000 N12","xver":6.991,"iver":1.2020052,"good":15.946109351202,"id":1467,"Cm":0.00432032597806198,"CDp":-0.00155800404982717,"n":6,"CD":0.00580984124674687,"CL":0.0879625367927106,"Cpmin":-1.41062470992236,"CDf":0.004},
             {"CDp":0.000503473999599035,"n":7,"CD":0.00542688643538503,"CL":-0.0448240671546609,"Cpmin":-1.08259146025189,"CDf":0.00369,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","iver":1.2020052,"good":20.0790734590762,"id":1468,"Cm":0.00209760694439832,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.335774350688985,"diter":3,"src":"retestc_19.txt","Re":36000000,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"Bot_Xtr":0.354206534542017,"sym":0.000990696463258582,"alpha":-0.3,"CDpres":0.00174,"clcd":184.26772181553},
             {"CDf":0.00348,"Cpmin":-1.0909592540185,"n":8,"CD":0.00501319507927437,"CL":0.0595448628538508,"CDp":0.000352425203427425,"Cm":0.00112345717718163,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt25.4879963271261>5.90468665950213) l1 Foil spline 17pts Re36000000 N8","xver":6.991,"iver":1.2020052,"good":25.4879868876045,"id":1469,"r":6,"Re":36000000,"src":"retestc_2.txt","diter":3,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re36000000-N8.dat","Top_Xtr":0.343200997935276,"CDpres":0.00154,"clcd":199.473586043802,"alpha":0.6,"sym":0.000990696463258582,"xy":[1,0,0.867935867415093,0.0244215849421494,0.765256324145788,0.050327132759832,0.608365821336593,0.106922389493019,0.435418780836389,0.146093434343095,0.270182631260474,0.147885963073633,0.123421225360211,0.115622444716806,0.0257824653263784,0.0594671028734008,0,0,0.0262080994032648,-0.0604398151446136,0.120992516399386,-0.114863490781751,0.245670511459264,-0.144944745281071,0.396783126454799,-0.150254065621535,0.570306654876705,-0.118648842541677,0.7408836798323,-0.0595266795612252,0.825204455146615,-0.0334023284339298,1,0],"Bot_Xtr":0.404618659905754},
             {"Cpmin":-0.497449225194502,"CDf":0.00365,"CDp":0.000258692959913323,"CD":0.00463067901011229,"CL":0.0841281500060425,"n":9,"Cm":0.000294288635134893,"r":6,"id":1470,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt48.8352366403963>27.1369023540978) l1 Foil spline 17pts Re10000000 N6","good":19.3026882170848,"xver":6.991,"iver":1.2020052,"src":"retest_74.txt","Re":36000000,"Top_Xtr":0.303570673669098,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N6.dat","diter":3,"alpha":0.8,"clcd":215.951051199239,"CDpres":0.00098,"Bot_Xtr":0.426394154645782,"xy":[1,0,0.910673421760927,0.014779067524005,0.849186318940748,0.029551175851234,0.695794612861528,0.0661900769530461,0.498442662240797,0.0847902236920406,0.302873885493542,0.0808699106599605,0.139977327975174,0.060354528252266,0.0380656693660804,0.0309733937048017,0,0,0.0396582029585364,-0.0315251984703351,0.144634720957126,-0.0606318997414456,0.306852823166501,-0.0803781697409137,0.500818080902831,-0.083882263762875,0.698940635957709,-0.065034120422648,0.860665749892887,-0.0262521256539404,0.919783730358342,-0.0129648243284087,1,0],"sym":0.000291833128254308},
             {"Cm":-0.00052383907404535,"r":6,"id":1471,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","xver":6.991,"good":27.8157141111977,"iver":1.2020052,"Cpmin":-0.524160533776318,"CDf":0.00341,"CDp":0.000199823513783127,"CL":-0.0403670340224116,"CD":0.00439786400510195,"n":10,"alpha":-0.4,"CDpres":0.00099,"clcd":227.383111173948,"Bot_Xtr":0.380143874634232,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"sym":0.000250140694931259,"src":"retest_76.txt","Re":36000000,"Top_Xtr":0.446622505435212,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","diter":4},
             {"Cpmin":-0.535774479336167,"CDf":0.00319,"CDp":0.000122183162660336,"CD":0.00408857458101939,"CL":0.0704150704951908,"n":11,"Cm":0.00296152123620344,"r":6,"id":1472,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","good":36.8886545493662,"xver":6.991,"iver":1.2020052,"src":"retest_152.txt","Re":36000000,"Top_Xtr":0.381342397625206,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","diter":3,"alpha":0.8,"CDpres":0.0009,"clcd":244.584018264545,"Bot_Xtr":0.521137797977687,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"sym":0.000250140694931259},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt63.0705525476291>40.2214842027205) l1 Foil spline 17pts Re16000000 N9","good":39.9572381424297,"xver":6.991,"iver":1.2020052,"id":1473,"r":6,"Cm":0.00250058295517494,"n":12,"CL":0.0512356952573524,"CD":0.00380464207885743,"CDp":8.13863920009318e-05,"CDf":0.00307,"Cpmin":-0.482568521170813,"sym":0.000613495700008926,"Bot_Xtr":0.529357817167781,"xy":[1,0,0.910673421760927,0.014722606251893,0.849186318940748,0.0294382798936063,0.695794612861528,0.0659372074171373,0.498442662240797,0.0844662950081411,0.302873885493542,0.0805609589602657,0.139977327975174,0.0601239525791183,0.0380656693660804,0.0308550643712792,0,0,0.0396582029585364,-0.032163775830461,0.144634720957126,-0.0618600651568908,0.306852823166501,-0.0820063174429243,0.500818080902831,-0.0855813907201719,0.698940635957709,-0.0663514576307446,0.860665749892887,-0.0267838911593523,0.919783730358342,-0.0132274410190513,1,0],"clcd":262.836813364665,"CDpres":0.00074,"alpha":0.6,"diter":5,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re16000000-N9.dat","Top_Xtr":0.4101105063094,"Re":36000000,"src":"retest_69.txt"},
             {"xy":[1,0,0.910673421760927,0.0158252047798378,0.849186318940748,0.0316429577557032,0.695794612861528,0.070875345854792,0.498442662240797,0.0907921051903536,0.302873885493542,0.0865942925453429,0.139977327975174,0.0646267274597164,0.0380656693660804,0.0331658473925287,0,0,0.0396582029585364,-0.0345424669123108,0.144634720957126,-0.0664349628954824,0.306852823166501,-0.0880711431955055,0.500818080902831,-0.0919106131333434,0.698940635957709,-0.0712585189585541,0.860665749892887,-0.0287647096855668,0.919783730358342,-0.0142056842499942,1,0],"Bot_Xtr":0.536522871911271,"sym":0.000632587599920376,"alpha":0.2,"clcd":285.507697588455,"CDpres":0.0007,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N10.dat","Top_Xtr":0.498266615072805,"diter":4,"src":"retest_70.txt","Re":36000000,"r":6,"good":56.8737706743246,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt121.166970570197>107.079217347325) l1 Foil spline 17pts Re8192000 N10","xver":6.991,"iver":1.2020052,"id":1474,"Cm":0.00176903954475056,"CDp":5.63859353668776e-06,"n":13,"CL":0.0121229059949795,"CD":0.00350253253571275,"Cpmin":-0.511645535123474,"CDf":0.0028},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt121.166970570197>107.079217347325) l1 Foil spline 17pts Re8192000 N10","xver":6.991,"iver":1.2020052,"good":64.5940801737503,"id":1475,"r":6,"Cm":0.00128271937551365,"n":14,"CD":0.00327675864244442,"CL":0.00382931684206482,"CDp":-4.08951107638661e-05,"CDf":0.00265,"Cpmin":-0.505509504511197,"sym":0.000632587599920376,"Bot_Xtr":0.550717692266855,"xy":[1,0,0.910673421760927,0.0158252047798378,0.849186318940748,0.0316429577557032,0.695794612861528,0.070875345854792,0.498442662240797,0.0907921051903536,0.302873885493542,0.0865942925453429,0.139977327975174,0.0646267274597164,0.0380656693660804,0.0331658473925287,0,0,0.0396582029585364,-0.0345424669123108,0.144634720957126,-0.0664349628954824,0.306852823166501,-0.0880711431955055,0.500818080902831,-0.0919106131333434,0.698940635957709,-0.0712585189585541,0.860665749892887,-0.0287647096855668,0.919783730358342,-0.0142056842499942,1,0],"CDpres":0.00063,"clcd":305.179633021128,"alpha":0.1,"diter":4,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re8192000-N10.dat","Top_Xtr":0.536780533823649,"Re":36000000,"src":"retest_71.txt"},
             {"id":1476,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.0963339431087>13.2691910720325) l1 Foil spline 17pts Re55000000 N6","iver":1.2020052,"xver":6.991,"good":12.2294077245627,"r":6,"Cm":0.00890836757495669,"CD":0.00730619212071341,"CL":0.0160154922612823,"n":3,"CDp":-0.00688831626890316,"CDf":0.00398,"Cpmin":-1.92012802093975,"sym":0.00030814107380968,"Bot_Xtr":0.324017033209209,"xy":[1,0,0.94211262451681,0.029249679081892,0.870368703940721,0.0547027809046478,0.612947600635354,0.144061508717353,0.407050317206713,0.205703963591321,0.25912563537128,0.214494518916858,0.123234615368669,0.169601019901092,0.0345811184073606,0.0908790303203946,0,0,0.0345316777956586,-0.0907058137301499,0.128173188513251,-0.1723376907143,0.264469450799845,-0.214943501458162,0.407758505638372,-0.205436542786436,0.611699288725026,-0.144484010115043,0.879132615239467,-0.05161556871522,0.940446499493271,-0.0300983258985774,1,0],"clcd":136.870203175325,"CDpres":0.00333,"alpha":0.6,"diter":3,"Top_Xtr":0.309338152658037,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N6.dat","Re":45000000,"src":"retest_157.txt"},
             {"alpha":0.9,"clcd":149.368119942793,"CDpres":0.00278,"Bot_Xtr":0.328664282011969,"xy":[1,0,0.94211262451681,0.0272417719626303,0.870368703940721,0.0509475908762603,0.612947600635354,0.134172096660719,0.407050317206713,0.191582972663558,0.25912563537128,0.199770081415511,0.123234615368669,0.157958393178931,0.0345811184073606,0.0846404438572396,0,0,0.0345316777956586,-0.085214770528189,0.128173188513251,-0.161904911754247,0.264469450799845,-0.201931501411519,0.407758505638372,-0.193000063962071,0.611699288725026,-0.135737404920645,0.879132615239467,-0.0484909253648804,0.940446499493271,-0.0282762684028201,1,0],"sym":0.00117229540331301,"src":"retestc_9.txt","Re":45000000,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N4.dat","Top_Xtr":0.31444647427095,"diter":6,"Cm":0.00709262757206457,"r":6,"good":12.88387979386,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.21287648185>13.5199346256169) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"iver":1.2020052,"id":1477,"Cpmin":-1.79627469935151,"CDf":0.00392,"CDp":-0.00525975460716789,"n":4,"CD":0.00669486902816338,"CL":0.0559920965612912},
             {"xy":[1,0,0.94211262451681,0.0272417719626303,0.870368703940721,0.0509475908762603,0.612947600635354,0.134172096660719,0.407050317206713,0.191582972663558,0.25912563537128,0.199770081415511,0.123234615368669,0.157958393178931,0.0345811184073606,0.0846404438572396,0,0,0.0345316777956586,-0.085214770528189,0.128173188513251,-0.161904911754247,0.264469450799845,-0.201931501411519,0.407758505638372,-0.193000063962071,0.611699288725026,-0.135737404920645,0.879132615239467,-0.0484909253648804,0.940446499493271,-0.0282762684028201,1,0],"Bot_Xtr":0.33067554571336,"sym":0.00117229540331301,"alpha":0.5,"clcd":151.378451719235,"CDpres":0.00272,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N4.dat","Top_Xtr":0.320750221288797,"diter":3,"src":"retest_100.txt","Re":45000000,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.21287648185>13.5199346256169) l1 Foil spline 17pts Re36000000 N4","xver":6.991,"good":14.1024317908294,"iver":1.2020052,"id":1478,"Cm":0.00400329050434344,"CDp":-0.00522832631595321,"n":5,"CL":0.0294221042026033,"CD":0.00660596002035164,"Cpmin":-1.76476477687169,"CDf":0.00389},
             {"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re45000000-N6.dat","Top_Xtr":0.318471099836596,"diter":4,"src":"retestc_10.txt","Re":45000000,"xy":[1,0,0.94211262451681,0.0261608724212786,0.870368703940721,0.0489260914052762,0.612947600635354,0.128848413680709,0.407050317206713,0.1839813398635,0.25912563537128,0.191843600360093,0.123234615368669,0.151690917077378,0.0345811184073606,0.0812820787306759,0,0,0.0345316777956586,-0.0816543414122058,0.128173188513251,-0.155140228140626,0.264469450799845,-0.193494433605042,0.407758505638372,-0.18493616796308,0.611699288725026,-0.130066047647582,0.879132615239467,-0.0464648857304373,0.940446499493271,-0.027094834143375,1,0],"Bot_Xtr":0.33587886989547,"sym":0.000687853808457282,"alpha":1.1,"clcd":158.873917753412,"CDpres":0.00244,"CDp":-0.00444455549440545,"n":6,"CL":0.0568132638340446,"CD":0.0062942993673266,"Cpmin":-1.71331961952851,"CDf":0.00386,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.2495942783375>15.0777024837279) l1 Foil spline 17pts Re45000000 N6","good":15.2495942783026,"xver":6.991,"iver":1.2020052,"id":1479,"Cm":0.0117789205728732},
             {"CDp":-0.0028461995114536,"CL":0.0472857851469077,"CD":0.00599332435274612,"n":7,"Cpmin":-1.50578620283041,"CDf":0.00392,"r":6,"id":1480,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt16.344500788256>16.2000027753785) l1 Foil spline 17pts Re45000000 N7","good":16.3445007882418,"iver":1.2020052,"Cm":0.00211351168942676,"Top_Xtr":0.315130751121592,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re45000000-N7.dat","diter":3,"src":"retest_110.txt","Re":45000000,"xy":[1,0,0.94211262451681,0.023884399485241,0.870368703940721,0.0446686293009307,0.612947600635354,0.117636252179668,0.407050317206713,0.167971608452764,0.25912563537128,0.175149708920274,0.123234615368669,0.138491041254869,0.0345811184073606,0.0742090557276374,0,0,0.0345316777956586,-0.0735903176821595,0.128173188513251,-0.139818881356439,0.264469450799845,-0.174385300186819,0.407758505638372,-0.166672232191807,0.611699288725026,-0.117220978095081,0.879132615239467,-0.0418761041094746,0.940446499493271,-0.0244190010925535,1,0],"Bot_Xtr":0.316924086525114,"sym":0.000719117405195286,"alpha":0.5,"clcd":166.85230785846,"CDpres":0.00207},
             {"Cpmin":-1.46754062703771,"CDf":0.00385,"CDp":-0.00288157430730362,"CL":-0.0228511392325811,"CD":0.00584743355558357,"n":8,"Cm":-0.0036192872430292,"r":6,"id":1481,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt16.344500788256>16.2000027753785) l1 Foil spline 17pts Re45000000 N7","xver":6.991,"iver":1.2020052,"good":17.78458397815,"src":"retest_111.txt","Re":45000000,"Top_Xtr":0.331822348644025,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re45000000-N7.dat","diter":3,"alpha":-0.4,"CDpres":0.002,"clcd":171.015196751594,"Bot_Xtr":0.317186513089818,"xy":[1,0,0.94211262451681,0.023884399485241,0.870368703940721,0.0446686293009307,0.612947600635354,0.117636252179668,0.407050317206713,0.167971608452764,0.25912563537128,0.175149708920274,0.123234615368669,0.138491041254869,0.0345811184073606,0.0742090557276374,0,0,0.0345316777956586,-0.0735903176821595,0.128173188513251,-0.139818881356439,0.264469450799845,-0.174385300186819,0.407758505638372,-0.166672232191807,0.611699288725026,-0.117220978095081,0.879132615239467,-0.0418761041094746,0.940446499493271,-0.0244190010925535,1,0],"sym":0.000719117405195286},
             {"Top_Xtr":0.320440296682293,"Foil_fn":"optbs_spline_sym_naca633018.dat-s17_n17s0_nsopt-Re45000000-N9.dat","diter":3,"src":"retestc_13.txt","Re":45000000,"xy":[1,0,0.941701382715975,0.00480759153374923,0.840420457463641,0.020996854406255,0.690206567397583,0.0520735710620504,0.493921513622977,0.0871571563836827,0.305452081941457,0.097200391677963,0.139938788091908,0.0761734536229195,0.0386682922645405,0.0415324540906658,0,0,0.0405377285335924,-0.0424027861581172,0.148258857506298,-0.0773254029520778,0.309953500079998,-0.096458941003623,0.492786686674529,-0.0865602224783985,0.688332798275104,-0.0520300777437361,0.843872499199579,-0.0201416230248084,0.944032400719071,-0.00452313135779394,1,0],"Bot_Xtr":0.336998978127881,"sym":0.000312397105578103,"alpha":0.1,"CDpres":0.00079,"clcd":229.161635756398,"CDp":0.000283503554707851,"CL":0.0154302911227422,"CD":0.00436373216092337,"n":9,"Cpmin":-0.700509649944086,"CDf":0.00357,"r":6,"id":1482,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca633018.dat-s17_n17s0.dat (opt19.90207213763>16.9357551632277) l1 Foil spline 17pts Re45000000 N9","good":19.9020721376031,"xver":6.991,"iver":1.2020052,"Cm":-0.00063742215591433},
             {"Cm":0.00220845049540313,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt67.8462156431864>37.3379899972252) l1 Foil spline 17pts Re20000000 N10","xver":6.991,"good":24.0409159517009,"iver":1.2020052,"id":1483,"r":6,"CDf":0.00352,"Cpmin":-0.568966686692061,"n":10,"CL":0.0635763801196443,"CD":0.00470507251806765,"CDp":0.000253311041840752,"clcd":212.536575400265,"CDpres":0.00118,"alpha":0.7,"sym":7.85400925867198e-05,"xy":[1,0,0.910673421760927,0.0170236138564171,0.849186318940748,0.034039211599607,0.695794612861528,0.0762425849496249,0.498442662240797,0.0976675980800562,0.302873885493542,0.0931518940178065,0.139977327975174,0.0695207719826673,0.0380656693660804,0.0356774264274041,0,0,0.0396582029585364,-0.0367065728461499,0.144634720957126,-0.0705971525208346,0.306852823166501,-0.0935888522830824,0.500818080902831,-0.0976688672780052,0.698940635957709,-0.075722907217397,0.860665749892887,-0.0305668357199847,0.919783730358342,-0.0150956787503204,1,0],"Bot_Xtr":0.422051363432852,"Re":45000000,"src":"retest_70.txt","diter":5,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N10.dat","Top_Xtr":0.324780690121204},
             {"CD":0.00437844128799808,"CL":0.0729426668745217,"n":11,"CDp":0.000207876773047901,"CDf":0.00338,"Cpmin":-0.537315918237322,"id":1484,"good":26.7779755724532,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","xver":6.991,"iver":1.2020052,"r":6,"Cm":0.00243559925654836,"diter":4,"Top_Xtr":0.335456526635855,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","Re":45000000,"src":"retest_92.txt","sym":0.000250140694931259,"Bot_Xtr":0.45848510808452,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"clcd":228.391780139005,"CDpres":0.001,"alpha":0.8},
             {"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re10000000-N8.dat","Top_Xtr":0.365087747870825,"diter":3,"src":"retest_93.txt","Re":45000000,"xy":[1,0,0.910673421760927,0.0159839452695534,0.849186318940748,0.0319603639870962,0.695794612861528,0.071586286867327,0.498442662240797,0.0917028285232097,0.302873885493542,0.0874629081870649,0.139977327975174,0.0652749894258896,0.0380656693660804,0.033498529523987,0,0,0.0396582029585364,-0.0346852586124908,0.144634720957126,-0.0667095918421446,0.306852823166501,-0.088435211815897,0.500818080902831,-0.0922905533601724,0.698940635957709,-0.0715530875283158,0.860665749892887,-0.028883617284483,0.919783730358342,-0.0142644077282977,1,0],"Bot_Xtr":0.493951328252404,"sym":0.000250140694931259,"alpha":0.8,"CDpres":0.00091,"clcd":243.241523851724,"CDp":0.000149405125250109,"n":12,"CD":0.00411114017115591,"CL":0.0724708439374854,"Cpmin":-0.536988529328661,"CDf":0.0032,"r":6,"good":32.9627300150369,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt76.6295329177673>55.9550183383669) l1 Foil spline 17pts Re10000000 N8","xver":6.991,"iver":1.2020052,"id":1485,"Cm":0.0025369129318857},
             {"Cpmin":-0.725783356625646,"CDf":0.00302,"CDp":0.000107127516562101,"CD":0.00365933683970926,"CL":0.00614818526456817,"n":13,"Cm":0.000570032532207312,"r":6,"id":1486,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711520.dat-s17_n17s0.dat (opt19.4125984978855>6.77310804867891) l1 Foil spline 17pts Re30000000 N7","xver":6.991,"good":29.8220022770142,"iver":1.2020052,"src":"retest_99.txt","Re":45000000,"Top_Xtr":0.403360351285435,"Foil_fn":"optbs_spline_sym_fx711520.dat-s17_n17s0_nsopt-Re30000000-N7.dat","diter":3,"alpha":0.1,"clcd":273.273558517081,"CDpres":0.00064,"Bot_Xtr":0.429341640869994,"xy":[1,0,0.853694247755346,0.0161755229516158,0.766409503853615,0.0320054103325881,0.583893795685248,0.0785659338051314,0.444207114147005,0.102388518951634,0.300186235321574,0.106831018897361,0.144251593783031,0.087559737627556,0.0289129616777066,0.04487412729606,0,0,0.0259166339183309,-0.0432617880933848,0.114364051808134,-0.0803391028716537,0.242100554077629,-0.103853878148252,0.400816303377971,-0.107232822053974,0.562528610462096,-0.084237243610787,0.754321232202995,-0.035342196214169,0.842007085235557,-0.017868989002118,1,0],"sym":0.000918659341396021},
             {"Cm":0.00180422398202601,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt63.0705525476291>40.2214842027205) l1 Foil spline 17pts Re16000000 N9","good":41.3051848121588,"xver":6.991,"iver":1.2020052,"id":1487,"r":6,"CDf":0.00293,"Cpmin":-0.474095431215488,"n":14,"CD":0.00362830160910653,"CL":0.0333259644607765,"CDp":6.53962745975536e-05,"clcd":275.611045534401,"CDpres":0.0007,"alpha":0.4,"sym":0.000613495700008926,"xy":[1,0,0.910673421760927,0.014722606251893,0.849186318940748,0.0294382798936063,0.695794612861528,0.0659372074171373,0.498442662240797,0.0844662950081411,0.302873885493542,0.0805609589602657,0.139977327975174,0.0601239525791183,0.0380656693660804,0.0308550643712792,0,0,0.0396582029585364,-0.032163775830461,0.144634720957126,-0.0618600651568908,0.306852823166501,-0.0820063174429243,0.500818080902831,-0.0855813907201719,0.698940635957709,-0.0663514576307446,0.860665749892887,-0.0267838911593523,0.919783730358342,-0.0132274410190513,1,0],"Bot_Xtr":0.509956881951944,"Re":45000000,"src":"retest_83.txt","diter":3,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re16000000-N9.dat","Top_Xtr":0.437651118314209},
             {"alpha":2,"CDpres":0.00269,"clcd":145.513960418381,"Bot_Xtr":0.303239809269163,"xy":[1,0,0.934059429447841,0.0255974633309028,0.803112667984734,0.0624811505186229,0.640336773132615,0.110597028805229,0.409507830013704,0.17242646288107,0.253558173430737,0.181720836416866,0.123492454733844,0.145613902850086,0.0350150102873282,0.079465773426074,0,0,0.033652356669074,-0.0770300927566754,0.123386675148442,-0.145379431197245,0.261115618487171,-0.181959435695752,0.416397663171949,-0.17030812301812,0.629871409666205,-0.113241287828272,0.80244136469583,-0.0624811070988687,0.93425668155926,-0.0254317314209442,1,0],"sym":0.000579661259632415,"src":"retest_79.txt","Re":55000000,"Top_Xtr":0.229161821207883,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N6.dat","diter":15,"Cm":0.0212987863120302,"r":6,"id":1488,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt15.1201160281058>14.8990837741401) l1 Foil spline 17pts Re45000000 N6","iver":1.2020052,"good":8.91786832859108,"Cpmin":-1.66508635941485,"CDf":0.00419,"CDp":-0.00274388126206447,"CL":0.112076809935697,"CD":0.00687219286125403,"n":3},
             {"Re":55000000,"src":"retestc_18.txt","diter":6,"Top_Xtr":0.300944007583205,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re55000000-N4.dat","CDpres":0.00016,"clcd":245.314902142782,"alpha":-0.8,"sym":0.000710136447067271,"xy":[1,0,0.934059429447841,0.0307711045068562,0.803112667984734,0.0751095523592786,0.640336773132615,0.132950389947623,0.409507830013704,0.207276503943872,0.253558173430737,0.21844941337238,0.123492454733844,0.175044712998644,0.0350150102873282,0.09552702887789,0,0,0.033652356669074,-0.0927321272841155,0.123386675148442,-0.175013990452543,0.261115618487171,-0.219050567740904,0.416397663171949,-0.205024218147089,0.629871409666205,-0.136324715976646,0.80244136469583,-0.0752174347582184,0.93425668155926,-0.0306158083261306,1,0],"Bot_Xtr":0.300175087589646,"CDf":0.00391,"Cpmin":-2.01622141248834,"CL":-0.056445278733424,"CD":0.00407639320426594,"n":4,"CDp":-0.00820651744399134,"Cm":-0.0047887179393336,"id":1489,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt17.3175052471633>9.85188374516529) l1 Foil spline 17pts Re55000000 N4","good":17.3175052470549,"iver":1.2020052,"r":6},
             {"CDpres":0.00252,"clcd":155.167290199988,"alpha":1,"sym":0.000933753239449797,"xy":[1,0,0.934059429447841,0.0272498909967404,0.803112667984734,0.0665145807212826,0.640336773132615,0.117736548366005,0.409507830013704,0.183557341511659,0.253558173430737,0.193451707311088,0.123492454733844,0.155013914034381,0.0350150102873282,0.0845956349595762,0,0,0.033652356669074,-0.0827642663411574,0.123386675148442,-0.156201576988132,0.261115618487171,-0.195504622417903,0.416397663171949,-0.182985977935393,0.629871409666205,-0.121671047914226,0.80244136469583,-0.0671322440900606,0.93425668155926,-0.027324887164405,1,0],"Bot_Xtr":0.310834452056899,"Re":55000000,"src":"retest_97.txt","diter":3,"Top_Xtr":0.287548090064768,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N4.dat","Cm":0.0130509237917844,"id":1490,"good":12.5575514483338,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt12.5202252641475>11.7993684602621) l1 Foil spline 17pts Re45000000 N4","xver":6.991,"iver":1.2020052,"r":6,"CDf":0.00393,"Cpmin":-1.71708531758711,"CD":0.00644465723872053,"CL":0.0394096570961526,"n":5,"CDp":-0.00351248805468726},
             {"xy":[1,0,0.94211262451681,0.029249679081892,0.870368703940721,0.0547027809046478,0.612947600635354,0.144061508717353,0.407050317206713,0.205703963591321,0.25912563537128,0.214494518916858,0.123234615368669,0.169601019901092,0.0345811184073606,0.0908790303203946,0,0,0.0345316777956586,-0.0907058137301499,0.128173188513251,-0.1723376907143,0.264469450799845,-0.214943501458162,0.407758505638372,-0.205436542786436,0.611699288725026,-0.144484010115043,0.879132615239467,-0.05161556871522,0.940446499493271,-0.0300983258985774,1,0],"Bot_Xtr":0.330142110140338,"sym":0.00030814107380968,"alpha":1,"clcd":145.661641822075,"CDpres":0.00308,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N6.dat","Top_Xtr":0.321840435849511,"diter":3,"src":"retestc_20.txt","Re":55000000,"r":6,"good":14.0963340135977,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.0963339431087>13.2691910720325) l1 Foil spline 17pts Re55000000 N6","xver":6.991,"iver":1.2020052,"id":1491,"Cm":0.00840921547296808,"CDp":-0.00693050200921843,"n":6,"CD":0.00686522537773875,"CL":0.060421495716408,"Cpmin":-1.96773051766808,"CDf":0.00378},
             {"alpha":0.9,"clcd":158.167469013017,"CDpres":0.00252,"Bot_Xtr":0.327666135972133,"xy":[1,0,0.94211262451681,0.0268340574624991,0.870368703940721,0.0501850827848079,0.612947600635354,0.132164007414666,0.407050317206713,0.18871564244582,0.25912563537128,0.196780218678343,0.123234615368669,0.155594305871952,0.0345811184073606,0.083373671038442,0,0,0.0345316777956586,-0.082697415786458,0.128173188513251,-0.157122030866487,0.264469450799845,-0.195966183199285,0.407758505638372,-0.187298591985348,0.611699288725026,-0.131727546092307,0.879132615239467,-0.0470584405956135,0.940446499493271,-0.0274409507941345,1,0],"sym":0.00086608867785912,"src":"retest_157.txt","Re":55000000,"Top_Xtr":0.316649718227028,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re36000000-N3.dat","diter":3,"Cm":0.0050367485058616,"r":6,"id":1492,"good":15.027965216073,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt12.7873196579229>12.1660261200543) l1 Foil spline 17pts Re36000000 N3","xver":6.991,"iver":1.2020052,"Cpmin":-1.76968955848429,"CDf":0.0038,"CDp":-0.00476576044097982,"CD":0.006322412606335,"CL":0.0735429416532818,"n":7},
             {"CL":-0.0305408289032127,"CD":0.00504012793877191,"n":8,"CDp":-0.000556749269320419,"CDf":0.0038,"Cpmin":-1.03716415318134,"id":1493,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt17.2291233740456>15.5071997018388) l1 Foil spline 17pts Re20000000 N5","xver":6.991,"good":17.1004574559414,"r":6,"Cm":-0.000387303676635655,"diter":3,"Top_Xtr":0.300217349740472,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re20000000-N5.dat","Re":55000000,"src":"retest_96.txt","sym":0.000282422749798419,"Bot_Xtr":0.306117425953353,"xy":[1,0,0.94211262451681,0.0178798659616771,0.870368703940721,0.033438944323721,0.612947600635354,0.0880625205798547,0.407050317206713,0.12574357778426,0.25912563537128,0.131117105148757,0.123234615368669,0.103674419616884,0.0345811184073606,0.0555529131210809,0,0,0.0345316777956586,-0.0551813673329278,0.128173188513251,-0.104842556673446,0.264469450799845,-0.130762029709305,0.407758505638372,-0.124978420510404,0.611699288725026,-0.087897620979531,0.879132615239467,-0.0314006075271646,0.940446499493271,-0.0183104776773919,1,0],"CDpres":0.00124,"clcd":198.407661898293,"alpha":-0.3},
             {"Top_Xtr":0.307027966831819,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re20000000-N5.dat","diter":2,"src":"retest_97.txt","Re":55000000,"xy":[1,0,0.94211262451681,0.0178798659616771,0.870368703940721,0.033438944323721,0.612947600635354,0.0880625205798547,0.407050317206713,0.12574357778426,0.25912563537128,0.131117105148757,0.123234615368669,0.103674419616884,0.0345811184073606,0.0555529131210809,0,0,0.0345316777956586,-0.0551813673329278,0.128173188513251,-0.104842556673446,0.264469450799845,-0.130762029709305,0.407758505638372,-0.124978420510404,0.611699288725026,-0.087897620979531,0.879132615239467,-0.0314006075271646,0.940446499493271,-0.0183104776773919,1,0],"Bot_Xtr":0.324238893215131,"sym":0.000282422749798419,"alpha":0.7,"CDpres":0.00117,"clcd":205.017135629196,"CDp":-0.000618293907298424,"CL":0.0706742526806201,"CD":0.00487764106610411,"n":9,"Cpmin":-1.08278010453855,"CDf":0.00371,"r":6,"id":1494,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt17.2291233740456>15.5071997018388) l1 Foil spline 17pts Re20000000 N5","xver":6.991,"good":19.1143363337655,"iver":1.2020052,"Cm":0.00210164911513497},
             {"diter":2,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re100000000-N12.dat","Top_Xtr":0.332164935553528,"Re":55000000,"src":"retest_93.txt","sym":0.000176424247568075,"Bot_Xtr":0.316631417106441,"xy":[1,0,0.94211262451681,0.0189000588059641,0.870368703940721,0.0353469100653373,0.612947600635354,0.0930872088822169,0.407050317206713,0.132918279124052,0.25912563537128,0.138598410250434,0.123234615368669,0.109589894668847,0.0345811184073606,0.0587226619641035,0,0,0.0345316777956586,-0.0588047911815373,0.128173188513251,-0.111726927948767,0.264469450799845,-0.139348374699321,0.407758505638372,-0.133184991157825,0.611699288725026,-0.0936693216728413,0.879132615239467,-0.0334624939151603,0.940446499493271,-0.0195128150731908,1,0],"clcd":203.310527940585,"CDpres":0.00126,"alpha":-1.8,"n":10,"CL":-0.142788381062113,"CD":0.00491858444385249,"CDp":-0.00110459529739149,"CDf":0.00366,"Cpmin":-1.2224218335103,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt19.8645642108868>17.3838054208721) l1 Foil spline 17pts Re100000000 N12","xver":6.991,"good":20.7488864646704,"iver":1.2020052,"id":1495,"r":6,"Cm":-0.0129211382762681},
             {"Cpmin":-0.617615281506782,"CDf":0.00345,"CDp":0.000212632458097709,"n":11,"CL":0.0885743346979359,"CD":0.00471570128341802,"Cm":0.00361968049330217,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt60.1540588960657>28.9686109611356) l1 Foil spline 17pts Re20000000 N9","good":23.8328417468501,"iver":1.2020052,"id":1496,"src":"retest_150.txt","Re":55000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N9.dat","Top_Xtr":0.311812295778728,"diter":3,"alpha":1,"CDpres":0.00127,"clcd":212.05753712949,"Bot_Xtr":0.435052411115667,"xy":[1,0,0.910673421760927,0.0180477615490604,0.849186318940748,0.0360870247321865,0.695794612861528,0.0808293705825639,0.498442662240797,0.10354332141726,0.302873885493542,0.0987559507197696,0.139977327975174,0.0737031705507591,0.0380656693660804,0.0378237952456384,0,0,0.0396582029585364,-0.0388689937986743,0.144634720957126,-0.0747561014491226,0.306852823166501,-0.0991022652608588,0.500818080902831,-0.103422638023547,0.698940635957709,-0.0801838194861418,0.860665749892887,-0.0323675586120484,0.919783730358342,-0.0159849802974599,1,0],"sym":8.14582294892033e-05},
             {"Foil_fn":"optbs_spline_sym_naca633018.dat-s17_n17s0_nsopt-Re45000000-N9.dat","Top_Xtr":0.337220228339425,"diter":3,"src":"retest_90.txt","Re":55000000,"xy":[1,0,0.941701382715975,0.00480759153374923,0.840420457463641,0.020996854406255,0.690206567397583,0.0520735710620504,0.493921513622977,0.0871571563836827,0.305452081941457,0.097200391677963,0.139938788091908,0.0761734536229195,0.0386682922645405,0.0415324540906658,0,0,0.0405377285335924,-0.0424027861581172,0.148258857506298,-0.0773254029520778,0.309953500079998,-0.096458941003623,0.492786686674529,-0.0865602224783985,0.688332798275104,-0.0520300777437361,0.843872499199579,-0.0201416230248084,0.944032400719071,-0.00452313135779394,1,0],"Bot_Xtr":0.368403981609252,"sym":0.000312397105578103,"alpha":0.6,"CDpres":0.0007,"clcd":248.668267064286,"CDp":0.000207950159423527,"n":12,"CL":0.0765959421963555,"CD":0.00402142183964903,"Cpmin":-0.740778974619041,"CDf":0.00333,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca633018.dat-s17_n17s0.dat (opt19.90207213763>16.9357551632277) l1 Foil spline 17pts Re45000000 N9","good":23.8059885784752,"xver":6.991,"iver":1.2020052,"id":1497,"Cm":-0.00172414940629894},
             {"sym":6.87781482133858e-05,"Bot_Xtr":0.400864961863167,"xy":[1,0,0.910673421760927,0.0142385217004873,0.849186318940748,0.0284703387374935,0.695794612861528,0.0637691684892904,0.498442662240797,0.0816890130630604,0.302873885493542,0.077912085859141,0.139977327975174,0.0581470555464169,0.0380656693660804,0.0298405388355682,0,0,0.0396582029585364,-0.0307438722871965,0.144634720957126,-0.0591291878442944,0.306852823166501,-0.0783860627402097,0.500818080902831,-0.0818033106663372,0.698940635957709,-0.0634223030971704,0.860665749892887,-0.025601488254916,0.919783730358342,-0.0126435017928151,1,0],"CDpres":0.00082,"clcd":241.120434253528,"alpha":0.3,"diter":3,"Top_Xtr":0.357376089885971,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re20000000-N11.dat","Re":55000000,"src":"retest_67.txt","id":1498,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt72.2068193960119>47.7320396835587) l1 Foil spline 17pts Re20000000 N11","good":25.2865725516071,"iver":1.2020052,"r":6,"Cm":0.000343784910477971,"CD":0.00414730507223848,"CL":0.0302266671207152,"n":13,"CDp":0.000194569611667717,"CDf":0.00333,"Cpmin":-0.458784171102349},
             {"Cpmin":-0.439124439743828,"CDf":0.0032,"CDp":0.000150978930090957,"n":14,"CD":0.00394440537656176,"CL":0.0122805158937955,"Cm":0.00171994165132495,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt52.4451570534734>27.2151936556964) l1 Foil spline 17pts Re30000000 N12","xver":6.991,"good":29.8710072629289,"iver":1.2020052,"id":1499,"src":"retest_72.txt","Re":55000000,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re30000000-N12.dat","Top_Xtr":0.387736883990585,"diter":3,"alpha":0.2,"CDpres":0.00074,"clcd":253.523637793962,"Bot_Xtr":0.418063551821365,"xy":[1,0,0.910673421760927,0.0138460733821946,0.849186318940748,0.0276856268977544,0.695794612861528,0.062011534975153,0.498442662240797,0.0794374650109549,0.302873885493542,0.0757646391147887,0.139977327975174,0.0565443811506553,0.0380656693660804,0.0290180609457064,0,0,0.0396582029585364,-0.0304455670771905,0.144634720957126,-0.0585554623020918,0.306852823166501,-0.0776254893586647,0.500818080902831,-0.0810095800152483,0.698940635957709,-0.0628069218183344,0.860665749892887,-0.0253530791651629,0.919783730358342,-0.0125208229571017,1,0],"sym":0.00109431581500508},
             {"Cm":0.0270872214873471,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt12.5202252641475>11.7993684602621) l1 Foil spline 17pts Re45000000 N4","xver":6.991,"iver":1.2020052,"good":8.22906669155272,"id":1500,"Cpmin":-1.76825265589275,"CDf":0.00414,"CDp":-0.00370364074359165,"n":3,"CL":0.0738290407812759,"CD":0.0071228298824185,"alpha":2,"clcd":140.393637993283,"CDpres":0.00298,"Bot_Xtr":0.296810606184549,"xy":[1,0,0.934059429447841,0.0272498909967404,0.803112667984734,0.0665145807212826,0.640336773132615,0.117736548366005,0.409507830013704,0.183557341511659,0.253558173430737,0.193451707311088,0.123492454733844,0.155013914034381,0.0350150102873282,0.0845956349595762,0,0,0.033652356669074,-0.0827642663411574,0.123386675148442,-0.156201576988132,0.261115618487171,-0.195504622417903,0.416397663171949,-0.182985977935393,0.629871409666205,-0.121671047914226,0.80244136469583,-0.0671322440900606,0.93425668155926,-0.027324887164405,1,0],"sym":0.000933753239449797,"src":"retest_103.txt","Re":65536000,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N4.dat","Top_Xtr":0.230341691193346,"diter":4},
             {"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt12.5202252641475>11.7993684602621) l1 Foil spline 17pts Re45000000 N4","good":10.0266615128585,"iver":1.2020052,"id":1501,"r":6,"Cm":0.0196396743496454,"n":4,"CL":0.0698851899269555,"CD":0.00676861221351213,"CDp":-0.0035461230688823,"CDf":0.00403,"Cpmin":-1.75229740007341,"sym":0.000933753239449797,"Bot_Xtr":0.298327653910532,"xy":[1,0,0.934059429447841,0.0272498909967404,0.803112667984734,0.0665145807212826,0.640336773132615,0.117736548366005,0.409507830013704,0.183557341511659,0.253558173430737,0.193451707311088,0.123492454733844,0.155013914034381,0.0350150102873282,0.0845956349595762,0,0,0.033652356669074,-0.0827642663411574,0.123386675148442,-0.156201576988132,0.261115618487171,-0.195504622417903,0.416397663171949,-0.182985977935393,0.629871409666205,-0.121671047914226,0.80244136469583,-0.0671322440900606,0.93425668155926,-0.027324887164405,1,0],"CDpres":0.00274,"clcd":147.74077291704,"alpha":1.6,"diter":3,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N4.dat","Top_Xtr":0.25490463351156,"Re":65536000,"src":"retest_104.txt"},
             {"xy":[1,0,0.94211262451681,0.029249679081892,0.870368703940721,0.0547027809046478,0.612947600635354,0.144061508717353,0.407050317206713,0.205703963591321,0.25912563537128,0.214494518916858,0.123234615368669,0.169601019901092,0.0345811184073606,0.0908790303203946,0,0,0.0345316777956586,-0.0907058137301499,0.128173188513251,-0.1723376907143,0.264469450799845,-0.214943501458162,0.407758505638372,-0.205436542786436,0.611699288725026,-0.144484010115043,0.879132615239467,-0.05161556871522,0.940446499493271,-0.0300983258985774,1,0],"Bot_Xtr":0.321545630638537,"sym":0.00030814107380968,"alpha":1,"clcd":144.392910248185,"CDpres":0.00313,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N6.dat","Top_Xtr":0.307456879044435,"diter":3,"src":"retestc_23.txt","Re":65536000,"r":6,"good":11.6759815346239,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt14.0963339431087>13.2691910720325) l1 Foil spline 17pts Re55000000 N6","xver":6.991,"iver":1.2020052,"id":1502,"Cm":0.0102715354536214,"CDp":-0.00687333162849092,"n":5,"CL":0.0505739648940139,"CD":0.00692554778680741,"Cpmin":-1.96009668604215,"CDf":0.0038},
             {"CDp":-0.00359403416801325,"CD":0.00627302951611968,"CL":0.0848453209235197,"n":6,"Cpmin":-1.76670612053292,"CDf":0.00384,"r":6,"id":1503,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt12.5202252641475>11.7993684602621) l1 Foil spline 17pts Re45000000 N4","iver":1.2020052,"good":13.2165240774544,"Cm":0.014765284148023,"Top_Xtr":0.2857664603179,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N4.dat","diter":3,"src":"retest_106.txt","Re":65536000,"xy":[1,0,0.934059429447841,0.0272498909967404,0.803112667984734,0.0665145807212826,0.640336773132615,0.117736548366005,0.409507830013704,0.183557341511659,0.253558173430737,0.193451707311088,0.123492454733844,0.155013914034381,0.0350150102873282,0.0845956349595762,0,0,0.033652356669074,-0.0827642663411574,0.123386675148442,-0.156201576988132,0.261115618487171,-0.195504622417903,0.416397663171949,-0.182985977935393,0.629871409666205,-0.121671047914226,0.80244136469583,-0.0671322440900606,0.93425668155926,-0.027324887164405,1,0],"Bot_Xtr":0.311898976564845,"sym":0.000933753239449797,"alpha":1.5,"CDpres":0.00244,"clcd":159.412608761097},
             {"Cm":0.00473515531991635,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt15.1201160281058>14.8990837741401) l1 Foil spline 17pts Re45000000 N6","xver":6.991,"iver":1.2020052,"good":14.2921515249776,"id":1504,"r":6,"CDf":0.00382,"Cpmin":-1.64353754370712,"n":7,"CL":0.109434305183529,"CD":0.00592091024832293,"CDp":-0.00255379637051963,"clcd":168.892950249203,"CDpres":0.0021,"alpha":1.2,"sym":0.000579661259632415,"xy":[1,0,0.934059429447841,0.0255974633309028,0.803112667984734,0.0624811505186229,0.640336773132615,0.110597028805229,0.409507830013704,0.17242646288107,0.253558173430737,0.181720836416866,0.123492454733844,0.145613902850086,0.0350150102873282,0.079465773426074,0,0,0.033652356669074,-0.0770300927566754,0.123386675148442,-0.145379431197245,0.261115618487171,-0.181959435695752,0.416397663171949,-0.17030812301812,0.629871409666205,-0.113241287828272,0.80244136469583,-0.0624811070988687,0.93425668155926,-0.0254317314209442,1,0],"Bot_Xtr":0.304172964935631,"Re":65536000,"src":"retest_94.txt","diter":3,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re45000000-N6.dat","Top_Xtr":0.29238681633457},
             {"src":"retest_86.txt","Re":65536000,"Top_Xtr":0.30273727313977,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re20000000-N6.dat","diter":3,"alpha":-0.6,"clcd":193.349137099955,"CDpres":0.0014,"Bot_Xtr":0.285229575596961,"xy":[1,0,0.934059429447841,0.0206201241244863,0.803112667984734,0.050331904473492,0.640336773132615,0.0890918147740847,0.409507830013704,0.138898726838352,0.253558173430737,0.146385841225037,0.123492454733844,0.117299777411724,0.0350150102873282,0.0640139255406508,0,0,0.033652356669074,-0.0626972549009572,0.123386675148442,-0.118328966368017,0.261115618487171,-0.148102601375386,0.416397663171949,-0.138619225531769,0.629871409666205,-0.0921707041261031,0.80244136469583,-0.0508553703894157,0.93425668155926,-0.0206996991748195,1,0],"sym":0.00063771083618727,"Cpmin":-1.23421774956281,"CDf":0.00377,"CDp":-0.000822176093073053,"CL":-0.0322111798483514,"CD":0.00517199101583283,"n":8,"Cm":-0.00795717350904884,"r":6,"id":1505,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt17.6793364428351>15.7803944731301) l1 Foil spline 17pts Re20000000 N6","good":15.50631689501,"xver":6.991,"iver":1.2020052},
             {"r":6,"id":1506,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt17.6793364428351>15.7803944731301) l1 Foil spline 17pts Re20000000 N6","good":17.1350001031372,"xver":6.991,"iver":1.2020052,"Cm":-0.0129193519793425,"CDp":-0.000981120126086774,"CD":0.0050701146906247,"CL":-0.110247843879967,"n":9,"Cpmin":-1.31145986688439,"CDf":0.0037,"xy":[1,0,0.934059429447841,0.0206201241244863,0.803112667984734,0.050331904473492,0.640336773132615,0.0890918147740847,0.409507830013704,0.138898726838352,0.253558173430737,0.146385841225037,0.123492454733844,0.117299777411724,0.0350150102873282,0.0640139255406508,0,0,0.033652356669074,-0.0626972549009572,0.123386675148442,-0.118328966368017,0.261115618487171,-0.148102601375386,0.416397663171949,-0.138619225531769,0.629871409666205,-0.0921707041261031,0.80244136469583,-0.0508553703894157,0.93425668155926,-0.0206996991748195,1,0],"Bot_Xtr":0.287182629163982,"sym":0.00063771083618727,"alpha":-1.5,"clcd":197.234197058526,"CDpres":0.00137,"Top_Xtr":0.31878237109779,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re20000000-N6.dat","diter":3,"src":"retest_87.txt","Re":65536000},
             {"sym":0.000176424247568075,"Bot_Xtr":0.316965955393737,"xy":[1,0,0.94211262451681,0.0189000588059641,0.870368703940721,0.0353469100653373,0.612947600635354,0.0930872088822169,0.407050317206713,0.132918279124052,0.25912563537128,0.138598410250434,0.123234615368669,0.109589894668847,0.0345811184073606,0.0587226619641035,0,0,0.0345316777956586,-0.0588047911815373,0.128173188513251,-0.111726927948767,0.264469450799845,-0.139348374699321,0.407758505638372,-0.133184991157825,0.611699288725026,-0.0936693216728413,0.879132615239467,-0.0334624939151603,0.940446499493271,-0.0195128150731908,1,0],"clcd":205.941992846657,"CDpres":0.00123,"alpha":-0.6,"diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re100000000-N12.dat","Top_Xtr":0.315653454559721,"Re":65536000,"src":"retest_102.txt","good":19.3347528019821,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt19.8645642108868>17.3838054208721) l1 Foil spline 17pts Re100000000 N12","xver":6.991,"iver":1.2020052,"id":1507,"r":6,"Cm":-0.00878968000771111,"n":10,"CD":0.00485573624969528,"CL":-0.0274204666771454,"CDp":-0.000949734770810362,"CDf":0.00362,"Cpmin":-1.12331369131759},
             {"alpha":0.5,"clcd":232.511826031881,"CDpres":0.00101,"Bot_Xtr":0.365423021538945,"xy":[1,0,0.867935867415093,0.0195910806779479,0.765256324145788,0.040372601554045,0.608365821336593,0.085773514036814,0.435418780836389,0.117196662932154,0.270182631260474,0.118634635736159,0.123421225360211,0.0927527287026748,0.0257824653263784,0.0477047174799002,0,0,0.0262080994032648,-0.0484087656842255,0.120992516399386,-0.0919989546232345,0.245670511459264,-0.116092284443336,0.396783126454799,-0.120344740273802,0.570306654876705,-0.0950308005337515,0.7408836798323,-0.0476773973570985,0.825204455146615,-0.0267533162799515,1,0],"sym":0.000615778978064873,"src":"retestc_11.txt","Re":65536000,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re65536000-N11.dat","Top_Xtr":0.332595013016071,"diter":3,"Cm":-0.000133024590192026,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt21.2031568209603>6.3962531633) l1 Foil spline 17pts Re65536000 N11","xver":6.991,"good":21.2031568203895,"id":1508,"Cpmin":-0.847370896408972,"CDf":0.0033,"CDp":0.000338792686230811,"n":11,"CL":0.0571340855852681,"CD":0.00430085650724227},
             {"diter":3,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re65536000-N11.dat","Top_Xtr":0.350805164586854,"Re":65536000,"src":"retestc_15.txt","sym":0.000615778978064873,"Bot_Xtr":0.382463990629886,"xy":[1,0,0.867935867415093,0.0195910806779479,0.765256324145788,0.040372601554045,0.608365821336593,0.085773514036814,0.435418780836389,0.117196662932154,0.270182631260474,0.118634635736159,0.123421225360211,0.0927527287026748,0.0257824653263784,0.0477047174799002,0,0,0.0262080994032648,-0.0484087656842255,0.120992516399386,-0.0919989546232345,0.245670511459264,-0.116092284443336,0.396783126454799,-0.120344740273802,0.570306654876705,-0.0950308005337515,0.7408836798323,-0.0476773973570985,0.825204455146615,-0.0267533162799515,1,0],"CDpres":0.00093,"clcd":242.932016708105,"alpha":0.3,"n":12,"CL":0.0324132263145464,"CD":0.00411637796265261,"CDp":0.000276000574518967,"CDf":0.00319,"Cpmin":-0.829956447621716,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt21.2031568209603>6.3962531633) l1 Foil spline 17pts Re65536000 N11","xver":6.991,"iver":1.2020052,"good":23.4974531762469,"id":1509,"r":6,"Cm":0.000279396664244705},
             {"diter":3,"Top_Xtr":0.309395844834398,"Foil_fn":"optbs_spline_sym_fxlv152.dat-s17_n17s0_nsopt-Re81920000-N11.dat","Re":65536000,"src":"retest_78.txt","sym":0.000109499860168599,"Bot_Xtr":0.311510514812305,"xy":[1,0,0.957105380742757,0.00405862608673295,0.829797410083379,0.0204664696651787,0.676727661661368,0.0465021697794161,0.473556206102344,0.0796643905517399,0.285660851754636,0.0846709804861972,0.131408224527202,0.0662141387815741,0.0383045235410549,0.0372448057981655,0,0,0.0367163458153901,-0.0362890666551873,0.127240811399429,-0.0655665872777781,0.286764894309666,-0.0848451846743742,0.480015081990432,-0.0789125861253266,0.702357711552594,-0.0416541006673549,0.837676944457889,-0.0190743903662538,0.964724148609054,-0.00243791190580847,1,0],"CDpres":0.00065,"clcd":243.878055426703,"alpha":-0.1,"CL":0.00135409221071007,"CD":0.00410040992925888,"n":13,"CDp":0.000186484275628278,"CDf":0.00345,"Cpmin":-0.56513543484184,"id":1510,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fxlv152.dat-s17_n17s0.dat (opt9.70709722852417>8.42445692081182) l1 Foil spline 17pts Re81920000 N11","xver":6.991,"good":17.1779562649818,"r":6,"Cm":-0.00337942247077598},
             {"sym":0.000312397105578103,"Bot_Xtr":0.364945316928717,"xy":[1,0,0.941701382715975,0.00480759153374923,0.840420457463641,0.020996854406255,0.690206567397583,0.0520735710620504,0.493921513622977,0.0871571563836827,0.305452081941457,0.097200391677963,0.139938788091908,0.0761734536229195,0.0386682922645405,0.0415324540906658,0,0,0.0405377285335924,-0.0424027861581172,0.148258857506298,-0.0773254029520778,0.309953500079998,-0.096458941003623,0.492786686674529,-0.0865602224783985,0.688332798275104,-0.0520300777437361,0.843872499199579,-0.0201416230248084,0.944032400719071,-0.00452313135779394,1,0],"CDpres":0.00066,"clcd":257.615777470717,"alpha":0.3,"diter":3,"Top_Xtr":0.349424109112322,"Foil_fn":"optbs_spline_sym_naca633018.dat-s17_n17s0_nsopt-Re45000000-N9.dat","Re":65536000,"src":"retest_104.txt","id":1511,"good":26.0215202208444,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_naca633018.dat-s17_n17s0.dat (opt19.90207213763>16.9357551632277) l1 Foil spline 17pts Re45000000 N9","xver":6.991,"iver":1.2020052,"r":6,"Cm":-0.00110005679361866,"CL":0.0401695188562898,"CD":0.00388174982843848,"n":14,"CDp":0.000186651085761338,"CDf":0.00322,"Cpmin":-0.716761005312091},
             {"Top_Xtr":0.11158091122419,"Foil_fn":"optbs_spline_sym_e478.dat-s17_n17s0_nsopt-Re81920000-N3.dat","diter":2,"src":"retestc_13.txt","Re":81920000,"xy":[1,0,0.959592901338117,0.00504022210242424,0.769745152057064,0.0318610321393229,0.641225998859076,0.0512329827590279,0.427444533720106,0.0809247995142207,0.240918171367756,0.0935692329093211,0.111036453427268,0.0787924106932601,0.0338152868197339,0.0456400152104926,0,0,0.0350666542931089,-0.0464215725137249,0.126166117642051,-0.0826376141755398,0.27466906469648,-0.0931845030386984,0.465100266429952,-0.0762149664234906,0.632679583683504,-0.0524610984517673,0.787916449288627,-0.0292373271910613,0.968523409715057,-0.00382531798719577,1,0],"Bot_Xtr":0.139667662262742,"sym":7.76843684380541e-05,"alpha":0,"CDpres":0.00108,"clcd":185.307598708892,"CDp":0.000605903978044043,"CL":-0.000921609804432965,"CD":0.00539643277969915,"n":3,"Cpmin":-0.845587853778211,"CDf":0.00432,"r":6,"id":1512,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e478.dat-s17_n17s0.dat (opt2.77974694980935>2.38378871408899) l1 Foil spline 17pts Re81920000 N3","xver":6.991,"good":2.77974694982658,"Cm":0.000120750703179743},
             {"xy":[1,0,0.959592901338117,0.00554244890119474,0.769745152057064,0.0350357859203437,0.641225998859076,0.0563380309889769,0.427444533720106,0.0889884526976038,0.240918171367756,0.102892825273407,0.111036453427268,0.0866435845871354,0.0338152868197339,0.0501877589942393,0,0,0.0350666542931089,-0.0510019072824803,0.126166117642051,-0.0907913219652385,0.27466906469648,-0.102378853769733,0.465100266429952,-0.0837349628756967,0.632679583683504,-0.0576373426036579,0.787916449288627,-0.0321221227511234,0.968523409715057,-0.00420275537308178,1,0],"Bot_Xtr":0.141394325576649,"sym":9.75879406921279e-05,"alpha":-1.3,"CDpres":0.00118,"clcd":184.320263536486,"Foil_fn":"optbs_spline_sym_e478.dat-s17_n17s0_nsopt-Re81920000-N4.dat","Top_Xtr":0.1509464508111,"diter":2,"src":"retestc_14.txt","Re":81920000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e478.dat-s17_n17s0.dat (opt3.67828850662202>2.90348461819828) l1 Foil spline 17pts Re81920000 N4","good":3.67828850660639,"iver":1.2020052,"id":1513,"Cm":0.000545045718505248,"CDp":0.000638329715083631,"n":4,"CL":-0.155093149868327,"CD":0.00542533946519696,"Cpmin":-1.13089749504138,"CDf":0.00425},
             {"Foil_fn":"optbs_spline_sym_e478.dat-s17_n17s0_nsopt-Re30000000-N3.dat","Top_Xtr":0.132971788827287,"diter":3,"src":"retest_82.txt","Re":81920000,"xy":[1,0,0.959592901338117,0.00483281405355182,0.769745152057064,0.0305499322757077,0.641225998859076,0.0491247159453782,0.427444533720106,0.0775946973021447,0.240918171367756,0.0897188049643149,0.111036453427268,0.0755500575120414,0.0338152868197339,0.043761902239883,0,0,0.0350666542931089,-0.0443002961211269,0.126166117642051,-0.0788614124960433,0.27466906469648,-0.0889263515856531,0.465100266429952,-0.0727322535320003,0.632679583683504,-0.0500638403743381,0.787916449288627,-0.0279013006716079,0.968523409715057,-0.00365051656835069,1,0],"Bot_Xtr":0.150132544255107,"sym":0.000135402915120222,"alpha":0,"CDpres":0.00096,"clcd":193.498970397231,"CDp":0.000517345028574919,"n":5,"CL":0.00154687378119932,"CD":0.00516798615489846,"Cpmin":-0.804530736010329,"CDf":0.00421,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e478.dat-s17_n17s0.dat (opt4.23414723430376>3.78815521632328) l1 Foil spline 17pts Re30000000 N3","good":3.78677758623166,"xver":6.991,"iver":1.2020052,"id":1514,"Cm":-0.000168023937917356},
             {"id":1515,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e862.dat-s17_n17s0.dat (opt9.21442784929373>8.03731083413969) l1 Foil spline 17pts Re81920000 N6","xver":6.991,"good":9.21442784920985,"iver":1.2020052,"r":6,"Cm":-0.0109011447506075,"CD":0.00645145532344731,"CL":-0.0570138640259722,"n":6,"CDp":-0.0014243690505496,"CDf":0.00407,"Cpmin":-1.63528624642357,"sym":0.000477176799923542,"Bot_Xtr":0.217092663416379,"xy":[1,0,0.934436275513069,0.0232027578194484,0.797673904807906,0.0588034208986915,0.629741009212088,0.107595764551688,0.413663160507397,0.166016844364167,0.253857739439213,0.179305665638564,0.120433219903703,0.144349185140362,0.0336537647861184,0.0783697563506747,0,0,0.0328190994927224,-0.0770380713727218,0.122077736563837,-0.145940425862313,0.260296149439335,-0.180186920785488,0.415542990883403,-0.16590900681261,0.613601466905141,-0.112618021919565,0.792433214393538,-0.0604049735988185,0.934427669399613,-0.0232353061062115,1,0],"CDpres":0.00238,"clcd":155.00378594665,"alpha":-1,"diter":3,"Top_Xtr":0.268343100352339,"Foil_fn":"optbs_spline_sym_e862.dat-s17_n17s0_nsopt-Re81920000-N6.dat","Re":81920000,"src":"retestc_16.txt"},
             {"id":1516,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e862.dat-s17_n17s0.dat (opt10.208937649674>10.1006808970756) l1 Foil spline 17pts Re81920000 N7","xver":6.991,"good":10.2089376495709,"iver":1.2020052,"r":6,"Cm":-0.0228848416372092,"CL":-0.112653382642421,"CD":0.00602451049047388,"n":7,"CDp":-0.00118842511595885,"CDf":0.00399,"Cpmin":-1.56350030302472,"sym":0.000356837708959236,"Bot_Xtr":0.219307429936807,"xy":[1,0,0.934436275513069,0.0215858974825087,0.797673904807906,0.0547057649360984,0.629741009212088,0.100098064257609,0.413663160507397,0.154448131153217,0.253857739439213,0.166810934571873,0.120433219903703,0.134290360498086,0.0336537647861184,0.0729086404072577,0,0,0.0328190994927224,-0.0714967657950623,0.122077736563837,-0.135443012292285,0.260296149439335,-0.167226175904698,0.415542990883403,-0.153975264333691,0.613601466905141,-0.104517470310626,0.792433214393538,-0.0560600774824286,0.934427669399613,-0.0215640034758271,1,0],"CDpres":0.00204,"clcd":165.988589708861,"alpha":-2,"diter":3,"Top_Xtr":0.278303074347978,"Foil_fn":"optbs_spline_sym_e862.dat-s17_n17s0_nsopt-Re81920000-N7.dat","Re":81920000,"src":"retestc_17.txt"},
             {"alpha":1.5,"clcd":168.789583739969,"CDpres":0.00218,"Bot_Xtr":0.299349650138579,"xy":[1,0,0.934059429447841,0.0262266290355171,0.803112667984734,0.0640168885166808,0.640336773132615,0.11331541760247,0.409507830013704,0.176664570993985,0.253558173430737,0.186187392989653,0.123492454733844,0.14919297912823,0.0350150102873282,0.0814189802217637,0,0,0.033652356669074,-0.0789931443814395,0.123386675148442,-0.149084312217193,0.261115618487171,-0.186596529500273,0.416397663171949,-0.174648292238185,0.629871409666205,-0.116127153418021,0.80244136469583,-0.0640733892111976,0.93425668155926,-0.0260798391915546,1,0],"sym":0.000545829560627176,"src":"retest_64.txt","Re":81920000,"Top_Xtr":0.288481978269303,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re100000000-N3.dat","diter":4,"Cm":0.00632965722455044,"r":6,"id":1517,"good":13.8655419913385,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt5.79414842407246>5.6128693851768) l1 Foil spline 17pts Re100000000 N3","xver":6.991,"iver":1.2020052,"Cpmin":-1.71959734608039,"CDf":0.00375,"CDp":-0.00285734771725128,"CD":0.00592453620562607,"CL":0.1332480117893,"n":8},
             {"xy":[1,0,0.94211262451681,0.0202578802684388,0.870368703940721,0.03788630920751,0.612947600635354,0.09977479707439,0.407050317206713,0.142467418309423,0.25912563537128,0.148555622449347,0.123234615368669,0.117463071814981,0.0345811184073606,0.062941426126009,0,0,0.0345316777956586,-0.0631151407876403,0.128173188513251,-0.119916432752693,0.264469450799845,-0.14956251201582,0.407758505638372,-0.142947356819557,0.611699288725026,-0.100535216707313,0.879132615239467,-0.035915271054036,0.940446499493271,-0.0209430906183422,1,0],"Bot_Xtr":0.292277455843395,"sym":0.000273606032692906,"alpha":0.3,"CDpres":0.00151,"clcd":191.347644724752,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re65536000-N12.dat","Top_Xtr":0.290387995753863,"diter":3,"src":"retest_105.txt","Re":81920000,"r":6,"good":15.4853404713365,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt21.9163355412526>18.5489252798603) l1 Foil spline 17pts Re65536000 N12","xver":6.991,"iver":1.2020052,"id":1518,"Cm":0.00161102412565132,"CDp":-0.00124520779697196,"n":9,"CL":0.0250156101282956,"CD":0.00522608993404894,"Cpmin":-1.21574920228083,"CDf":0.00371},
             {"Cm":0.0112492236237273,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt19.8645642108868>17.3838054208721) l1 Foil spline 17pts Re100000000 N12","xver":6.991,"iver":1.2020052,"good":17.6267578342046,"id":1519,"r":6,"CDf":0.00359,"Cpmin":-1.15187562054016,"n":10,"CL":0.0484645641316711,"CD":0.00481904288182284,"CDp":-0.000931661879281142,"CDpres":0.00123,"clcd":207.510085409687,"alpha":0.9,"sym":0.000176424247568075,"xy":[1,0,0.94211262451681,0.0189000588059641,0.870368703940721,0.0353469100653373,0.612947600635354,0.0930872088822169,0.407050317206713,0.132918279124052,0.25912563537128,0.138598410250434,0.123234615368669,0.109589894668847,0.0345811184073606,0.0587226619641035,0,0,0.0345316777956586,-0.0588047911815373,0.128173188513251,-0.111726927948767,0.264469450799845,-0.139348374699321,0.407758505638372,-0.133184991157825,0.611699288725026,-0.0936693216728413,0.879132615239467,-0.0334624939151603,0.940446499493271,-0.0195128150731908,1,0],"Bot_Xtr":0.31466841539993,"Re":81920000,"src":"retest_111.txt","diter":2,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re100000000-N12.dat","Top_Xtr":0.297720350629054},
             {"CD":0.00517347631115089,"CL":0.108724481264059,"n":11,"CDp":-0.00199061799636519,"CDf":0.00358,"Cpmin":-1.42338990836746,"id":1520,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt15.1518401370576>14.6720785089457) l1 Foil spline 17pts Re25000000 N4","xver":6.991,"iver":1.2020052,"good":18.7266635184948,"r":6,"Cm":0.0030914675086723,"diter":3,"Top_Xtr":0.309028827400227,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re25000000-N4.dat","Re":81920000,"src":"retest_90.txt","sym":0.000349060530452803,"Bot_Xtr":0.323470039915799,"xy":[1,0,0.94211262451681,0.0220141438247601,0.870368703940721,0.0411708751770469,0.612947600635354,0.108424805743565,0.407050317206713,0.154818677741528,0.25912563537128,0.161434700730843,0.123234615368669,0.12764657124871,0.0345811184073606,0.0683981536524431,0,0,0.0345316777956586,-0.0680022217417774,0.128173188513251,-0.129201705783543,0.264469450799845,-0.161143316475794,0.407758505638372,-0.154015941888671,0.611699288725026,-0.108319778963832,0.879132615239467,-0.0386962335131298,0.940446499493271,-0.0225647392117603,1,0],"clcd":193.293626926368,"CDpres":0.0016,"alpha":1.1},
             {"Re":81920000,"src":"retest_98.txt","diter":3,"Top_Xtr":0.335794105894955,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N9.dat","CDpres":0.00175,"clcd":189.786171164417,"alpha":-2.2,"sym":0.000208796576696122,"xy":[1,0,0.94211262451681,0.0230140174956533,0.870368703940721,0.0430408399789876,0.612947600635354,0.113349417365879,0.407050317206713,0.161850480607382,0.25912563537128,0.168767000733706,0.123234615368669,0.13344422782747,0.0345811184073606,0.0715047706310179,0,0,0.0345316777956586,-0.0713036911767481,0.128173188513251,-0.13547437558263,0.264469450799845,-0.168966733422594,0.407758505638372,-0.161493328827211,0.611699288725026,-0.113578643016978,0.879132615239467,-0.0405749137815071,0.940446499493271,-0.0236602445483153,1,0],"Bot_Xtr":0.311241267973396,"CDf":0.00352,"Cpmin":-1.57224035957853,"CD":0.00526908780478885,"CL":-0.191404476368053,"n":12,"CDp":-0.00270336836365541,"Cm":-0.0102351906265801,"id":1521,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt18.7235239474156>17.0399242179934) l1 Foil spline 17pts Re55000000 N9","good":19.5615912952337,"xver":6.991,"iver":1.2020052,"r":6},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt19.8645642108868>17.3838054208721) l1 Foil spline 17pts Re100000000 N12","xver":6.991,"iver":1.2020052,"good":22.2870369971082,"id":1522,"r":6,"Cm":-0.00560894982870123,"n":13,"CL":0.0250896068851822,"CD":0.00460737776662564,"CDp":-0.000927563289475216,"CDf":0.00346,"Cpmin":-1.11155067295795,"sym":0.000176424247568075,"Bot_Xtr":0.331376943291856,"xy":[1,0,0.94211262451681,0.0189000588059641,0.870368703940721,0.0353469100653373,0.612947600635354,0.0930872088822169,0.407050317206713,0.132918279124052,0.25912563537128,0.138598410250434,0.123234615368669,0.109589894668847,0.0345811184073606,0.0587226619641035,0,0,0.0345316777956586,-0.0588047911815373,0.128173188513251,-0.111726927948767,0.264469450799845,-0.139348374699321,0.407758505638372,-0.133184991157825,0.611699288725026,-0.0936693216728413,0.879132615239467,-0.0334624939151603,0.940446499493271,-0.0195128150731908,1,0],"clcd":217.043196944622,"CDpres":0.00115,"alpha":0,"diter":3,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re100000000-N12.dat","Top_Xtr":0.316480815547841,"Re":81920000,"src":"retestc_3.txt"},
             {"Cm":0.0135768832679803,"r":6,"id":1523,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt17.1556622400955>16.3979034511652) l1 Foil spline 17pts Re100000000 N11","iver":1.2020052,"good":19.7915576872352,"Cpmin":-1.41726489086027,"CDf":0.0035,"CDp":-0.00137290337278769,"CD":0.0049014275052575,"CL":0.160840402071489,"n":14,"alpha":2,"clcd":204.022195355813,"CDpres":0.0014,"Bot_Xtr":0.32545267384937,"xy":[1,0,0.934059429447841,0.021790631708355,0.803112667984734,0.0531890102571967,0.640336773132615,0.0941491385915422,0.409507830013704,0.146783355086585,0.253558173430737,0.154695477786412,0.123492454733844,0.123958334761701,0.0350150102873282,0.0676476953892795,0,0,0.033652356669074,-0.0657173322399921,0.123386675148442,-0.124028779389241,0.261115618487171,-0.155236586921842,0.416397663171949,-0.145296404340385,0.629871409666205,-0.0966104942779027,0.80244136469583,-0.0533050334874879,0.93425668155926,-0.0216967873647484,1,0],"sym":0.000336128940020058,"src":"retest_156.txt","Re":81920000,"Top_Xtr":0.309680741453354,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re100000000-N11.dat","diter":4},
             {"Re":100000000,"src":"retestc_23.txt","diter":7,"Top_Xtr":0.169451197482005,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re100000000-N3.dat","clcd":131.751853615871,"CDpres":0.00337,"alpha":4,"sym":0.000545829560627176,"xy":[1,0,0.934059429447841,0.0262266290355171,0.803112667984734,0.0640168885166808,0.640336773132615,0.11331541760247,0.409507830013704,0.176664570993985,0.253558173430737,0.186187392989653,0.123492454733844,0.14919297912823,0.0350150102873282,0.0814189802217637,0,0,0.033652356669074,-0.0789931443814395,0.123386675148442,-0.149084312217193,0.261115618487171,-0.186596529500273,0.416397663171949,-0.174648292238185,0.629871409666205,-0.116127153418021,0.80244136469583,-0.0640733892111976,0.93425668155926,-0.0260798391915546,1,0],"Bot_Xtr":0.27390187560247,"CDf":0.00422,"Cpmin":-1.87274973350677,"CL":0.245207679517535,"CD":0.00759002604180089,"n":3,"CDp":-0.00379553525464403,"Cm":0.0366931502948514,"id":1524,"good":5.79419461812915,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt5.79414842407246>5.6128693851768) l1 Foil spline 17pts Re100000000 N3","xver":6.991,"iver":1.2020052,"r":6},
             {"Re":100000000,"src":"retestc_0.txt","diter":2,"Foil_fn":"optbs_spline_sym_e478.dat-s17_n17s0_nsopt-Re100000000-N4.dat","Top_Xtr":0.132244022665448,"clcd":186.829958151739,"CDpres":0.00116,"alpha":-0.8,"sym":0.000228527942578074,"xy":[1,0,0.959592901338117,0.00553726185594373,0.769745152057064,0.0350029967669905,0.641225998859076,0.0562853055743989,0.427444533720106,0.0889051705349373,0.240918171367756,0.102796530341291,0.111036453427268,0.0865624969304018,0.0338152868197339,0.0501407894719955,0,0,0.0350666542931089,-0.0506913583839409,0.126166117642051,-0.090238496658587,0.27466906469648,-0.101755472371547,0.465100266429952,-0.0832251035022763,0.632679583683504,-0.0572863907625596,0.787916449288627,-0.0319265322257758,0.968523409715057,-0.0041771649369298,1,0],"Bot_Xtr":0.141410656492305,"CDf":0.00419,"Cpmin":-1.0451306753203,"n":4,"CL":-0.0939039290932281,"CD":0.00535246065402329,"CDp":0.000639356790587653,"Cm":0.000254921892125403,"good":3.3300148814274,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e478.dat-s17_n17s0.dat (opt3.33001488145384>2.22072123165446) l1 Foil spline 17pts Re100000000 N4","xver":6.991,"iver":1.2020052,"id":1525,"r":6},
             {"Cm":0.000654717068223271,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt19.8645642108868>17.3838054208721) l1 Foil spline 17pts Re100000000 N12","iver":1.2020052,"xver":6.991,"good":6.03202922267331,"id":1526,"Cpmin":-1.09342544632989,"CDf":0.0042,"CDp":-0.000383828923743387,"n":5,"CD":0.0059843851691737,"CL":-0.00365027849924709,"alpha":0,"clcd":167.101543722674,"CDpres":0.00179,"Bot_Xtr":0.202746588729299,"xy":[1,0,0.94211262451681,0.0189000588059641,0.870368703940721,0.0353469100653373,0.612947600635354,0.0930872088822169,0.407050317206713,0.132918279124052,0.25912563537128,0.138598410250434,0.123234615368669,0.109589894668847,0.0345811184073606,0.0587226619641035,0,0,0.0345316777956586,-0.0588047911815373,0.128173188513251,-0.111726927948767,0.264469450799845,-0.139348374699321,0.407758505638372,-0.133184991157825,0.611699288725026,-0.0936693216728413,0.879132615239467,-0.0334624939151603,0.940446499493271,-0.0195128150731908,1,0],"sym":0.000176424247568075,"src":"retest_75.txt","Re":100000000,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re100000000-N12.dat","Top_Xtr":0.191963298158846,"diter":3},
             {"xy":[1,0,0.910673421760927,0.0203623790435987,0.849186318940748,0.0407151698095633,0.695794612861528,0.0911957018704826,0.498442662240797,0.116822706926843,0.302873885493542,0.111421358039363,0.139977327975174,0.0831555698134592,0.0380656693660804,0.0426746803788114,0,0,0.0396582029585364,-0.0434244814899449,0.144634720957126,-0.0835175965823067,0.306852823166501,-0.110717156860864,0.500818080902831,-0.115543881937278,0.698940635957709,-0.0895814489848668,0.860665749892887,-0.0361610711381868,0.919783730358342,-0.0178584371038659,1,0],"Bot_Xtr":0.213881190549788,"sym":0.00057709854695603,"alpha":1.2,"CDpres":0.0019,"clcd":164.482531208466,"Foil_fn":"optbs_spline_sym_ah85l120.dat-s17_n17s0_nsopt-Re30000000-N11.dat","Top_Xtr":0.166490016714605,"diter":5,"src":"retest_155.txt","Re":100000000,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_ah85l120.dat-s17_n17s0.dat (opt61.637674525234>20.9692188621533) l1 Foil spline 17pts Re30000000 N11","good":4.82597575119662,"iver":1.2020052,"id":1527,"Cm":0.0137024632300131,"CDp":6.82719411741387e-05,"n":6,"CD":0.0060796729759259,"CL":0.0640042600991795,"Cpmin":-0.689362555852141,"CDf":0.00418},
             {"CDp":-0.00117586174465136,"CL":-0.122178155856465,"CD":0.00569010385464243,"n":7,"Cpmin":-1.41258389720514,"CDf":0.00388,"r":6,"id":1528,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt17.1556622400955>16.3979034511652) l1 Foil spline 17pts Re100000000 N11","xver":6.991,"good":9.92471934040406,"Cm":-0.0211781347531884,"Top_Xtr":0.2800450677546,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re100000000-N11.dat","diter":2,"src":"retest_158.txt","Re":100000000,"xy":[1,0,0.934059429447841,0.021790631708355,0.803112667984734,0.0531890102571967,0.640336773132615,0.0941491385915422,0.409507830013704,0.146783355086585,0.253558173430737,0.154695477786412,0.123492454733844,0.123958334761701,0.0350150102873282,0.0676476953892795,0,0,0.033652356669074,-0.0657173322399921,0.123386675148442,-0.124028779389241,0.261115618487171,-0.155236586921842,0.416397663171949,-0.145296404340385,0.629871409666205,-0.0966104942779027,0.80244136469583,-0.0533050334874879,0.93425668155926,-0.0216967873647484,1,0],"Bot_Xtr":0.220873265178037,"sym":0.000336128940020058,"alpha":-2,"CDpres":0.00181,"clcd":175.743716730956},
             {"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt15.0680063200731>15.0049353081315) l1 Foil spline 17pts Re30000000 N5","good":11.7289827723955,"xver":6.991,"iver":1.2020052,"id":1529,"r":6,"Cm":-0.0154345248170324,"n":8,"CL":-0.038495116481639,"CD":0.00553020914728249,"CDp":-0.00113018920048708,"CDf":0.0038,"Cpmin":-1.34693390740615,"sym":0.000337061284557841,"Bot_Xtr":0.247657480313254,"xy":[1,0,0.934059429447841,0.0220707844428012,0.803112667984734,0.053872838374962,0.640336773132615,0.0953595733772424,0.409507830013704,0.14867048524642,0.253558173430737,0.156684330688354,0.123492454733844,0.125552013499687,0.0350150102873282,0.0685174125730647,0,0,0.033652356669074,-0.0667036809185155,0.123386675148442,-0.125890322128113,0.261115618487171,-0.157566526332798,0.416397663171949,-0.147477151968605,0.629871409666205,-0.0980605171274989,0.80244136469583,-0.0541050864955288,0.93425668155926,-0.022022433534731,1,0],"CDpres":0.00173,"clcd":180.824987512705,"alpha":-1,"diter":4,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re30000000-N5.dat","Top_Xtr":0.278162867817572,"Re":100000000,"src":"retest_85.txt"},
             {"CDf":0.00372,"Cpmin":-1.39763503364267,"CD":0.00550218239086675,"CL":-0.00709586211461801,"n":9,"CDp":-0.00154327974788744,"Cm":-0.00131947425102945,"id":1530,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt14.8473834171576>14.4622137947907) l1 Foil spline 17pts Re36000000 N5","iver":1.2020052,"xver":6.991,"good":13.6268682410809,"r":6,"Re":100000000,"src":"retest_95.txt","diter":3,"Top_Xtr":0.286323928461945,"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re36000000-N5.dat","clcd":181.746065281284,"CDpres":0.00179,"alpha":-0.1,"sym":0.000902203136885201,"xy":[1,0,0.934059429447841,0.0232691417222156,0.803112667984734,0.0567979228093944,0.640336773132615,0.100537225273333,0.409507830013704,0.156742711165297,0.253558173430737,0.165191677073671,0.123492454733844,0.132368996815908,0.0350150102873282,0.0722376401135204,0,0,0.033652356669074,-0.0707988210891594,0.123386675148442,-0.13361910872794,0.261115618487171,-0.167240010654038,0.416397663171949,-0.156531219164935,0.629871409666205,-0.104080748054987,0.80244136469583,-0.0574267609532648,0.93425668155926,-0.0233744571559398,1,0],"Bot_Xtr":0.270031000834242},
             {"src":"retest_108.txt","Re":100000000,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N9.dat","Top_Xtr":0.289276069291738,"diter":3,"alpha":1,"clcd":184.012947469183,"CDpres":0.00181,"Bot_Xtr":0.305622008185824,"xy":[1,0,0.94211262451681,0.0230140174956533,0.870368703940721,0.0430408399789876,0.612947600635354,0.113349417365879,0.407050317206713,0.161850480607382,0.25912563537128,0.168767000733706,0.123234615368669,0.13344422782747,0.0345811184073606,0.0715047706310179,0,0,0.0345316777956586,-0.0713036911767481,0.128173188513251,-0.13547437558263,0.264469450799845,-0.168966733422594,0.407758505638372,-0.161493328827211,0.611699288725026,-0.113578643016978,0.879132615239467,-0.0405749137815071,0.940446499493271,-0.0236602445483153,1,0],"sym":0.000208796576696122,"Cpmin":-1.48229727358494,"CDf":0.00363,"CDp":-0.00235493954016894,"n":10,"CD":0.00543440020799337,"CL":0.0899750988262893,"Cm":0.00428866560385182,"r":6,"iver":1.2020052,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt18.7235239474156>17.0399242179934) l1 Foil spline 17pts Re55000000 N9","xver":6.991,"good":15.47240140944,"id":1531},
             {"diter":3,"Top_Xtr":0.303737019823978,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re55000000-N9.dat","Re":100000000,"src":"retest_109.txt","sym":0.000208796576696122,"Bot_Xtr":0.306972472521673,"xy":[1,0,0.94211262451681,0.0230140174956533,0.870368703940721,0.0430408399789876,0.612947600635354,0.113349417365879,0.407050317206713,0.161850480607382,0.25912563537128,0.168767000733706,0.123234615368669,0.13344422782747,0.0345811184073606,0.0715047706310179,0,0,0.0345316777956586,-0.0713036911767481,0.128173188513251,-0.13547437558263,0.264469450799845,-0.168966733422594,0.407758505638372,-0.161493328827211,0.611699288725026,-0.113578643016978,0.879132615239467,-0.0405749137815071,0.940446499493271,-0.0236602445483153,1,0],"CDpres":0.00173,"clcd":188.863374839327,"alpha":-0.2,"CL":-0.0209331154648972,"CD":0.00529483284332252,"n":11,"CDp":-0.00235057150012087,"CDf":0.00357,"Cpmin":-1.40389267317808,"id":1532,"good":17.2523292122917,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt18.7235239474156>17.0399242179934) l1 Foil spline 17pts Re55000000 N9","xver":6.991,"iver":1.2020052,"r":6,"Cm":-5.40993294116618e-05},
             {"alpha":-0.4,"clcd":217.540231891016,"CDpres":0.00115,"Bot_Xtr":0.316592822662476,"xy":[1,0,0.94211262451681,0.0189000588059641,0.870368703940721,0.0353469100653373,0.612947600635354,0.0930872088822169,0.407050317206713,0.132918279124052,0.25912563537128,0.138598410250434,0.123234615368669,0.109589894668847,0.0345811184073606,0.0587226619641035,0,0,0.0345316777956586,-0.0588047911815373,0.128173188513251,-0.111726927948767,0.264469450799845,-0.139348374699321,0.407758505638372,-0.133184991157825,0.611699288725026,-0.0936693216728413,0.879132615239467,-0.0334624939151603,0.940446499493271,-0.0195128150731908,1,0],"sym":0.000176424247568075,"src":"retestc_8.txt","Re":100000000,"Foil_fn":"optbs_spline_sym_e864.dat-s17_n17s0_nsopt-Re100000000-N12.dat","Top_Xtr":0.309109282212959,"diter":3,"Cm":-0.00746570067768575,"r":6,"xver":6.991,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e864.dat-s17_n17s0.dat (opt19.8645642108868>17.3838054208721) l1 Foil spline 17pts Re100000000 N12","good":19.8645642108983,"iver":1.2020052,"id":1533,"Cpmin":-1.10905847207162,"CDf":0.00344,"CDp":-0.000906285067123581,"n":12,"CL":-0.0112872717935939,"CD":0.00459685085056351},
             {"Foil_fn":"optbs_spline_sym_e863.dat-s17_n17s0_nsopt-Re100000000-N11.dat","Top_Xtr":0.327755790642371,"diter":3,"src":"retest_153.txt","Re":100000000,"xy":[1,0,0.934059429447841,0.021790631708355,0.803112667984734,0.0531890102571967,0.640336773132615,0.0941491385915422,0.409507830013704,0.146783355086585,0.253558173430737,0.154695477786412,0.123492454733844,0.123958334761701,0.0350150102873282,0.0676476953892795,0,0,0.033652356669074,-0.0657173322399921,0.123386675148442,-0.124028779389241,0.261115618487171,-0.155236586921842,0.416397663171949,-0.145296404340385,0.629871409666205,-0.0966104942779027,0.80244136469583,-0.0533050334874879,0.93425668155926,-0.0216967873647484,1,0],"Bot_Xtr":0.29529675983139,"sym":0.000336128940020058,"alpha":-2.5,"CDpres":0.00141,"clcd":206.471293907418,"CDp":-0.00142853620379114,"n":13,"CD":0.00484328828998574,"CL":-0.207575594698333,"Cpmin":-1.48505331988751,"CDf":0.00344,"r":6,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_e863.dat-s17_n17s0.dat (opt17.1556622400955>16.3979034511652) l1 Foil spline 17pts Re100000000 N11","good":18.2893602329619,"xver":6.991,"iver":1.2020052,"id":1534,"Cm":-0.0153193204321115},
             {"CDp":0.000330582102256207,"CD":0.00415280821388538,"CL":0.0705711564866408,"n":14,"Cpmin":-0.924568811470122,"CDf":0.00311,"r":6,"id":1535,"good":19.3445772928473,"cmt":"OPT s(0) foildb2020_spline/spline_foil_sym_fx711525.dat-s17_n17s0.dat (opt31.64106001835>10.1388522120791) l1 Foil spline 17pts Re45000000 N11","xver":6.991,"iver":1.2020052,"Cm":-0.000461727711339001,"Top_Xtr":0.329509080164306,"Foil_fn":"optbs_spline_sym_fx711525.dat-s17_n17s0_nsopt-Re45000000-N11.dat","diter":3,"src":"retest_73.txt","Re":100000000,"xy":[1,0,0.867935867415093,0.0209882353262224,0.765256324145788,0.0432518081098967,0.608365821336593,0.0918905254363059,0.435418780836389,0.125554643028792,0.270182631260474,0.127095166091266,0.123421225360211,0.0993674687559356,0.0257824653263784,0.051106820144236,0,0,0.0262080994032648,-0.0517004585469142,0.120992516399386,-0.0982546874027793,0.245670511459264,-0.123986312285485,0.396783126454799,-0.128527926046508,0.570306654876705,-0.101492692371545,0.7408836798323,-0.0509193587327647,0.825204455146615,-0.0285724847509349,1,0],"Bot_Xtr":0.372535161297469,"sym":0.0007408566452154,"alpha":0.6,"clcd":240.800910732257,"CDpres":0.00104}
             ]
